/*
            Copyright(C) 1997-2022.  Sinowealth Tech. Co., Ltd.
********************************************************************************
* @file    CFG32F205.c 
* @author  
* @version V1.0.3
* @date    8-May-2022
* @brief   Keil configuration Wizard file.
********************************************************************************
*/

#include "CFG32F205.h"
#include "sh32f205.h"


#ifdef _MODULE_DBG_PRINTF


#if defined ( __CC_ARM )
struct __FILE { int handle; /* Add whatever you need here */ };
FILE __stdout;
FILE __stdin;
#elif defined(__ICCARM__)
struct __FILE { int handle; /* Add whatever you need here */ };
typedef struct __FILE FILE;
FILE __stdout;
FILE __stdin;
#endif
#define UNUSED_PARAM(m)  m=m
  
#include <stdio.h>


#ifdef _DBG_DEVICE_ITM
//Cortex-M3 Debug Kernel Registers
#define ITM_DATA      0xE0000000
#define ITM_LOCK_KEY  0xC5ACCE55
#define ITM_KEY       (*((volatile unsigned long*)(0xE0000FB0)))
#define ITM_CTRL      (*((volatile unsigned long*)(0xE0000E80)))
#define ITM_PRIV      (*((volatile unsigned long*)(0xE0000E40)))
#define ITM_TRIG      (*((volatile unsigned long*)(0xE0000E20)))
#define ITM_ENABLE    (*((volatile unsigned long*)(0xE0000E00)))
#define ITM_PORT0     (*((volatile unsigned long*)(ITM_DATA)))
#define ITM_PORT1     (*((volatile unsigned long*)(ITM_DATA+4)))
#define DBGMCU_CR     (*((volatile unsigned long*)(0xE0042004)))
#define ITM_FREQ      (*((volatile unsigned long*)(0xE0040010)))   
#define ITM_CHARS     (*((volatile unsigned long*)(0xE0040004)))   
                    
#define DEM_CR        (*((volatile unsigned long*)(0xE000EDFC)))
#define DEM_CR_TRCENA (1 << 24)
#endif /*_DBG_DEVICE_ITM*/

/**
  * @brief    retarget initial function, parameters defined in sh32f2xx_config.h 
  * \n  1. initial the retarget device
  * \n  2. can be selected as ITM or UART
  * @retval  None
  */
void RetargetInit(void)
{
#ifdef _DBG_DEVICE_ITM  
    DEM_CR = 0;
    ITM_ENABLE = 0X0;
    DEM_CR |= DEM_CR_TRCENA;
    ITM_FREQ = SYS_CLK/ITM_FREQ_DEFAULT - 1;
    ITM_KEY = ITM_LOCK_KEY;
    ITM_CTRL = (1<<23)|(0x1<<0);
    ITM_PRIV = 0X1;
    ITM_ENABLE = 0X1;    
#endif /* _DBG_DEVICE_ITM */

#ifdef _DBG_DEVICE_UART
    uint32_t module_clk = (SYS_CLK /APB1_F);
   	uint32_t sbrt;
    uint32_t fine;

    /* Enable Clock Gates */    
    RCC->RCCLOCK = 0x33CC;
    PTN_DBG_UART_CLKGATE();

    /* GPIO Config */
    PTN_DBG_UART_IOAF();
    

    PTN_DBG_UART->CR.BIT.SBRTEN = 1;
	PTN_DBG_UART->CR.BIT.SM = 1;
    sbrt = module_clk /16/ PTN_DBG_UART_BAUDRATE-1;
    fine = module_clk / PTN_DBG_UART_BAUDRATE - (16*(sbrt+1));    
    
    PTN_DBG_UART->BRT.BIT.SBRT = sbrt;
    PTN_DBG_UART->BRT.BIT.BFINE = fine;//10;//0;
    
    PTN_DBG_UART->FR.BIT.RIC = 1;
    PTN_DBG_UART->CR.BIT.RIE = 0;   
    PTN_DBG_UART->CR.BIT.TIE = 0;   
    PTN_DBG_UART->CR.BIT.REN = 1;   
    PTN_DBG_UART->CR.BIT.TEN = 1;   

#endif    
}


#ifdef _DBG_DEVICE_UART
/**
  * @brief send data to UART
  * @param ch: data to transmit
  * @retval  uint8_t data to transmit
  */
static uint8_t dbg_uart_send(uint8_t ch)
{
   while(PTN_DBG_UART->FR.BIT.TI == 0)
   {
        CLR_WDT();
   }
   PTN_DBG_UART->TDR = ch;
   return (ch);
}   

/**
  * @brief read data from to UART
  * @retval  uint8_t data readed
  */
static uint8_t dbg_uart_read()
{
   while(PTN_DBG_UART->FR.BIT.RI == 0)
   {
       CLR_WDT();
   }        
   return (uint8_t)PTN_DBG_UART->RDR;
}
  
#endif 
    

#ifdef _DBG_DEVICE_ITM

/* define scanf input buffer */
volatile int32_t ITM_RxBuffer = ITM_RXBUFFER_EMPTY;

#endif /* _DBG_DEVICE_ITM*/


/**
  * @brief    output character function
  * @param  ch  output character
  * @param  f   file handle
  * @retval  int   outputted character
  */
int fputc(int ch, FILE *f) 
{  
	UNUSED_PARAM(f); 
    
#ifdef _DBG_DEVICE_ITM
  if (ch == '\n')  {
    ITM_SendChar('\r');
  }
  return (int)(ITM_SendChar((uint8_t)ch));
#endif 
  
#ifdef _DBG_DEVICE_UART
   if(ch == '\n'){
       dbg_uart_send('\r');
   }
   return (int)dbg_uart_send((unsigned char)ch);
#endif  
}

/**
  * @brief    input retarget
  * @param  f  file handle
  * @retval  int character which read
  */
int fgetc(FILE *f) 
{
  char ch;
	UNUSED_PARAM(f);
	 
#ifdef _DBG_DEVICE_ITM  
  while (ITM_CheckChar() != 1) 
  {    
      CLR_WDT();
  }
  ch = (char)ITM_ReceiveChar();
  ITM_SendChar(ch);
  if(ch == '\r')
      ITM_SendChar('\n');
//  flush_printfbuffer();
#endif

#ifdef _DBG_DEVICE_UART
  ch = dbg_uart_read();
  dbg_uart_send(ch);
  if(ch == '\r')
     dbg_uart_send('\n');
#endif 
   return ch;
}

#if defined ( __CC_ARM )
/*! flush printf buffer to output device. No body code*/
void flush_printfbuffer(void)
{
}
#endif

#if defined(__ICCARM__)

#ifdef _DBG_DEVICE_UART
/*! for replace the function in getchar.o */
int _UngetChar(void)
{
    return 0;
}
/*! for replace the function in getchar.o */
int __ungetchar(int a)
{
    return 0;
}
/**
  * @brief  replace the function getchar for IAR scanf
  * @retval  int data readed from input device
  */
int getchar(void)
{
   char ch = dbg_uart_read();
   dbg_uart_send(ch);
   if(ch == '\r')
      dbg_uart_send('\n');
   return (int)ch;
}

/**
  * @brief  replace the function putchar for IAR printf
  * @param ch data to output device
  * @retval  int data to output device
  */
int putchar(int ch) 
{  
   if(ch == '\n')
   {
       dbg_uart_send('\r');
   }
   return (int)dbg_uart_send(ch);
}
#endif /*_DBG_DEVICE_UART*/

/*! flush printf buffer to output device. No body code*/
void flush_printfbuffer(void)
{

}

#endif /*__ICCARM__*/



#if defined(__GNUC__)
/**
  * @brief  provide the function for GCC printf
  * @param  fd: file pointer no used
  * @param  pBuffer data buffer
  * @param  size data buffer size
  * @retval int outputted data size
  */
extern int _write (int fd, char *pBuffer, int size);
int _write (int fd, char *pBuffer, int size)  
{  
   int i;
	UNUSED_PARAM(fd);
	
#ifdef _DBG_DEVICE_ITM    
   for (i = 0; i < size; i++)  
   {  
      ITM_SendChar(pBuffer[i]);
      CLR_WDT();
   }  
#endif
   
#ifdef _DBG_DEVICE_UART   
   for (i = 0; i < size; i++)  
   {  
      if(pBuffer[i] == '\n')
      {
        dbg_uart_send('\r');
      }
      dbg_uart_send(pBuffer[i]);
   }     
#endif   
   return size;  
}  

/**
  * @brief  provide the function for GCC scanf
  * @param  fd: file pointer no used
  * @param  pBuffer data buffer
  * @param  size data buffer size
  * @retval int readed data size
  */
extern int _read (int fd, char *pBuffer, int size);
int _read (int fd, char *pBuffer, int size)  
{  
    int i;
	  UNUSED_PARAM(fd);
	
#ifdef _DBG_DEVICE_ITM  
    for(i = 0; i < size; i++)
    {
        while (ITM_CheckChar() != 1) 
        {
            CLR_WDT();
        }
        pBuffer[i]=(char)ITM_ReceiveChar();
        ITM_SendChar(pBuffer[i]);
        if(pBuffer[i] == '\r')
        {
            ITM_SendChar('\n');
            i += 1;
            pBuffer[i]='\n';
            i++;
            break;
        }
    }
#endif    
    
#ifdef _DBG_DEVICE_UART
    for(i = 0; i < size; i++)
    {
        pBuffer[i]=dbg_uart_read();
        dbg_uart_send(pBuffer[i]);
        if(pBuffer[i] == '\r')
        {
            dbg_uart_send('\n');
            i += 1;
            pBuffer[i]='\n';
            i++;
            break;
        }
    }    
#endif    
   return i;  
}      
#if !defined(__CC_ARM)
/*! flush printf buffer to output device */
extern void flush_printfbuffer(void);
void flush_printfbuffer(void)
{
    fflush(0);
}
#endif


#endif  /* __GNUC__ */
  
#endif /* _MODULE_DBG_PRINTF */


void IWDT_InitCfg(void)
{
	//Set the registers
	IWDT->CR.V32 = (0x5AA5<<16) | CFG_IWDTRLR_INIT | CFG_IWDTPR_INIT;	
}

void WWDT_InitCfg(void)
{
	//Enable WWDT Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.WWDTEN = 1;
  RCC_WriteDisable();	
	
	//Set the registers
	WWDT->CR.V32 = (0x5AA5<<16) | CFG_WWDT_CR_INIT;
	WWDT->WTR.V32 = (0x5AA5<<16) | CFG_WWDT_WTR_INIT;
}

void GPIO_InitCfg(void)
{
  //Enable GPIO Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.IODATEN = 1;
  RCC->AHBENR.BIT.IOCFGEN = 1;
  RCC_WriteDisable();
	
#if CFG_GPIOA_EN
	//Set the registers
	GPIOA->ODR = CFG_GPIO_ODR_A_INIT;
	GPIOA->MODER = CFG_GPIO_MODER_A_INIT;
	GPIOA_CFG->OTYPER = CFG_GPIO_OTYPER_A_INIT;
	GPIOA_CFG->ODRVR.V32 = CFG_GPIO_ODRVR_A_INIT;
	GPIOA_CFG->PUPDR.V32 = CFG_GPIO_PUPDR_A_INIT;
	GPIOA_CFG->AFRL.V32 = CFG_GPIO_AFRL_A_INIT;
	GPIOA_CFG->AFRH.V32 = CFG_GPIO_AFRH_A_INIT;
	GPIOA_CFG->TTLEN.V32 = CFG_GPIO_TTLEN_A_INIT;
	GPIOA_CFG->LCKR.V32 = CFG_GPIO_LCKR_A_INIT;
#endif

#if CFG_GPIOB_EN
	//Set the registers
	GPIOB->ODR = CFG_GPIO_ODR_B_INIT;
	GPIOB->MODER = CFG_GPIO_MODER_B_INIT;
	GPIOB_CFG->OTYPER = CFG_GPIO_OTYPER_B_INIT;
	GPIOB_CFG->ODRVR.V32 = CFG_GPIO_ODRVR_B_INIT;
	GPIOB_CFG->PUPDR.V32 = CFG_GPIO_PUPDR_B_INIT;
	GPIOB_CFG->AFRL.V32 = CFG_GPIO_AFRL_B_INIT;
	GPIOB_CFG->AFRH.V32 = CFG_GPIO_AFRH_B_INIT;
	GPIOB_CFG->TTLEN.V32 = CFG_GPIO_TTLEN_B_INIT;
	GPIOB_CFG->LCKR.V32 = CFG_GPIO_LCKR_B_INIT;
#endif

#if CFG_GPIOC_EN
	//Set the registers
	GPIOC->ODR = CFG_GPIO_ODR_C_INIT;
	GPIOC->MODER = CFG_GPIO_MODER_C_INIT;
	GPIOC_CFG->OTYPER = CFG_GPIO_OTYPER_C_INIT;
	GPIOC_CFG->ODRVR.V32 = CFG_GPIO_ODRVR_C_INIT;
	GPIOC_CFG->PUPDR.V32 = CFG_GPIO_PUPDR_C_INIT;
	GPIOC_CFG->AFRL.V32 = CFG_GPIO_AFRL_C_INIT;
	GPIOC_CFG->AFRH.V32 = CFG_GPIO_AFRH_C_INIT;
	GPIOC_CFG->TTLEN.V32 = 0x0;
	GPIOC_CFG->LCKR.V32 = CFG_GPIO_LCKR_C_INIT;
#endif

#if CFG_GPIOD_EN
	//Set the registers
	GPIOD->ODR = CFG_GPIO_ODR_D_INIT;
	GPIOD->MODER = CFG_GPIO_MODER_D_INIT;
	GPIOD_CFG->OTYPER = CFG_GPIO_OTYPER_D_INIT;
	GPIOD_CFG->ODRVR.V32 = CFG_GPIO_ODRVR_D_INIT;
	GPIOD_CFG->PUPDR.V32 = CFG_GPIO_PUPDR_D_INIT;
	GPIOD_CFG->AFRL.V32 = CFG_GPIO_AFRL_D_INIT;
	GPIOD_CFG->AFRH.V32 = CFG_GPIO_AFRH_D_INIT;
	GPIOD_CFG->TTLEN.V32 = 0x0;
	GPIOD_CFG->LCKR.V32 = CFG_GPIO_LCKR_D_INIT;
#endif

#if CFG_GPIOE_EN
	//Set the registers
	GPIOE->ODR = CFG_GPIO_ODR_E_INIT;
	GPIOE->MODER = CFG_GPIO_MODER_E_INIT;
	GPIOE_CFG->OTYPER = CFG_GPIO_OTYPER_E_INIT;
	GPIOE_CFG->ODRVR.V32 = CFG_GPIO_ODRVR_E_INIT;
	GPIOE_CFG->PUPDR.V32 = CFG_GPIO_PUPDR_E_INIT;
	GPIOE_CFG->AFRL.V32 = CFG_GPIO_AFRL_E_INIT;
	GPIOE_CFG->AFRH.V32 = CFG_GPIO_AFRH_E_INIT;
	GPIOE_CFG->TTLEN.V32 = 0x0;
	GPIOE_CFG->LCKR.V32 = CFG_GPIO_LCKR_E_INIT;
#endif
}


void EXTI_InitCfg(void)
{
	//Set the registers
	EXTI->IMR = CFG_EXTI_IMR_INIT;
	EXTI->EMR = CFG_EXTI_EMR_INIT;
	EXTI->TMSR = CFG_EXTI_TMSR_INIT;
	EXTI->RTSR = CFG_EXTI_RTSR_INIT;
	EXTI->FTSR = CFG_EXTI_FTSR_INIT;
	EXTI->CFGL.V32 = CFG_EXTI_CFGL_INIT;
	EXTI->CFGH.V32 = CFG_EXTI_CFGH_INIT;
	EXTI->SAMPL.V32 = CFG_EXTI_SAMPL_INIT;
	EXTI->SAMPH.V32 = CFG_EXTI_SAMPH_INIT;
	EXTI->DMR = CFG_EXTI_DMR_INIT;
}

void DMA_InitCfg(void)
{
	//Enable DMA Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.DMAEN = 1;
  RCC_WriteDisable();
	
#if CFG_DMA_CH0_EN
	//Set the registers
	DMA->NPKT0 = CFG_DMA_NPKT0_INIT;
	DMA->SAR0 =	CFG_DMA_SAR0_INIT;
	DMA->DAR0 =	CFG_DMA_DAR0_INIT;
	DMA->CCR0.V32 = CFG_DMA_CCR0_INIT | CFG_DMA_CH0_EN;
#endif

#if CFG_DMA_CH1_EN
	//Set the registers
	DMA->NPKT1 = CFG_DMA_NPKT1_INIT;
	DMA->SAR1 =	CFG_DMA_SAR1_INIT;
	DMA->DAR1 =	CFG_DMA_DAR1_INIT;
	DMA->CCR1.V32 = CFG_DMA_CCR1_INIT | CFG_DMA_CH1_EN;
#endif
	
#if CFG_DMA_CH2_EN
	//Set the registers
	DMA->CCR2.V32 = CFG_DMA_CCR2_INIT;
	DMA->NPKT2 = CFG_DMA_NPKT2_INIT;
	DMA->SAR2 =	CFG_DMA_SAR2_INIT;
	DMA->DAR2 =	CFG_DMA_DAR2_INIT;
#endif
	
#if CFG_DMA_CH3_EN
	//Set the registers
	DMA->CCR3.V32 = CFG_DMA_CCR3_INIT;
	DMA->NPKT3 = CFG_DMA_NPKT3_INIT;
	DMA->SAR3 =	CFG_DMA_SAR3_INIT;
	DMA->DAR3 =	CFG_DMA_DAR3_INIT;
#endif
	
#if CFG_DMA_CH4_EN
	//Set the registers
	DMA->CCR4.V32 = CFG_DMA_CCR4_INIT;
	DMA->NPKT4 = CFG_DMA_NPKT4_INIT;
	DMA->SAR4 =	CFG_DMA_SAR4_INIT;
	DMA->DAR4 =	CFG_DMA_DAR4_INIT;
#endif
	
#if CFG_DMA_CH5_EN
	//Set the registers
	DMA->CCR5.V32 = CFG_DMA_CCR5_INIT;
	DMA->NPKT5 = CFG_DMA_NPKT5_INIT;
	DMA->SAR5 =	CFG_DMA_SAR5_INIT;
	DMA->DAR5 =	CFG_DMA_DAR5_INIT;
#endif
	
#if CFG_DMA_CH6_EN
	//Set the registers
	DMA->CCR6.V32 = CFG_DMA_CCR6_INIT;
	DMA->NPKT6 = CFG_DMA_NPKT6_INIT;
	DMA->SAR6 =	CFG_DMA_SAR6_INIT;
	DMA->DAR6 =	CFG_DMA_DAR6_INIT;
#endif
	
#if CFG_DMA_CH7_EN
	//Set the registers
	DMA->CCR7.V32 = CFG_DMA_CCR7_INIT;
	DMA->NPKT7 = CFG_DMA_NPKT7_INIT;
	DMA->SAR7 =	CFG_DMA_SAR7_INIT;
	DMA->DAR7 =	CFG_DMA_DAR7_INIT;
#endif

  DMA->CSR.V32 = CFG_DMA_CSR_INIT; 
}

void MCM1_InitCfg(void)
{
	//Enable MCM Clock
	RCC_WriteEnable();
  RCC->APB2ENR.BIT.MCM1EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	MCM1->PWMRLDEN = 0x55;
	
	MCM1->PWMCON1.V32 = CFG_MCM1_PWMCON1_INIT;
	MCM1->PWMCON2.V32 = CFG_MCM1_PWMCON2_INIT;	
	
	MCM1->PWMP = 	CFG_MCM1_PWMP_INIT;
	MCM1->PWM0D = CFG_MCM1_PWM0D_INIT;
	MCM1->PWM1D = CFG_MCM1_PWM1D_INIT;
	MCM1->PWM2D = CFG_MCM1_PWM2D_INIT;
	MCM1->PWM01D = CFG_MCM1_PWM01D_INIT; 
	MCM1->PWM11D = CFG_MCM1_PWM11D_INIT; 
	MCM1->PWM21D = CFG_MCM1_PWM21D_INIT; 

	MCM1->PWMDT21	= CFG_MCM1_PWMDT21_INIT;
	MCM1->PWMDT20	= CFG_MCM1_PWMDT20_INIT;
	MCM1->PWMDT11	= CFG_MCM1_PWMDT11_INIT;
	MCM1->PWMDT10	= CFG_MCM1_PWMDT10_INIT;
	MCM1->PWMDT01	= CFG_MCM1_PWMDT01_INIT;
	MCM1->PWMDT00	= CFG_MCM1_PWMDT00_INIT;
	
	MCM1->PWMPSQ = CFG_MCM1_PWMPSQ_INIT;
	
	MCM1->PMANUALCON1.V32 = CFG_MCM1_PMANUALCON1_INIT;
	MCM1->PMANUALCON2.V32 = CFG_MCM1_PMANUALCON2_INIT;	
		
	MCM1->PWMCMP1 = CFG_MCM1_PWMCMP1_INIT;
	MCM1->PWMCMP2 = CFG_MCM1_PWMCMP2_INIT;
	MCM1->PWMCMP3 = CFG_MCM1_PWMCMP3_INIT;
	MCM1->PWMCMP4 = CFG_MCM1_PWMCMP4_INIT;
	
	MCM1->PWMDMAEN.V32 = CFG_MCM1_PWMDMAEN_INIT;
	MCM1->PWMINTEN.V32 = CFG_MCM1_PWMINTEN_INIT;
	MCM1->PSCON.V32 = CFG_MCM1_PSCON_INIT;	
	MCM1->PWMDMAX = CFG_MCM1_PWMDMAX_INIT;	
	MCM1->PWMDMIN = CFG_MCM1_PWMDMIN_INIT;	
	MCM1->PWMDCMP1 = CFG_MCM1_PWMDCMP1_INIT;
	MCM1->PWMDCMP2 = CFG_MCM1_PWMDCMP2_INIT;
	
	MCM1->SC1CON.V32 = CFG_MCM1_SC1CON_INIT;
	MCM1->SC2CON.V32 = CFG_MCM1_SC2CON_INIT;
	MCM1->SC3CON.V32 = CFG_MCM1_SC3CON_INIT;

	MCM1->FLTWEN = 0x33CC;
	MCM1->FLTCON.V32 = CFG_MCM1_FLTCON_INIT;
	MCM1->POSCR.V32 = CFG_MCM1_POSCR_INIT;	
	MCM1->POSTDCR.V32 = CFG_MCM1_POSTDCR_INIT;
	MCM1->FLTWEN = 0x0000;
	MCM1->PWMOE = CFG_MCM1_PWMOE;
	MCM1->PWMRLDEN = 0xAA;
}

void MCM2_InitCfg(void)
{
	//Enable MCM Clock
	RCC_WriteEnable();
  RCC->APB2ENR.BIT.MCM2EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	MCM2->PWMRLDEN = 0x55;
	
	MCM2->PWMCON1.V32 = CFG_MCM2_PWMCON1_INIT;
	MCM2->PWMCON2.V32 = CFG_MCM2_PWMCON2_INIT;
	
	MCM2->PWMP = 	CFG_MCM2_PWMP_INIT;
	MCM2->PWM0D = CFG_MCM2_PWM0D_INIT;
	MCM2->PWM1D = CFG_MCM2_PWM1D_INIT;
	MCM2->PWM2D = CFG_MCM2_PWM2D_INIT;
	MCM2->PWM01D = CFG_MCM2_PWM01D_INIT; 
	MCM2->PWM11D = CFG_MCM2_PWM11D_INIT; 
	MCM2->PWM21D = CFG_MCM2_PWM21D_INIT; 

	MCM2->PWMDT21	= CFG_MCM2_PWMDT21_INIT;
	MCM2->PWMDT20	= CFG_MCM2_PWMDT20_INIT;
	MCM2->PWMDT11	= CFG_MCM2_PWMDT11_INIT;
	MCM2->PWMDT10	= CFG_MCM2_PWMDT10_INIT;
	MCM2->PWMDT01	= CFG_MCM2_PWMDT01_INIT;
	MCM2->PWMDT00	= CFG_MCM2_PWMDT00_INIT;
	
	MCM2->PWMPSQ = CFG_MCM2_PWMPSQ_INIT;
	
	MCM2->PMANUALCON1.V32 = CFG_MCM2_PMANUALCON1_INIT;
	MCM2->PMANUALCON2.V32 = CFG_MCM2_PMANUALCON2_INIT;	
	
	MCM2->PWMCMP1 = CFG_MCM2_PWMCMP1_INIT;
	MCM2->PWMCMP2 = CFG_MCM2_PWMCMP2_INIT;
	MCM2->PWMCMP3 = CFG_MCM2_PWMCMP3_INIT;
	MCM2->PWMCMP4 = CFG_MCM2_PWMCMP4_INIT;
	
	MCM2->PWMDMAEN.V32 = CFG_MCM2_PWMDMAEN_INIT;
	MCM2->PWMINTEN.V32 = CFG_MCM2_PWMINTEN_INIT;
	MCM2->PSCON.V32 = CFG_MCM2_PSCON_INIT;	
	MCM2->PWMDMAX = CFG_MCM2_PWMDMAX_INIT;	
	MCM2->PWMDMIN = CFG_MCM2_PWMDMIN_INIT;	
	MCM2->PWMDCMP1 = CFG_MCM2_PWMDCMP1_INIT;
	MCM2->PWMDCMP2 = CFG_MCM2_PWMDCMP2_INIT;
	
	MCM2->SC1CON.V32 = CFG_MCM2_SC1CON_INIT;
	MCM2->SC2CON.V32 = CFG_MCM2_SC2CON_INIT;
	MCM2->SC3CON.V32 = CFG_MCM2_SC3CON_INIT;

	MCM2->FLTWEN = 0x33CC;
	MCM2->FLTCON.V32 = CFG_MCM2_FLTCON_INIT;
	MCM2->POSCR.V32 = CFG_MCM2_POSCR_INIT;	
	MCM2->POSTDCR.V32 = CFG_MCM2_POSTDCR_INIT;
	MCM2->FLTWEN = 0x0000;
	MCM2->PWMOE = CFG_MCM2_PWMOE;
	MCM2->PWMRLDEN = 0xAA;
}


void GPT_InitCfg(void)
{
	//Enable GPT Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.GPTEN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	GPT->GTPRWEN = 0x33CC;
	GPT->GTETINT.V32 = CFG_GPT_GTETINT_INIT;
	GPT->GTPOECR.V32 = CFG_GPT_GTPOECR_INIT;
	GPT->GTPRWEN = 0x0;
	
#if CFG_GPT0_EN
	//Enable GPT Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.GPT0EN = 1;
  RCC_WriteDisable();

	//ģĴ޸
	GPT0->GTWP = 0x55;
	
	//Set the registers
	GPT0->GTPSQ = CFG_GPT0_GTPSQ_INIT;
	GPT0->GTCR.V32 = CFG_GPT0_GTCR_INIT;

	GPT0->GTPR = CFG_GPT0_GTPR_INIT;
	GPT0->GTPBR = CFG_GPT0_GTPBR_INIT;
	GPT0->GTPDBR = CFG_GPT0_GTPDBR_INIT;
	
	GPT0->GTHCR.V32 = CFG_GPT0_GTHCR_INIT;
	GPT0->GTDEB.V32 = CFG_GPT0_GTDEB_INIT;
	GPT0->GTBDR.V32 = CFG_GPT0_GTBDR_INIT;
	GPT0->GTIOR.V32 = CFG_GPT0_GTIOR_INIT;
	GPT0->GTDMA.V32 = CFG_GPT0_GTDMA_INIT;
	GPT0->GTBER.V32 = CFG_GPT0_GTBER_INIT;
	GPT0->GTUDC.V32 = CFG_GPT0_GTUDC_INIT;
	GPT0->GTITC.V32 = CFG_GPT0_GTITC_INIT;
	GPT0->GTST.V32 = CFG_GPT0_GTCR_INIT;

	GPT0->GTCCRA = CFG_GPT0_GTCCRA_INIT;
	GPT0->GTCCRB = CFG_GPT0_GTCCRB_INIT;
	GPT0->GTCCRC = CFG_GPT0_GTCCRC_INIT;
	GPT0->GTCCRD = CFG_GPT0_GTCCRD_INIT;
	GPT0->GTCCRE = CFG_GPT0_GTCCRE_INIT;
	GPT0->GTCCRF = CFG_GPT0_GTCCRF_INIT;

	GPT0->GTINTAD.V32 = CFG_GPT0_GTINTAD_INIT;
	GPT0->GTADTRA = CFG_GPT0_GTADTRA_INIT;
	GPT0->GTADTRB = CFG_GPT0_GTADTRB_INIT;
	GPT0->GTADTBRA = CFG_GPT0_GTADTBRA_INIT;
	GPT0->GTADTBRB = CFG_GPT0_GTADTBRB_INIT;
	GPT0->GTADTDBRA = CFG_GPT0_GTADTDBRA_INIT;
	GPT0->GTADTDBRB = CFG_GPT0_GTADTDBRB_INIT;
	
	GPT0->GTDTCR.V32 = CFG_GPT0_GTDTCR_INIT;
	GPT0->GTDVU = CFG_GPT0_GTDVU_INIT;
	GPT0->GTDVD = CFG_GPT0_GTDVD_INIT;
	GPT0->GTDBU = CFG_GPT0_GTDBU_INIT;
	GPT0->GTDBD = CFG_GPT0_GTDBD_INIT;
	
	GPT0->GTOSCR.V32 = CFG_GPT0_GTOSCR_INIT;
	
	//ֹԱĴ޸
	GPT0->GTWP = 0x00;

	//Enable GPT0
	GPT->GTPRWEN = 0x33CC;
	GPT->GTSTR.BIT.CST0 = 1;
	GPT->GTPRWEN = 0x0;
#endif

#if CFG_GPT1_EN
	//Enable GPT Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.GPT1EN = 1;
  RCC_WriteDisable();

	//ģĴ޸
	GPT1->GTWP = 0x55;
	
	//Set the registers
	GPT1->GTPSQ = CFG_GPT1_GTPSQ_INIT;
	GPT1->GTCR.V32 = CFG_GPT1_GTCR_INIT;

	GPT1->GTPR = CFG_GPT1_GTPR_INIT;
	GPT1->GTPBR = CFG_GPT1_GTPBR_INIT;
	GPT1->GTPDBR = CFG_GPT1_GTPDBR_INIT;
	
	GPT1->GTHCR.V32 = CFG_GPT1_GTHCR_INIT;
	GPT1->GTDEB.V32 = CFG_GPT1_GTDEB_INIT;
	GPT1->GTBDR.V32 = CFG_GPT1_GTBDR_INIT;
	GPT1->GTIOR.V32 = CFG_GPT1_GTIOR_INIT;
	GPT1->GTDMA.V32 = CFG_GPT1_GTDMA_INIT;
	GPT1->GTBER.V32 = CFG_GPT1_GTBER_INIT;
	GPT1->GTUDC.V32 = CFG_GPT1_GTUDC_INIT;
	GPT1->GTITC.V32 = CFG_GPT1_GTITC_INIT;
	GPT1->GTST.V32 = CFG_GPT1_GTCR_INIT;

	GPT1->GTCCRA = CFG_GPT1_GTCCRA_INIT;
	GPT1->GTCCRB = CFG_GPT1_GTCCRB_INIT;
	GPT1->GTCCRC = CFG_GPT1_GTCCRC_INIT;
	GPT1->GTCCRD = CFG_GPT1_GTCCRD_INIT;
	GPT1->GTCCRE = CFG_GPT1_GTCCRE_INIT;
	GPT1->GTCCRF = CFG_GPT1_GTCCRF_INIT;

	GPT1->GTINTAD.V32 = CFG_GPT1_GTINTAD_INIT;
	GPT1->GTADTRA = CFG_GPT1_GTADTRA_INIT;
	GPT1->GTADTRB = CFG_GPT1_GTADTRB_INIT;
	GPT1->GTADTBRA = CFG_GPT1_GTADTBRA_INIT;
	GPT1->GTADTBRB = CFG_GPT1_GTADTBRB_INIT;
	GPT1->GTADTDBRA = CFG_GPT1_GTADTDBRA_INIT;
	GPT1->GTADTDBRB = CFG_GPT1_GTADTDBRB_INIT;
	
	GPT1->GTDTCR.V32 = CFG_GPT1_GTDTCR_INIT;
	GPT1->GTDVU = CFG_GPT1_GTDVU_INIT;
	GPT1->GTDVD = CFG_GPT1_GTDVD_INIT;
	GPT1->GTDBU = CFG_GPT1_GTDBU_INIT;
	GPT1->GTDBD = CFG_GPT1_GTDBD_INIT;
	
	GPT1->GTOSCR.V32 = CFG_GPT1_GTOSCR_INIT;
	
	//ֹԱĴ޸
	GPT1->GTWP = 0x00;

	//Enable GPT1
	GPT->GTPRWEN = 0x33CC;
	GPT->GTSTR.BIT.CST1 = 1;
	GPT->GTPRWEN = 0x0;
#endif

#if CFG_GPT2_EN
	//Enable GPT Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.GPT2EN = 1;
  RCC_WriteDisable();

	//ģĴ޸
	GPT2->GTWP = 0x55;
	
	//Set the registers
	GPT2->GTPSQ = CFG_GPT2_GTPSQ_INIT;
	GPT2->GTCR.V32 = CFG_GPT2_GTCR_INIT;

	GPT2->GTPR = CFG_GPT2_GTPR_INIT;
	GPT2->GTPBR = CFG_GPT2_GTPBR_INIT;
	GPT2->GTPDBR = CFG_GPT2_GTPDBR_INIT;
	
	GPT2->GTHCR.V32 = CFG_GPT2_GTHCR_INIT;
	GPT2->GTDEB.V32 = CFG_GPT2_GTDEB_INIT;
	GPT2->GTBDR.V32 = CFG_GPT2_GTBDR_INIT;
	GPT2->GTIOR.V32 = CFG_GPT2_GTIOR_INIT;
	GPT2->GTDMA.V32 = CFG_GPT2_GTDMA_INIT;
	GPT2->GTBER.V32 = CFG_GPT2_GTBER_INIT;
	GPT2->GTUDC.V32 = CFG_GPT2_GTUDC_INIT;
	GPT2->GTITC.V32 = CFG_GPT2_GTITC_INIT;
	GPT2->GTST.V32 = CFG_GPT2_GTCR_INIT;

	GPT2->GTCCRA = CFG_GPT2_GTCCRA_INIT;
	GPT2->GTCCRB = CFG_GPT2_GTCCRB_INIT;
	GPT2->GTCCRC = CFG_GPT2_GTCCRC_INIT;
	GPT2->GTCCRD = CFG_GPT2_GTCCRD_INIT;
	GPT2->GTCCRE = CFG_GPT2_GTCCRE_INIT;
	GPT2->GTCCRF = CFG_GPT2_GTCCRF_INIT;

	GPT2->GTINTAD.V32 = CFG_GPT2_GTINTAD_INIT;
	GPT2->GTADTRA = CFG_GPT2_GTADTRA_INIT;
	GPT2->GTADTRB = CFG_GPT2_GTADTRB_INIT;
	GPT2->GTADTBRA = CFG_GPT2_GTADTBRA_INIT;
	GPT2->GTADTBRB = CFG_GPT2_GTADTBRB_INIT;
	GPT2->GTADTDBRA = CFG_GPT2_GTADTDBRA_INIT;
	GPT2->GTADTDBRB = CFG_GPT2_GTADTDBRB_INIT;
	
	GPT2->GTDTCR.V32 = CFG_GPT2_GTDTCR_INIT;
	GPT2->GTDVU = CFG_GPT2_GTDVU_INIT;
	GPT2->GTDVD = CFG_GPT2_GTDVD_INIT;
	GPT2->GTDBU = CFG_GPT2_GTDBU_INIT;
	GPT2->GTDBD = CFG_GPT2_GTDBD_INIT;
	
	GPT2->GTOSCR.V32 = CFG_GPT2_GTOSCR_INIT;
	
	//ֹԱĴ޸
	GPT2->GTWP = 0x00;

	//Enable GPT2
	GPT->GTPRWEN = 0x33CC;
	GPT->GTSTR.BIT.CST2 = 1;
	GPT->GTPRWEN = 0x0;
#endif

#if CFG_GPT3_EN
	//Enable GPT Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.GPT3EN = 1;
  RCC_WriteDisable();

	//ģĴ޸
	GPT3->GTWP = 0x55;
	
	//Set the registers
	GPT3->GTPSQ = CFG_GPT3_GTPSQ_INIT;
	GPT3->GTCR.V32 = CFG_GPT3_GTCR_INIT;

	GPT3->GTPR = CFG_GPT3_GTPR_INIT;
	GPT3->GTPBR = CFG_GPT3_GTPBR_INIT;
	GPT3->GTPDBR = CFG_GPT3_GTPDBR_INIT;
	
	GPT3->GTHCR.V32 = CFG_GPT3_GTHCR_INIT;
	GPT3->GTDEB.V32 = CFG_GPT3_GTDEB_INIT;
	GPT3->GTBDR.V32 = CFG_GPT3_GTBDR_INIT;
	GPT3->GTIOR.V32 = CFG_GPT3_GTIOR_INIT;
	GPT3->GTDMA.V32 = CFG_GPT3_GTDMA_INIT;
	GPT3->GTBER.V32 = CFG_GPT3_GTBER_INIT;
	GPT3->GTUDC.V32 = CFG_GPT3_GTUDC_INIT;
	GPT3->GTITC.V32 = CFG_GPT3_GTITC_INIT;
	GPT3->GTST.V32 = CFG_GPT3_GTCR_INIT;

	GPT3->GTCCRA = CFG_GPT3_GTCCRA_INIT;
	GPT3->GTCCRB = CFG_GPT3_GTCCRB_INIT;
	GPT3->GTCCRC = CFG_GPT3_GTCCRC_INIT;
	GPT3->GTCCRD = CFG_GPT3_GTCCRD_INIT;
	GPT3->GTCCRE = CFG_GPT3_GTCCRE_INIT;
	GPT3->GTCCRF = CFG_GPT3_GTCCRF_INIT;

	GPT3->GTINTAD.V32 = CFG_GPT3_GTINTAD_INIT;
	GPT3->GTADTRA = CFG_GPT3_GTADTRA_INIT;
	GPT3->GTADTRB = CFG_GPT3_GTADTRB_INIT;
	GPT3->GTADTBRA = CFG_GPT3_GTADTBRA_INIT;
	GPT3->GTADTBRB = CFG_GPT3_GTADTBRB_INIT;
	GPT3->GTADTDBRA = CFG_GPT3_GTADTDBRA_INIT;
	GPT3->GTADTDBRB = CFG_GPT3_GTADTDBRB_INIT;
	
	GPT3->GTDTCR.V32 = CFG_GPT3_GTDTCR_INIT;
	GPT3->GTDVU = CFG_GPT3_GTDVU_INIT;
	GPT3->GTDVD = CFG_GPT3_GTDVD_INIT;
	GPT3->GTDBU = CFG_GPT3_GTDBU_INIT;
	GPT3->GTDBD = CFG_GPT3_GTDBD_INIT;
	
	GPT3->GTOSCR.V32 = CFG_GPT3_GTOSCR_INIT;
	
	//ֹԱĴ޸
	GPT3->GTWP = 0x00;

	//Enable GPT3
	GPT->GTPRWEN = 0x33CC;
	GPT->GTSTR.BIT.CST3 = 1;
	GPT->GTPRWEN = 0x0;
#endif
}

void MACP_InitCfg()
{
	//Enable MACP Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.MACPEN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	MACP->CORDCSR0.V32 = CFG_MACP_CORDCSR0_INIT;	
	MACP->CORDCSR1.V32 = CFG_MACP_CORDCSR1_INIT;
	MACP->IQDIVCSR0.V32 = CFG_MACP_IQDIVCSR0_INIT;
	MACP->IQDIVCSR1.V32 = CFG_MACP_IQDIVCSR1_INIT;
	MACP->SVUALPHA = CFG_MACP_SVUALPHA_INIT;
	MACP->SVUBETA = CFG_MACP_SVUBETA_INIT;
	MACP->SVIQN.V32 = CFG_MACP_SVIQN_INIT;
}



void TIM_InitCfg(void)
{
#if CFG_TIM5_EN
	//Enable TIM5 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.TIM5EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	TIM5->TCNT = CFG_TIM5_TCNT_INIT;
	TIM5->TPR = CFG_TIM5_TPR_INIT;
	TIM5->PSQ = CFG_TIM5_PSQ_INIT;	
	TIM5->CR.V32 = (CFG_TIM5_CR_START |CFG_TIM5_CR_INIT);
#endif
	
#if CFG_TIM6_EN
	//Enable TIM6 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.TIM6EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	TIM6->TCNT = CFG_TIM6_TCNT_INIT;
	TIM6->TPR = CFG_TIM6_TPR_INIT;
	TIM6->PSQ = CFG_TIM6_PSQ_INIT;	
	TIM6->CR.V32 = CFG_TIM6_CR_START |CFG_TIM6_CR_INIT;
#endif

#if CFG_TIM56_EN
	//Enable TIM6 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.TIM5EN = 1;
  RCC->APB1ENR.BIT.TIM6EN = 1;	
  RCC_WriteDisable();
	
	//Set the registers
	TIM5->TCNT = (CFG_TIM56_TCNT_INIT >> 16)&0xFFFF;
	TIM5->TPR = (CFG_TIM56_TPR_INIT >> 16)&0xFFFF;
	TIM5->PSQ = CFG_TIM56_PSQ_INIT;	
	
	TIM6->TCNT = CFG_TIM6_TCNT_INIT&0x0000FFFF;
	TIM6->TPR = CFG_TIM56_TPR_INIT&0x0000FFFF;
	TIM6->PSQ = CFG_TIM56_PSQ_INIT;	
	
	TIM5->CR.V32 = CFG_TIM56_CR_START | CFG_TIM56_CR_INIT;
	TIM6->CR.V32 = CFG_TIM56_CR_START | CFG_TIM56_CR_INIT;
#endif

#if CFG_TIM7_EN
	//Enable TIM7 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.TIM7EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	TIM7->TCNT = CFG_TIM7_TCNT_INIT;
	TIM7->TPR = CFG_TIM7_TPR_INIT;
	TIM7->PSQ = CFG_TIM7_PSQ_INIT;	
	TIM7->CR.V32 = (CFG_TIM7_CR_START) |CFG_TIM7_CR_INIT;
#endif

#if CFG_TIM8_EN
	//Enable TIM8 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.TIM8EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	TIM8->TCNT = CFG_TIM8_TCNT_INIT;
	TIM8->TPR = CFG_TIM8_TPR_INIT;
	TIM8->PSQ = CFG_TIM8_PSQ_INIT;	
	TIM8->CR.V32 = (CFG_TIM8_CR_START) |CFG_TIM8_CR_INIT;
#endif

#if CFG_TIM78_EN
	//Enable TIM6 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.TIM7EN = 1;
  RCC->APB1ENR.BIT.TIM8EN = 1;	
  RCC_WriteDisable();
	
	//Set the registers
	TIM7->TCNT = (CFG_TIM78_TCNT_INIT >> 16)&0xFFFF;
	TIM7->TPR = (CFG_TIM78_TPR_INIT >> 16)&0xFFFF;
	TIM7->PSQ = (CFG_TIM78_PSQ_INIT >> 16)&0xFFFF;
	
	TIM8->TCNT = CFG_TIM78_TCNT_INIT&0x0000FFFF;
	TIM8->TPR = CFG_TIM78_TPR_INIT&0x0000FFFF;
	TIM8->PSQ = CFG_TIM78_PSQ_INIT&0x0000FFFF;	
	
	TIM7->CR.V32 = CFG_TIM78_CR_START | CFG_TIM78_CR_INIT;
	TIM8->CR.V32 = CFG_TIM78_CR_START | CFG_TIM78_CR_INIT;
#endif
}

void ADC_InitCfg(void)
{
#if CFG_ADC1_EN
  //Enable ADC1 Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.ADC1EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	ADC1->ADCON1.V32 = CFG_ADC1_ADCON1_INIT;
	ADC1->ADCON2.V32 = CFG_ADC1_ADCON2_INIT;
	ADC1->ADCMPCON.V32 = CFG_ADC1_ADCMPCON_INIT;
	ADC1->ADDLT = CFG_ADC1_ADDLT_INIT;
	ADC1->ADDGT = CFG_ADC1_ADDGT_INIT;	
	ADC1->SEQCHSEL.V32 = CFG_ADC1_SEQCHSEL_INIT;
	ADC1->ADGAPON = CFG_ADC1_ADGAPON_INIT;
#endif
	
#if CFG_ADC2_EN
  //Enable ADC2 Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.ADC2EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	ADC2->ADCON1.V32 = CFG_ADC2_ADCON1_INIT;
	ADC2->ADCON2.V32 = CFG_ADC2_ADCON2_INIT;
	ADC2->ADCMPCON.V32 = CFG_ADC2_ADCMPCON_INIT;
	ADC2->ADDLT = CFG_ADC2_ADDLT_INIT;
	ADC2->ADDGT = CFG_ADC2_ADDGT_INIT;	
	ADC2->SEQCHSEL.V32 = (uint32_t)CFG_ADC2_SEQCHSEL_INIT;
	ADC2->ADGAPON = CFG_ADC2_ADGAPON_INIT;
#endif	

#if CFG_ADC3_EN
  //Enable ADC3 Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.ADC3EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	ADC3->ADCON1.V32 = CFG_ADC3_ADCON1_INIT;
	ADC3->ADCON2.V32 = CFG_ADC3_ADCON2_INIT;
	ADC3->ADCMPCON.V32 = CFG_ADC3_ADCMPCON_INIT;
	ADC3->ADDLT = CFG_ADC3_ADDLT_INIT;
	ADC3->ADDGT = CFG_ADC3_ADDGT_INIT;	
	ADC3->SEQCHSEL.V32 = CFG_ADC3_SEQCHSEL_INIT;
	ADC3->ADGAPON = CFG_ADC3_ADGAPON_INIT;
#endif	

}

void QEI_InitCfg(void)
{
  //Enable QEI Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.QEIEN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	QEI->QEICON.V32 = CFG_QEI_QEICON_INIT;
	QEI->QFLTCON.V32 = CFG_QEI_QFLTCON_INIT;
	QEI->QPOSMAX = CFG_QEI_QPOSMAX_INIT;
	QEI->QCNTMIN = CFG_QEI_QCNTMIN_INIT;
	QEI->QTPR = CFG_QEI_QTPR_INIT;
	QEI->QTPSQ = CFG_QEI_QTPSQ_INIT;
	QEI->QEIINT.V32 = (uint32_t)CFG_QEI_QEIINT_INIT;
}

void AMOC_InitCfg(void)
{
  //Enable AMOC Clock
	RCC_WriteEnable();	
  RCC->APB1ENR.BIT.AMOCEN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	AMOC->CMP1CON.V32 = CFG_AMOC_CMP1CON_INIT;
	AMOC->CMP2CON.V32 = CFG_AMOC_CMP2CON_INIT;
	AMOC->CMP3CON.V32 = CFG_AMOC_CMP3CON_INIT;
	AMOC->OPCON.V32 = CFG_AMOC_OPCON_INIT;
	AMOC->AVREFCON.V32 = CFG_AMOC_AVREFCON_INIT;
	AMOC->TPSCON.V32 = CFG_AMOC_TPSCON_INIT;
}

void UART_InitCfg(void)
{
#if CFG_UART1_EN
  //Enable UART1 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.UART1EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	UART1->ADDR.V32 = CFG_UART1_ADDR_INIT;
	UART1->BRT.V32 = CFG_UART1_BRT_INIT;
	UART1->CR.V32 = CFG_UART1_CR_INIT;
#endif
	
#if CFG_UART2_EN
  //Enable UART2 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.UART2EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	UART2->ADDR.V32 = CFG_UART2_ADDR_INIT;
	UART2->BRT.V32 = CFG_UART2_BRT_INIT;
	UART2->CR.V32 = CFG_UART2_CR_INIT;	
#endif

#if CFG_UART3_EN
  //Enable UART3 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.UART3EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	UART3->ADDR.V32 = CFG_UART3_ADDR_INIT;
	UART3->BRT.V32 = CFG_UART3_BRT_INIT;
	UART3->CR.V32 = CFG_UART3_CR_INIT;
#endif	
}

void SPI_InitCfg(void)
{
#if CFG_SPI1_EN
  //Enable SPI1 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.SPI1EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	SPI1->CR.V32 = CFG_SPI1_CR_INIT;	
	
#endif
	
#if CFG_SPI2_EN
  //Enable SPI2 Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.SPI2EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	SPI2->CR.V32 = CFG_SPI2_CR_INIT;
#endif
}

void TWI_InitCfg(void)
{
  //Enable TWI Clock
	RCC_WriteEnable();
  RCC->APB1ENR.BIT.TWI1EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	TWI1->HOC = CFG_TWI1_HOC_INIT;
	TWI1->BRT = CFG_TWI1_BRT_INIT;
	TWI1->ADDR.V32 = CFG_TWI1_ADDR_INIT;
	TWI1->CR.V32 = CFG_TWI1_CR_INIT;
}
void SysTick_InitCfg(void)
{
	//set reload register 
	SysTick->LOAD  = CFG_SYSTICK_LOAD_INIT; 

	//Load the SysTick Counter Value 	
  SysTick->VAL   = CFG_SYSTICK_VAL_INIT;                          
  SysTick->CTRL  = (CFG_SYSTICK_CR_CLK << 2) |	
                   (CFG_SYSTICK_INT_EN << 1) |
                   CFG_SYSTICK_START_EN;     
}

void NVIC_InitCfg(void)
{
	//Setting Interrupt Set Enable Register 
	NVIC->ISER[1] = CFG_NVIC_ISER1_INIT;
	NVIC->ISER[0] = CFG_NVIC_ISER0_INIT;

#if CFG_PRI_EN
	//Setting PRI 
	SCB->AIRCR |= CFG_SCB_PRIGROUP_INIT; 
	
	//Setting Exception Priority Register
	*((volatile uint32_t *)(volatile void*)(&SCB->SHP[0])) = CFG_SCB_SHP0_INIT;
	*((volatile uint32_t *)(volatile void*)(&SCB->SHP[1])) = CFG_SCB_SHP1_INIT;
	*((volatile uint32_t *)(volatile void*)(&SCB->SHP[2])) = CFG_SCB_SHP2_INIT;	
	
	//Setting Interrupt Priority Register
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[0])) = CFG_NVIC_IP0_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[4])) = CFG_NVIC_IP1_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[8])) = CFG_NVIC_IP2_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[12])) = CFG_NVIC_IP3_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[16])) = CFG_NVIC_IP4_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[24])) = CFG_NVIC_IP5_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[28])) = CFG_NVIC_IP6_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[32])) = CFG_NVIC_IP7_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[36])) = CFG_NVIC_IP8_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[40])) = CFG_NVIC_IP9_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[44])) = CFG_NVIC_IP10_INIT;
	*((volatile uint32_t *)(volatile void*)(&NVIC->IP[48])) = CFG_NVIC_IP11_INIT;
#endif
}


void Peripherals_InitCfg(void)
{
	NVIC_InitCfg();

#if CFG_SYSTICK_EN	
	SysTick_InitCfg();
#endif	
	
#if CFG_IWDT_EN
	IWDT_InitCfg();
	CLR_WDT();	
#endif 
	
#if CFG_WWDT_EN
	WWDT_InitCfg();
#endif 
	
#if CFG_GPIO_EN
	GPIO_InitCfg();
#endif 	

#if CFG_EXTI_EN	
	EXTI_InitCfg();
#endif

#if CFG_MCM1_EN	
	MCM1_InitCfg();
#endif	

#if CFG_MCM2_EN	
	MCM2_InitCfg();
#endif	

#if CFG_GPT_EN	
	GPT_InitCfg();
#endif		
	
#if CFG_TIM_EN
	TIM_InitCfg();
#endif 

#if CFG_MACP_EN
	MACP_InitCfg();
#endif 
	
#if CFG_ADC_EN	
	ADC_InitCfg();
#endif	
	
#if CFG_QEI_EN
	QEI_InitCfg();
#endif 

#if CFG_AMOC_EN	
	AMOC_InitCfg();
#endif	
	
#if CFG_UART_EN	
	UART_InitCfg();
#endif

#if CFG_SPI_EN	
	SPI_InitCfg();
#endif	
	
#if CFG_TWI_EN	
	TWI_InitCfg();
#endif	

	
#if CFG_DMA_EN	
	DMA_InitCfg();
#endif

}
