/**
  ******************************************************************************
  * @file    sh3xf2xx_sa0_IQmath.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    31-May-2021 
  * @brief   This file contains all the functions prototypes for the PPP firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2021 Sinowealth
  *
  *
  ******************************************************************************
  */
/*==============================================================================
Function List :
             1: IQN                  N=1~31
             1: IQNmpy          N=1~31
             1: IQNdiv            N=1~31             
             2: IQNSinCos     N=1~31
             3: IQNatan          N=1~31
             4: IQAtan2          N=1~31
             5: IQrms             N=1~31
==============================================================================*/
#ifndef __IQMATH_H__
#define __IQMATH_H__

#include "sh3xf2xx_sa0_lib.h"

#ifndef CORDIC_K
#define CORDIC_K          1.6467602579
#endif

#ifndef IQn
#define   IQn(x,N)     (int32_t) ((x) * (1L<<N))
#endif

#ifndef  IQ31
#define   IQ31(x)      (int32_t) ((x) * 2147483648.0L)
#endif
#ifndef  IQ30
#define   IQ30(x)      (int32_t) ((x) * 1073741824.0L)
#endif
#ifndef  IQ29
#define   IQ29(x)      (int32_t) ((x) * 536870912.0L)
#endif
#ifndef  IQ28
#define   IQ28(x)      (int32_t) ((x) * 268435456.0L)
#endif
#ifndef  IQ27
#define   IQ27(x)      (int32_t) ((x) * 134217728.0L)
#endif
#ifndef  IQ26
#define   IQ26(x)      (int32_t) ((x) * 67108864.0L)
#endif
#ifndef  IQ25
#define   IQ25(x)      (int32_t) ((x) * 33554432.0L)
#endif
#ifndef  IQ24
#define   IQ24(x)      (int32_t) ((x) * 16777216.0L)
#endif
#ifndef  IQ23
#define   IQ23(x)      (int32_t) ((x) * 8388608.0L)
#endif
#ifndef  IQ22
#define   IQ22(x)      (int32_t) ((x) * 4194304.0L)
#endif
#ifndef  IQ21
#define   IQ21(x)      (int32_t) ((x) * 2097152.0L)
#endif
#ifndef  IQ20
#define   IQ20(x)      (int32_t) ((x) * 1048576.0L)
#endif
#ifndef  IQ19
#define   IQ19(x)      (int32_t) ((x) * 524288.0L)
#endif
#ifndef  IQ18
#define   IQ18(x)      (int32_t) ((x) * 262144.0L)
#endif
#ifndef  IQ17
#define   IQ17(x)      (int32_t) ((x) * 131072.0L)
#endif
#ifndef  IQ16
#define   IQ16(x)      (int32_t) ((x) * 65536.0L)
#endif
#ifndef  IQ15
#define   IQ15(x)      (int32_t) ((x) * 32768.0L)
#endif
#ifndef  IQ14
#define   IQ14(x)      (int32_t) ((x) * 16384.0L)
#endif
#ifndef  IQ13
#define   IQ13(x)      (int32_t) ((x) * 8192.0L)
#endif
#ifndef  IQ12
#define   IQ12(x)      (int32_t) ((x) * 4096.0L)
#endif
#ifndef  IQ11
#define   IQ11(x)      (int32_t) ((x) * 2048.0L)
#endif
#ifndef  IQ10
#define   IQ10(x)      (int32_t) ((x) * 1024.0L)
#endif
#ifndef  IQ9
#define   IQ9(x)       (int32_t) ((x) * 512.0L)
#endif
#ifndef  IQ8
#define   IQ8(x)       (int32_t) ((x) * 256.0L)
#endif
#ifndef  IQ7
#define   IQ7(x)       (int32_t) ((x) * 128.0L)
#endif
#ifndef  IQ6
#define   IQ6(x)       (int32_t) ((x) * 64.0L)
#endif
#ifndef  IQ5
#define   IQ5(x)       (int32_t) ((x) * 32.0L)
#endif
#ifndef  IQ4
#define   IQ4(x)       (int32_t) ((x) * 16.0L)
#endif
#ifndef  IQ3
#define   IQ3(x)       (int32_t) ((x) * 8.0L)
#endif
#ifndef  IQ2
#define   IQ2(x)       (int32_t) ((x) * 4.0L)
#endif
#ifndef  IQ1
#define   IQ1(x)       (int32_t) ((x) * 2.0L)
#endif

#ifndef  IQ0
#define   IQ0(x)       (int32_t) ((x) * 1.0L)
#endif

#ifndef IQ24_1_K
#define IQ24_1_K          IQ24(1/CORDIC_K)
#endif

#define IQ24_1_SQRT3      IQ24(0.57735026918963)  // 1/sqrt(3) = 0.57735026918963
#define IQ24_SQRT_3_2     IQ24(1.2247)  // sqrt(3/2) = 1.2247
#define IQ24_SQRT_0_5     IQ24(0.707)  // 1/sqrt(2) = 0.707

#define Qabs(x)                     abs(x)

/*-------------------- typedef format ----------------------*/
#ifndef SH_DATATYPE_IQ
#define SH_DATATYPE_IQ
typedef int32_t   IQN;
typedef int32_t   IQ31;
typedef int32_t   IQ30;
typedef int32_t   IQ29;
typedef int32_t   IQ28;
typedef int32_t   IQ27;
typedef int32_t   IQ26;
typedef int32_t   IQ25;
typedef int32_t   IQ24;
typedef int32_t   IQ23;
typedef int32_t   IQ22;
typedef int32_t   IQ21;
typedef int32_t   IQ20;
typedef int32_t   IQ19;
typedef int32_t   IQ18;
typedef int32_t   IQ17;
typedef int32_t   IQ16;
typedef int32_t   IQ15;
typedef int32_t   IQ14;
typedef int32_t   IQ13;
typedef int32_t   IQ12;
typedef int32_t   IQ11;
typedef int32_t   IQ10;
typedef int32_t   IQ9;
typedef int32_t   IQ8;
typedef int32_t   IQ7;
typedef int32_t   IQ6;
typedef int32_t   IQ5;
typedef int32_t   IQ4;
typedef int32_t   IQ3;
typedef int32_t   IQ2;
typedef int32_t   IQ1;
#endif /*SH_DATATYPE_IQ*/


/*--------------------  IQ format multiplication ----------------------*/
#ifndef IQNmpy
#define IQNmpy(x, y, N)    ((IQN)((((int64_t)(x))*(y)) >> ((uint8_t)(N))))
#endif
#ifndef IQ31mpy
#define IQ31mpy(x, y)       IQNmpy(x, y, 31) 
#endif
#ifndef IQ30mpy
#define IQ30mpy(x, y)       IQNmpy(x, y, 30)
#endif
#ifndef IQ29mpy
#define IQ29mpy(x, y)       IQNmpy(x, y, 29) 
#endif
#ifndef IQ28mpy
#define IQ28mpy(x, y)       IQNmpy(x, y, 28)
#endif
#ifndef IQ27mpy
#define IQ27mpy(x, y)       IQNmpy(x, y, 27) 
#endif
#ifndef IQ26mpy
#define IQ26mpy(x, y)       IQNmpy(x, y, 26)
#endif
#ifndef IQ25mpy
#define IQ25mpy(x, y)       IQNmpy(x, y, 25) 
#endif
#ifndef IQ24mpy
#define IQ24mpy(x, y)       IQNmpy(x, y, 24)
#endif
#ifndef IQ23mpy
#define IQ23mpy(x, y)       IQNmpy(x, y, 23) 
#endif
#ifndef IQ22mpy
#define IQ22mpy(x, y)       IQNmpy(x, y, 22)
#endif
#ifndef IQ21mpy
#define IQ21mpy(x, y)       IQNmpy(x, y, 21) 
#endif
#ifndef IQ20mpy
#define IQ20mpy(x, y)       IQNmpy(x, y, 20)
#endif
#ifndef IQ19mpy
#define IQ19mpy(x, y)       IQNmpy(x, y, 19) 
#endif
#ifndef IQ18mpy
#define IQ18mpy(x, y)       IQNmpy(x, y, 18)
#endif
#ifndef IQ17mpy
#define IQ17mpy(x, y)       IQNmpy(x, y, 17) 
#endif
#ifndef IQ16mpy
#define IQ16mpy(x, y)       IQNmpy(x, y, 16)
#endif
#ifndef IQ15mpy
#define IQ15mpy(x, y)       IQNmpy(x, y, 15) 
#endif
#ifndef IQ14mpy
#define IQ14mpy(x, y)       IQNmpy(x, y, 14)
#endif
#ifndef IQ13mpy
#define IQ13mpy(x, y)       IQNmpy(x, y, 13) 
#endif
#ifndef IQ12mpy
#define IQ12mpy(x, y)       IQNmpy(x, y, 12)
#endif
#ifndef IQ11mpy
#define IQ11mpy(x, y)       IQNmpy(x, y, 11) 
#endif
#ifndef IQ10mpy
#define IQ10mpy(x, y)       IQNmpy(x, y, 10)
#endif
#ifndef IQ9mpy
#define IQ9mpy(x, y)         IQNmpy(x, y, 9) 
#endif
#ifndef IQ8mpy
#define IQ8mpy(x, y)         IQNmpy(x, y, 8)
#endif
#ifndef IQ7mpy
#define IQ7mpy(x, y)         IQNmpy(x, y, 7) 
#endif
#ifndef IQ6mpy
#define IQ6mpy(x, y)         IQNmpy(x, y, 6)
#endif
#ifndef IQ5mpy
#define IQ5mpy(x, y)         IQNmpy(x, y, 5) 
#endif
#ifndef IQ4mpy
#define IQ4mpy(x, y)         IQNmpy(x, y, 4)
#endif
#ifndef IQ3mpy
#define IQ3mpy(x, y)         IQNmpy(x, y, 3) 
#endif
#ifndef IQ2mpy
#define IQ2mpy(x, y)         IQNmpy(x, y, 2)
#endif
#ifndef IQ1mpy
#define IQ1mpy(x, y)         IQNmpy(x, y, 1) 
#endif
#ifndef IQ0mpy
#define IQ0mpy(x, y)         IQNmpy(x, y, 0) 
#endif

#ifndef IQNmpy1
#define IQNmpy1(x, y, N)    ((IQN)((((int64_t)(x))*(y)) >> ((uint8_t)(N))))
#endif
#ifndef IQ31mpy1
#define IQ31mpy1(x, y)       IQNmpy1(x, y, 31) 
#endif
#ifndef IQ30mpy1
#define IQ30mpy1(x, y)       IQNmpy1(x, y, 30)
#endif
#ifndef IQ29mpy1
#define IQ29mpy1(x, y)       IQNmpy1(x, y, 29) 
#endif
#ifndef IQ28mpy1
#define IQ28mpy1(x, y)       IQNmpy1(x, y, 28)
#endif
#ifndef IQ27mpy1
#define IQ27mpy1(x, y)       IQNmpy1(x, y, 27) 
#endif
#ifndef IQ26mpy1
#define IQ26mpy1(x, y)       IQNmpy1(x, y, 26)
#endif
#ifndef IQ25mpy1
#define IQ25mpy1(x, y)       IQNmpy1(x, y, 25) 
#endif
#ifndef IQ24mpy1
#define IQ24mpy1(x, y)       IQNmpy1(x, y, 24)
#endif
#ifndef IQ23mpy1
#define IQ23mpy1(x, y)       IQNmpy1(x, y, 23) 
#endif
#ifndef IQ22mpy1
#define IQ22mpy1(x, y)       IQNmpy1(x, y, 22)
#endif
#ifndef IQ21mpy1
#define IQ21mpy1(x, y)       IQNmpy1(x, y, 21) 
#endif
#ifndef IQ20mpy1
#define IQ20mpy1(x, y)       IQNmpy1(x, y, 20)
#endif
#ifndef IQ19mpy1
#define IQ19mpy1(x, y)       IQNmpy1(x, y, 19) 
#endif
#ifndef IQ18mpy1
#define IQ18mpy1(x, y)       IQNmpy1(x, y, 18)
#endif
#ifndef IQ17mpy1
#define IQ17mpy1(x, y)       IQNmpy1(x, y, 17) 
#endif
#ifndef IQ16mpy1
#define IQ16mpy1(x, y)       IQNmpy1(x, y, 16)
#endif
#ifndef IQ15mpy1
#define IQ15mpy1(x, y)       IQNmpy1(x, y, 15) 
#endif
#ifndef IQ14mpy1
#define IQ14mpy1(x, y)       IQNmpy1(x, y, 14)
#endif
#ifndef IQ13mpy1
#define IQ13mpy1(x, y)       IQNmpy1(x, y, 13) 
#endif
#ifndef IQ12mpy1
#define IQ12mpy1(x, y)       IQNmpy1(x, y, 12)
#endif
#ifndef IQ11mpy1
#define IQ11mpy1(x, y)       IQNmpy1(x, y, 11) 
#endif
#ifndef IQ10mpy1
#define IQ10mpy1(x, y)       IQNmpy1(x, y, 10)
#endif
#ifndef IQ9mpy1
#define IQ9mpy1(x, y)         IQNmpy1(x, y, 9) 
#endif
#ifndef IQ8mpy1
#define IQ8mpy1(x, y)         IQNmpy1(x, y, 8)
#endif
#ifndef IQ7mpy1
#define IQ7mpy1(x, y)         IQNmpy1(x, y, 7) 
#endif
#ifndef IQ6mpy1
#define IQ6mpy1(x, y)         IQNmpy1(x, y, 6)
#endif
#ifndef IQ5mpy1
#define IQ5mpy1(x, y)         IQNmpy1(x, y, 5) 
#endif
#ifndef IQ4mpy1
#define IQ4mpy1(x, y)         IQNmpy1(x, y, 4)
#endif
#ifndef IQ3mpy1
#define IQ3mpy1(x, y)         IQNmpy1(x, y, 3) 
#endif
#ifndef IQ2mpy1
#define IQ2mpy1(x, y)         IQNmpy1(x, y, 2)
#endif
#ifndef IQ1mpy1
#define IQ1mpy1(x, y)         IQNmpy1(x, y, 1) 
#endif
#ifndef IQ0mpy1
#define IQ0mpy1(x, y)         IQNmpy1(x, y, 0) 
#endif
/*--------------------  IQ format division ----------------------*/
IQN IQNdiv(IQN x, IQN y, uint8_t N);
IQN IQNdiv1(IQN x, IQN y, uint8_t N);

//#define IQNdiv(x, y, N)    ((IQN)(((int64_t)(x) << ((uint8_t)(N)) ) / (y)))
#define IQ31div(x, y)       IQNdiv(x, y, 31) 
#define IQ30div(x, y)       IQNdiv(x, y, 30)
#define IQ29div(x, y)       IQNdiv(x, y, 29) 
#define IQ28div(x, y)       IQNdiv(x, y, 28)
#define IQ27div(x, y)       IQNdiv(x, y, 27) 
#define IQ26div(x, y)       IQNdiv(x, y, 26)
#define IQ25div(x, y)       IQNdiv(x, y, 25) 
#define IQ24div(x, y)       IQNdiv(x, y, 24)
#define IQ23div(x, y)       IQNdiv(x, y, 23) 
#define IQ22div(x, y)       IQNdiv(x, y, 22)
#define IQ21div(x, y)       IQNdiv(x, y, 21) 
#define IQ20div(x, y)       IQNdiv(x, y, 20)
#define IQ19div(x, y)       IQNdiv(x, y, 19) 
#define IQ18div(x, y)       IQNdiv(x, y, 18)
#define IQ17div(x, y)       IQNdiv(x, y, 17) 
#define IQ16div(x, y)       IQNdiv(x, y, 16)
#define IQ15div(x, y)       IQNdiv(x, y, 15) 
#define IQ14div(x, y)       IQNdiv(x, y, 14)
#define IQ13div(x, y)       IQNdiv(x, y, 13) 
#define IQ12div(x, y)       IQNdiv(x, y, 12)
#define IQ11div(x, y)       IQNdiv(x, y, 11) 
#define IQ10div(x, y)       IQNdiv(x, y, 10)
#define IQ9div(x, y)         IQNdiv(x, y, 9) 
#define IQ8div(x, y)         IQNdiv(x, y, 8)
#define IQ7div(x, y)         IQNdiv(x, y, 7) 
#define IQ6div(x, y)         IQNdiv(x, y, 6)
#define IQ5div(x, y)         IQNdiv(x, y, 5) 
#define IQ4div(x, y)         IQNdiv(x, y, 4)
#define IQ3div(x, y)         IQNdiv(x, y, 3) 
#define IQ2div(x, y)         IQNdiv(x, y, 2)
#define IQ1div(x, y)         IQNdiv(x, y, 1) 
#define IQ0div(x, y)         IQNdiv(x, y, 0) 

#define IQ31div1(x,y)        IQNdiv1(x, y, 31)
#define IQ30div1(x,y)        IQNdiv1(x, y, 30)
#define IQ29div1(x,y)        IQNdiv1(x, y, 29)
#define IQ28div1(x,y)        IQNdiv1(x, y, 28)
#define IQ27div1(x,y)        IQNdiv1(x, y, 27)
#define IQ26div1(x,y)        IQNdiv1(x, y, 26)
#define IQ25div1(x,y)        IQNdiv1(x, y, 25)
#define IQ24div1(x,y)        IQNdiv1(x, y, 24)
#define IQ23div1(x,y)        IQNdiv1(x, y, 23)
#define IQ22div1(x,y)        IQNdiv1(x, y, 22)
#define IQ21div1(x,y)        IQNdiv1(x, y, 21)
#define IQ20div1(x,y)        IQNdiv1(x, y, 20)
#define IQ19div1(x,y)        IQNdiv1(x, y, 19)
#define IQ18div1(x,y)        IQNdiv1(x, y, 18)
#define IQ17div1(x,y)        IQNdiv1(x, y, 17)
#define IQ16div1(x,y)        IQNdiv1(x, y, 16)
#define IQ15div1(x,y)        IQNdiv1(x, y, 15)
#define IQ14div1(x,y)        IQNdiv1(x, y, 14)
#define IQ13div1(x,y)        IQNdiv1(x, y, 13)
#define IQ12div1(x,y)        IQNdiv1(x, y, 12)
#define IQ11div1(x,y)        IQNdiv1(x, y, 11)
#define IQ10div1(x,y)        IQNdiv1(x, y, 10)
#define IQ9div1(x,y)          IQNdiv1(x, y, 9)
#define IQ8div1(x,y)          IQNdiv1(x, y, 8)
#define IQ7div1(x,y)          IQNdiv1(x, y, 7)
#define IQ6div1(x,y)          IQNdiv1(x, y, 6)
#define IQ5div1(x,y)          IQNdiv1(x, y, 5)
#define IQ4div1(x,y)          IQNdiv1(x, y, 4)
#define IQ3div1(x,y)          IQNdiv1(x, y, 3)
#define IQ2div1(x,y)          IQNdiv1(x, y, 2)
#define IQ1div1(x,y)          IQNdiv1(x, y, 1)
#define IQ0div1(x,y)          IQNdiv1(x, y, 0)

/*--------------------  IQ format sin&cos ----------------------*/
typedef struct
{
    __IO IQN Sin;
    __IO IQN Cos;        
}TRIG_TypeDef;

TRIG_TypeDef IQNSinCos(IQN Theta, uint8_t QN);
TRIG_TypeDef IQNSinCos1(IQN Theta, uint8_t QN);

#define IQ31sincos(x)        IQNSinCos(x, 31)
#define IQ30sincos(x)        IQNSinCos(x, 30)
#define IQ29sincos(x)        IQNSinCos(x, 29)
#define IQ28sincos(x)        IQNSinCos(x, 28)
#define IQ27sincos(x)        IQNSinCos(x, 27)
#define IQ26sincos(x)        IQNSinCos(x, 26)
#define IQ25sincos(x)        IQNSinCos(x, 25)
#define IQ24sincos(x)        IQNSinCos(x, 24)
#define IQ23sincos(x)        IQNSinCos(x, 23)
#define IQ22sincos(x)        IQNSinCos(x, 22)
#define IQ21sincos(x)        IQNSinCos(x, 21)
#define IQ20sincos(x)        IQNSinCos(x, 20)
#define IQ19sincos(x)        IQNSinCos(x, 19)
#define IQ18sincos(x)        IQNSinCos(x, 18)
#define IQ17sincos(x)        IQNSinCos(x, 17)
#define IQ16sincos(x)        IQNSinCos(x, 16)
#define IQ15sincos(x)        IQNSinCos(x, 15)
#define IQ14sincos(x)        IQNSinCos(x, 14)
#define IQ13sincos(x)        IQNSinCos(x, 13)
#define IQ12sincos(x)        IQNSinCos(x, 12)
#define IQ11sincos(x)        IQNSinCos(x, 11)
#define IQ10sincos(x)        IQNSinCos(x, 10)
#define IQ9sincos(x)          IQNSinCos(x, 9)
#define IQ8sincos(x)          IQNSinCos(x, 8)
#define IQ7sincos(x)          IQNSinCos(x, 7)
#define IQ6sincos(x)          IQNSinCos(x, 6)
#define IQ5sincos(x)          IQNSinCos(x, 5)
#define IQ4sincos(x)          IQNSinCos(x, 4)
#define IQ3sincos(x)          IQNSinCos(x, 3)
#define IQ2sincos(x)          IQNSinCos(x, 2)
#define IQ1sincos(x)          IQNSinCos(x, 1)

#define IQ31sincos1(x)        IQNSinCos1(x, 31)
#define IQ30sincos1(x)        IQNSinCos1(x, 30)
#define IQ29sincos1(x)        IQNSinCos1(x, 29)
#define IQ28sincos1(x)        IQNSinCos1(x, 28)
#define IQ27sincos1(x)        IQNSinCos1(x, 27)
#define IQ26sincos1(x)        IQNSinCos1(x, 26)
#define IQ25sincos1(x)        IQNSinCos1(x, 25)
#define IQ24sincos1(x)        IQNSinCos1(x, 24)
#define IQ23sincos1(x)        IQNSinCos1(x, 23)
#define IQ22sincos1(x)        IQNSinCos1(x, 22)
#define IQ21sincos1(x)        IQNSinCos1(x, 21)
#define IQ20sincos1(x)        IQNSinCos1(x, 20)
#define IQ19sincos1(x)        IQNSinCos1(x, 19)
#define IQ18sincos1(x)        IQNSinCos1(x, 18)
#define IQ17sincos1(x)        IQNSinCos1(x, 17)
#define IQ16sincos1(x)        IQNSinCos1(x, 16)
#define IQ15sincos1(x)        IQNSinCos1(x, 15)
#define IQ14sincos1(x)        IQNSinCos1(x, 14)
#define IQ13sincos1(x)        IQNSinCos1(x, 13)
#define IQ12sincos1(x)        IQNSinCos1(x, 12)
#define IQ11sincos1(x)        IQNSinCos1(x, 11)
#define IQ10sincos1(x)        IQNSinCos1(x, 10)
#define IQ9sincos1(x)          IQNSinCos1(x, 9)
#define IQ8sincos1(x)          IQNSinCos1(x, 8)
#define IQ7sincos1(x)          IQNSinCos1(x, 7)
#define IQ6sincos1(x)          IQNSinCos1(x, 6)
#define IQ5sincos1(x)          IQNSinCos1(x, 5)
#define IQ4sincos1(x)          IQNSinCos1(x, 4)
#define IQ3sincos1(x)          IQNSinCos1(x, 3)
#define IQ2sincos1(x)          IQNSinCos1(x, 2)
#define IQ1sincos1(x)          IQNSinCos1(x, 1)
/*--------------------  IQ format atan ----------------------*/
IQN IQNatan(IQN X, uint8_t QN);

#define IQ31atan(x)            IQNatan(x, 31)
#define IQ30atan(x)            IQNatan(x, 30)
#define IQ29atan(x)            IQNatan(x, 29)
#define IQ28atan(x)            IQNatan(x, 28)
#define IQ27atan(x)            IQNatan(x, 27)
#define IQ26atan(x)            IQNatan(x, 26)
#define IQ25atan(x)            IQNatan(x, 25)
#define IQ24atan(x)            IQNatan(x, 24)
#define IQ23atan(x)            IQNatan(x, 23)
#define IQ22atan(x)            IQNatan(x, 22)
#define IQ21atan(x)            IQNatan(x, 21)
#define IQ20atan(x)            IQNatan(x, 20)
#define IQ19atan(x)            IQNatan(x,19)
#define IQ18atan(x)            IQNatan(x, 18)
#define IQ17atan(x)            IQNatan(x, 17)
#define IQ16atan(x)            IQNatan(x, 16)
#define IQ15atan(x)            IQNatan(x, 15)
#define IQ14atan(x)            IQNatan(x, 14)
#define IQ13atan(x)            IQNatan(x, 13)
#define IQ12atan(x)            IQNatan(x, 12)
#define IQ11atan(x)            IQNatan(x, 11)
#define IQ10atan(x)            IQNatan(x, 10)
#define IQ9atan(x)              IQNatan(x, 9)
#define IQ8atan(x)              IQNatan(x, 8)
#define IQ7atan(x)              IQNatan(x, 7)
#define IQ6atan(x)              IQNatan(x, 6)
#define IQ5atan(x)              IQNatan(x, 5)
#define IQ4atan(x)              IQNatan(x, 4)
#define IQ3atan(x)              IQNatan(x, 3)
#define IQ2atan(x)              IQNatan(x, 2)
#define IQ1atan(x)              IQNatan(x, 1)

/*--------------------  IQ format atan2 ----------------------*/
IQN IQNatan2(IQN X, IQN Y, uint8_t QN);

#define IQ31atan2(x, y)            IQNatan2(x, y, 31)
#define IQ30atan2(x, y)            IQNatan2(x, y, 30)
#define IQ29atan2(x, y)            IQNatan2(x, y, 29)
#define IQ28atan2(x, y)            IQNatan2(x, y, 28)
#define IQ27atan2(x, y)            IQNatan2(x, y, 27)
#define IQ26atan2(x, y)            IQNatan2(x, y, 26)
#define IQ25atan2(x, y)            IQNatan2(x, y, 25)
#define IQ24atan2(x, y)            IQNatan2(x, y, 24)
#define IQ23atan2(x, y)            IQNatan2(x, y, 23)
#define IQ22atan2(x, y)            IQNatan2(x, y, 22)
#define IQ21atan2(x, y)            IQNatan2(x, y, 21)
#define IQ20atan2(x, y)            IQNatan2(x, y, 20)
#define IQ19atan2(x, y)            IQNatan2(x, y,19)
#define IQ18atan2(x, y)            IQNatan2(x, y, 18)
#define IQ17atan2(x, y)            IQNatan2(x, y, 17)
#define IQ16atan2(x, y)            IQNatan2(x, y, 16)
#define IQ15atan2(x, y)            IQNatan2(x, y, 15)
#define IQ14atan2(x, y)            IQNatan2(x, y, 14)
#define IQ13atan2(x, y)            IQNatan2(x, y, 13)
#define IQ12atan2(x, y)            IQNatan2(x, y, 12)
#define IQ11atan2(x, y)            IQNatan2(x, y, 11)
#define IQ10atan2(x, y)            IQNatan2(x, y, 10)
#define IQ9atan2(x, y)              IQNatan2(x, y, 9)
#define IQ8atan2(x, y)              IQNatan2(x, y, 8)
#define IQ7atan2(x, y)              IQNatan2(x, y, 7)
#define IQ6atan2(x, y)              IQNatan2(x, y, 6)
#define IQ5atan2(x, y)              IQNatan2(x, y, 5)
#define IQ4atan2(x, y)              IQNatan2(x, y, 4)
#define IQ3atan2(x, y)              IQNatan2(x, y, 3)
#define IQ2atan2(x, y)              IQNatan2(x, y, 2)
#define IQ1atan2(x, y)              IQNatan2(x, y, 1)

/*-------------------- root mean square ----------------------*/
//IQN IQrms(IQN X, IQN Y);
//IQN IQrms1(IQN X, IQN Y);
//_iq MLIB_ThetaLimit(_iq theta);
//_iq MLIB_gAdd(_iq cur, _iq obj, _iq inc, _iq dec);	
//_iq MLIB_Slope(_iq cur,_iq xdn,_iq xup,_iq ydn,_iq yup);	
//_iq MLIB_Sat(_iq cur,_iq dnlimit,_iq uplimit);	

/*-------------------- mode ----------------------*/
IQN IQmode(IQN X, IQN Y);
IQN IQmode1(IQN X, IQN Y);

#endif 

