/**
  ******************************************************************************
  * @file    sh3xf2xx_sa0_macp.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    31-May-2021 
  * @brief   This file provides MACP APIs
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2021 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SA0_MACP_H
#define __SH3xF2xx_SA0_MACP_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sa0_lib.h"

/** @addtogroup SH3xF2xx_sa0_StdLib_Driver
  * @{
  */

/** @addtogroup MACP_MODULE
  * @{
  */ 

/** @defgroup MACP_Group_Constant  Public Constants
  * @{
  */ 
#ifndef IQ26_1_K
/*! IQ26_1_K constant */     
#define IQ26_1_K          ((IQ26)(0x026DD3B6))  
#endif

#ifndef IQ24_1_K
/*! IQ24_1_K constant */     
#define IQ24_1_K          ((IQ24)(0x009B74EE))
#endif

#ifndef IQ15_1_K
/*! IQ15_1_K constant */     
#define IQ15_1_K          ((IQ15)(0x004DBA))
#endif

#ifndef IQ26_1
/*! IQ26_1 constant */     
#define IQ26_1            ((IQ26)(0x3FFFFFF))          
#endif

#ifndef IQ24_1
/*! IQ24_1 constant */     
#define IQ24_1            ((IQ24)(0xFFFFFF))
#endif

#ifndef IQ15_1
/*! IQ15_1 constant */     
#define IQ15_1            ((IQ15)(0x7FFF))
#endif

#ifndef  C_IQ24_1_K
/*! IQ24_1_K constant */     
#define C_IQ24_1_K          ((IQ24)(0x009B74BC))	//((IQ24)(0x009B74EE))			// 0.60725 ൱1/Kڵµķ,IQ24(0.60725) = 0x 9B74BC, 2/29
#endif

#ifndef PI
/*! PI CONSTANT */
#define PI  3.141593
#endif
     
/*!  CORDIC K Adjust*/   
typedef enum
{
   CORDIC_KADJ_NONE = 0,  /*!< Result do nothing */
   CORDIC_KADJ_DIVK  = 1  /*!< Result /= K */   
}CORDIC_KADJ_Type;
/*! check CORDIC K adjust type */
#define IS_CORDIC_KADJ_TYPE(type) (((type) == CORDIC_KADJ_NONE) || ((type) == CORDIC_KADJ_DIVK))
     
/*!  CORDIC XY Adjust */   
typedef enum
{
   CORDIC_XYMRS_NONE = 0, /*!< X,Y do nothing */
   CORDIC_XYMRS_DIV2 = 1  /*!< X/=2 Y/=2 */   
}CORDIC_XYMRS_Type;
/*! check CORDIC XY adjust type */
#define IS_CORDIC_XYMRS_TYPE(type) (((type) == CORDIC_XYMRS_NONE) || ((type) == CORDIC_XYMRS_DIV2))

/*!  CORDIC data Format */   
typedef enum
{
   CORDIC_FMT_IQ26 = 0, /*!< IQ26 Format */
   CORDIC_FMT_IQ24 = 1, /*!< IQ24 Format */
   CORDIC_FMT_IQ15 = 2  /*!< IQ15 Format */
}CORDIC_FMT_Type;
/*! check CORDIC data format */
#define IS_CORDIC_FMT_TYPE(type) (((type) == CORDIC_FMT_IQ26) \
                               || ((type) == CORDIC_FMT_IQ24) \
                               || ((type) == CORDIC_FMT_IQ15))

/*!  CORDIC MODE */   
typedef enum
{
   CORDIC_MODE_ROTATE = 0, /*!< rotate conversion*/
   CORDIC_MODE_VECTOR = 1  /*!< vector conversion*/
}CORDIC_MODE_Type;
/*! check CORDIC transform mode */
#define IS_CORDIC_MODE_TYPE(type) (((type) == CORDIC_MODE_ROTATE) || ((type) == CORDIC_MODE_VECTOR))



/*!  IQDIV sign flag */   
typedef enum
{
   IQDIV_UNSIGNED = 0, /*!< unsigned IQ data*/
   IQDIV_SIGNED   = 1  /*!< signed IQ data is unsigned*/   
}IQDIV_Sign_Type;
/*! check IQDIV sign type */
#define IS_IQDIV_SIGN_TYPE(type) (((type) == IQDIV_UNSIGNED) || ((type) == IQDIV_SIGNED))

/*!  IQDIV approximate method */   
typedef enum
{
   IQDIV_CMOD_TRUNC = 0, /*!< use trucation method of last data */
   IQDIV_CMOD_ROUND = 1  /*!< use roung method of last data */
}IQDIV_CMOD_Type;
/*! check IQDIV CMOD type */
#define IS_IQDIV_CMOD_TYPE(type) (((type) == IQDIV_CMOD_TRUNC) || ((type) == IQDIV_CMOD_ROUND))


/*!  SVPWM  Type */   
typedef enum
{
    SVPWM_SVTYPE_7 = 0, /*!< 7 segment type */
    SVPWM_SVTYPE_5 = 1  /*!< 5 segment type */  
}SVPWM_SVTYPE_Type;
/*! check SVPWM  Type */
#define IS_SVPWM_SVTYPE_TYPE(type) (((type) == SVPWM_SVTYPE_7) || ((type) == SVPWM_SVTYPE_5))


/**
  * @}
  */ 

/** @defgroup MACP_Group_Types  Public Types
  * @{
  */   
#ifndef SH_DATATYPE_IQ
#define SH_DATATYPE_IQ
typedef int32_t   IQN;
typedef int32_t   IQ31;
typedef int32_t   IQ30;
typedef int32_t   IQ29;
typedef int32_t   IQ28;
typedef int32_t   IQ27;
typedef int32_t   IQ26;
typedef int32_t   IQ25;
typedef int32_t   IQ24;
typedef int32_t   IQ23;
typedef int32_t   IQ22;
typedef int32_t   IQ21;
typedef int32_t   IQ20;
typedef int32_t   IQ19;
typedef int32_t   IQ18;
typedef int32_t   IQ17;
typedef int32_t   IQ16;
typedef int32_t   IQ15;
typedef int32_t   IQ14;
typedef int32_t   IQ13;
typedef int32_t   IQ12;
typedef int32_t   IQ11;
typedef int32_t   IQ10;
typedef int32_t   IQ9;
typedef int32_t   IQ8;
typedef int32_t   IQ7;
typedef int32_t   IQ6;
typedef int32_t   IQ5;
typedef int32_t   IQ4;
typedef int32_t   IQ3;
typedef int32_t   IQ2;
typedef int32_t   IQ1;
#endif /*SH_DATATYPE_IQ*/

/*! @struct  CORDIC_TypeDef
  *  this structure for CORDIC device registers
  */      
typedef struct {
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  RUN       : 1;  /*!< run control bit */
            __I   uint32_t  OVF       : 1;  /*!< overflow flag */
            __IO  uint32_t  KADJ      : 1;  /*!< K value adjust @ref CORDIC_KADJ_Type*/
            __IO  uint32_t  XYMRS     : 1;  /*!< result adjust @ref CORDIC_XYMRS_Type*/
                  uint32_t  rev0      : 1;  /*!< reserved*/
            __IO  uint32_t  FORMAT    : 2;  /*!< Data format: @ref CORDIC_FMT_Type*/
            __IO  uint32_t  MODE      : 1;  /*!< Mode rotation or vector @ref CORDIC_MODE_Type*/
                  uint32_t  rev1      :24;  /*!< reserved*/
        }BIT;
    }CSR;                               /*!< 0000H */
    __IO uint32_t  OPRDX;               /*!< operation data X */
    __IO uint32_t  OPRDY;               /*!< operation data Y */
    __IO uint32_t  OPRDZ;               /*!< operation data Z */
}CORDIC_TypeDef;
/*! define CORDIC0 device pointer*/
#define CORDIC0  ((volatile CORDIC_TypeDef *)&(MACP->CORDCSR0.V32))
/*! define CORDIC1 device pointer*/
#define CORDIC1  ((volatile CORDIC_TypeDef *)&(MACP->CORDCSR1.V32))
/*! check CORDIC device pointer */
#define IS_CORDIC_MODULE(CORDICx) ((CORDICx == CORDIC0) || (CORDICx == CORDIC1))

/*! @struct  CORDIC_InitTypeDef
  *  CORDIC initial structure
  */  
typedef struct {
    uint32_t  RunCtrl          : 1;  /*!< run control bit : ENABLE or DISABLE */
    uint32_t  rev0             : 1;  /*!< reserved */
    uint32_t  KAdjust          : 1;  /*!< K value adjust @ref CORDIC_KADJ_Type*/
    uint32_t  XYAmplitude      : 1;  /*!< X,Y amplitude adjustment @ref CORDIC_XYMRS_Type*/
    uint32_t  rev1             : 1;  /*!< reserved*/
    uint32_t  Format           : 2;  /*!< Data format: @ref CORDIC_FMT_Type*/
    uint32_t  TransformMode    : 1;  /*!< Transform method: rotation or vector @ref CORDIC_MODE_Type*/
    uint32_t  rev              : 24;  /*!< Transform method: rotation or vector @ref CORDIC_MODE_Type*/
}CORDIC_InitTypeDef;

/*! @struct  CORDIC_DataTypeDef
  *  this structure for IQDIV device registers
  */  
typedef struct{
    int32_t X; /*!< Cordic opeartion data or result X */
    int32_t Y; /*!< Cordic opeartion data or result Y */
    int32_t Z; /*!< Cordic opeartion data or result Z */
}CORDIC_DataTypeDef;

/*! @struct  IQRotate_TypeDef
  *  this structure for IQRotate parameters
  */  
typedef struct{
    IQN    X;      /*!< X axis value */
    IQN    Y;      /*!< Y axis value */
    IQN    Angle;  /*!< rotate angle */
}IQRotate_TypeDef;

/*! @struct  IQVector_TypeDef
  *  this structure for IQVector parameters
  */ 
typedef struct{
    IQN    X;    /*!< X axis value */
    IQN    Y;    /*!< Y axis value */
    IQN    MOD;  /*!< root mean square */
    IQN    ATAN; /*!< direction of vector */
}IQVector_TypeDef;

/*! @struct  IQSinCos_TypeDef
  *  this structure for IQSinCos parameters
  */ 
typedef struct{
    IQN    Theta;   /*!< operation data: theta */
    IQN    SIN;     /*!< result: sine */
    IQN    COS;     /*!< result: cosine */
}IQSinCos_TypeDef; 

/*! @struct  PARK_TypeDef
  *  Park transform parameters
  */  
typedef struct {
	IQN  Alpha; /*!< operation data: Ialpha */
	IQN  Beta;  /*!< operation data: Ibeta  */
	IQN  Theta; /*!< operation data: theta  */   
    IQN  Id;	/*!< output : Id */		
    IQN  Iq;	/*!< output : Iq */		
}PARK_TypeDef;	

/*! @struct  IPARK_TypeDef
  *  IPark transform parameters
  */  
typedef struct {
    IQN  Ud;	/*!< operation data: Ud*/		
    IQN  Uq;	/*!< operation data: Uq */		
	IQN  Theta; /*!< operation data: theta */   
	IQN  Alpha; /*!< output : Ualpha */
	IQN  Beta;  /*!< output : Ubeta */
}IPARK_TypeDef;	


/*! @struct  IQDiv_DataTypeDef
  *  IQ division parameters
  */  
typedef struct {
    IQN Dividend;  /*!< operation data : Dividend*/
    IQN Divisor;   /*!< operation data : Divisor*/
    IQN Quotient;  /*!< result: quotient*/
}IQDiv_DataTypeDef;	

/*! @struct  IQDIV_TypeDef
  *  this structure for IQDIV device registers
  */      
typedef struct {
    union {
        __IO  uint32_t  V32;                /*!< 0000H */
        struct {
            __IO  uint32_t  RUN       : 1;  /*!< run control bit */
            __IO  uint32_t  SIGN      : 1;  /*!< sign mode select bit */
            __IO  uint32_t  SAT       : 1;  /*!< saturated flag */
            __IO  uint32_t  Q         : 5;  /*!< Q format selection */
            __IO  uint32_t  CMOD      : 1;  /*!< approximate method for result */
                  uint32_t  rev       :23;  /*!< reserved */
        }BIT;
    }CSR;                             /*!< Control and status */
    __IO uint32_t  DIVDND;            /*!< Dividend */
    __IO uint32_t  DIVSOR;            /*!< Divisor */
    __IO uint32_t  RLT;               /*!< Result */
}IQDIV_TypeDef;
/*! define IQDIV0 device pointer*/
#define IQDIV0  ((volatile IQDIV_TypeDef *)&(MACP->IQDIVCSR0.V32))
/*! define IQDIV1 device pointer*/
#define IQDIV1  ((volatile IQDIV_TypeDef *)&(MACP->IQDIVCSR1.V32))
/*! check IQDIV device pointer*/
#define IS_IQDIV_MODULE(DIVx) ((DIVx == IQDIV0) || (DIVx == IQDIV1))

/*! @struct  IQDIV_InitTypeDef
  *  IQDIV initial value structure
  */ 
typedef struct{
    uint32_t  RunCtrl           : 1;  /*!< run control bit */
    uint32_t  SignMode          : 1;  /*!< sign mode select bit @ref IQDIV_Sign_Type */
    uint32_t  SaturateFlag      : 1;  /*!< Saturated flag : SET or RESET */
    uint32_t  QFormat           : 5;  /*!< Q format selection 0~31 */
    uint32_t  ApproximateMethod : 1;  /*!< approximate method for result @ref IQDIV_CMOD_Type */
    uint32_t  rev               : 23;
}IQDIV_InitTypeDef;    

/*! @struct  SVPWM_DataTypeDef
  *  this structure for IQDIV device registers
  */  
typedef struct {
    IQ24  UAlpha;	 /*!< Input uAlpha */
	IQ24  UBeta;	 /*!< Input uBeta */		
	IQ24  Ta;        /*!< transform result Ta */
	IQ24  Tb;        /*!< transform result Tb */ 
	IQ24  Tc;        /*!< transform result Tc */ 
    uint16_t SVType; /*!< Input SVType :SVPWM_SVTYPE_7 or SVPWM_SVTYPE_5*/
    uint8_t  SVIQN;   /*!< IQ data format 0~31 */
    uint8_t  Sector;  /*!< transform result sector */ 
}SVPWM_DataTypeDef;



/**
  * @}
  */ 

/* Exported macro ------------------------------------------------------------*/
/** @defgroup MACP_Group_Macro  Public Macros
  * @{
  */ 

/** @defgroup MACP_IQMATH_Macro  IQ Match Macros
  * @{
  */ 

/** 
  *@brief  convert data to IQ26
  */
#ifndef IQ26
#define IQ26(X)   ((IQ26)(X*67108864))
#endif
/** 
  *@brief  convert data to IQ24
  */
#ifndef IQ24
#define IQ24(X)   ((IQ24)(X*16777216))
#endif
/** 
  *@brief  convert data to IQ15
  */
#ifndef IQ15 
#define IQ15(X)   ((IQ15)(X*32768))
#endif

/**
  * @verbatim   Example
       convert float (0.4) to IQ24 format data
       IQ24 X = IQn(0x666666,24);
       printf("Float:0.4 to IQ24:%X\n",(unsigned int)X);
  * @endverbatim  
  *@brief  convert data to IQn q=0~31
  */
#ifndef IQn
#define IQn(x,q)  ((IQN)(x*(1<<(q))))
#endif


/**
  * @verbatim   Example
       convert IQ24 format data to float data
       float f = IQnToFloat(0x666666,24);
       printf("IQ24:0x666666 to float:%f\n",f);
  * @endverbatim  
  *@brief  convert IQn data to float
  */
#ifndef IQnToFloat  
#define IQnToFloat(x,q) (((float)(((int32_t)((x)<<(31-q)))>>(31-q)))/((int32_t)1<<(q)))
#endif
/** 
  *@brief  IQ30 format data multiplication
  */
#ifndef IQ30mpy  
#define IQ30mpy(X, Y)   ((IQ30)(((int64_t)(((int64_t)(X))*((int64_t)(Y)))) >> 30))
#endif
/** 
  *@brief  IQ26 format data multiplication
  */
#ifndef IQ30mpy  
#define IQ26mpy(X, Y)   ((IQ26)(((int64_t)(((int64_t)(X))*((int64_t)(Y)))) >> 26))
#endif

/** 
  *@brief  IQ24 format data multiplication
  */
#ifndef IQ24mpy  
#define IQ24mpy(X, Y)   ((IQ24)(((int64_t)(((int64_t)(X))*((int64_t)(Y)))) >> 24))
#endif
/** 
  *@brief  IQ15 format data multiplication
  */
#ifndef IQ15mpy  
#define IQ15mpy(X, Y)   ((IQ24)(((int64_t)(((int64_t)(X))*((int64_t)(Y)))) >> 15))
#endif



/** 
  *@brief  IQ Rotate function
  */
#ifndef  IQRotate 
#define IQRotate(CORDICx,SinCosData) CORDIC_IQRotate(CORDICx,SinCosData)
#endif

/** 
  *@brief  IQ Vector function
  */
#ifndef IQVector
#define IQVector(CORDICx,SinCosData) CORDIC_IQVector(CORDICx,SinCosData)
#endif

/** 
  *@brief  IQ Sin Cos function
  */
#ifndef IQSinCos  
#define IQSinCos(CORDICx,SinCosData) CORDIC_IQSinCos(CORDICx,SinCosData)
#endif

/** 
  *@brief  IQ IPark Conversation
  */
#ifndef IQIPark  
#define IQIPark(CORDICx,IParkData) CORDIC_IQIPark(CORDICx,IParkData)
#endif

/** 
  *@brief  IQ Park Conversation
  */
#ifndef IQPark  
#define IQPark(CORDICx,ParkData) CORDIC_IQPark(CORDICx,ParkData)
#endif


/** 
  *@brief  IQ arctan = arctan(X);
  */
#ifndef IQAtan  
#define IQAtan(CORDICx,X) CORDIC_IQAtan(CORDICx, (X))
#endif
/** 
  *@brief  IQ arctan = arctan(Y/X);
  */
#ifndef IQAtan2  
#define IQAtan2(CORDICx,X,Y) CORDIC_IQAtan2(CORDICx, (X), (Y))
#endif

/** 
  *@brief  IQ division = X / Y;
  */
#ifndef IQDiv  
#define IQDiv(CORDICx,X,Y) IQDIV_IQDiv(CORDICx, (X), (Y))
#endif

/** 
  *@brief  IQ SVPWM  Input: alpha, beta  Output:Ta,Tb,Tc,Sector
  *        svdata : SVPWM_DataTypeDef
  */
#ifndef IQSvpwm  
#define IQSvpwm(svdata) SVPWM_Transform(svdata)
#endif



/**
  * @}
  */ 

/** 
  *@brief  set CORDIC format use CORDIC_FMT_Type
  *   @arg CORDIC_FMT_IQ26
  *   @arg CORDIC_FMT_IQ24
  *   @arg CORDIC_FMT_IQ15
  */
#define CORDIC_SetFormat(CORDICx,fmt)     ((CORDICx)->CSR.BIT.FORMAT = fmt)

/** 
  *@brief set CORDIC mode use CORDIC_MODE_Type
  *   @arg CORDIC_MODE_ROTATE
  *   @arg CORDIC_MODE_VECTOR  
  */
#define CORDIC_SetMode(CORDICx,mode)     ((CORDICx)->CSR.BIT.MODE = mode)

/** 
  *@brief set CORDIC XYMRS use CORDIC_XYMRS_Type
  *   @arg CORDIC_XYMRS_NONE
  *   @arg CORDIC_XYMRS_DIV2  
  */
#define CORDIC_SetXYMRS(CORDICx,xymrs)     ((CORDICx)->CSR.BIT.XYMRS = xymrs)

/** 
  *@brief set CORDIC mode use CORDIC_KADJ_Type
  *   @arg CORDIC_KADJ_NONE
  *   @arg CORDIC_KADJ_DIVK  
  */
#define CORDIC_SetKADJ(CORDICx,kadj)     ((CORDICx)->CSR.BIT.KADJ = kadj)


/** 
  *@brief  check CORDIC busy flag
  */
#define CORDIC_IS_BUSY(CORDICx)     ((CORDICx)->CSR.BIT.RUN)

/** 
  *@brief  check CORDIC Overflow flag
  */
#define CORDIC_IS_OVERFLOW(CORDICx)  ((CORDICx)->CSR.BIT.OVF)

/** 
  *@brief  start CORDIC
  */
#define CORDIC_START(CORDICx)     (CORDICx)->CSR.BIT.RUN = 1


/** 
  *@brief  check iqdiv busy flag
  */
#define IQDIV_IS_BUSY(DIVx)     ((DIVx)->CSR.BIT.RUN )

/** 
  *@brief  start IQDIV
  */
#define IQDIV_START(DIVx)     (DIVx)->CSR.BIT.RUN = 1


/** 
  *@brief check IQDIV saturate flag  
  */
#define IQDIV_IS_SATURATE(DIVx) ((DIVx)->CSR.BIT.SAT)

/** 
  *@brief  clear IQDIV saturate flag
  */
#define IQDIV_CLEAR_SAT(DIVx)     (DIVx)->CSR.BIT.SAT = 0


/** 
  *@brief  get IQDIV result
  */
#define IQDIV_GET_RESULT(DIVx)  ((DIVx)->RLT)


/** 
  *@brief  start IQDIV
  */
#define SVPWM_IS_BUSY()     (MACP->SVCON == 1)


/** 
  *@brief  start IQDIV
  */
#define SVPWM_START()        (MACP->SVCON = 1)

      
/**
  * @}
  */ 

/* Exported functions --------------------------------------------------------*/ 
/** @addtogroup MACP_Group_Pub_Funcs
  * @{
  */     


/* CORDIC functions --------------------------------------------------------*/ 
/** @addtogroup  MACP_Group_Cordic_Funcs
  * @{
  */

/* CORDIC Module Init */
void CORDIC_Init(CORDIC_TypeDef* CORDICx, const CORDIC_InitTypeDef* InitCfg);

/*Fills each InitStruct member with its default value*/
void CORDIC_StructInit(CORDIC_InitTypeDef* InitStruct);

/* Deinitializes the CORDICx registers to their default reset */
void CORDIC_Reset(CORDIC_TypeDef* CORDICx);

/*  CORDIC transform then return the result */
SH_Bool CORDIC_Transform(CORDIC_TypeDef* CORDICx, CORDIC_DataTypeDef* CordicData);

/* start CORDIC transform then return immediately */
void CORDIC_Run(CORDIC_TypeDef* CORDICx, CORDIC_DataTypeDef* CordicData);
   
/* get CORDIC result */
SH_Bool CORDIC_GetResult(CORDIC_TypeDef* CORDICx, CORDIC_DataTypeDef* CordicData);

/* coordinate(X,Y) rotate  transform */
SH_Bool CORDIC_IQRotate(CORDIC_TypeDef* CORDICx, IQRotate_TypeDef* RotateData);

/* coordinate(X,Y) vector  transform */
SH_Bool CORDIC_IQVector(CORDIC_TypeDef* CORDICx, IQVector_TypeDef* VectorData);


/* caculate IQ24 format sin and cos */
SH_Bool CORDIC_IQSinCos(CORDIC_TypeDef* CORDICx,IQSinCos_TypeDef* SinCosData);


/*  Park transform */  
SH_Bool CORDIC_IQPark(CORDIC_TypeDef* CORDICx,PARK_TypeDef* ParkData);


/*  IPark transform */  
SH_Bool CORDIC_IQIPark(CORDIC_TypeDef* CORDICx,IPARK_TypeDef* IParkData);

/* = arctan(X) */
IQN CORDIC_IQAtan(CORDIC_TypeDef* CORDICx, IQN X);

/* = arctan(Y/X) */
IQN CORDIC_IQAtan2(CORDIC_TypeDef* CORDICx, IQN X, IQN Y);


/**
  * @}
  */

/* CORDIC functions --------------------------------------------------------*/ 
/** @addtogroup  MACP_Group_IQDiv_Funcs
  * @{
  */



/* IQDIV Module Init */
void IQDIV_Init(IQDIV_TypeDef* IQDIVx, const IQDIV_InitTypeDef* InitCfg);

/*Fills each InitStruct member with its default value*/
void IQDIV_StructInit(IQDIV_InitTypeDef* InitStruct);

/* Deinitializes the IQDIVx registers to their default reset */
void IQDIV_Reset(IQDIV_TypeDef* IQDIVx);


/* transform then return the result */
IQN IQDIV_IQDiv(IQDIV_TypeDef* IQDIVx, IQN Dividend, IQN Divisor);

/* start IQDIV then return immediately */
void IQDIV_Div_Run(IQDIV_TypeDef* IQDIVx,IQN Dividend, IQN Divisor);
   

/* IQ division then return the result */
SH_Bool IQDIV_IQDiv2(IQDIV_TypeDef* IQDIVx, IQDiv_DataTypeDef* DivData);

/**
  * @}
  */

/** @addtogroup  MACP_Group_SVPWM_Funcs 
  * @{
  */

/* SVPWM transform */
void SVPWM_Transform(SVPWM_DataTypeDef* SVPWMData);

/**
  * @}
  */
     
     
/**
  * @}
  */ 


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SA0_MACP_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
