/**
  ******************************************************************************
  * @file    sh3xf2xx_sa0_IQmath.c
  * @author  sinowealth
  * @version V1.1.0
  * @date    31-May-2021 
  * @brief   This file provide MACP APIs
  *         
  *  @verbatim
  *
  *          ===================================================================
  *                                  How to use this driver
  *          ===================================================================
  *          
  *
  *  @endverbatim
  *
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2021 Sinowealth</center></h2>
  *
  ******************************************************************************
  */
/*==============================================================================
Function List :
             1: IQNdiv
             2: IQNSinCos
             3: IQNatan
             4: IQAtan2
             5: IQrms
==============================================================================*/

#include "sh3xf2xx_sa0_IQmath.h"
/******************************************************************************
* Function Name : IQNdiv
* Description       : caculate IQN format division
* Arguments        : x, y, N
* Return Value     : IQNSin&IQNCos
******************************************************************************/
#if   defined ( __CC_ARM )
#pragma arm section code = ".smo_est"
#endif

IQN IQNdiv(IQN x, IQN y, uint8_t N) 
{
    /* input IQN format Dividend */
    MACP->IQDIVDND1 = (uint32_t)x; 
    /* input IQN format Divsor */    
    MACP->IQDIVSOR1 = (uint32_t)y;
    /* input IQN */ 
    MACP->IQDIVCSR1.BIT.SIGN = 1;	
    MACP->IQDIVCSR1.BIT.Q = N;
    /* start division */
    MACP->IQDIVCSR1.BIT.RUN = 1;
    /* wait for division operation to end */ 
    while(MACP->IQDIVCSR1.BIT.RUN);  
    /* return result */    
    return (IQN)MACP->IQDIVRLT1;
}

#if   defined ( __CC_ARM )
#pragma arm section code = ".smo_est"
#endif

IQN IQNdiv1(IQN x, IQN y, uint8_t N) 
{
    /* input IQN format Dividend */
    MACP->IQDIVDND0 = (uint32_t)x; 
    /* input IQN format Divsor */    
    MACP->IQDIVSOR0 = (uint32_t)y;
    /* input IQN */ 
    MACP->IQDIVCSR0.BIT.SIGN = 1;		
    MACP->IQDIVCSR0.BIT.Q = N;
    /* start division */
    MACP->IQDIVCSR0.BIT.RUN = 1;
    /* wait for division operation to end */ 
    while(MACP->IQDIVCSR0.BIT.RUN);  
    /* return result */    
    return (IQN)MACP->IQDIVRLT0;
}
/******************************************************************************
* Function Name : IQNSinCos
* Description       : caculate IQN format sin and cos
* Arguments        : Theta
* Return Value     : IQNSin&IQNCos
******************************************************************************/
#if   defined ( __CC_ARM )
#pragma arm section code = ".smo_est"
#endif
TRIG_TypeDef IQNSinCos(IQN Theta, uint8_t QN)
{
    TRIG_TypeDef IQ24TtigTemp;
    
    /* set cordic mode(0:Rotation; 1:vector) */
    MACP->CORDCSR1.BIT.MODE = 0;    
	/* set cordic iteration number (00:26; 01:24,02:16) */
    MACP->CORDCSR1.BIT.FORMAT = 01;
    /* select cordic result (0:X&Y; 1:X/2&Y/2) */
    MACP->CORDCSR1.BIT.XYMRS = 0;   
    
    /* input 1/k */    
    MACP->OPRDX1 = IQ24_1_K;                // IQ24(1/k) K=1.6467602579
    /* input 0 */ 
    MACP->OPRDY1 = 0x0;    
    /* input IQ26 format theta */    
    MACP->OPRDZ1 = (uint32_t)(Theta<<(24 - QN));
     /* start cordic */
    MACP->CORDCSR1.BIT.RUN = 1;        
    /* wait for the Cordic operation to end */ 
    while(MACP->CORDCSR1.BIT.RUN);    
    /* read result */    
    IQ24TtigTemp.Cos = (IQN)MACP->OPRDX1; 
    IQ24TtigTemp.Sin = (IQN)MACP->OPRDY1; 
		
		IQ24TtigTemp.Cos >>= (24 - QN);
		IQ24TtigTemp.Sin >>= (24 - QN);		
    /* return result */
    return IQ24TtigTemp;   
}
#if   defined ( __CC_ARM )
#pragma arm section code = ".smo_est"
#endif
TRIG_TypeDef IQNSinCos1(IQN Theta, uint8_t QN)
{
    TRIG_TypeDef IQ24TtigTemp;
    
    /* set cordic mode(0:Rotation; 1:vector) */
    MACP->CORDCSR0.BIT.MODE = 0;    
	/* set cordic iteration number (00:26; 01:24,02:16) */
    MACP->CORDCSR0.BIT.FORMAT = 01;
    /* select cordic result (0:X&Y; 1:X/2&Y/2) */
    MACP->CORDCSR0.BIT.XYMRS = 0;   
    
    /* input 1/k */    
    MACP->OPRDX0 = IQ24_1_K;                // IQ24(1/k) K=1.6467602579
    /* input 0 */ 
    MACP->OPRDY0 = 0x0;    
    /* input IQ26 format theta */    
    MACP->OPRDZ0 = ((uint32_t)Theta<<(24 - QN));
     /* start cordic */
    MACP->CORDCSR0.BIT.RUN = 1;        
    /* wait for the Cordic operation to end */ 
    while(MACP->CORDCSR0.BIT.RUN);    
    /* read result */    
    IQ24TtigTemp.Cos = (IQN)MACP->OPRDX0; 
    IQ24TtigTemp.Sin = (IQN)MACP->OPRDY0; 

		IQ24TtigTemp.Cos >>= (24 - QN);
		IQ24TtigTemp.Sin >>= (24 - QN);		
    /* return result */
    return IQ24TtigTemp;   
}
/******************************************************************************
* Function Name : IQNatan
* Description       : caculate IQN format arctan, = atan(x)
* Arguments        : X,QN
* Return Value     : IQN format theta
******************************************************************************/
#if   defined ( __CC_ARM )
#pragma arm section code = ".smo_est"
#endif
IQN IQNatan(IQN X, uint8_t QN)
{    
    /* set cordic mode(0:Rotation; 1:vector) */
    MACP->CORDCSR0.BIT.MODE = 1;    
	/* set cordic iteration number (00:26; 01:24,02:16) */
    MACP->CORDCSR0.BIT.FORMAT = 01; 
    /* select cordic result (0:X&Y; 1:X/2&Y/2) */
    MACP->CORDCSR0.BIT.XYMRS = 0;   
    
    /* input 1/k */    
    MACP->OPRDX0 = (uint32_t) (1 << QN);                
    /* input 0 */ 
    MACP->OPRDY0 = (uint32_t)X;    
    /* input IQ26 format theta */    
    MACP->OPRDZ0 = 0;
    /* start cordic */
    MACP->CORDCSR0.BIT.RUN = 1;        
    /* wait for the Cordic operation to end */ 
    while(MACP->CORDCSR0.BIT.RUN);    

    /* return result */
    return (IQN)(MACP->OPRDZ0 >> (24 - QN));   
}

/******************************************************************************
* Function Name : IQNAtan2
* Description       : caculate IQN format atan, = arctan(Y/X)
* Arguments        : X,Y,QN
* Return Value     : IQN format theta
******************************************************************************/
#if   defined ( __CC_ARM )
#pragma arm section code = ".smo_est"
#endif
IQN IQNatan2(IQN X, IQN Y, uint8_t QN)
{    
    /* set cordic mode(0:Rotation; 1:vector) */
    MACP->CORDCSR0.BIT.MODE = 1;    
	/* set cordic iteration number (00:26; 01:24,02:16) */
    MACP->CORDCSR0.BIT.FORMAT = 01;
    /* select cordic result (0:X&Y; 1:X/2&Y/2) */
    MACP->CORDCSR0.BIT.XYMRS = 0;   
    
    /* input 1/k */    
    MACP->OPRDX0 = (uint32_t)X;                
    /* input 0 */ 
    MACP->OPRDY0 = (uint32_t)Y;    
    /* input IQ26 format theta */    
    MACP->OPRDZ0 = 0;
     /* start cordic */
    MACP->CORDCSR0.BIT.RUN = 1;        
    /* wait for the Cordic operation to end */ 
    while(MACP->CORDCSR0.BIT.RUN);    

    /* return result */
    return (IQN)(MACP->OPRDZ0 >> (24 - QN));   
}

/******************************************************************************
* Function Name : IQrms
* Description       : root mean square, result = sqrt(X^2 + Y^2)
* Arguments        : X,Y
* Return Value     : any IQN format
******************************************************************************/
#if   defined ( __CC_ARM )
#pragma arm section code = ".smo_est"
#endif
IQN IQmode(IQN X, IQN Y)
{    
    /* set cordic mode(0:Rotation; 1:vector) */
    MACP->CORDCSR1.BIT.MODE = 1;    
	/* set cordic iteration number (00:26; 01:24,02:16) */
    MACP->CORDCSR1.BIT.FORMAT = 01;
    /* select cordic result (0:X&Y; 1:X/2&Y/2) */
    MACP->CORDCSR1.BIT.XYMRS = 0;   
    
    /* input 1/k */    
    MACP->OPRDX1 = (uint32_t)X;                
    /* input 0 */ 
    MACP->OPRDY1 = (uint32_t)Y;    
    /* input IQ26 format theta */    
    MACP->OPRDZ1 = 0;
    /* start cordic */
    MACP->CORDCSR1.BIT.RUN = 1;        
    /* wait for the Cordic operation to end */ 
    while(MACP->CORDCSR1.BIT.RUN);    

    /* output */    
    X = IQ24mpy(MACP->OPRDX1, IQ24_1_K) ;
    /* return result */
    return X;   
}
#if   defined ( __CC_ARM )
#pragma arm section code = ".smo_est"
#endif
IQN IQmode1(IQN X, IQN Y)
{    
    /* set cordic mode(0:Rotation; 1:vector) */
    MACP->CORDCSR0.BIT.MODE = 1;    
	/* set cordic iteration number (00:26; 01:24,02:16) */
    MACP->CORDCSR0.BIT.FORMAT = 01;
    /* select cordic result (0:X&Y; 1:X/2&Y/2) */
    MACP->CORDCSR0.BIT.XYMRS = 0;   
    
    /* input 1/k */    
    MACP->OPRDX0 = (uint32_t)X;                
    /* input 0 */ 
    MACP->OPRDY0 = (uint32_t)Y;    
    /* input IQ26 format theta */    
    MACP->OPRDZ0 = 0;
    /* start cordic */
    MACP->CORDCSR0.BIT.RUN = 1;        
    /* wait for the Cordic operation to end */ 
    while(MACP->CORDCSR0.BIT.RUN);    

    /* output */    
    X = IQ24mpy(MACP->OPRDX0, IQ24_1_K) ;
    /* return result */
    return X;   
}

//#pragma arm section code = ".smo_est"
//IQN MLIB_ThetaLimit(IQN theta)
//{
////    IQN TempReg;
//    
////    TempReg = a + b;
//    if (theta > IQ24(1))
//    {
//        theta -= IQ24(2); 
//    }
//    else if (theta < IQ24(-1))
//    {
//        theta += IQ24(2); 
//    }
//    
//    return (theta);
//}	
///*=============================================================================
//																
//            Name:       MLIB_gAdd (in MotorLib.c)   
//            Function:   Gradual addition
//            Input:      current value, object
//                        step for increament and decreament 
//            Return:     next value             
//            date:       2014/9/5								
//=============================================================================*/
//#pragma arm section code = ".smo_est"
//IQN MLIB_gAdd(IQN cur, IQN obj, IQN inc, IQN dec)
//{
//    IQN TempReg;
//    
//    TempReg = cur;
//    if (cur < obj)
//    {
//        TempReg += inc; 
//        if (TempReg > obj)
//        {
//            TempReg = obj;	
//        }
//    }
//    else if (cur > obj)
//    {
//        TempReg -= dec;
//        if (TempReg < obj)
//        {
//            TempReg = obj;	
//        }
//    }
//    
//    return (TempReg);
//}

//#pragma arm section code = ".smo_est"
//IQN MLIB_Slope(IQN cur,IQN xdn,IQN xup,IQN ydn,IQN yup)
//{	
//	IQN temp;
//	if(cur <= xdn)
//	{
//		temp = ydn;
//	}
//	else if(cur >= xup)
//	{
//		temp = yup;		
//	}
//	else
//	{
//		temp = ydn + IQ24mpy(IQ24div(yup - ydn,xup - xdn),cur - xdn);
//	}	
//	return temp;
//	
//}

//#pragma arm section code = ".smo_est"
//IQN MLIB_Sat(IQN cur,IQN dnlimit,IQN uplimit)
//{	
//	IQN temp;
//	if(cur < dnlimit)
//	{
//		temp = dnlimit;
//	}
//	else if(cur > uplimit)
//	{
//		temp = uplimit;		
//	}	
//	else
//	{
//		temp = cur;
//	}
//	return temp;
//	
//}
