/**
  ******************************************************************************
  * @file    sh33f2811.h
  * @version V1.0
  * @date    07-March-2021
  * @brief   CMSIS CORE Device Peripheral Access Layer Header File.
  *          This file contains all the peripheral register's definitions, bits
  *          definitions and memory mapping for Sinowealth M3 based devices.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2021 Sinowealth
  *
  *
  ******************************************************************************
*/

#ifndef __SH33f2811_H__
#define __SH33f2811_H__

#ifndef __FPU_PRESENT
#define __FPU_PRESENT  1
#endif

#ifndef __DSP_PRESENT
#define __DSP_PRESENT  1 
#endif

#ifdef _RTE_
#include "RTE_Components.h"
#endif

#include "sh3xf2xx_sb0.h"

#ifdef SH_USE_PRJ_CFG        
#include "CFG33F2811.h"
#endif

#ifdef SH_USE_MODULE_LIB
#include "sh3xf2xx_sb0_lib.h"
#endif


/***************************************/
#define ROM_SIZE   0x20000
#define SRAM_SIZE  0x4000
#define ROM_BASE   0x0
#define SRAM_BASE  0x20000000
/***************************************/

#define IS_IN_SRAM(addr) ((((uint32_t)(addr)) >= SRAM_BASE) && (((uint32_t)(addr)) <= (SRAM_BASE+SRAM_SIZE)))
#define IS_IN_ROM(addr)  ((((uint32_t)(addr)) >= ROM_BASE)  && (((uint32_t)(addr)) <= (ROM_BASE+ROM_SIZE)))



/**************************************************/
/***********  COMMON FUNCTIONS ********************/
/**************************************************/
#ifndef CLR_WDT
#define CLR_WDT() IWDT->CLR=0xAAAA
#endif


/**********************************************************************************/  
#ifndef SH_MODULE_DBG_FUNCTIONS
#define SH_MODULE_DBG_FUNCTIONS

#ifdef _MODULE_DBG_PRINTF
#include <stdio.h>
#else
#include <stdio.h>
/** @brief  Bypass the printf function to save code size */
#define printf(...) ((void)0)
#endif /*_MODULE_DBG_PRINTF*/

#ifdef DEFAULT_ASSERT_ENABLE

#ifdef _MODULE_DBG_PRINTF
#define assert_failed(file, line) printf("assert failed:%s (%d)\n",file,(int)line)
#else
#define assert_failed(file, line) __BKPT(0)
#endif

/** @brief  assert for function's input parameters. Enable or disable it by the macro _DEBUG  at compile time*/
#define assert_param(expr) if(!(expr)) assert_failed((uint8_t*)__FILE__,(uint32_t)__LINE__)
/** @brief  break the program at the assert  failed satement . Enable or disable it by the macro _DEBUG at compile time */
#define assert_break(expr) if(!(expr)){ __BKPT(0);}
/** @brief  define the assert failed actions here. Enable or disable it by the macro _DEBUG  at compile time */

#else /*DEFAULT_ASSERT_ENABLE*/
/** @brief  assert for function's input parameters. Enable or disable it by the macro _DEBUG  at compile time*/
#define assert_param(expr) ((void)0)
/** @brief  break the program at the assert  failed satement . Enable or disable it by the macro _DEBUG at compile time */
#define assert_break(expr) ((void)0)

#endif /* DEFAULT_ASSERT_ENABLE*/
#endif /*SH_MODULE_DBG_FUNCTIONS*/
/**********************************************************************************/  

#endif /*__SH33F2811_H__*/
