/**
  ******************************************************************************
  * @file    system_sh3xf2xx_sb0.c
  * @author  sinowealth
  * @version V1.0.0
  * @date    07-March-2021 
  * @brief   This file provide system clock config
  *         
  *  @verbatim
  *
  *          ======================================================
  *                                   How to use this driver
  *          ======================================================
  * 1. Modify the file sh32f2xx_config.h, which in the project folder.
  *     -Modify the System Clock setting as the requirement
  * 2. This function will complete the RCC register's option by the configuration
  *  @endverbatim
  *
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2021 Sinowealth
  *
  ******************************************************************************
  */
  

  
/* Includes ------------------------------------------------------------------*/
#include "system_sh3xf2xx_sb0.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @defgroup System_Group  System Configuration 
  * @brief System Clock Configuration Function
  * @{
  */ 

/** @defgroup System_Group_Funcs  Private Functions
  * @{
  */ 

#ifdef DEFAULT_SYSTEMINIT    
/** 
   *@brief    System Init function, called by startup file
  * @retval   None
  */
void SystemInit(void)
{
	/***** ============= SET SYSTEM CLOCK ============ ****/
	RCC->RCCLOCK = 0x33CC;
  FLASH->ACR.V32 = (uint32_t)(0x5aa5<<16)
                 | (FLASH_LATENCY << FLASH_ACR_LATENCY_Pos) 
                 | (DCACHE_EN     << FLASH_ACR_DCEN_Pos)
                 | (PREFETCH_EN   << FLASH_ACR_PRFTEN_Pos);
  __DSB();

#if (CLK_SRC == 1)||(PLL_CLK_SRC == 1)
//HSE Enable
	RCC->AHBENR.BIT.SYSCFGEN = 1;
	SYSCFG->SAFR.V32 = ((uint32_t)0x5AA5<<16)|(1<<0);
	RCC->CR.BIT.HSEON = 1;
	while(RCC->CR.BIT.HSERDY == 0){CLR_WDT();}	
#endif	

	RCC->CFGR.V32 = (uint32_t)(PLL_XTPRE    <<RCC_CFGR_PLLXTPRE_Pos) 
	                          |(PLL_CLK_SRC <<RCC_CFGR_PLLSRC_Pos)
	                          |((PLL_MUL-15)<<RCC_CFGR_PLLF_Pos)
	                          |((PLL_DIV-1) <<RCC_CFGR_PLLK_Pos)
	                          |(CLK_AHB     <<RCC_CFGR_HPRE_Pos)
	                          |(CLK_APB0    <<RCC_CFGR_PPRE_Pos);
#if PLL_EN == 1
	RCC->CR.BIT.PLLON = 1;
	while(RCC->CR.BIT.PLLRDY == 0){CLR_WDT();}				
#endif	
	
	// Switch to clock source
	RCC->CR.BIT.SW = CLK_SRC;
	while(RCC->CR.BIT.SWS != CLK_SRC){CLR_WDT();}
		
	
	/***** =========================================== ****/
	
#if defined (__VTOR_PRESENT) && (__VTOR_PRESENT == 1U)
  SCB->VTOR = (uint32_t) &__Vectors;
#endif

#if defined (__FPU_USED) && (__FPU_USED == 1U)
  SCB->CPACR |= ((3U << 10U*2U) |           /* enable CP10 Full Access */
                 (3U << 11U*2U)  );         /* enable CP11 Full Access */
#endif

#ifdef UNALIGNED_SUPPORT_DISABLE
  SCB->CCR |= SCB_CCR_UNALIGN_TRP_Msk;
#endif

#if defined (__ARM_FEATURE_CMSE) && (__ARM_FEATURE_CMSE == 3U)
  TZ_SAU_Setup();
#endif      
}

#endif

/**
  * @}
  */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/


