/*
            Copyright(C) 1997-2020.  Sinowealth Tech. Co., Ltd.
********************************************************************************
* @file    CFG33F2811.c 
* @author  
* @version V1.1.0
* @date    6-May-2022
* @brief   Keil configuration Wizard file.
********************************************************************************
*/
#include "CFG33F2811.h"
#include <sh33f2811.h>


#ifdef _MODULE_DBG_PRINTF

void flush_printfbuffer(void);
#if defined ( __CC_ARM )
struct __FILE { int handle; /* Add whatever you need here */ };
FILE __stdout;
FILE __stdin;
#elif defined(__ICCARM__)
struct __FILE { int handle; /* Add whatever you need here */ };
typedef struct __FILE FILE;
FILE __stdout;
FILE __stdin;
#endif
  
#include <stdio.h>



/**
  * @brief    retarget initial function, parameters defined in sh32f2xx_config.h 
  * \n  1. initial the retarget device
  * \n  2. can be selected as ITM or UART
  * @retval  None
  */
void RetargetInit(void)
{
#ifdef _DBG_DEVICE_UART
  	uint32_t sbrt;
    uint32_t fine;
    uint32_t module_clk = (SYS_CLK >> (CLK_APB0));

	
    /* Enable Clock Gates */
		RCC->RCCLOCK = 0x33CC;	
	  RCC->AHBENR.BIT.GPIOEN = 1;
	  PTN_DBG_UART_CLKGATE();

		/* IO CONFIG IN NEED in periph_init */
	  /* GPIO Config */
    PTN_DBG_UART_IOAF();
		PTN_DBG_UART->CR.BIT.SBRTEN = 1;
	  PTN_DBG_UART->CR.BIT.SM = 1;
    sbrt = module_clk /16/ PTN_DBG_UART_BAUDRATE-1;
    fine = module_clk / PTN_DBG_UART_BAUDRATE - (16*(sbrt+1));    
    
    PTN_DBG_UART->BRT.BIT.SBRT = sbrt;
    PTN_DBG_UART->BRT.BIT.BFINE = fine;//10;//0;
    
    PTN_DBG_UART->FR.BIT.RIC = 1;
    PTN_DBG_UART->CR.BIT.RIE = 0;   
    PTN_DBG_UART->CR.BIT.TIE = 0;   
    PTN_DBG_UART->CR.BIT.REN = 1;   
    PTN_DBG_UART->CR.BIT.TEN = 1;   
 		
#endif    
}


#ifdef _DBG_DEVICE_UART
/**
  * @brief send data to UART
  * @param ch: data to transmit
  * @retval  uint8_t data to transmit
  */
static uint8_t dbg_uart_send(uint8_t ch)
{
   while(PTN_DBG_UART->FR.BIT.TI == 0)
   {
        CLR_WDT();
   }
	 PTN_DBG_UART->TDR.BIT.TDR = ch;
   return (ch);
}   

/**
  * @brief read data from to UART
  * @retval  uint8_t data readed
  */
static uint8_t dbg_uart_read()
{
	 while(PTN_DBG_UART->FR.BIT.RI == 0)
   {
       CLR_WDT();
   }        
   return (uint8_t)PTN_DBG_UART->RDR.BIT.RDR;
}
  
#endif 
    

/**
  * @brief    output character function
  * @param  ch  output character
  * @param  f   file handle
  * @retval  int   outputted character
  */
int fputc(int ch, FILE *f) 
{  

#if !defined(__GNUC__)   
    f = f;
#else
    f = 0;
#endif  

#ifdef _DBG_DEVICE_UART
   if(ch == '\n'){
       dbg_uart_send('\r');
   }
   return (int)dbg_uart_send((uint8_t)ch);
#endif  
}

/**
  * @brief    input retarget
  * @param  f  file handle
  * @retval  int character which read
  */
int fgetc(FILE *f) 
{
  char ch;
#if !defined(__GNUC__)   
    f = f;
#else
    f = 0;
#endif  

#ifdef _DBG_DEVICE_UART
  ch = dbg_uart_read();
  dbg_uart_send(ch);
  if(ch == '\r')
     dbg_uart_send('\n');
#endif 
   return ch;
}
#if defined(__ICCARM__)

#ifdef _DBG_DEVICE_UART
/*! for replace the function in getchar.o */
int _UngetChar(void)
{
    return 0;
}
/*! for replace the function in getchar.o */
int __ungetchar(int a)
{
    return 0;
}
/**
  * @brief  replace the function getchar for IAR scanf
  * @retval  int data readed from input device
  */
int getchar(void)
{
   char ch = dbg_uart_read();
   dbg_uart_send(ch);
   if(ch == '\r')
      dbg_uart_send('\n');
   return (int)ch;
}

/**
  * @brief  replace the function putchar for IAR printf
  * @param ch data to output device
  * @retval  int data to output device
  */
int putchar(int ch) 
{  
   if(ch == '\n')
   {
       dbg_uart_send('\r');
   }
   return (int)dbg_uart_send(ch);
}
#endif /*_DBG_DEVICE_UART*/

#endif /*__ICCARM__*/



#if defined(__GNUC__)

#if !defined(__CC_ARM)
/**
  * @brief  provide the function for GCC printf
  * @param  fd: file pointer no used
  * @param  pBuffer data buffer
  * @param  size data buffer size
  * @retval int outputted data size
  */
extern int _write (int fd, char *pBuffer, int size);
int _write (int fd, char *pBuffer, int size)  
{  
   int i;
   fd = 0;
#ifdef _DBG_DEVICE_UART   
   for (i = 0; i < size; i++)  
   {  
      if(pBuffer[i] == '\n')
      {
        dbg_uart_send('\r');
      }
      dbg_uart_send(pBuffer[i]);
   }     
#endif   
   return size;  
}  

/**
  * @brief  provide the function for GCC scanf
  * @param  fd: file pointer no used
  * @param  pBuffer data buffer
  * @param  size data buffer size
  * @retval int readed data size
  */
extern int _read (int fd, char *pBuffer, int size);  
int _read (int fd, char *pBuffer, int size)  
{  
    int i; 
    fd = 0;
#ifdef _DBG_DEVICE_UART
    for(i = 0; i < size; i++)
    {
        pBuffer[i]=dbg_uart_read();
        dbg_uart_send(pBuffer[i]);
        if(pBuffer[i] == '\r')
        {
            dbg_uart_send('\n');
            i += 1;
            pBuffer[i]='\n';
            i++;
            break;
        }
    }    
#endif    
   return i;  
}      

/*! flush printf buffer to output device */
void flush_printfbuffer(void)
{
    fflush(0);
}
#endif

#endif  /* __GNUC__ */
  
#endif /* _MODULE_DBG_PRINTF */

void Peripherals_InitCfg(void)
{
	NVIC_InitCfg();

#if CFG_SYSTICK_EN	
	SysTick_InitCfg();
#endif	
	
#if CFG_SYSCFG_EN	
	SYSCFG_InitCfg();
#endif	
	
#if CFG_IWDT_EN
	IWDT_InitCfg();
	CLR_WDT();	
#endif 
	
#if CFG_WWDT_EN
	WWDT_InitCfg();
#endif 
	
#if CFG_GPIO_EN
	GPIO_InitCfg();
#endif 	

#if CFG_EXTI_EN	
	EXTI_InitCfg();
#endif

#if CFG_MCM_EN	
	MCM_InitCfg();
#endif	

#if CFG_PCA_EN	
	PCA_InitCfg();
#endif	

#if CFG_TIM_EN
	TIM_InitCfg();
#endif 

#if CFG_MACP_EN
	MACP_InitCfg();
#endif 
	
#if CFG_ADC_EN	
	ADC_InitCfg();
#endif	
	
#if CFG_QEI_EN
	QEI_InitCfg();
#endif 

#if CFG_AMOC_EN	
	AMOC_InitCfg();
#endif	
	
#if CFG_UART_EN	
	UART_InitCfg();
#endif

#if CFG_SPI_EN	
	SPI_InitCfg();
#endif	
	
#if CFG_TWI_EN	
	TWI_InitCfg();
#endif

#if CFG_CAN_EN	
	CAN_InitCfg();
#endif

#if CFG_FIFO0_EN	
	FIFO0_InitCfg();
#endif

#if CFG_FIFO1_EN	
	FIFO1_InitCfg();
#endif

#if CFG_FIFO2_EN	
	FIFO2_InitCfg();
#endif

}

#if CFG_SYSCFG_EN
void SYSCFG_InitCfg(void)
{
	//Enable SYSCFG Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.SYSCFGEN = 1;
  RCC_WriteDisable();	
	
	//Set the registers
	SYSCFG->PWRCR.V32 = CFG_SYSCFG_PWRCR_INIT;
  SYSCFG->SAFR.V32  = (0x5AA50000UL) | CFG_SYSCFG_SAFR_INIT;
  SYSCFG->DBGCR.V32 = (0x5AA50000UL) | CFG_SYSCFG_DBGCR_INIT;

}
#endif

void IWDT_InitCfg(void)
{
	//Set the registers
	IWDT->CR.V32 = (0x5AA5<<16) | CFG_IWDTRLR_INIT | CFG_IWDTPR_INIT;	
}

void WWDT_InitCfg(void)
{
	//Enable WWDT Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.WWDTEN = 1;
  RCC_WriteDisable();	
	
	//Set the registers
	WWDT->CR.V32 = (0x5AA5<<16) | CFG_WWDT_CR_INIT;
	WWDT->WTR.V32 = (0x5AA5<<16) | CFG_WWDT_WTR_INIT;
}

void GPIO_InitCfg(void)
{
  //Enable GPIO Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.GPIOEN = 1;
  RCC_WriteDisable();
	
#if CFG_GPIOA_EN
	//Set the registers
	GPIOA->ODR = CFG_GPIO_ODR_A_INIT;
	GPIOA->MODER.V32 = CFG_GPIO_MODER_A_INIT;
	GPIOA->OTYPER.V32 = CFG_GPIO_OTYPER_A_INIT;
	GPIOA->PUPDR.V32 = CFG_GPIO_PUPDR_A_INIT;
	GPIOA->AFRL.V32 = CFG_GPIO_AFRL_A_INIT;
	GPIOA->AFRH.V32 = CFG_GPIO_AFRH_A_INIT;
	GPIOA->IE.V32 = CFG_GPIO_IE_A_INIT;
	GPIOA->TTLEN.V32 = CFG_GPIO_TTLEN_A_INIT;
	GPIOA->LCKR.V32 = CFG_GPIO_LCKR_A_INIT;
#endif

#if CFG_GPIOB_EN
	//Set the registers
	GPIOB->ODR = CFG_GPIO_ODR_B_INIT;
	GPIOB->MODER.V32 = CFG_GPIO_MODER_B_INIT;
	GPIOB->PUPDR.V32 = CFG_GPIO_PUPDR_B_INIT;
	GPIOB->AFRL.V32 = CFG_GPIO_AFRL_B_INIT;
	GPIOB->AFRH.V32 = CFG_GPIO_AFRH_B_INIT;
	GPIOB->IE.V32 = CFG_GPIO_IE_B_INIT;
	GPIOB->LCKR.V32 = CFG_GPIO_LCKR_B_INIT;
#endif

#if CFG_GPIOC_EN
	//Set the registers
	GPIOC->ODR = CFG_GPIO_ODR_C_INIT;
	GPIOC->MODER.V32 = CFG_GPIO_MODER_C_INIT;
	GPIOC->PUPDR.V32 = CFG_GPIO_PUPDR_C_INIT;
	GPIOC->AFRL.V32 = CFG_GPIO_AFRL_C_INIT;
	GPIOC->AFRH.V32 = CFG_GPIO_AFRH_C_INIT;
	GPIOC->IE.V32 = CFG_GPIO_IE_C_INIT;
	GPIOC->TTLEN.V32 = CFG_GPIO_TTLEN_C_INIT;
	GPIOC->LCKR.V32 = CFG_GPIO_LCKR_C_INIT;
#endif

}


void EXTI_InitCfg(void)
{
	//Set the registers
	EXTI->IMR = CFG_EXTI_IMR_INIT;
	EXTI->EMR = CFG_EXTI_EMR_INIT;
	EXTI->TMSR = CFG_EXTI_TMSR_INIT;
	EXTI->RTSR = CFG_EXTI_RTSR_INIT;
	EXTI->FTSR = CFG_EXTI_FTSR_INIT;
	EXTI->CFG.V32 = CFG_EXTI_CFG_INIT;
	EXTI->SAMP.V32 = CFG_EXTI_SAMP_INIT;
}

void MCM_InitCfg(void)
{
	//Enable MCM Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.MCMEN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	MCM->PWMRLDEN = 0x55;
	
	MCM->PWMCON1.V32 = CFG_MCM_PWMCON1_INIT;
	MCM->PWMCON2.V32 = CFG_MCM_PWMCON2_INIT;	
	
	MCM->PWMP = CFG_MCM_PWMP_INIT;
	MCM->PWM0D = CFG_MCM_PWM0D_INIT;
	MCM->PWM1D = CFG_MCM_PWM1D_INIT;
	MCM->PWM2D = CFG_MCM_PWM2D_INIT;
	MCM->PWM01D = CFG_MCM_PWM01D_INIT; 
	MCM->PWM11D = CFG_MCM_PWM11D_INIT; 
	MCM->PWM21D = CFG_MCM_PWM21D_INIT; 

	MCM->PWMDT21	= CFG_MCM_PWMDT21_INIT;
	MCM->PWMDT20	= CFG_MCM_PWMDT20_INIT;
	MCM->PWMDT11	= CFG_MCM_PWMDT11_INIT;
	MCM->PWMDT10	= CFG_MCM_PWMDT10_INIT;
	MCM->PWMDT01	= CFG_MCM_PWMDT01_INIT;
	MCM->PWMDT00	= CFG_MCM_PWMDT00_INIT;
	
	MCM->PWMPSQ = CFG_MCM_PWMPSQ_INIT;
	
	MCM->PMANUALCON1.V32 = CFG_MCM_PMANUALCON1_INIT;
	MCM->PMANUALCON2.V32 = CFG_MCM_PMANUALCON2_INIT;	
		
	MCM->PWMCMP1 = CFG_MCM_PWMCMP1_INIT;
	MCM->PWMCMP2 = CFG_MCM_PWMCMP2_INIT;
	MCM->PWMCMP3 = CFG_MCM_PWMCMP3_INIT;
	MCM->PWMCMP4 = CFG_MCM_PWMCMP4_INIT;
	
	MCM->PWMINTEN.V32 = CFG_MCM_PWMINTEN_INIT;
	MCM->PSCON.V32 = CFG_MCM_PSCON_INIT;	
	MCM->PWMDMAX = CFG_MCM_PWMDMAX_INIT;	
	MCM->PWMDMIN = CFG_MCM_PWMDMIN_INIT;	
	MCM->PWMDCMP1 = CFG_MCM_PWMDCMP1_INIT;
	MCM->PWMDCMP2 = CFG_MCM_PWMDCMP2_INIT;
	
	MCM->SC0CON.V32 = CFG_MCM_SC0CON_INIT;
	MCM->SC1CON.V32 = CFG_MCM_SC1CON_INIT;
	MCM->SC2CON.V32 = CFG_MCM_SC2CON_INIT;

	MCM->FLTWEN = 0x33CC;
	MCM->FLTCON.V32 = CFG_MCM_FLTCON_INIT;
	MCM->POSCR.V32 = CFG_MCM_POSCR_INIT;	
	MCM->POSTDCR.V32 = CFG_MCM_POSTDCR_INIT;
	MCM->FLTWEN = 0x0000;
	MCM->PWMOE = CFG_MCM_PWMOE;
	MCM->PWMRLDEN = 0xAA;
}



void MACP_InitCfg()
{
	//Enable MACP Clock
	RCC_WriteEnable();
  RCC->AHBENR.BIT.MACPEN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	MACP->CORDCSR0.V32 = CFG_MACP_CORDCSR0_INIT;	
	MACP->CORDCSR1.V32 = CFG_MACP_CORDCSR1_INIT;
	MACP->SVUALPHA = CFG_MACP_SVUALPHA_INIT;
	MACP->SVUBETA = CFG_MACP_SVUBETA_INIT;
	MACP->SVIQN.V32 = CFG_MACP_SVIQN_INIT;
}



void TIM_InitCfg(void)
{

#if CFG_TIM7_EN
	//Enable TIM7 Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.TIM7EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	TIM7->TCNT.V32 = CFG_TIM7_TCNT_INIT;
	TIM7->TPR.V32 = CFG_TIM7_TPR_INIT;
	TIM7->PSQ.V32 = CFG_TIM7_PSQ_INIT;	
	TIM7->CR.V32 = (CFG_TIM7_CR_START) |CFG_TIM7_CR_INIT;
#endif

#if CFG_TIM8_EN
	//Enable TIM8 Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.TIM8EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	TIM8->TCNT.V32 = CFG_TIM8_TCNT_INIT;
	TIM8->TPR.V32 = CFG_TIM8_TPR_INIT;
	TIM8->PSQ.V32 = CFG_TIM8_PSQ_INIT;	
	TIM8->CR.V32 = (CFG_TIM8_CR_START) |CFG_TIM8_CR_INIT;
#endif

#if CFG_TIM78_EN
	//Enable TIM7/8 Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.TIM7EN = 1;
  RCC->APB0ENR.BIT.TIM8EN = 1;	
  RCC_WriteDisable();
	
	//Set the registers
	TIM7->CR.V32 = CFG_TIM78_CR_INIT;
	TIM7->TCNT.V32 = CFG_TIM78_TCNT_INIT;
	TIM7->TPR.V32 = CFG_TIM78_TPR_INIT;
	TIM7->PSQ.V32 = CFG_TIM78_PSQ_INIT;		
	TIM7->CR.V32 |= CFG_TIM78_CR_START;
#endif
}

void ADC_InitCfg(void)
{
#if CFG_ADC_EN
  //Enable ADC1 Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.ADCEN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	ADC->ADCON1.BIT.ADSOC = 0;
	ADC->ADCON2.V32 = CFG_ADC_ADCON2_INIT;
	ADC->ADCMPCON.V32 = CFG_ADC_ADCMPCON_INIT;
	ADC->ADDLT = CFG_ADC_ADDLT_INIT;
	ADC->ADDGT = CFG_ADC_ADDGT_INIT;	
	ADC->SEQCHSEL0.V32 = CFG_ADC_SEQCHSEL0_INIT;
	ADC->SEQCHSEL1.V32 = CFG_ADC_SEQCHSEL1_INIT;
	ADC->HARDCHSEL.V32 = CFG_ADC_HARDCHSEL_INIT;
	ADC->HARDCHLH.V32 = CFG_ADC_HARDCHLH_INIT;	
	ADC->ADGAPON = CFG_ADC_ADGAPON_INIT;
	ADC->ADCON1.V32 = CFG_ADC_ADCON1_INIT;
#endif

}

void QEI_InitCfg(void)
{
  //Enable QEI Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.QEIEN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	QEI->QEICON.V32 = CFG_QEI_QEICON_INIT;
	QEI->QFLTCON.V32 = CFG_QEI_QFLTCON_INIT;
	QEI->QPOSMAX = CFG_QEI_QPOSMAX_INIT;
	QEI->QCNTMIN = CFG_QEI_QCNTMIN_INIT;
	QEI->QTPR = CFG_QEI_QTPR_INIT;
	QEI->QTPSQ = CFG_QEI_QTPSQ_INIT;
	QEI->QEIINT.V32 = (uint32_t)CFG_QEI_QEIINT_INIT;
}

void AMOC_InitCfg(void)
{
  //Enable AMOC Clock
	RCC_WriteEnable();	
  RCC->APB0ENR.BIT.AMOCEN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	AMOC->CMP0CON.V32 = CFG_AMOC_CMP0CON_INIT;
	AMOC->CMP1CON.V32 = CFG_AMOC_CMP1CON_INIT;
	AMOC->OPCON.V32 = CFG_AMOC_OPCON_INIT;
}

void UART_InitCfg(void)
{
#if CFG_UART0_EN
  //Enable UART1 Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.UART0EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	UART0->ADDR.V32 = CFG_UART0_ADDR_INIT;
	UART0->BRT.V32 = CFG_UART0_BRT_INIT;
	UART0->CR.V32 = CFG_UART0_CR_INIT;
#endif
	
#if CFG_UART1_EN
  //Enable UART1 Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.UART1EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	UART1->ADDR.V32 = CFG_UART1_ADDR_INIT;
	UART1->BRT.V32 = CFG_UART1_BRT_INIT;
	UART1->CR.V32 = CFG_UART1_CR_INIT;	
#endif

#if CFG_UART2_EN
  //Enable UART2 Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.UART2EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	UART2->ADDR.V32 = CFG_UART2_ADDR_INIT;
	UART2->BRT.V32 = CFG_UART2_BRT_INIT;
	UART2->CR.V32 = CFG_UART2_CR_INIT;
#endif	
}

void SPI_InitCfg(void)
{
#if CFG_SPI_EN
  //Enable SPI1 Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.SPI0EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	SPI0->CR.V32 = CFG_SPI_CR_INIT;	
	
#endif

}

void TWI_InitCfg(void)
{
  //Enable TWI Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.TWI0EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	TWI0->HOC = CFG_TWI_HOC_INIT;
	TWI0->BRT = CFG_TWI_BRT_INIT;
	TWI0->ADDR.V32 = CFG_TWI_ADDR_INIT;
	TWI0->CR.V32 = CFG_TWI_CR_INIT;
}
void SysTick_InitCfg(void)
{
	//set reload register 
	SysTick->LOAD  = CFG_SYSTICK_LOAD_INIT; 

	//Load the SysTick Counter Value 	
  SysTick->VAL   = CFG_SYSTICK_VAL_INIT;                          
  SysTick->CTRL  = (CFG_SYSTICK_CR_CLK << 2) |	
                   (CFG_SYSTICK_INT_EN << 1) |
                   CFG_SYSTICK_START_EN;    
}

void NVIC_InitCfg(void)
{
	//Setting Interrupt Set Enable Register 
	NVIC->ISER[0] = CFG_NVIC_ISER0_INIT;

#if CFG_PRI_EN
	//Setting PRI 
	SCB->AIRCR |= CFG_SCB_PRIGROUP_INIT; 
	
	//Setting Exception Priority Register
	SCB->SHPR[0] = CFG_SCB_SHP4_INIT;
	SCB->SHPR[1] = CFG_SCB_SHP5_INIT;
	SCB->SHPR[2] = CFG_SCB_SHP6_INIT;	
	
	SCB->SHPR[7] = CFG_SCB_SHP11_INIT;
	SCB->SHPR[8] = CFG_SCB_SHP12_INIT;
	SCB->SHPR[10] = CFG_SCB_SHP14_INIT;
	SCB->SHPR[11] = CFG_SCB_SHP15_INIT;
	
	//Setting Interrupt Priority Register
	NVIC->IPR[0] = CFG_NVIC_IP0_INIT;
	NVIC->IPR[1] = CFG_NVIC_IP1_INIT;
	NVIC->IPR[2] = CFG_NVIC_IP2_INIT;
	NVIC->IPR[3] = CFG_NVIC_IP3_INIT;
	NVIC->IPR[4] = CFG_NVIC_IP4_INIT;
	NVIC->IPR[5] = CFG_NVIC_IP5_INIT;
	NVIC->IPR[6] = CFG_NVIC_IP6_INIT;
	NVIC->IPR[7] = CFG_NVIC_IP7_INIT;
	NVIC->IPR[8] = CFG_NVIC_IP8_INIT;
	NVIC->IPR[9] = CFG_NVIC_IP9_INIT;
	NVIC->IPR[10] = CFG_NVIC_IP10_INIT;
	NVIC->IPR[11] = CFG_NVIC_IP11_INIT;
	NVIC->IPR[12] = CFG_NVIC_IP12_INIT;
	NVIC->IPR[13] = CFG_NVIC_IP13_INIT;
	NVIC->IPR[14] = CFG_NVIC_IP14_INIT;
	NVIC->IPR[15] = CFG_NVIC_IP15_INIT;
	NVIC->IPR[16] = CFG_NVIC_IP16_INIT;
	NVIC->IPR[17] = CFG_NVIC_IP17_INIT;
	NVIC->IPR[18] = CFG_NVIC_IP18_INIT;
	NVIC->IPR[19] = CFG_NVIC_IP19_INIT;
	NVIC->IPR[20] = CFG_NVIC_IP20_INIT;
	NVIC->IPR[21] = CFG_NVIC_IP21_INIT;	
	NVIC->IPR[22] = CFG_NVIC_IP22_INIT;
	NVIC->IPR[23] = CFG_NVIC_IP23_INIT;
	NVIC->IPR[24] = CFG_NVIC_IP24_INIT;
	NVIC->IPR[25] = CFG_NVIC_IP25_INIT;
	NVIC->IPR[26] = CFG_NVIC_IP26_INIT;
	NVIC->IPR[27] = CFG_NVIC_IP27_INIT;
	NVIC->IPR[28] = CFG_NVIC_IP28_INIT;	
#endif
}

void PCA_InitCfg(void)
{
#if CFG_PCA0_EN
  //Enable PCA0 Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.PCA0EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	PCA0->LCKR			= 0x33CC; 
	PCA0->CFGR.V32 	= CFG_PCA0_CFGR_INIT; 
	PCA0->CNT.V32  			= CFG_PCA0_CNT_INIT;  
	PCA0->PSC  			= CFG_PCA0_PSC_INIT;  
	PCA0->PR.V32   	= CFG_PCA0_PR_INIT;   
	PCA0->ADTR 			= CFG_PCA0_ADTR_INIT; 
	PCA0->CCR0.V32 			= CFG_PCA0_CCR0_INIT; 
	PCA0->CCR1.V32 			= CFG_PCA0_CCR1_INIT; 
	PCA0->CCR2.V32 			= CFG_PCA0_CCR2_INIT; 
	PCA0->CCMR0.V32 = CFG_PCA0_CCMR0_INIT;
	PCA0->CCMR1.V32 = CFG_PCA0_CCMR1_INIT;
	PCA0->CCMR2.V32 = CFG_PCA0_CCMR2_INIT;
	PCA0->CR = CFG_PCA0_CR_INIT;
	PCA0->LCKR			= 0x0; 	
	
	PCA0->FLTWPR 		= 0x33CC;
	PCA0->FLTCR.V32 = CFG_PCA0_FLTCR_INIT;
	PCA0->FLTWPR 		= 0;	
#endif

#if CFG_PCA1_EN
  //Enable PCA1 Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.PCA1EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	PCA1->LCKR			= 0x33CC;             
	PCA1->CFGR.V32 	= CFG_PCA1_CFGR_INIT; 
	PCA1->CNT.V32  			= CFG_PCA1_CNT_INIT;  
	PCA1->PSC  			= CFG_PCA1_PSC_INIT;  
	PCA1->PR.V32   			= CFG_PCA1_PR_INIT;   
	PCA1->CCMR0.V32 = CFG_PCA1_CCMR0_INIT;
	PCA1->CCMR1.V32 = CFG_PCA1_CCMR1_INIT;
	PCA1->CCMR2.V32 = CFG_PCA1_CCMR2_INIT;
	PCA1->CCR0.V32 			= CFG_PCA1_CCR0_INIT; 
	PCA1->CCR1.V32 			= CFG_PCA1_CCR1_INIT; 
	PCA1->CCR2.V32 			= CFG_PCA1_CCR2_INIT; 
	PCA1->ADTR 			= CFG_PCA1_ADTR_INIT; 
	PCA1->CR = CFG_PCA1_CR_INIT;
	PCA1->LCKR			= 0x0;
	                                      
	PCA1->FLTWPR 		= 0x33CC;             
	PCA1->FLTCR.V32 = CFG_PCA1_FLTCR_INIT;
	PCA1->FLTWPR 		= 0;	    
#endif
}

#define CANBUF0  (CAN_TypeDef*)(CAN0_BASE+0X00)
#define CANBUF1  (CAN_TypeDef*)(CAN0_BASE+0X20)
#define CANBUF2  (CAN_TypeDef*)(CAN0_BASE+0X40)
#define CANBUF3  (CAN_TypeDef*)(CAN0_BASE+0X60)
#define CANBUF4  (CAN_TypeDef*)(CAN0_BASE+0X80)
#define CANBUF5  (CAN_TypeDef*)(CAN0_BASE+0XA0)
#define CANBUF6  (CAN_TypeDef*)(CAN0_BASE+0XC0)
#define CANBUF7  (CAN_TypeDef*)(CAN0_BASE+0XE0)
#define CANBUF8   (CAN_TypeDef*)(CAN0_BASE+0X100)
#define CANBUF9   (CAN_TypeDef*)(CAN0_BASE+0X120)
#define CANBUF10  (CAN_TypeDef*)(CAN0_BASE+0X140)
#define CANBUF11  (CAN_TypeDef*)(CAN0_BASE+0X160)
#define CANBUF12  (CAN_TypeDef*)(CAN0_BASE+0X180)
#define CANBUF13  (CAN_TypeDef*)(CAN0_BASE+0X1A0)
#define CANBUF14  (CAN_TypeDef*)(CAN0_BASE+0X1C0)

static void CAN_ClearRAM()
{
	uint32_t* p = (uint32_t*)(CAN0_BASE+0X00);
	int i;
	for(i = 0; i < (0x1E0/4); i++)
	{
		*p = 0;
		p++;
	}
}

void CAN_InitCfg(void)
{
  //Enable CAN Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.CAN0EN = 1;
  RCC_WriteDisable();
	
	CAN_ClearRAM();
	
	CAN0->CGCR.V32 = CFG_CAN0_CGCR_INIT;
	CAN0->CTIM.V32 = CFG_CAN0_CGCR_INIT;

	CAN0->GMSKB.V32 = CFG_CAN0_GMSKB_INIT;
	CAN0->GMSKX.V32 = CFG_CAN0_GMSKX_INIT;

	CAN0->BMSKB.V32 = CFG_CAN0_BMSKB_INIT;
	CAN0->BMSKX.V32 = CFG_CAN0_BMSKX_INIT;
	CAN0->CIEN.V32 = CFG_CAN0_CIEN_INIT;	

}

void FIFO0_InitCfg(void)
{
  //Enable FIFO Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.FIFO0EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	FIFO0->CR.V32 = CFG_FIFO0_CR_INIT;
}

void FIFO1_InitCfg(void)
{
  //Enable FIFO Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.FIFO1EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	FIFO1->CR.V32 = CFG_FIFO1_CR_INIT;
}

void FIFO2_InitCfg(void)
{
  //Enable FIFO Clock
	RCC_WriteEnable();
  RCC->APB0ENR.BIT.FIFO2EN = 1;
  RCC_WriteDisable();
	
	//Set the registers
	FIFO2->CR.V32 = CFG_FIFO2_CR_INIT;
}

