/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_IQmath.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the GPIO firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */
/*==============================================================================
Function List :
             1: IQn            N=1~31
             2: IQNmpy         N=1~31
             3: IQNdiv         N=1~31             
             4: IQNSinCos      N=1~31
             5: IQNSinhCosh    N=1~31
             6: IQNatan        N=1~31
             7: IQNatan2       N=1~31
             8: IQNrms         N=1~31
             9: IQNhypot       N=1~31
             10:IQNsqrt        N=1~31
             11:IQNatanh       N=1~31
             12:IQNatanh2      N=1~31
             14:IQNrotate      N=1~31
             15:IQNpark        N=1~31
             16:IQNipark       N=1~31
             17:IQNpid         N=1~31
             18:IQNsvpwm       N=1~31
==============================================================================*/
#ifndef __IQMATH_H__
#define __IQMATH_H__

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"
	 
	 
/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup IQMATH_MODULE
  * @{
  */  

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/** @defgroup IQMath_Exported_Constants Public Constants
  * @{
  */ 
#ifdef  C_IQ26_1_K
#undef  C_IQ26_1_K
#endif 
/*! IQ26_1_K constant */     
#define C_IQ26_1_K          ((IQ26)(0x026DD2F1))  

#ifdef  C_IQ24_1_K
#undef  C_IQ24_1_K
#endif
/*! IQ24_1_K constant */     
#define C_IQ24_1_K          ((IQ24)(0x009B74BC))

#ifdef  C_IQ15_1_K
#undef  C_IQ15_1_K
#endif 
/*! IQ15_1_K constant */     
#define C_IQ15_1_K          ((IQ15)(0x004DBA))

#ifdef  L_IQ26_1_K
#undef  L_IQ26_1_K
#endif 
/*! IQ26_1_K constant */     
#define L_IQ26_1_K          ((IQ26)(0X04000000))

#ifdef  L_IQ24_1_K
#undef  L_IQ24_1_K
#endif
/*! IQ24_1_K constant */     
#define L_IQ24_1_K          ((IQ24)(0X01000000))

#ifdef  L_IQ15_1_K
#undef  L_IQ15_1_K
#endif 
/*! IQ15_1_K constant */     
#define L_IQ15_1_K          ((IQ15)(0x8000))

#ifdef  L_IQ26_1
#undef  L_IQ26_1
#endif
/*! IQ26_1 constant */     
#define L_IQ26_1            ((IQ26)(0X04000000))    

#ifdef  L_IQ24_1
#undef  L_IQ24_1
#endif
/*! IQ24_1 constant */     
#define L_IQ24_1            ((IQ24)(0X01000000))

#ifdef  L_IQ15_1
#undef  L_IQ15_1
#endif
/*! IQ15_1 constant */     
#define L_IQ15_1            ((IQ15)(0x8000))


#ifdef  H_IQ26_1_K
#undef  H_IQ26_1_K
#endif 
/*! IQ26_1_K constant */     
#define H_IQ26_1_K          ((IQ26)(0x04D205BC))

#ifdef  H_IQ24_1_K
#undef  H_IQ24_1_K
#endif
/*! IQ24_1_K constant */     
#define H_IQ24_1_K          ((IQ24)(0x134816F))

#ifdef  H_IQ15_1_K
#undef  H_IQ15_1_K
#endif 
/*! IQ15_1_K constant */     
#define H_IQ15_1_K          ((IQ15)(0x9A41))


#ifdef PI
#undef  PI
#endif
/*! PI CONSTANT */
#define PI  3.141593

#ifdef IQ24_1_PI
#undef  IQ24_1_PI
#endif
/*! 1/PI CONSTANT */
#define IQ24_1_PI  ((IQ24)((1/3.141593)*(1<<24)))


#ifdef IQ24_1_SQRT3
#undef  IQ24_1_SQRT3
#endif
#define IQ24_1_SQRT3      IQ24(0.57735026918963)  /*!< 1/sqrt(3) = 0.57735026918963*/

#ifdef IQ24_SQRT_3_2
#undef  IQ24_SQRT_3_2
#endif
#define IQ24_SQRT_3_2     IQ24(1.2247)  /*!< sqrt(3/2) = 1.2247 */

#ifdef IQ24_SQRT_0_5
#undef  IQ24_SQRT_0_5
#endif
#define IQ24_SQRT_0_5     IQ24(0.707)  /*!< 1/sqrt(2) = 0.707 */

/**
  * @}
  */

  
/** @defgroup IQMath_Exported_Types Public Types
  * @{
  */ 

/*-------------------- typedef format ----------------------*/
typedef int32_t   IQN; /*!< data type IQN */
typedef int32_t   IQ31;/*!< data type IQ31 */
typedef int32_t   IQ30;/*!< data type IQ30 */
typedef int32_t   IQ29;/*!< data type IQ29 */
typedef int32_t   IQ28;/*!< data type IQ28 */
typedef int32_t   IQ27;/*!< data type IQ27 */
typedef int32_t   IQ26;/*!< data type IQ26 */
typedef int32_t   IQ25;/*!< data type IQ25 */
typedef int32_t   IQ24;/*!< data type IQ24 */
typedef int32_t   IQ23;/*!< data type IQ23 */
typedef int32_t   IQ22;/*!< data type IQ22 */
typedef int32_t   IQ21;/*!< data type IQ21 */
typedef int32_t   IQ20;/*!< data type IQ20 */
typedef int32_t   IQ19;/*!< data type IQ19 */
typedef int32_t   IQ18;/*!< data type IQ18 */
typedef int32_t   IQ17;/*!< data type IQ17 */
typedef int32_t   IQ16;/*!< data type IQ16 */
typedef int32_t   IQ15;/*!< data type IQ15 */
typedef int32_t   IQ14;/*!< data type IQ14 */
typedef int32_t   IQ13;/*!< data type IQ13 */
typedef int32_t   IQ12;/*!< data type IQ12 */
typedef int32_t   IQ11;/*!< data type IQ11 */
typedef int32_t   IQ10;/*!< data type IQ10 */
typedef int32_t   IQ9;/*!< data type IQ9 */
typedef int32_t   IQ8;/*!< data type IQ8 */
typedef int32_t   IQ7;/*!< data type IQ7 */
typedef int32_t   IQ6;/*!< data type IQ6 */
typedef int32_t   IQ5;/*!< data type IQ5 */
typedef int32_t   IQ4;/*!< data type IQ4 */
typedef int32_t   IQ3;/*!< data type IQ3 */
typedef int32_t   IQ2;/*!< data type IQ2 */
typedef int32_t   IQ1;/*!< data type IQ1 */


/**
  * @}
  */


/* Exported functions --------------------------------------------------------*/ 
/** @addtogroup IQMath_Group_Pub_Funcs  Public Functions
  * @{
  */     

/** @defgroup IQMath_Format_Conversion Format Conversion Marcos
  * @{
  */
  
/**
  * @verbatim   Example
       convert float (0.4) to IQ24 format data
       IQ24 X = IQn(0x666666,24);
       printf("Float:0.4 to IQ24:%X\n",(unsigned int)X);
  * @endverbatim  
  *@brief  convert data to IQn q=0~31
  */
#define   IQn(x,N)     (int32_t) ((float)(x) * (float)((uint32_t)1L<<N)) /*!< Convert float to IQx Format */
#define   IQ31(x)      (int32_t) ((x) * 2147483648.0L)/*!< Convert to IQ31 format */
#define   IQ30(x)      (int32_t) ((x) * 1073741824.0L)/*!< Convert to IQ30 format */
#define   IQ29(x)      (int32_t) ((x) * 536870912.0L) /*!< Convert to IQ29 format */
#define   IQ28(x)      (int32_t) ((x) * 268435456.0L) /*!< Convert to IQ28 format */
#define   IQ27(x)      (int32_t) ((x) * 134217728.0L) /*!< Convert to IQ27 format */
#define   IQ26(x)      (int32_t) ((x) * 67108864.0L)  /*!< Convert to IQ26 format */
#define   IQ25(x)      (int32_t) ((x) * 33554432.0L)  /*!< Convert to IQ25 format */
#define   IQ24(x)      (int32_t) ((x) * 16777216.0L)  /*!< Convert to IQ24 format */
#define   IQ23(x)      (int32_t) ((x) * 8388608.0L)   /*!< Convert to IQ23 format */
#define   IQ22(x)      (int32_t) ((x) * 4194304.0L)   /*!< Convert to IQ22 format */
#define   IQ21(x)      (int32_t) ((x) * 2097152.0L)   /*!< Convert to IQ21 format */
#define   IQ20(x)      (int32_t) ((x) * 1048576.0L)   /*!< Convert to IQ20 format */
#define   IQ19(x)      (int32_t) ((x) * 524288.0L)    /*!< Convert to IQ19 format */
#define   IQ18(x)      (int32_t) ((x) * 262144.0L)    /*!< Convert to IQ18 format */
#define   IQ17(x)      (int32_t) ((x) * 131072.0L)    /*!< Convert to IQ17 format */
#define   IQ16(x)      (int32_t) ((x) * 65536.0L)     /*!< Convert to IQ16 format */
#define   IQ15(x)      (int32_t) ((x) * 32768.0L)     /*!< Convert to IQ15 format */
#define   IQ14(x)      (int32_t) ((x) * 16384.0L)     /*!< Convert to IQ14 format */
#define   IQ13(x)      (int32_t) ((x) * 8192.0L)      /*!< Convert to IQ13 format */
#define   IQ12(x)      (int32_t) ((x) * 4096.0L)      /*!< Convert to IQ12 format */
#define   IQ11(x)      (int32_t) ((x) * 2048.0L)      /*!< Convert to IQ11 format */
#define   IQ10(x)      (int32_t) ((x) * 1024.0L)      /*!< Convert to IQ10 format */
#define   IQ9(x)       (int32_t) ((x) * 512.0L)       /*!< Convert to IQ9 format */
#define   IQ8(x)       (int32_t) ((x) * 256.0L)       /*!< Convert to IQ8 format */
#define   IQ7(x)       (int32_t) ((x) * 128.0L)       /*!< Convert to IQ7 format */
#define   IQ6(x)       (int32_t) ((x) * 64.0L)        /*!< Convert to IQ6 format */
#define   IQ5(x)       (int32_t) ((x) * 32.0L)        /*!< Convert to IQ5 format */
#define   IQ4(x)       (int32_t) ((x) * 16.0L)        /*!< Convert to IQ4 format */
#define   IQ3(x)       (int32_t) ((x) * 8.0L)         /*!< Convert to IQ3 format */
#define   IQ2(x)       (int32_t) ((x) * 4.0L)         /*!< Convert to IQ2 format */
#define   IQ1(x)       (int32_t) ((x) * 2.0L)         /*!< Convert to IQ1 format */

#define IQnToFloat(x,q)   ((float)x / (float)(int32_t)(1<<q))/*!< Convet IQx format to float */

/**
  * @}
  */

/** @addtogroup IQMATH_Arithmetic Arithmetic Functions
  * @{
  */

/*--------------------  IQ format multiplication ----------------------*/
/** @defgroup IQMATH_Arithmetic_MPY_Marcos  MPY Marcos
  * @{
  */
// ʹcordic˷岻ʱ,˳˷ֱں˳˷ʵ 7/29
/*! Performance: Compiler Optimization (Obalance): 23 cycles */
#define IQNmpy(x, y, N)    ((IQN)((((int64_t)(x))*(y)) >> ((N)))) /*!< (X*Y) IQx Format*/

#define IQ31mpy(x, y)       IQNmpy(x, y, 31) /*!< (X*Y) IQ31 Format*/
#define IQ30mpy(x, y)       IQNmpy(x, y, 30) /*!< (X*Y) IQ30 Format*/
#define IQ29mpy(x, y)       IQNmpy(x, y, 29) /*!< (X*Y) IQ29 Format*/
#define IQ28mpy(x, y)       IQNmpy(x, y, 28) /*!< (X*Y) IQ28 Format*/
#define IQ27mpy(x, y)       IQNmpy(x, y, 27) /*!< (X*Y) IQ27 Format*/
#define IQ26mpy(x, y)       IQNmpy(x, y, 26) /*!< (X*Y) IQ26 Format*/
#define IQ25mpy(x, y)       IQNmpy(x, y, 25) /*!< (X*Y) IQ25 Format*/
#define IQ24mpy(x, y)       IQNmpy(x, y, 24) /*!< (X*Y) IQ24 Format*/
#define IQ23mpy(x, y)       IQNmpy(x, y, 23) /*!< (X*Y) IQ23 Format*/
#define IQ22mpy(x, y)       IQNmpy(x, y, 22) /*!< (X*Y) IQ22 Format*/
#define IQ21mpy(x, y)       IQNmpy(x, y, 21) /*!< (X*Y) IQ21 Format*/
#define IQ20mpy(x, y)       IQNmpy(x, y, 20) /*!< (X*Y) IQ20 Format*/
#define IQ19mpy(x, y)       IQNmpy(x, y, 19) /*!< (X*Y) IQ19 Format*/
#define IQ18mpy(x, y)       IQNmpy(x, y, 18) /*!< (X*Y) IQ18 Format*/
#define IQ17mpy(x, y)       IQNmpy(x, y, 17) /*!< (X*Y) IQ17 Format*/
#define IQ16mpy(x, y)       IQNmpy(x, y, 16) /*!< (X*Y) IQ16 Format*/
#define IQ15mpy(x, y)       IQNmpy(x, y, 15) /*!< (X*Y) IQ15 Format*/
#define IQ14mpy(x, y)       IQNmpy(x, y, 14) /*!< (X*Y) IQ14 Format*/
#define IQ13mpy(x, y)       IQNmpy(x, y, 13) /*!< (X*Y) IQ13 Format*/
#define IQ12mpy(x, y)       IQNmpy(x, y, 12) /*!< (X*Y) IQ12 Format*/
#define IQ11mpy(x, y)       IQNmpy(x, y, 11) /*!< (X*Y) IQ11 Format*/
#define IQ10mpy(x, y)       IQNmpy(x, y, 10) /*!< (X*Y) IQ10 Format*/
#define IQ9mpy(x, y)        IQNmpy(x, y, 9)  /*!< (X*Y) IQ9 Format*/
#define IQ8mpy(x, y)        IQNmpy(x, y, 8)  /*!< (X*Y) IQ8 Format*/
#define IQ7mpy(x, y)        IQNmpy(x, y, 7)  /*!< (X*Y) IQ7 Format*/
#define IQ6mpy(x, y)        IQNmpy(x, y, 6)  /*!< (X*Y) IQ6 Format*/
#define IQ5mpy(x, y)        IQNmpy(x, y, 5)  /*!< (X*Y) IQ5 Format*/
#define IQ4mpy(x, y)        IQNmpy(x, y, 4)  /*!< (X*Y) IQ4 Format*/
#define IQ3mpy(x, y)        IQNmpy(x, y, 3)  /*!< (X*Y) IQ3 Format*/
#define IQ2mpy(x, y)        IQNmpy(x, y, 2)  /*!< (X*Y) IQ2 Format*/
#define IQ1mpy(x, y)        IQNmpy(x, y, 1)  /*!< (X*Y) IQ1 Format*/
#define IQ0mpy(x, y)        IQNmpy(x, y, 0)  /*!< (X*Y) IQ0 Format*/

#define IQ31mpy1(x, y)       IQNmpy(x, y, 31) /*!< (X*Y) IQ31 Format*/
#define IQ30mpy1(x, y)       IQNmpy(x, y, 30) /*!< (X*Y) IQ30 Format*/
#define IQ29mpy1(x, y)       IQNmpy(x, y, 29) /*!< (X*Y) IQ29 Format*/
#define IQ28mpy1(x, y)       IQNmpy(x, y, 28) /*!< (X*Y) IQ28 Format*/
#define IQ27mpy1(x, y)       IQNmpy(x, y, 27) /*!< (X*Y) IQ27 Format*/
#define IQ26mpy1(x, y)       IQNmpy(x, y, 26) /*!< (X*Y) IQ26 Format*/
#define IQ25mpy1(x, y)       IQNmpy(x, y, 25) /*!< (X*Y) IQ25 Format*/
#define IQ24mpy1(x, y)       IQNmpy(x, y, 24) /*!< (X*Y) IQ24 Format*/
#define IQ23mpy1(x, y)       IQNmpy(x, y, 23) /*!< (X*Y) IQ23 Format*/
#define IQ22mpy1(x, y)       IQNmpy(x, y, 22) /*!< (X*Y) IQ22 Format*/
#define IQ21mpy1(x, y)       IQNmpy(x, y, 21) /*!< (X*Y) IQ21 Format*/
#define IQ20mpy1(x, y)       IQNmpy(x, y, 20) /*!< (X*Y) IQ20 Format*/
#define IQ19mpy1(x, y)       IQNmpy(x, y, 19) /*!< (X*Y) IQ19 Format*/
#define IQ18mpy1(x, y)       IQNmpy(x, y, 18) /*!< (X*Y) IQ18 Format*/
#define IQ17mpy1(x, y)       IQNmpy(x, y, 17) /*!< (X*Y) IQ17 Format*/
#define IQ16mpy1(x, y)       IQNmpy(x, y, 16) /*!< (X*Y) IQ16 Format*/
#define IQ15mpy1(x, y)       IQNmpy(x, y, 15) /*!< (X*Y) IQ15 Format*/
#define IQ14mpy1(x, y)       IQNmpy(x, y, 14) /*!< (X*Y) IQ14 Format*/
#define IQ13mpy1(x, y)       IQNmpy(x, y, 13) /*!< (X*Y) IQ13 Format*/
#define IQ12mpy1(x, y)       IQNmpy(x, y, 12) /*!< (X*Y) IQ12 Format*/
#define IQ11mpy1(x, y)       IQNmpy(x, y, 11) /*!< (X*Y) IQ11 Format*/
#define IQ10mpy1(x, y)       IQNmpy(x, y, 10) /*!< (X*Y) IQ10 Format*/
#define IQ9mpy1(x, y)        IQNmpy(x, y, 9)  /*!< (X*Y) IQ9 Format*/
#define IQ8mpy1(x, y)        IQNmpy(x, y, 8)  /*!< (X*Y) IQ8 Format*/
#define IQ7mpy1(x, y)        IQNmpy(x, y, 7)  /*!< (X*Y) IQ7 Format*/
#define IQ6mpy1(x, y)        IQNmpy(x, y, 6)  /*!< (X*Y) IQ6 Format*/
#define IQ5mpy1(x, y)        IQNmpy(x, y, 5)  /*!< (X*Y) IQ5 Format*/
#define IQ4mpy1(x, y)        IQNmpy(x, y, 4)  /*!< (X*Y) IQ4 Format*/
#define IQ3mpy1(x, y)        IQNmpy(x, y, 3)  /*!< (X*Y) IQ3 Format*/
#define IQ2mpy1(x, y)        IQNmpy(x, y, 2)  /*!< (X*Y) IQ2 Format*/
#define IQ1mpy1(x, y)        IQNmpy(x, y, 1)  /*!< (X*Y) IQ1 Format*/
#define IQ0mpy1(x, y)        IQNmpy(x, y, 0)  /*!< (X*Y) IQ0 Format*/
/**
  * @}
  */
  
/*--------------------  IQ format division  X / Y ----------------------*/
/*! Performance: Compiler Optimization (Obalance): 74 cycles */
IQN IQNdiv(IQN X,  IQN Y,  int32_t QN);

/** @defgroup IQMATH_Arithmetic_DIV_Marcos  DIV Marcos
  * @{
  */
#define IQ31div(x, y)       IQNdiv(x, y, 31) /*!< (X/Y) IQ31 Format*/
#define IQ30div(x, y)       IQNdiv(x, y, 30) /*!< (X/Y) IQ30 Format*/
#define IQ29div(x, y)       IQNdiv(x, y, 29) /*!< (X/Y) IQ29 Format*/
#define IQ28div(x, y)       IQNdiv(x, y, 28) /*!< (X/Y) IQ28 Format*/
#define IQ27div(x, y)       IQNdiv(x, y, 27) /*!< (X/Y) IQ27 Format*/
#define IQ26div(x, y)       IQNdiv(x, y, 26) /*!< (X/Y) IQ26 Format*/
#define IQ25div(x, y)       IQNdiv(x, y, 25) /*!< (X/Y) IQ25 Format*/
#define IQ24div(x, y)       IQNdiv(x, y, 24) /*!< (X/Y) IQ24 Format*/
#define IQ23div(x, y)       IQNdiv(x, y, 23) /*!< (X/Y) IQ23 Format*/
#define IQ22div(x, y)       IQNdiv(x, y, 22) /*!< (X/Y) IQ22 Format*/
#define IQ21div(x, y)       IQNdiv(x, y, 21) /*!< (X/Y) IQ21 Format*/
#define IQ20div(x, y)       IQNdiv(x, y, 20) /*!< (X/Y) IQ20 Format*/
#define IQ19div(x, y)       IQNdiv(x, y, 19) /*!< (X/Y) IQ19 Format*/
#define IQ18div(x, y)       IQNdiv(x, y, 18) /*!< (X/Y) IQ18 Format*/
#define IQ17div(x, y)       IQNdiv(x, y, 17) /*!< (X/Y) IQ17 Format*/
#define IQ16div(x, y)       IQNdiv(x, y, 16) /*!< (X/Y) IQ16 Format*/
#define IQ15div(x, y)       IQNdiv(x, y, 15) /*!< (X/Y) IQ15 Format*/
#define IQ14div(x, y)       IQNdiv(x, y, 14) /*!< (X/Y) IQ14 Format*/
#define IQ13div(x, y)       IQNdiv(x, y, 13) /*!< (X/Y) IQ13 Format*/
#define IQ12div(x, y)       IQNdiv(x, y, 12) /*!< (X/Y) IQ12 Format*/
#define IQ11div(x, y)       IQNdiv(x, y, 11) /*!< (X/Y) IQ11 Format*/
#define IQ10div(x, y)       IQNdiv(x, y, 10) /*!< (X/Y) IQ10 Format*/
#define IQ9div(x, y)        IQNdiv(x, y, 9)  /*!< (X/Y) IQ9 Format*/
#define IQ8div(x, y)        IQNdiv(x, y, 8)  /*!< (X/Y) IQ8 Format*/
#define IQ7div(x, y)        IQNdiv(x, y, 7)  /*!< (X/Y) IQ7 Format*/
#define IQ6div(x, y)        IQNdiv(x, y, 6)  /*!< (X/Y) IQ6 Format*/
#define IQ5div(x, y)        IQNdiv(x, y, 5)  /*!< (X/Y) IQ5 Format*/
#define IQ4div(x, y)        IQNdiv(x, y, 4)  /*!< (X/Y) IQ4 Format*/
#define IQ3div(x, y)        IQNdiv(x, y, 3)  /*!< (X/Y) IQ3 Format*/
#define IQ2div(x, y)        IQNdiv(x, y, 2)  /*!< (X/Y) IQ2 Format*/
#define IQ1div(x, y)        IQNdiv(x, y, 1)  /*!< (X/Y) IQ1 Format*/
#define IQ0div(x, y)        (IQN)((x)/(y))   /*!< (X/Y) IQ0 Format*/

#define IQ31div1(x, y)       IQNdiv(x, y, 31) /*!< (X/Y) IQ31 Format*/
#define IQ30div1(x, y)       IQNdiv(x, y, 30) /*!< (X/Y) IQ30 Format*/
#define IQ29div1(x, y)       IQNdiv(x, y, 29) /*!< (X/Y) IQ29 Format*/
#define IQ28div1(x, y)       IQNdiv(x, y, 28) /*!< (X/Y) IQ28 Format*/
#define IQ27div1(x, y)       IQNdiv(x, y, 27) /*!< (X/Y) IQ27 Format*/
#define IQ26div1(x, y)       IQNdiv(x, y, 26) /*!< (X/Y) IQ26 Format*/
#define IQ25div1(x, y)       IQNdiv(x, y, 25) /*!< (X/Y) IQ25 Format*/
#define IQ24div1(x, y)       IQNdiv(x, y, 24) /*!< (X/Y) IQ24 Format*/
#define IQ23div1(x, y)       IQNdiv(x, y, 23) /*!< (X/Y) IQ23 Format*/
#define IQ22div1(x, y)       IQNdiv(x, y, 22) /*!< (X/Y) IQ22 Format*/
#define IQ21div1(x, y)       IQNdiv(x, y, 21) /*!< (X/Y) IQ21 Format*/
#define IQ20div1(x, y)       IQNdiv(x, y, 20) /*!< (X/Y) IQ20 Format*/
#define IQ19div1(x, y)       IQNdiv(x, y, 19) /*!< (X/Y) IQ19 Format*/
#define IQ18div1(x, y)       IQNdiv(x, y, 18) /*!< (X/Y) IQ18 Format*/
#define IQ17div1(x, y)       IQNdiv(x, y, 17) /*!< (X/Y) IQ17 Format*/
#define IQ16div1(x, y)       IQNdiv(x, y, 16) /*!< (X/Y) IQ16 Format*/
#define IQ15div1(x, y)       IQNdiv(x, y, 15) /*!< (X/Y) IQ15 Format*/
#define IQ14div1(x, y)       IQNdiv(x, y, 14) /*!< (X/Y) IQ14 Format*/
#define IQ13div1(x, y)       IQNdiv(x, y, 13) /*!< (X/Y) IQ13 Format*/
#define IQ12div1(x, y)       IQNdiv(x, y, 12) /*!< (X/Y) IQ12 Format*/
#define IQ11div1(x, y)       IQNdiv(x, y, 11) /*!< (X/Y) IQ11 Format*/
#define IQ10div1(x, y)       IQNdiv(x, y, 10) /*!< (X/Y) IQ10 Format*/
#define IQ9div1(x, y)        IQNdiv(x, y, 9)  /*!< (X/Y) IQ9 Format*/
#define IQ8div1(x, y)        IQNdiv(x, y, 8)  /*!< (X/Y) IQ8 Format*/
#define IQ7div1(x, y)        IQNdiv(x, y, 7)  /*!< (X/Y) IQ7 Format*/
#define IQ6div1(x, y)        IQNdiv(x, y, 6)  /*!< (X/Y) IQ6 Format*/
#define IQ5div1(x, y)        IQNdiv(x, y, 5)  /*!< (X/Y) IQ5 Format*/
#define IQ4div1(x, y)        IQNdiv(x, y, 4)  /*!< (X/Y) IQ4 Format*/
#define IQ3div1(x, y)        IQNdiv(x, y, 3)  /*!< (X/Y) IQ3 Format*/
#define IQ2div1(x, y)        IQNdiv(x, y, 2)  /*!< (X/Y) IQ2 Format*/
#define IQ1div1(x, y)        IQNdiv(x, y, 1)  /*!< (X/Y) IQ1 Format*/
#define IQ0div1(x, y)        (IQN)((x)/(y))   /*!< (X/Y) IQ0 Format*/

/**
  * @}
  */
  
/**
  * @}
  */

/** @addtogroup IQMath_Trigonometric Trigonometric Functions
  * @{
  */
/*--------------------  IQ format sin & cos ----------------------*/

/*! structure TRIG_TypeDef definition */
typedef struct
{
    IQN Sin; /*!< sin value*/
    IQN Cos; /*!< cos value*/       
}TRIG_TypeDef;

#ifdef SINOIQMATH_USE_GENERAL
/*! Performance: Compiler Optimization (Obalance): 160 cycles */
TRIG_TypeDef IQNSinCos_G(IQN Theta,  int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 121 cycles */
TRIG_TypeDef IQNSinCos_Q24_G(IQN Theta);
/*! Performance: Compiler Optimization (Obalance): 160 cycles */
TRIG_TypeDef IQNSinCos1_G(IQN Theta,  int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 121 cycles */
TRIG_TypeDef IQNSinCos1_Q24_G(IQN Theta);
#else
/*! Performance: Compiler Optimization (Obalance): 129 cycles */
TRIG_TypeDef IQNSinCos_N(IQN Theta,  int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 98 cycles */
TRIG_TypeDef IQNSinCos_Q24_N(IQN Theta);
/*! Performance: Compiler Optimization (Obalance): 129 cycles */
TRIG_TypeDef IQNSinCos1_N(IQN Theta,  int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 98 cycles */
TRIG_TypeDef IQNSinCos1_Q24_N(IQN Theta);
#endif

/** @defgroup IQMath_Trigonometric_SinCos  SIN COS Marcos
  * @{
  */
#ifdef SINOIQMATH_USE_GENERAL
#define IQNSinCos(t,q)     IQNSinCos_G(t,q)    /*!< sin(t) and cos(t),Format:q*/
#define IQNSinCos_Q24(t)   IQNSinCos_Q24_G(t)  /*!< sin(t) and cos(t),Format:IQ24*/
#define IQNSinCos1(t,q)     IQNSinCos1_G(t,q)  /*!< sin(t) and cos(t),Format:q*/
#define IQNSinCos1_Q24(t)   IQNSinCos1_Q24_G(t)/*!< sin(t) and cos(t),Format:IQ24*/
#else
#define IQNSinCos(t,q)     IQNSinCos_N(t,q)    /*!< sin(t) and cos(t),Format:q*/
#define IQNSinCos_Q24(t)   IQNSinCos_Q24_N(t)  /*!< sin(t) and cos(t),Format:IQ24*/
#define IQNSinCos1(t,q)     IQNSinCos1_N(t,q)  /*!< sin(t) and cos(t),Format:q*/
#define IQNSinCos1_Q24(t)   IQNSinCos1_Q24_N(t)/*!< sin(t) and cos(t),Format:IQ24*/
#endif 
  
#define IQ31sincos(x)        IQNSinCos(x, 31)/*!< sin(x) and cos(x),Format:IQ31*/
#define IQ30sincos(x)        IQNSinCos(x, 30)/*!< sin(x) and cos(x),Format:IQ30*/
#define IQ29sincos(x)        IQNSinCos(x, 29)/*!< sin(x) and cos(x),Format:IQ29*/
#define IQ28sincos(x)        IQNSinCos(x, 28)/*!< sin(x) and cos(x),Format:IQ28*/
#define IQ27sincos(x)        IQNSinCos(x, 27)/*!< sin(x) and cos(x),Format:IQ27*/
#define IQ26sincos(x)        IQNSinCos(x, 26)/*!< sin(x) and cos(x),Format:IQ26*/
#define IQ25sincos(x)        IQNSinCos(x, 25)/*!< sin(x) and cos(x),Format:IQ25*/
#define IQ24sincos(x)        IQNSinCos_Q24(x)/*!< sin(x) and cos(x),Format:IQ24*/
#define IQ23sincos(x)        IQNSinCos(x, 23)/*!< sin(x) and cos(x),Format:IQ23*/
#define IQ22sincos(x)        IQNSinCos(x, 22)/*!< sin(x) and cos(x),Format:IQ22*/
#define IQ21sincos(x)        IQNSinCos(x, 21)/*!< sin(x) and cos(x),Format:IQ21*/
#define IQ20sincos(x)        IQNSinCos(x, 20)/*!< sin(x) and cos(x),Format:IQ20*/
#define IQ19sincos(x)        IQNSinCos(x, 19)/*!< sin(x) and cos(x),Format:IQ19*/
#define IQ18sincos(x)        IQNSinCos(x, 18)/*!< sin(x) and cos(x),Format:IQ18*/
#define IQ17sincos(x)        IQNSinCos(x, 17)/*!< sin(x) and cos(x),Format:IQ17*/
#define IQ16sincos(x)        IQNSinCos(x, 16)/*!< sin(x) and cos(x),Format:IQ16*/
#define IQ15sincos(x)        IQNSinCos(x, 15)/*!< sin(x) and cos(x),Format:IQ15*/
#define IQ14sincos(x)        IQNSinCos(x, 14)/*!< sin(x) and cos(x),Format:IQ14*/
#define IQ13sincos(x)        IQNSinCos(x, 13)/*!< sin(x) and cos(x),Format:IQ13*/
#define IQ12sincos(x)        IQNSinCos(x, 12)/*!< sin(x) and cos(x),Format:IQ12*/
#define IQ11sincos(x)        IQNSinCos(x, 11)/*!< sin(x) and cos(x),Format:IQ11*/
#define IQ10sincos(x)        IQNSinCos(x, 10)/*!< sin(x) and cos(x),Format:IQ10*/
#define IQ9sincos(x)         IQNSinCos(x, 9) /*!< sin(x) and cos(x),Format:IQ9*/
#define IQ8sincos(x)         IQNSinCos(x, 8) /*!< sin(x) and cos(x),Format:IQ8*/
#define IQ7sincos(x)         IQNSinCos(x, 7) /*!< sin(x) and cos(x),Format:IQ7*/
#define IQ6sincos(x)         IQNSinCos(x, 6) /*!< sin(x) and cos(x),Format:IQ6*/
#define IQ5sincos(x)         IQNSinCos(x, 5) /*!< sin(x) and cos(x),Format:IQ5*/
#define IQ4sincos(x)         IQNSinCos(x, 4) /*!< sin(x) and cos(x),Format:IQ4*/
#define IQ3sincos(x)         IQNSinCos(x, 3) /*!< sin(x) and cos(x),Format:IQ3*/
#define IQ2sincos(x)         IQNSinCos(x, 2) /*!< sin(x) and cos(x),Format:IQ2*/
#define IQ1sincos(x)         IQNSinCos(x, 1) /*!< sin(x) and cos(x),Format:IQ1*/

#define IQ31sincos1(x)        IQNSinCos1(x, 31)/*!< sin(x) and cos(x),Format:IQ31*/
#define IQ30sincos1(x)        IQNSinCos1(x, 30)/*!< sin(x) and cos(x),Format:IQ30*/
#define IQ29sincos1(x)        IQNSinCos1(x, 29)/*!< sin(x) and cos(x),Format:IQ29*/
#define IQ28sincos1(x)        IQNSinCos1(x, 28)/*!< sin(x) and cos(x),Format:IQ28*/
#define IQ27sincos1(x)        IQNSinCos1(x, 27)/*!< sin(x) and cos(x),Format:IQ27*/
#define IQ26sincos1(x)        IQNSinCos1(x, 26)/*!< sin(x) and cos(x),Format:IQ26*/
#define IQ25sincos1(x)        IQNSinCos1(x, 25)/*!< sin(x) and cos(x),Format:IQ25*/
#define IQ24sincos1(x)        IQNSinCos1_Q24(x)/*!< sin(x) and cos(x),Format:IQ24*/
#define IQ23sincos1(x)        IQNSinCos1(x, 23)/*!< sin(x) and cos(x),Format:IQ23*/
#define IQ22sincos1(x)        IQNSinCos1(x, 22)/*!< sin(x) and cos(x),Format:IQ22*/
#define IQ21sincos1(x)        IQNSinCos1(x, 21)/*!< sin(x) and cos(x),Format:IQ21*/
#define IQ20sincos1(x)        IQNSinCos1(x, 20)/*!< sin(x) and cos(x),Format:IQ20*/
#define IQ19sincos1(x)        IQNSinCos1(x, 19)/*!< sin(x) and cos(x),Format:IQ19*/
#define IQ18sincos1(x)        IQNSinCos1(x, 18)/*!< sin(x) and cos(x),Format:IQ18*/
#define IQ17sincos1(x)        IQNSinCos1(x, 17)/*!< sin(x) and cos(x),Format:IQ17*/
#define IQ16sincos1(x)        IQNSinCos1(x, 16)/*!< sin(x) and cos(x),Format:IQ16*/
#define IQ15sincos1(x)        IQNSinCos1(x, 15)/*!< sin(x) and cos(x),Format:IQ15*/
#define IQ14sincos1(x)        IQNSinCos1(x, 14)/*!< sin(x) and cos(x),Format:IQ14*/
#define IQ13sincos1(x)        IQNSinCos1(x, 13)/*!< sin(x) and cos(x),Format:IQ13*/
#define IQ12sincos1(x)        IQNSinCos1(x, 12)/*!< sin(x) and cos(x),Format:IQ12*/
#define IQ11sincos1(x)        IQNSinCos1(x, 11)/*!< sin(x) and cos(x),Format:IQ11*/
#define IQ10sincos1(x)        IQNSinCos1(x, 10)/*!< sin(x) and cos(x),Format:IQ10*/
#define IQ9sincos1(x)         IQNSinCos1(x, 9) /*!< sin(x) and cos(x),Format:IQ9*/
#define IQ8sincos1(x)         IQNSinCos1(x, 8) /*!< sin(x) and cos(x),Format:IQ8*/
#define IQ7sincos1(x)         IQNSinCos1(x, 7) /*!< sin(x) and cos(x),Format:IQ7*/
#define IQ6sincos1(x)         IQNSinCos1(x, 6) /*!< sin(x) and cos(x),Format:IQ6*/
#define IQ5sincos1(x)         IQNSinCos1(x, 5) /*!< sin(x) and cos(x),Format:IQ5*/
#define IQ4sincos1(x)         IQNSinCos1(x, 4) /*!< sin(x) and cos(x),Format:IQ4*/
#define IQ3sincos1(x)         IQNSinCos1(x, 3) /*!< sin(x) and cos(x),Format:IQ3*/
#define IQ2sincos1(x)         IQNSinCos1(x, 2) /*!< sin(x) and cos(x),Format:IQ2*/
#define IQ1sincos1(x)         IQNSinCos1(x, 1) /*!< sin(x) and cos(x),Format:IQ1*/

/**
  * @}
  */
  
/*--------------------  IQ format sinh & cosh ----------------------*/
/*! structure TRIGH_TypeDef */
typedef struct
{
    IQN Sinh; /*!< sinh value*/
    IQN Cosh; /*!< cosh value*/        
}TRIGH_TypeDef;

#ifdef SINOIQMATH_USE_GENERAL
/*! Performance: Compiler Optimization (Obalance): 155 cycles */
TRIGH_TypeDef IQNSinhCosh_G(IQN Theta,  int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 118 cycles */
TRIGH_TypeDef IQNSinhCosh_Q24_G(IQN Theta);
/*! Performance: Compiler Optimization (Obalance): 155 cycles */
TRIGH_TypeDef IQNSinhCosh1_G(IQN Theta,  int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 118 cycles */
TRIGH_TypeDef IQNSinhCosh1_Q24_G(IQN Theta);
#else
/*! Performance: Compiler Optimization (Obalance): 131 cycles */
TRIGH_TypeDef IQNSinhCosh_N(IQN Theta,  int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 103 cycles */
TRIGH_TypeDef IQNSinhCosh_Q24_N(IQN Theta);
/*! Performance: Compiler Optimization (Obalance): 131 cycles */
TRIGH_TypeDef IQNSinhCosh1_N(IQN Theta,  int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 103 cycles */
TRIGH_TypeDef IQNSinhCosh1_Q24_N(IQN Theta);
#endif

/** @defgroup IQMath_Trigonometric_SinCosh  SINH COSH Marcos
  * @{
  */
#ifdef SINOIQMATH_USE_GENERAL
#define IQNSinhCosh(t,q)      IQNSinhCosh_G(t,q)     /*!< sinh(t) and cosh(t),Format:q*/
#define IQNSinhCosh_Q24(t)    IQNSinhCosh_Q24_G(t)   /*!< sinh(t) and cosh(t),Format:IQ24*/
#define IQNSinhCosh1(t,q)     IQNSinhCosh1_G(t,q)    /*!< sinh(t) and cosh(t),Format:q*/
#define IQNSinhCosh1_Q24(t)   IQNSinhCosh1_Q24_G(t)  /*!< sinh(t) and cosh(t),Format:IQ24*/
#else
#define IQNSinhCosh(t,q)      IQNSinhCosh_N(t,q)     /*!< sinh(t) and cosh(t),Format:q*/
#define IQNSinhCosh_Q24(t)    IQNSinhCosh_Q24_N(t)   /*!< sinh(t) and cosh(t),Format:IQ24*/
#define IQNSinhCosh1(t,q)     IQNSinhCosh1_N(t,q)    /*!< sinh(t) and cosh(t),Format:q*/
#define IQNSinhCosh1_Q24(t)   IQNSinhCosh1_Q24_N(t)  /*!< sinh(t) and cosh(t),Format:IQ24*/
#endif 
   
#define IQ31sinhcosh(x)        IQNSinhCosh(x, 31)/*!< sinh(x) and cosh(x),Format:IQ31*/
#define IQ30sinhcosh(x)        IQNSinhCosh(x, 30)/*!< sinh(x) and cosh(x),Format:IQ30*/
#define IQ29sinhcosh(x)        IQNSinhCosh(x, 29)/*!< sinh(x) and cosh(x),Format:IQ29*/
#define IQ28sinhcosh(x)        IQNSinhCosh(x, 28)/*!< sinh(x) and cosh(x),Format:IQ28*/
#define IQ27sinhcosh(x)        IQNSinhCosh(x, 27)/*!< sinh(x) and cosh(x),Format:IQ27*/
#define IQ26sinhcosh(x)        IQNSinhCosh(x, 26)/*!< sinh(x) and cosh(x),Format:IQ26*/
#define IQ25sinhcosh(x)        IQNSinhCosh(x, 25)/*!< sinh(x) and cosh(x),Format:IQ25*/
#define IQ24sinhcosh(x)        IQNSinhCosh_Q24(x)/*!< sinh(x) and cosh(x),Format:IQ24*/
#define IQ23sinhcosh(x)        IQNSinhCosh(x, 23)/*!< sinh(x) and cosh(x),Format:IQ23*/
#define IQ22sinhcosh(x)        IQNSinhCosh(x, 22)/*!< sinh(x) and cosh(x),Format:IQ22*/
#define IQ21sinhcosh(x)        IQNSinhCosh(x, 21)/*!< sinh(x) and cosh(x),Format:IQ21*/
#define IQ20sinhcosh(x)        IQNSinhCosh(x, 20)/*!< sinh(x) and cosh(x),Format:IQ20*/
#define IQ19sinhcosh(x)        IQNSinhCosh(x, 19)/*!< sinh(x) and cosh(x),Format:IQ19*/
#define IQ18sinhcosh(x)        IQNSinhCosh(x, 18)/*!< sinh(x) and cosh(x),Format:IQ18*/
#define IQ17sinhcosh(x)        IQNSinhCosh(x, 17)/*!< sinh(x) and cosh(x),Format:IQ17*/
#define IQ16sinhcosh(x)        IQNSinhCosh(x, 16)/*!< sinh(x) and cosh(x),Format:IQ16*/
#define IQ15sinhcosh(x)        IQNSinhCosh(x, 15)/*!< sinh(x) and cosh(x),Format:IQ15*/
#define IQ14sinhcosh(x)        IQNSinhCosh(x, 14)/*!< sinh(x) and cosh(x),Format:IQ14*/
#define IQ13sinhcosh(x)        IQNSinhCosh(x, 13)/*!< sinh(x) and cosh(x),Format:IQ13*/
#define IQ12sinhcosh(x)        IQNSinhCosh(x, 12)/*!< sinh(x) and cosh(x),Format:IQ12*/
#define IQ11sinhcosh(x)        IQNSinhCosh(x, 11)/*!< sinh(x) and cosh(x),Format:IQ11*/
#define IQ10sinhcosh(x)        IQNSinhCosh(x, 10)/*!< sinh(x) and cosh(x),Format:IQ10*/
#define IQ9sinhcosh(x)         IQNSinhCosh(x, 9)/*!< sinh(x) and cosh(x),Format:IQ9*/
#define IQ8sinhcosh(x)         IQNSinhCosh(x, 8)/*!< sinh(x) and cosh(x),Format:IQ8*/
#define IQ7sinhcosh(x)         IQNSinhCosh(x, 7)/*!< sinh(x) and cosh(x),Format:IQ7*/
#define IQ6sinhcosh(x)         IQNSinhCosh(x, 6)/*!< sinh(x) and cosh(x),Format:IQ6*/
#define IQ5sinhcosh(x)         IQNSinhCosh(x, 5)/*!< sinh(x) and cosh(x),Format:IQ5*/
#define IQ4sinhcosh(x)         IQNSinhCosh(x, 4)/*!< sinh(x) and cosh(x),Format:IQ4*/
#define IQ3sinhcosh(x)         IQNSinhCosh(x, 3)/*!< sinh(x) and cosh(x),Format:IQ3*/
#define IQ2sinhcosh(x)         IQNSinhCosh(x, 2)/*!< sinh(x) and cosh(x),Format:IQ2*/
#define IQ1sinhcosh(x)         IQNSinhCosh(x, 1)/*!< sinh(x) and cosh(x),Format:IQ1*/

#define IQ31sinhcosh1(x)        IQNSinhCosh1(x, 31)/*!< sinh(x) and cosh(x),Format:IQ31*/
#define IQ30sinhcosh1(x)        IQNSinhCosh1(x, 30)/*!< sinh(x) and cosh(x),Format:IQ30*/
#define IQ29sinhcosh1(x)        IQNSinhCosh1(x, 29)/*!< sinh(x) and cosh(x),Format:IQ29*/
#define IQ28sinhcosh1(x)        IQNSinhCosh1(x, 28)/*!< sinh(x) and cosh(x),Format:IQ28*/
#define IQ27sinhcosh1(x)        IQNSinhCosh1(x, 27)/*!< sinh(x) and cosh(x),Format:IQ27*/
#define IQ26sinhcosh1(x)        IQNSinhCosh1(x, 26)/*!< sinh(x) and cosh(x),Format:IQ26*/
#define IQ25sinhcosh1(x)        IQNSinhCosh1(x, 25)/*!< sinh(x) and cosh(x),Format:IQ25*/
#define IQ24sinhcosh1(x)        IQNSinhCosh1_Q24(x)/*!< sinh(x) and cosh(x),Format:IQ24*/
#define IQ23sinhcosh1(x)        IQNSinhCosh1(x, 23)/*!< sinh(x) and cosh(x),Format:IQ23*/
#define IQ22sinhcosh1(x)        IQNSinhCosh1(x, 22)/*!< sinh(x) and cosh(x),Format:IQ22*/
#define IQ21sinhcosh1(x)        IQNSinhCosh1(x, 21)/*!< sinh(x) and cosh(x),Format:IQ21*/
#define IQ20sinhcosh1(x)        IQNSinhCosh1(x, 20)/*!< sinh(x) and cosh(x),Format:IQ20*/
#define IQ19sinhcosh1(x)        IQNSinhCosh1(x, 19)/*!< sinh(x) and cosh(x),Format:IQ19*/
#define IQ18sinhcosh1(x)        IQNSinhCosh1(x, 18)/*!< sinh(x) and cosh(x),Format:IQ18*/
#define IQ17sinhcosh1(x)        IQNSinhCosh1(x, 17)/*!< sinh(x) and cosh(x),Format:IQ17*/
#define IQ16sinhcosh1(x)        IQNSinhCosh1(x, 16)/*!< sinh(x) and cosh(x),Format:IQ16*/
#define IQ15sinhcosh1(x)        IQNSinhCosh1(x, 15)/*!< sinh(x) and cosh(x),Format:IQ15*/
#define IQ14sinhcosh1(x)        IQNSinhCosh1(x, 14)/*!< sinh(x) and cosh(x),Format:IQ14*/
#define IQ13sinhcosh1(x)        IQNSinhCosh1(x, 13)/*!< sinh(x) and cosh(x),Format:IQ13*/
#define IQ12sinhcosh1(x)        IQNSinhCosh1(x, 12)/*!< sinh(x) and cosh(x),Format:IQ12*/
#define IQ11sinhcosh1(x)        IQNSinhCosh1(x, 11)/*!< sinh(x) and cosh(x),Format:IQ11*/
#define IQ10sinhcosh1(x)        IQNSinhCosh1(x, 10)/*!< sinh(x) and cosh(x),Format:IQ10*/
#define IQ9sinhcosh1(x)         IQNSinhCosh1(x, 9)/*!< sinh(x) and cosh(x),Format:IQ9*/
#define IQ8sinhcosh1(x)         IQNSinhCosh1(x, 8)/*!< sinh(x) and cosh(x),Format:IQ8*/
#define IQ7sinhcosh1(x)         IQNSinhCosh1(x, 7)/*!< sinh(x) and cosh(x),Format:IQ7*/
#define IQ6sinhcosh1(x)         IQNSinhCosh1(x, 6)/*!< sinh(x) and cosh(x),Format:IQ6*/
#define IQ5sinhcosh1(x)         IQNSinhCosh1(x, 5)/*!< sinh(x) and cosh(x),Format:IQ5*/
#define IQ4sinhcosh1(x)         IQNSinhCosh1(x, 4)/*!< sinh(x) and cosh(x),Format:IQ4*/
#define IQ3sinhcosh1(x)         IQNSinhCosh1(x, 3)/*!< sinh(x) and cosh(x),Format:IQ3*/
#define IQ2sinhcosh1(x)         IQNSinhCosh1(x, 2)/*!< sinh(x) and cosh(x),Format:IQ2*/
#define IQ1sinhcosh1(x)         IQNSinhCosh1(x, 1)/*!< sinh(x) and cosh(x),Format:IQ1*/
/**
  * @}
  */


/*--------------------  IQ format atan =atan(x) ----------------------*/
#ifdef SINOIQMATH_USE_GENERAL
/*! Performance: Compiler Optimization (Obalance): 139 cycles */
IQN IQNatan_G(IQN X, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 105 cycles */
IQN IQNatan_Q24_G(IQN X);
/*! Performance: Compiler Optimization (Obalance): 139 cycles */
IQN IQNatan1_G(IQN X, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 105 cycles */
IQN IQNatan1_Q24_G(IQN X);
#else
/*! Performance: Compiler Optimization (Obalance): 113 cycles */
IQN IQNatan_N(IQN X, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 94 cycles */
IQN IQNatan_Q24_N(IQN X);
/*! Performance: Compiler Optimization (Obalance): 113 cycles */
IQN IQNatan1_N(IQN X, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 94 cycles */
IQN IQNatan1_Q24_N(IQN X);
#endif

/** @defgroup IQMath_Trigonometric_atan  ATAN Marcos
  * @{
  */
#ifdef SINOIQMATH_USE_GENERAL
#define IQNatan(x,q)     IQNatan_G(x,q)   /*!< atan(x),Format:IQx */
#define IQNatan_Q24(x)   IQNatan_Q24_G(x) /*!< atan(x),Format:IQ24 */
#define IQNatan1(x,q)    IQNatan1_G(x,q)  /*!< atan(x),Format:IQx */
#define IQNatan1_Q24(x)  IQNatan1_Q24_G(x)/*!< atan(x),Format:IQ24 */
#else
#define IQNatan(x,q)     IQNatan_N(x,q)   /*!< atan(x),Format:IQx */
#define IQNatan_Q24(x)   IQNatan_Q24_N(x) /*!< atan(x),Format:IQ24 */
#define IQNatan1(x,q)    IQNatan1_N(x,q)  /*!< atan(x),Format:IQx */
#define IQNatan1_Q24(x)  IQNatan1_Q24_N(x)/*!< atan(x),Format:IQ24 */
#endif
  
#define IQ31atan(x)            IQNatan(x, 31)/*!< atan(x),Format:IQ31 */
#define IQ30atan(x)            IQNatan(x, 30)/*!< atan(x),Format:IQ30 */
#define IQ29atan(x)            IQNatan(x, 29)/*!< atan(x),Format:IQ29 */
#define IQ28atan(x)            IQNatan(x, 28)/*!< atan(x),Format:IQ28 */
#define IQ27atan(x)            IQNatan(x, 27)/*!< atan(x),Format:IQ27 */
#define IQ26atan(x)            IQNatan(x, 26)/*!< atan(x),Format:IQ26 */
#define IQ25atan(x)            IQNatan(x, 25)/*!< atan(x),Format:IQ25 */
#define IQ24atan(x)            IQNatan_Q24(x)/*!< atan(x),Format:IQ24 */
#define IQ23atan(x)            IQNatan(x, 23)/*!< atan(x),Format:IQ23 */
#define IQ22atan(x)            IQNatan(x, 22)/*!< atan(x),Format:IQ22 */
#define IQ21atan(x)            IQNatan(x, 21)/*!< atan(x),Format:IQ21 */
#define IQ20atan(x)            IQNatan(x, 20)/*!< atan(x),Format:IQ20 */
#define IQ19atan(x)            IQNatan(x, 19)/*!< atan(x),Format:IQ19 */
#define IQ18atan(x)            IQNatan(x, 18)/*!< atan(x),Format:IQ18 */
#define IQ17atan(x)            IQNatan(x, 17)/*!< atan(x),Format:IQ17 */
#define IQ16atan(x)            IQNatan(x, 16)/*!< atan(x),Format:IQ16 */
#define IQ15atan(x)            IQNatan(x, 15)/*!< atan(x),Format:IQ15 */
#define IQ14atan(x)            IQNatan(x, 14)/*!< atan(x),Format:IQ14 */
#define IQ13atan(x)            IQNatan(x, 13)/*!< atan(x),Format:IQ13 */
#define IQ12atan(x)            IQNatan(x, 12)/*!< atan(x),Format:IQ12 */
#define IQ11atan(x)            IQNatan(x, 11)/*!< atan(x),Format:IQ11 */
#define IQ10atan(x)            IQNatan(x, 10)/*!< atan(x),Format:IQ10 */
#define IQ9atan(x)             IQNatan(x, 9)/*!< atan(x),Format:IQ9 */
#define IQ8atan(x)             IQNatan(x, 8)/*!< atan(x),Format:IQ8 */
#define IQ7atan(x)             IQNatan(x, 7)/*!< atan(x),Format:IQ7 */
#define IQ6atan(x)             IQNatan(x, 6)/*!< atan(x),Format:IQ6 */
#define IQ5atan(x)             IQNatan(x, 5)/*!< atan(x),Format:IQ5 */
#define IQ4atan(x)             IQNatan(x, 4)/*!< atan(x),Format:IQ4 */
#define IQ3atan(x)             IQNatan(x, 3)/*!< atan(x),Format:IQ3 */
#define IQ2atan(x)             IQNatan(x, 2)/*!< atan(x),Format:IQ2 */
#define IQ1atan(x)             IQNatan(x, 1)/*!< atan(x),Format:IQ1 */

#define IQ31atan1(x)            IQNatan1(x, 31)/*!< atan(x),Format:IQ31 */
#define IQ30atan1(x)            IQNatan1(x, 30)/*!< atan(x),Format:IQ30 */
#define IQ29atan1(x)            IQNatan1(x, 29)/*!< atan(x),Format:IQ29 */
#define IQ28atan1(x)            IQNatan1(x, 28)/*!< atan(x),Format:IQ28 */
#define IQ27atan1(x)            IQNatan1(x, 27)/*!< atan(x),Format:IQ27 */
#define IQ26atan1(x)            IQNatan1(x, 26)/*!< atan(x),Format:IQ26 */
#define IQ25atan1(x)            IQNatan1(x, 25)/*!< atan(x),Format:IQ25 */
#define IQ24atan1(x)            IQNatan1_Q24(x)/*!< atan(x),Format:IQ24 */
#define IQ23atan1(x)            IQNatan1(x, 23)/*!< atan(x),Format:IQ23 */
#define IQ22atan1(x)            IQNatan1(x, 22)/*!< atan(x),Format:IQ22 */
#define IQ21atan1(x)            IQNatan1(x, 21)/*!< atan(x),Format:IQ21 */
#define IQ20atan1(x)            IQNatan1(x, 20)/*!< atan(x),Format:IQ20 */
#define IQ19atan1(x)            IQNatan1(x, 19)/*!< atan(x),Format:IQ19 */
#define IQ18atan1(x)            IQNatan1(x, 18)/*!< atan(x),Format:IQ18 */
#define IQ17atan1(x)            IQNatan1(x, 17)/*!< atan(x),Format:IQ17 */
#define IQ16atan1(x)            IQNatan1(x, 16)/*!< atan(x),Format:IQ16 */
#define IQ15atan1(x)            IQNatan1(x, 15)/*!< atan(x),Format:IQ15 */
#define IQ14atan1(x)            IQNatan1(x, 14)/*!< atan(x),Format:IQ14 */
#define IQ13atan1(x)            IQNatan1(x, 13)/*!< atan(x),Format:IQ13 */
#define IQ12atan1(x)            IQNatan1(x, 12)/*!< atan(x),Format:IQ12 */
#define IQ11atan1(x)            IQNatan1(x, 11)/*!< atan(x),Format:IQ11 */
#define IQ10atan1(x)            IQNatan1(x, 10)/*!< atan(x),Format:IQ10 */
#define IQ9atan1(x)             IQNatan1(x, 9)/*!< atan(x),Format:IQ9 */
#define IQ8atan1(x)             IQNatan1(x, 8)/*!< atan(x),Format:IQ8 */
#define IQ7atan1(x)             IQNatan1(x, 7)/*!< atan(x),Format:IQ7 */
#define IQ6atan1(x)             IQNatan1(x, 6)/*!< atan(x),Format:IQ6 */
#define IQ5atan1(x)             IQNatan1(x, 5)/*!< atan(x),Format:IQ5 */
#define IQ4atan1(x)             IQNatan1(x, 4)/*!< atan(x),Format:IQ4 */
#define IQ3atan1(x)             IQNatan1(x, 3)/*!< atan(x),Format:IQ3 */
#define IQ2atan1(x)             IQNatan1(x, 2)/*!< atan(x),Format:IQ2 */
#define IQ1atan1(x)             IQNatan1(x, 1)/*!< atan(x),Format:IQ1 */

/**
  * @}
  */


/*--------------------  IQ format atan2 = atan(y/x)----------------------*/
#ifdef SINOIQMATH_USE_GENERAL
/*! Performance: Compiler Optimization (Obalance): 135 cycles */
IQN IQNatan2_G(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 111 cycles */
IQN IQNatan2_Q24_G(IQN X, IQN Y);
/*! Performance: Compiler Optimization (Obalance): 135 cycles */
IQN IQNatan21_G(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 111 cycles */
IQN IQNatan21_Q24_G(IQN X, IQN Y);
#else
/*! Performance: Compiler Optimization (Obalance): 119 cycles */
IQN IQNatan2_N(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 99 cycles */
IQN IQNatan2_Q24_N(IQN X, IQN Y);
/*! Performance: Compiler Optimization (Obalance): 119 cycles */
IQN IQNatan21_N(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 99 cycles */
IQN IQNatan21_Q24_N(IQN X, IQN Y);
#endif

/** @defgroup IQMath_Trigonometric_atan2  ATAN2 Marcos
  * @{
  */

#ifdef SINOIQMATH_USE_GENERAL
#define IQNatan2(x,y,q)        IQNatan2_G(x,y,q)   /*!< atan(y/x),Format:IQx */
#define IQNatan2_Q24(x,y)      IQNatan2_Q24_G(x,y) /*!< atan(y/x),Format:IQ24 */
#define IQNatan21(x,y,q)       IQNatan21_G(x,y,q)  /*!< atan(y/x),Format:IQx */
#define IQNatan21_Q24(x,y)     IQNatan21_Q24_G(x,y)/*!< atan(y/x),Format:IQ24 */
#else
#define IQNatan2(x,y,q)        IQNatan2_N(x,y,q)   /*!< atan(y/x),Format:IQx */
#define IQNatan2_Q24(x,y)      IQNatan2_Q24_N(x,y) /*!< atan(y/x),Format:IQ24 */
#define IQNatan21(x,y,q)       IQNatan21_N(x,y,q)  /*!< atan(y/x),Format:IQx */
#define IQNatan21_Q24(x,y)     IQNatan21_Q24_N(x,y)/*!< atan(y/x),Format:IQ24 */
#endif

  
#define IQ31atan2(x, y)            IQNatan2(x, y, 31)/*!< atan(y/x),Format:IQ31 */
#define IQ30atan2(x, y)            IQNatan2(x, y, 30)/*!< atan(y/x),Format:IQ30 */
#define IQ29atan2(x, y)            IQNatan2(x, y, 29)/*!< atan(y/x),Format:IQ29 */
#define IQ28atan2(x, y)            IQNatan2(x, y, 28)/*!< atan(y/x),Format:IQ28 */
#define IQ27atan2(x, y)            IQNatan2(x, y, 27)/*!< atan(y/x),Format:IQ27 */
#define IQ26atan2(x, y)            IQNatan2(x, y, 26)/*!< atan(y/x),Format:IQ26 */
#define IQ25atan2(x, y)            IQNatan2(x, y, 25)/*!< atan(y/x),Format:IQ25 */
#define IQ24atan2(x, y)            IQNatan2_Q24(x, y)/*!< atan(y/x),Format:IQ24 */
#define IQ23atan2(x, y)            IQNatan2(x, y, 23)/*!< atan(y/x),Format:IQ23 */
#define IQ22atan2(x, y)            IQNatan2(x, y, 22)/*!< atan(y/x),Format:IQ22 */
#define IQ21atan2(x, y)            IQNatan2(x, y, 21)/*!< atan(y/x),Format:IQ21 */
#define IQ20atan2(x, y)            IQNatan2(x, y, 20)/*!< atan(y/x),Format:IQ20 */
#define IQ19atan2(x, y)            IQNatan2(x, y, 19)/*!< atan(y/x),Format:IQ19 */
#define IQ18atan2(x, y)            IQNatan2(x, y, 18)/*!< atan(y/x),Format:IQ18 */
#define IQ17atan2(x, y)            IQNatan2(x, y, 17)/*!< atan(y/x),Format:IQ17 */
#define IQ16atan2(x, y)            IQNatan2(x, y, 16)/*!< atan(y/x),Format:IQ16 */
#define IQ15atan2(x, y)            IQNatan2(x, y, 15)/*!< atan(y/x),Format:IQ15 */
#define IQ14atan2(x, y)            IQNatan2(x, y, 14)/*!< atan(y/x),Format:IQ14 */
#define IQ13atan2(x, y)            IQNatan2(x, y, 13)/*!< atan(y/x),Format:IQ13 */
#define IQ12atan2(x, y)            IQNatan2(x, y, 12)/*!< atan(y/x),Format:IQ12 */
#define IQ11atan2(x, y)            IQNatan2(x, y, 11)/*!< atan(y/x),Format:IQ11 */
#define IQ10atan2(x, y)            IQNatan2(x, y, 10)/*!< atan(y/x),Format:IQ10 */
#define IQ9atan2(x, y)             IQNatan2(x, y, 9)/*!< atan(y/x),Format:IQ9 */
#define IQ8atan2(x, y)             IQNatan2(x, y, 8)/*!< atan(y/x),Format:IQ8 */
#define IQ7atan2(x, y)             IQNatan2(x, y, 7)/*!< atan(y/x),Format:IQ7 */
#define IQ6atan2(x, y)             IQNatan2(x, y, 6)/*!< atan(y/x),Format:IQ6 */
#define IQ5atan2(x, y)             IQNatan2(x, y, 5)/*!< atan(y/x),Format:IQ5 */
#define IQ4atan2(x, y)             IQNatan2(x, y, 4)/*!< atan(y/x),Format:IQ4 */
#define IQ3atan2(x, y)             IQNatan2(x, y, 3)/*!< atan(y/x),Format:IQ3 */
#define IQ2atan2(x, y)             IQNatan2(x, y, 2)/*!< atan(y/x),Format:IQ2 */
#define IQ1atan2(x, y)             IQNatan2(x, y, 1)/*!< atan(y/x),Format:IQ1 */

#define IQ31atan21(x, y)            IQNatan21(x, y, 31)/*!< atan(y/x),Format:IQ31 */
#define IQ30atan21(x, y)            IQNatan21(x, y, 30)/*!< atan(y/x),Format:IQ30 */
#define IQ29atan21(x, y)            IQNatan21(x, y, 29)/*!< atan(y/x),Format:IQ29 */
#define IQ28atan21(x, y)            IQNatan21(x, y, 28)/*!< atan(y/x),Format:IQ28 */
#define IQ27atan21(x, y)            IQNatan21(x, y, 27)/*!< atan(y/x),Format:IQ27 */
#define IQ26atan21(x, y)            IQNatan21(x, y, 26)/*!< atan(y/x),Format:IQ26 */
#define IQ25atan21(x, y)            IQNatan21(x, y, 25)/*!< atan(y/x),Format:IQ25 */
#define IQ24atan21(x, y)            IQNatan2_Q24(x, y)/*!< atan(y/x),Format:IQ24 */
#define IQ23atan21(x, y)            IQNatan21(x, y, 23)/*!< atan(y/x),Format:IQ23 */
#define IQ22atan21(x, y)            IQNatan21(x, y, 22)/*!< atan(y/x),Format:IQ22 */
#define IQ21atan21(x, y)            IQNatan21(x, y, 21)/*!< atan(y/x),Format:IQ21 */
#define IQ20atan21(x, y)            IQNatan21(x, y, 20)/*!< atan(y/x),Format:IQ20 */
#define IQ19atan21(x, y)            IQNatan21(x, y, 19)/*!< atan(y/x),Format:IQ19 */
#define IQ18atan21(x, y)            IQNatan21(x, y, 18)/*!< atan(y/x),Format:IQ18 */
#define IQ17atan21(x, y)            IQNatan21(x, y, 17)/*!< atan(y/x),Format:IQ17 */
#define IQ16atan21(x, y)            IQNatan21(x, y, 16)/*!< atan(y/x),Format:IQ16 */
#define IQ15atan21(x, y)            IQNatan21(x, y, 15)/*!< atan(y/x),Format:IQ15 */
#define IQ14atan21(x, y)            IQNatan21(x, y, 14)/*!< atan(y/x),Format:IQ14 */
#define IQ13atan21(x, y)            IQNatan21(x, y, 13)/*!< atan(y/x),Format:IQ13 */
#define IQ12atan21(x, y)            IQNatan21(x, y, 12)/*!< atan(y/x),Format:IQ12 */
#define IQ11atan21(x, y)            IQNatan21(x, y, 11)/*!< atan(y/x),Format:IQ11 */
#define IQ10atan21(x, y)            IQNatan21(x, y, 10)/*!< atan(y/x),Format:IQ10 */
#define IQ9atan21(x, y)             IQNatan21(x, y, 9)/*!< atan(y/x),Format:IQ9 */
#define IQ8atan21(x, y)             IQNatan21(x, y, 8)/*!< atan(y/x),Format:IQ8 */
#define IQ7atan21(x, y)             IQNatan21(x, y, 7)/*!< atan(y/x),Format:IQ7 */
#define IQ6atan21(x, y)             IQNatan21(x, y, 6)/*!< atan(y/x),Format:IQ6 */
#define IQ5atan21(x, y)             IQNatan21(x, y, 5)/*!< atan(y/x),Format:IQ5 */
#define IQ4atan21(x, y)             IQNatan21(x, y, 4)/*!< atan(y/x),Format:IQ4 */
#define IQ3atan21(x, y)             IQNatan21(x, y, 3)/*!< atan(y/x),Format:IQ3 */
#define IQ2atan21(x, y)             IQNatan21(x, y, 2)/*!< atan(y/x),Format:IQ2 */
#define IQ1atan21(x, y)             IQNatan21(x, y, 1)/*!< atan(y/x),Format:IQ1 */

/**
  * @}
  */



/*--------------------  IQ format atanh = atanh(x) ----------------------*/
#ifdef SINOIQMATH_USE_GENERAL
/*! Performance: Compiler Optimization (Obalance): 145 cycles */
IQN IQNatanh_G(IQN X, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 105 cycles */
IQN IQNatanh_Q24_G(IQN X);
/*! Performance: Compiler Optimization (Obalance): 145 cycles */
IQN IQNatanh1_G(IQN X, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 105 cycles */
IQN IQNatanh1_Q24_G(IQN X);
#else
/*! Performance: Compiler Optimization (Obalance): 132 cycles */
IQN IQNatanh_N(IQN X, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 93 cycles */
IQN IQNatanh_Q24_N(IQN X);
/*! Performance: Compiler Optimization (Obalance): 132 cycles */
IQN IQNatanh1_N(IQN X, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 93 cycles */
IQN IQNatanh1_Q24_N(IQN X);
#endif

/** @defgroup IQMath_Trigonometric_Atanh  ATANH Marcos
  * @{
  */
  
#ifdef SINOIQMATH_USE_GENERAL
#define IQNatanh(x,q)           IQNatanh_G(x,q)   /*!< atanh(x),Format:IQx */
#define IQNatanh_Q24(x)         IQNatanh_Q24_G(x) /*!< atanh(x),Format:IQ24 */
#define IQNatanh1(x,q)          IQNatanh1_G(x,q)  /*!< atanh(x),Format:IQx */
#define IQNatanh1_Q24(x)        IQNatanh1_Q24_G(x)/*!< atanh(x),Format:IQ24 */
#else
#define IQNatanh(x,q)           IQNatanh_N(x,q)   /*!< atanh(x),Format:IQx */
#define IQNatanh_Q24(x)         IQNatanh_Q24_N(x) /*!< atanh(x),Format:IQ24 */
#define IQNatanh1(x,q)          IQNatanh1_N(x,q)  /*!< atanh(x),Format:IQx */
#define IQNatanh1_Q24(x)        IQNatanh1_Q24_N(x)/*!< atanh(x),Format:IQ24 */
#endif  
  
#define IQ31atanh(x)            IQNatanh(x, 31)/*!< atanh(x),Format:IQ31 */
#define IQ30atanh(x)            IQNatanh(x, 30)/*!< atanh(x),Format:IQ30 */
#define IQ29atanh(x)            IQNatanh(x, 29)/*!< atanh(x),Format:IQ29 */
#define IQ28atanh(x)            IQNatanh(x, 28)/*!< atanh(x),Format:IQ28 */
#define IQ27atanh(x)            IQNatanh(x, 27)/*!< atanh(x),Format:IQ27 */
#define IQ26atanh(x)            IQNatanh(x, 26)/*!< atanh(x),Format:IQ26 */
#define IQ25atanh(x)            IQNatanh(x, 25)/*!< atanh(x),Format:IQ25 */
#define IQ24atanh(x)            IQNatan_Q24(x) /*!< atanh(x),Format:IQ24 */
#define IQ23atanh(x)            IQNatanh(x, 23)/*!< atanh(x),Format:IQ23 */
#define IQ22atanh(x)            IQNatanh(x, 22)/*!< atanh(x),Format:IQ22 */
#define IQ21atanh(x)            IQNatanh(x, 21)/*!< atanh(x),Format:IQ21 */
#define IQ20atanh(x)            IQNatanh(x, 20)/*!< atanh(x),Format:IQ20 */
#define IQ19atanh(x)            IQNatanh(x, 19)/*!< atanh(x),Format:IQ19 */
#define IQ18atanh(x)            IQNatanh(x, 18)/*!< atanh(x),Format:IQ18 */
#define IQ17atanh(x)            IQNatanh(x, 17)/*!< atanh(x),Format:IQ17 */
#define IQ16atanh(x)            IQNatanh(x, 16)/*!< atanh(x),Format:IQ16 */
#define IQ15atanh(x)            IQNatanh(x, 15)/*!< atanh(x),Format:IQ15 */
#define IQ14atanh(x)            IQNatanh(x, 14)/*!< atanh(x),Format:IQ14 */
#define IQ13atanh(x)            IQNatanh(x, 13)/*!< atanh(x),Format:IQ13 */
#define IQ12atanh(x)            IQNatanh(x, 12)/*!< atanh(x),Format:IQ12 */
#define IQ11atanh(x)            IQNatanh(x, 11)/*!< atanh(x),Format:IQ11 */
#define IQ10atanh(x)            IQNatanh(x, 10)/*!< atanh(x),Format:IQ10 */
#define IQ9atanh(x)             IQNatanh(x, 9)/*!< atanh(x),Format:IQ9 */
#define IQ8atanh(x)             IQNatanh(x, 8)/*!< atanh(x),Format:IQ8 */
#define IQ7atanh(x)             IQNatanh(x, 7)/*!< atanh(x),Format:IQ7 */
#define IQ6atanh(x)             IQNatanh(x, 6)/*!< atanh(x),Format:IQ6 */
#define IQ5atanh(x)             IQNatanh(x, 5)/*!< atanh(x),Format:IQ5 */
#define IQ4atanh(x)             IQNatanh(x, 4)/*!< atanh(x),Format:IQ4 */
#define IQ3atanh(x)             IQNatanh(x, 3)/*!< atanh(x),Format:IQ3 */
#define IQ2atanh(x)             IQNatanh(x, 2)/*!< atanh(x),Format:IQ2 */
#define IQ1atanh(x)             IQNatanh(x, 1)/*!< atanh(x),Format:IQ1 */

#define IQ31atanh1(x)            IQNatanh1(x, 31)/*!< atanh(x),Format:IQ31 */
#define IQ30atanh1(x)            IQNatanh1(x, 30)/*!< atanh(x),Format:IQ30 */
#define IQ29atanh1(x)            IQNatanh1(x, 29)/*!< atanh(x),Format:IQ29 */
#define IQ28atanh1(x)            IQNatanh1(x, 28)/*!< atanh(x),Format:IQ28 */
#define IQ27atanh1(x)            IQNatanh1(x, 27)/*!< atanh(x),Format:IQ27 */
#define IQ26atanh1(x)            IQNatanh1(x, 26)/*!< atanh(x),Format:IQ26 */
#define IQ25atanh1(x)            IQNatanh1(x, 25)/*!< atanh(x),Format:IQ25 */
#define IQ24atanh1(x)            IQNatanh1_Q24(x)/*!< atanh(x),Format:IQ24 */
#define IQ23atanh1(x)            IQNatanh1(x, 23)/*!< atanh(x),Format:IQ23 */
#define IQ22atanh1(x)            IQNatanh1(x, 22)/*!< atanh(x),Format:IQ22 */
#define IQ21atanh1(x)            IQNatanh1(x, 21)/*!< atanh(x),Format:IQ21 */
#define IQ20atanh1(x)            IQNatanh1(x, 20)/*!< atanh(x),Format:IQ20 */
#define IQ19atanh1(x)            IQNatanh1(x, 19)/*!< atanh(x),Format:IQ19 */
#define IQ18atanh1(x)            IQNatanh1(x, 18)/*!< atanh(x),Format:IQ18 */
#define IQ17atanh1(x)            IQNatanh1(x, 17)/*!< atanh(x),Format:IQ17 */
#define IQ16atanh1(x)            IQNatanh1(x, 16)/*!< atanh(x),Format:IQ16 */
#define IQ15atanh1(x)            IQNatanh1(x, 15)/*!< atanh(x),Format:IQ15 */
#define IQ14atanh1(x)            IQNatanh1(x, 14)/*!< atanh(x),Format:IQ14 */
#define IQ13atanh1(x)            IQNatanh1(x, 13)/*!< atanh(x),Format:IQ13 */
#define IQ12atanh1(x)            IQNatanh1(x, 12)/*!< atanh(x),Format:IQ12 */
#define IQ11atanh1(x)            IQNatanh1(x, 11)/*!< atanh(x),Format:IQ11 */
#define IQ10atanh1(x)            IQNatanh1(x, 10)/*!< atanh(x),Format:IQ10 */
#define IQ9atanh1(x)             IQNatanh1(x, 9)/*!< atanh(x),Format:IQ9 */
#define IQ8atanh1(x)             IQNatanh1(x, 8)/*!< atanh(x),Format:IQ8 */
#define IQ7atanh1(x)             IQNatanh1(x, 7)/*!< atanh(x),Format:IQ7 */
#define IQ6atanh1(x)             IQNatanh1(x, 6)/*!< atanh(x),Format:IQ6 */
#define IQ5atanh1(x)             IQNatanh1(x, 5)/*!< atanh(x),Format:IQ5 */
#define IQ4atanh1(x)             IQNatanh1(x, 4)/*!< atanh(x),Format:IQ4 */
#define IQ3atanh1(x)             IQNatanh1(x, 3)/*!< atanh(x),Format:IQ3 */
#define IQ2atanh1(x)             IQNatanh1(x, 2)/*!< atanh(x),Format:IQ2 */
#define IQ1atanh1(x)             IQNatanh1(x, 1)/*!< atanh(x),Format:IQ1 */

/**
  * @}
  */


/*--------------------  IQ format atanh2 = atanh(y/x) ----------------------*/
#ifdef SINOIQMATH_USE_GENERAL
/*! Performance: Compiler Optimization (Obalance): 164 cycles */
IQN IQNatanh2_G(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 132 cycles */
IQN IQNatanh2_Q24_G(IQN X, IQN Y);
/*! Performance: Compiler Optimization (Obalance): 164 cycles */
IQN IQNatanh21_G(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 132 cycles */
IQN IQNatanh21_Q24_G(IQN X, IQN Y);
#else
/*! Performance: Compiler Optimization (Obalance): 128 cycles */
IQN IQNatanh2_N(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 120 cycles */
IQN IQNatanh2_Q24_N(IQN X, IQN Y);
/*! Performance: Compiler Optimization (Obalance): 128 cycles */
IQN IQNatanh21_N(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 120 cycles */
IQN IQNatanh21_Q24_N(IQN X, IQN Y);
#endif

/** @defgroup IQMath_Trigonometric_atanh2  ATANH2 Marcos
  * @{
  */
#ifdef SINOIQMATH_USE_GENERAL
#define IQNatanh2(x,y,q)       IQNatanh2_G(x,y,q)   /*!< atanh(y/x),Format:IQx */
#define IQNatanh2_Q24(x,y)     IQNatanh2_Q24_G(x,y) /*!< atanh(y/x),Format:IQ24 */
#define IQNatanh21(x,y,q)      IQNatanh21_G(x,y,q)  /*!< atanh(y/x),Format:IQx */
#define IQNatanh21_Q24(x,y)    IQNatanh21_Q24_G(x,y)/*!< atanh(y/x),Format:IQ24 */
#else
#define IQNatanh2(x,y,q)       IQNatanh2_N(x,y,q)   /*!< atanh(y/x),Format:IQx */
#define IQNatanh2_Q24(x,y)     IQNatanh2_Q24_N(x,y) /*!< atanh(y/x),Format:IQ24 */
#define IQNatanh21(x,y,q)      IQNatanh21_N(x,y,q)  /*!< atanh(y/x),Format:IQx */
#define IQNatanh21_Q24(x,y)    IQNatanh21_Q24_N(x,y)/*!< atanh(y/x),Format:IQ24 */
#endif  
  
#define IQ31atanh2(x, y)            IQNatanh2(x, y, 31)/*!< atanh(y/x),Format:IQ31 */
#define IQ30atanh2(x, y)            IQNatanh2(x, y, 30)/*!< atanh(y/x),Format:IQ30 */
#define IQ29atanh2(x, y)            IQNatanh2(x, y, 29)/*!< atanh(y/x),Format:IQ29 */
#define IQ28atanh2(x, y)            IQNatanh2(x, y, 28)/*!< atanh(y/x),Format:IQ28 */
#define IQ27atanh2(x, y)            IQNatanh2(x, y, 27)/*!< atanh(y/x),Format:IQ27 */
#define IQ26atanh2(x, y)            IQNatanh2(x, y, 26)/*!< atanh(y/x),Format:IQ26 */
#define IQ25atanh2(x, y)            IQNatanh2(x, y, 25)/*!< atanh(y/x),Format:IQ25 */
#define IQ24atanh2(x, y)            IQNatanh2_Q24(x, y)/*!< atanh(y/x),Format:IQ24 */
#define IQ23atanh2(x, y)            IQNatanh2(x, y, 23)/*!< atanh(y/x),Format:IQ23 */
#define IQ22atanh2(x, y)            IQNatanh2(x, y, 22)/*!< atanh(y/x),Format:IQ22 */
#define IQ21atanh2(x, y)            IQNatanh2(x, y, 21)/*!< atanh(y/x),Format:IQ21 */
#define IQ20atanh2(x, y)            IQNatanh2(x, y, 20)/*!< atanh(y/x),Format:IQ20 */
#define IQ19atanh2(x, y)            IQNatanh2(x, y, 19)/*!< atanh(y/x),Format:IQ19 */
#define IQ18atanh2(x, y)            IQNatanh2(x, y, 18)/*!< atanh(y/x),Format:IQ18 */
#define IQ17atanh2(x, y)            IQNatanh2(x, y, 17)/*!< atanh(y/x),Format:IQ17 */
#define IQ16atanh2(x, y)            IQNatanh2(x, y, 16)/*!< atanh(y/x),Format:IQ16 */
#define IQ15atanh2(x, y)            IQNatanh2(x, y, 15)/*!< atanh(y/x),Format:IQ15 */
#define IQ14atanh2(x, y)            IQNatanh2(x, y, 14)/*!< atanh(y/x),Format:IQ14 */
#define IQ13atanh2(x, y)            IQNatanh2(x, y, 13)/*!< atanh(y/x),Format:IQ13 */
#define IQ12atanh2(x, y)            IQNatanh2(x, y, 12)/*!< atanh(y/x),Format:IQ12 */
#define IQ11atanh2(x, y)            IQNatanh2(x, y, 11)/*!< atanh(y/x),Format:IQ11 */
#define IQ10atanh2(x, y)            IQNatanh2(x, y, 10)/*!< atanh(y/x),Format:IQ10 */
#define IQ9atanh2(x, y)             IQNatanh2(x, y, 9)/*!< atanh(y/x),Format:IQ9 */
#define IQ8atanh2(x, y)             IQNatanh2(x, y, 8)/*!< atanh(y/x),Format:IQ8 */
#define IQ7atanh2(x, y)             IQNatanh2(x, y, 7)/*!< atanh(y/x),Format:IQ7 */
#define IQ6atanh2(x, y)             IQNatanh2(x, y, 6)/*!< atanh(y/x),Format:IQ6 */
#define IQ5atanh2(x, y)             IQNatanh2(x, y, 5)/*!< atanh(y/x),Format:IQ5 */
#define IQ4atanh2(x, y)             IQNatanh2(x, y, 4)/*!< atanh(y/x),Format:IQ4 */
#define IQ3atanh2(x, y)             IQNatanh2(x, y, 3)/*!< atanh(y/x),Format:IQ3 */
#define IQ2atanh2(x, y)             IQNatanh2(x, y, 2)/*!< atanh(y/x),Format:IQ2 */
#define IQ1atanh2(x, y)             IQNatanh2(x, y, 1)/*!< atanh(y/x),Format:IQ1 */

#define IQ31atanh21(x, y)            IQNatanh21(x, y, 31)/*!< atanh(y/x),Format:IQ31 */
#define IQ30atanh21(x, y)            IQNatanh21(x, y, 30)/*!< atanh(y/x),Format:IQ30 */
#define IQ29atanh21(x, y)            IQNatanh21(x, y, 29)/*!< atanh(y/x),Format:IQ29 */
#define IQ28atanh21(x, y)            IQNatanh21(x, y, 28)/*!< atanh(y/x),Format:IQ28 */
#define IQ27atanh21(x, y)            IQNatanh21(x, y, 27)/*!< atanh(y/x),Format:IQ27 */
#define IQ26atanh21(x, y)            IQNatanh21(x, y, 26)/*!< atanh(y/x),Format:IQ26 */
#define IQ25atanh21(x, y)            IQNatanh21(x, y, 25)/*!< atanh(y/x),Format:IQ25 */
#define IQ24atanh21(x, y)            IQNatanh2_Q24(x, y)/*!< atanh(y/x),Format:IQ24 */
#define IQ23atanh21(x, y)            IQNatanh21(x, y, 23)/*!< atanh(y/x),Format:IQ23 */
#define IQ22atanh21(x, y)            IQNatanh21(x, y, 22)/*!< atanh(y/x),Format:IQ22 */
#define IQ21atanh21(x, y)            IQNatanh21(x, y, 21)/*!< atanh(y/x),Format:IQ21 */
#define IQ20atanh21(x, y)            IQNatanh21(x, y, 20)/*!< atanh(y/x),Format:IQ20 */
#define IQ19atanh21(x, y)            IQNatanh21(x, y, 19)/*!< atanh(y/x),Format:IQ19 */
#define IQ18atanh21(x, y)            IQNatanh21(x, y, 18)/*!< atanh(y/x),Format:IQ18 */
#define IQ17atanh21(x, y)            IQNatanh21(x, y, 17)/*!< atanh(y/x),Format:IQ17 */
#define IQ16atanh21(x, y)            IQNatanh21(x, y, 16)/*!< atanh(y/x),Format:IQ16 */
#define IQ15atanh21(x, y)            IQNatanh21(x, y, 15)/*!< atanh(y/x),Format:IQ15 */
#define IQ14atanh21(x, y)            IQNatanh21(x, y, 14)/*!< atanh(y/x),Format:IQ14 */
#define IQ13atanh21(x, y)            IQNatanh21(x, y, 13)/*!< atanh(y/x),Format:IQ13 */
#define IQ12atanh21(x, y)            IQNatanh21(x, y, 12)/*!< atanh(y/x),Format:IQ12 */
#define IQ11atanh21(x, y)            IQNatanh21(x, y, 11)/*!< atanh(y/x),Format:IQ11 */
#define IQ10atanh21(x, y)            IQNatanh21(x, y, 10)/*!< atanh(y/x),Format:IQ10 */
#define IQ9atanh21(x, y)             IQNatanh21(x, y, 9)/*!< atanh(y/x),Format:IQ9 */
#define IQ8atanh21(x, y)             IQNatanh21(x, y, 8)/*!< atanh(y/x),Format:IQ8 */
#define IQ7atanh21(x, y)             IQNatanh21(x, y, 7)/*!< atanh(y/x),Format:IQ7 */
#define IQ6atanh21(x, y)             IQNatanh21(x, y, 6)/*!< atanh(y/x),Format:IQ6 */
#define IQ5atanh21(x, y)             IQNatanh21(x, y, 5)/*!< atanh(y/x),Format:IQ5 */
#define IQ4atanh21(x, y)             IQNatanh21(x, y, 4)/*!< atanh(y/x),Format:IQ4 */
#define IQ3atanh21(x, y)             IQNatanh21(x, y, 3)/*!< atanh(y/x),Format:IQ3 */
#define IQ2atanh21(x, y)             IQNatanh21(x, y, 2)/*!< atanh(y/x),Format:IQ2 */
#define IQ1atanh21(x, y)             IQNatanh21(x, y, 1)/*!< atanh(y/x),Format:IQ1 */

/**
  * @}
  */


/**
  * @}
  */

/** @addtogroup IQMath_Mathematical Mathematical Functions
  * @{
  */
/*-------------------- IQ format root mean square  = sqrt((x^2 + y^2)/2)----------------------*/
/*! Performance: Compiler Optimization (Obalance): 142 cycles */
IQN IQNrms(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 110 cycles */
IQN IQNrms_Q24(IQN X, IQN Y);
/*! Performance: Compiler Optimization (Obalance): 142 cycles */
IQN IQNrms1(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 110 cycles */
IQN IQNrms1_Q24(IQN X, IQN Y);

/** @defgroup IQMATH_Arithmetic_RMS_Marcos  RMS Marcos
  * @{
  */
#define IQ31rms(x, y)            IQNrms(x, y, 31)/*!< sqrt((x^2 + y^2)/2),Format:IQ31 */
#define IQ30rms(x, y)            IQNrms(x, y, 30)/*!< sqrt((x^2 + y^2)/2),Format:IQ30 */
#define IQ29rms(x, y)            IQNrms(x, y, 29)/*!< sqrt((x^2 + y^2)/2),Format:IQ29 */
#define IQ28rms(x, y)            IQNrms(x, y, 28)/*!< sqrt((x^2 + y^2)/2),Format:IQ28 */
#define IQ27rms(x, y)            IQNrms(x, y, 27)/*!< sqrt((x^2 + y^2)/2),Format:IQ27 */
#define IQ26rms(x, y)            IQNrms(x, y, 26)/*!< sqrt((x^2 + y^2)/2),Format:IQ26 */
#define IQ25rms(x, y)            IQNrms(x, y, 25)/*!< sqrt((x^2 + y^2)/2),Format:IQ25 */
#define IQ24rms(x, y)            IQNrms_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ24 */
#define IQ23rms(x, y)            IQNrms_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ23 */
#define IQ22rms(x, y)            IQNrms_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ22 */
#define IQ21rms(x, y)            IQNrms_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ21 */
#define IQ20rms(x, y)            IQNrms_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ20 */
#define IQ19rms(x, y)            IQNrms_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ19 */
#define IQ18rms(x, y)            IQNrms_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ18 */
#define IQ17rms(x, y)            IQNrms_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ17 */
#define IQ16rms(x, y)            IQNrms_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ16 */
#define IQ15rms(x, y)            IQNrms_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ15 */
#define IQ14rms(x, y)            IQNrms(x, y, 14)/*!< sqrt((x^2 + y^2)/2),Format:IQ14 */
#define IQ13rms(x, y)            IQNrms(x, y, 13)/*!< sqrt((x^2 + y^2)/2),Format:IQ13 */
#define IQ12rms(x, y)            IQNrms(x, y, 12)/*!< sqrt((x^2 + y^2)/2),Format:IQ12 */
#define IQ11rms(x, y)            IQNrms(x, y, 11)/*!< sqrt((x^2 + y^2)/2),Format:IQ11 */
#define IQ10rms(x, y)            IQNrms(x, y, 10)/*!< sqrt((x^2 + y^2)/2),Format:IQ10 */
#define IQ9rms(x, y)             IQNrms(x, y, 9)/*!< sqrt((x^2 + y^2)/2),Format:IQ9 */
#define IQ8rms(x, y)             IQNrms(x, y, 8)/*!< sqrt((x^2 + y^2)/2),Format:IQ8 */
#define IQ7rms(x, y)             IQNrms(x, y, 7)/*!< sqrt((x^2 + y^2)/2),Format:IQ7 */
#define IQ6rms(x, y)             IQNrms(x, y, 6)/*!< sqrt((x^2 + y^2)/2),Format:IQ6 */
#define IQ5rms(x, y)             IQNrms(x, y, 5)/*!< sqrt((x^2 + y^2)/2),Format:IQ5 */
#define IQ4rms(x, y)             IQNrms(x, y, 4)/*!< sqrt((x^2 + y^2)/2),Format:IQ4 */
#define IQ3rms(x, y)             IQNrms(x, y, 3)/*!< sqrt((x^2 + y^2)/2),Format:IQ3 */
#define IQ2rms(x, y)             IQNrms(x, y, 2)/*!< sqrt((x^2 + y^2)/2),Format:IQ2 */
#define IQ1rms(x, y)             IQNrms(x, y, 1)/*!< sqrt((x^2 + y^2)/2),Format:IQ1 */

#define IQ31rms1(x, y)            IQNrms1(x, y, 31)/*!< sqrt((x^2 + y^2)/2),Format:IQ31 */
#define IQ30rms1(x, y)            IQNrms1(x, y, 30)/*!< sqrt((x^2 + y^2)/2),Format:IQ30 */
#define IQ29rms1(x, y)            IQNrms1(x, y, 29)/*!< sqrt((x^2 + y^2)/2),Format:IQ29 */
#define IQ28rms1(x, y)            IQNrms1(x, y, 28)/*!< sqrt((x^2 + y^2)/2),Format:IQ28 */
#define IQ27rms1(x, y)            IQNrms1(x, y, 27)/*!< sqrt((x^2 + y^2)/2),Format:IQ27 */
#define IQ26rms1(x, y)            IQNrms1(x, y, 26)/*!< sqrt((x^2 + y^2)/2),Format:IQ26 */
#define IQ25rms1(x, y)            IQNrms1(x, y, 25)/*!< sqrt((x^2 + y^2)/2),Format:IQ25 */
#define IQ24rms1(x, y)            IQNrms1_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ24 */
#define IQ23rms1(x, y)            IQNrms1_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ23 */
#define IQ22rms1(x, y)            IQNrms1_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ22 */
#define IQ21rms1(x, y)            IQNrms1_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ21 */
#define IQ20rms1(x, y)            IQNrms1_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ20 */
#define IQ19rms1(x, y)            IQNrms1_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ19 */
#define IQ18rms1(x, y)            IQNrms1_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ18 */
#define IQ17rms1(x, y)            IQNrms1_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ17 */
#define IQ16rms1(x, y)            IQNrms1_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ16 */
#define IQ15rms1(x, y)            IQNrms1_Q24(x, y)/*!< sqrt((x^2 + y^2)/2),Format:IQ15 */
#define IQ14rms1(x, y)            IQNrms1(x, y, 14)/*!< sqrt((x^2 + y^2)/2),Format:IQ14 */
#define IQ13rms1(x, y)            IQNrms1(x, y, 13)/*!< sqrt((x^2 + y^2)/2),Format:IQ13 */
#define IQ12rms1(x, y)            IQNrms1(x, y, 12)/*!< sqrt((x^2 + y^2)/2),Format:IQ12 */
#define IQ11rms1(x, y)            IQNrms1(x, y, 11)/*!< sqrt((x^2 + y^2)/2),Format:IQ11 */
#define IQ10rms1(x, y)            IQNrms1(x, y, 10)/*!< sqrt((x^2 + y^2)/2),Format:IQ10 */
#define IQ9rms1(x, y)             IQNrms1(x, y, 9)/*!< sqrt((x^2 + y^2)/2),Format:IQ9 */
#define IQ8rms1(x, y)             IQNrms1(x, y, 8)/*!< sqrt((x^2 + y^2)/2),Format:IQ8 */
#define IQ7rms1(x, y)             IQNrms1(x, y, 7)/*!< sqrt((x^2 + y^2)/2),Format:IQ7 */
#define IQ6rms1(x, y)             IQNrms1(x, y, 6)/*!< sqrt((x^2 + y^2)/2),Format:IQ6 */
#define IQ5rms1(x, y)             IQNrms1(x, y, 5)/*!< sqrt((x^2 + y^2)/2),Format:IQ5 */
#define IQ4rms1(x, y)             IQNrms1(x, y, 4)/*!< sqrt((x^2 + y^2)/2),Format:IQ4 */
#define IQ3rms1(x, y)             IQNrms1(x, y, 3)/*!< sqrt((x^2 + y^2)/2),Format:IQ3 */
#define IQ2rms1(x, y)             IQNrms1(x, y, 2)/*!< sqrt((x^2 + y^2)/2),Format:IQ2 */
#define IQ1rms1(x, y)             IQNrms1(x, y, 1)/*!< sqrt((x^2 + y^2)/2),Format:IQ1 */

  /**
  * @}
  */

/*--------------------IQ format Square root of sum of squares = sqrt(x^2 + y^2)----------------------*/
/*! Performance: Compiler Optimization (Obalance): 131 cycles */
IQN IQNhypot(IQN X, IQN Y, int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 99 cycles */
IQN IQNhypot_Q24(IQN X, IQN Y);
/*! Performance: Compiler Optimization (Obalance): 131 cycles */
IQN IQNhypot1(IQN X, IQN Y,int32_t QN);
/*! Performance: Compiler Optimization (Obalance): 99 cycles */
IQN IQNhypot1_Q24(IQN X, IQN Y);

/** @defgroup IQMATH_Arithmetic_hypot_Marcos  HYPOT Marcos
  * @{
  */
#define IQ31hypot(x, y)            IQNhypot(x, y, 31)/*!< sqrt(x^2 + y^2),Format:IQ31 */
#define IQ30hypot(x, y)            IQNhypot(x, y, 30)/*!< sqrt(x^2 + y^2),Format:IQ30 */
#define IQ29hypot(x, y)            IQNhypot(x, y, 29)/*!< sqrt(x^2 + y^2),Format:IQ29 */
#define IQ28hypot(x, y)            IQNhypot(x, y, 28)/*!< sqrt(x^2 + y^2),Format:IQ28 */
#define IQ27hypot(x, y)            IQNhypot(x, y, 27)/*!< sqrt(x^2 + y^2),Format:IQ27 */
#define IQ26hypot(x, y)            IQNhypot(x, y, 26)/*!< sqrt(x^2 + y^2),Format:IQ26 */
#define IQ25hypot(x, y)            IQNhypot(x, y, 25)/*!< sqrt(x^2 + y^2),Format:IQ25 */
#define IQ24hypot(x, y)            IQNhypot_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ24 */
#define IQ23hypot(x, y)            IQNhypot_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ23 */
#define IQ22hypot(x, y)            IQNhypot_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ22 */
#define IQ21hypot(x, y)            IQNhypot_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ21 */
#define IQ20hypot(x, y)            IQNhypot_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ20 */
#define IQ19hypot(x, y)            IQNhypot_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ19 */
#define IQ18hypot(x, y)            IQNhypot_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ18 */
#define IQ17hypot(x, y)            IQNhypot_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ17 */
#define IQ16hypot(x, y)            IQNhypot_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ16 */
#define IQ15hypot(x, y)            IQNhypot_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ15 */
#define IQ14hypot(x, y)            IQNhypot(x, y, 14)/*!< sqrt(x^2 + y^2),Format:IQ14 */
#define IQ13hypot(x, y)            IQNhypot(x, y, 13)/*!< sqrt(x^2 + y^2),Format:IQ13 */
#define IQ12hypot(x, y)            IQNhypot(x, y, 12)/*!< sqrt(x^2 + y^2),Format:IQ12 */
#define IQ11hypot(x, y)            IQNhypot(x, y, 11)/*!< sqrt(x^2 + y^2),Format:IQ11 */
#define IQ10hypot(x, y)            IQNhypot(x, y, 10)/*!< sqrt(x^2 + y^2),Format:IQ10 */
#define IQ9hypot(x, y)             IQNhypot(x, y, 9)/*!< sqrt(x^2 + y^2),Format:IQ9 */
#define IQ8hypot(x, y)             IQNhypot(x, y, 8)/*!< sqrt(x^2 + y^2),Format:IQ8 */
#define IQ7hypot(x, y)             IQNhypot(x, y, 7)/*!< sqrt(x^2 + y^2),Format:IQ7 */
#define IQ6hypot(x, y)             IQNhypot(x, y, 6)/*!< sqrt(x^2 + y^2),Format:IQ6 */
#define IQ5hypot(x, y)             IQNhypot(x, y, 5)/*!< sqrt(x^2 + y^2),Format:IQ5 */
#define IQ4hypot(x, y)             IQNhypot(x, y, 4)/*!< sqrt(x^2 + y^2),Format:IQ4 */
#define IQ3hypot(x, y)             IQNhypot(x, y, 3)/*!< sqrt(x^2 + y^2),Format:IQ3 */
#define IQ2hypot(x, y)             IQNhypot(x, y, 2)/*!< sqrt(x^2 + y^2),Format:IQ2 */
#define IQ1hypot(x, y)             IQNhypot(x, y, 1)/*!< sqrt(x^2 + y^2),Format:IQ1 */

#define IQ31hypot1(x, y)            IQNhypot1(x, y, 31)/*!< sqrt(x^2 + y^2),Format:IQ31 */
#define IQ30hypot1(x, y)            IQNhypot1(x, y, 30)/*!< sqrt(x^2 + y^2),Format:IQ30 */
#define IQ29hypot1(x, y)            IQNhypot1(x, y, 29)/*!< sqrt(x^2 + y^2),Format:IQ29 */
#define IQ28hypot1(x, y)            IQNhypot1(x, y, 28)/*!< sqrt(x^2 + y^2),Format:IQ28 */
#define IQ27hypot1(x, y)            IQNhypot1(x, y, 27)/*!< sqrt(x^2 + y^2),Format:IQ27 */
#define IQ26hypot1(x, y)            IQNhypot1(x, y, 26)/*!< sqrt(x^2 + y^2),Format:IQ26 */
#define IQ25hypot1(x, y)            IQNhypot1(x, y, 25)/*!< sqrt(x^2 + y^2),Format:IQ25 */
#define IQ24hypot1(x, y)            IQNhypot1_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ24 */
#define IQ23hypot1(x, y)            IQNhypot1_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ23 */
#define IQ22hypot1(x, y)            IQNhypot1_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ22 */
#define IQ21hypot1(x, y)            IQNhypot1_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ21 */
#define IQ20hypot1(x, y)            IQNhypot1_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ20 */
#define IQ19hypot1(x, y)            IQNhypot1_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ19 */
#define IQ18hypot1(x, y)            IQNhypot1_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ18 */
#define IQ17hypot1(x, y)            IQNhypot1_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ17 */
#define IQ16hypot1(x, y)            IQNhypot1_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ16 */
#define IQ15hypot1(x, y)            IQNhypot1_Q24(x, y)/*!< sqrt(x^2 + y^2),Format:IQ15 */
#define IQ14hypot1(x, y)            IQNhypot1(x, y, 14)/*!< sqrt(x^2 + y^2),Format:IQ14 */
#define IQ13hypot1(x, y)            IQNhypot1(x, y, 13)/*!< sqrt(x^2 + y^2),Format:IQ13 */
#define IQ12hypot1(x, y)            IQNhypot1(x, y, 12)/*!< sqrt(x^2 + y^2),Format:IQ12 */
#define IQ11hypot1(x, y)            IQNhypot1(x, y, 11)/*!< sqrt(x^2 + y^2),Format:IQ11 */
#define IQ10hypot1(x, y)            IQNhypot1(x, y, 10)/*!< sqrt(x^2 + y^2),Format:IQ10 */
#define IQ9hypot1(x, y)             IQNhypot1(x, y, 9)/*!< sqrt(x^2 + y^2),Format:IQ9 */
#define IQ8hypot1(x, y)             IQNhypot1(x, y, 8)/*!< sqrt(x^2 + y^2),Format:IQ8 */
#define IQ7hypot1(x, y)             IQNhypot1(x, y, 7)/*!< sqrt(x^2 + y^2),Format:IQ7 */
#define IQ6hypot1(x, y)             IQNhypot1(x, y, 6)/*!< sqrt(x^2 + y^2),Format:IQ6 */
#define IQ5hypot1(x, y)             IQNhypot1(x, y, 5)/*!< sqrt(x^2 + y^2),Format:IQ5 */
#define IQ4hypot1(x, y)             IQNhypot1(x, y, 4)/*!< sqrt(x^2 + y^2),Format:IQ4 */
#define IQ3hypot1(x, y)             IQNhypot1(x, y, 3)/*!< sqrt(x^2 + y^2),Format:IQ3 */
#define IQ2hypot1(x, y)             IQNhypot1(x, y, 2)/*!< sqrt(x^2 + y^2),Format:IQ2 */
#define IQ1hypot1(x, y)             IQNhypot1(x, y, 1)/*!< sqrt(x^2 + y^2),Format:IQ1 */

#define IQhypot(x,y)     IQ24hypot(x,y) /*!< sqrt(x^2 + y^2),Format:IQ24 */
#define IQhypot1(x,y)    IQ24hypot1(x,y)/*!< sqrt(x^2 + y^2),Format:IQ24 */

#define IQmode(x,y)   IQ24hypot(x,y)  /*!< compatible former version */
#define IQmode1(x,y)  IQ24hypot1(x,y) /*!< compatible former version */
IQN IQNmode_Q24(IQN X, IQN Y); /*!< compatible former version */
IQN IQNmode1_Q24(IQN X, IQN Y); /*!< compatible former version */

  /**
  * @}
  */
/*-------------------- IQ Format sqrt(x)----------------------*/
/*! Performance: Compiler Optimization (Obalance): 121 cycles */
IQN IQNsqrt(IQN X, IQN QN);        //Q1~Q31
/*! Performance: Compiler Optimization (Obalance): 121 cycles */
IQN IQNsqrt1(IQN X, IQN QN);       //Q1~Q31  
/** @defgroup IQMATH_Arithmetic_sqrt_Marcos  SQRT Marcos
  * @{
  */
  
#define IQ31sqrt(x)            IQNsqrt(x, 31)/*!< sqrt(x),Format:IQ31 */
#define IQ30sqrt(x)            IQNsqrt(x, 30)/*!< sqrt(x),Format:IQ30 */
#define IQ29sqrt(x)            IQNsqrt(x, 29)/*!< sqrt(x),Format:IQ29 */
#define IQ28sqrt(x)            IQNsqrt(x, 28)/*!< sqrt(x),Format:IQ28 */
#define IQ27sqrt(x)            IQNsqrt(x, 27)/*!< sqrt(x),Format:IQ27 */
#define IQ26sqrt(x)            IQNsqrt(x, 26)/*!< sqrt(x),Format:IQ26 */
#define IQ25sqrt(x)            IQNsqrt(x, 25)/*!< sqrt(x),Format:IQ25 */
#define IQ24sqrt(x)            IQNsqrt(x, 24)/*!< sqrt(x),Format:IQ24 */
#define IQ23sqrt(x)            IQNsqrt(x, 23)/*!< sqrt(x),Format:IQ23 */
#define IQ22sqrt(x)            IQNsqrt(x, 22)/*!< sqrt(x),Format:IQ22 */
#define IQ21sqrt(x)            IQNsqrt(x, 21)/*!< sqrt(x),Format:IQ21 */
#define IQ20sqrt(x)            IQNsqrt(x, 20)/*!< sqrt(x),Format:IQ20 */
#define IQ19sqrt(x)            IQNsqrt(x, 19)/*!< sqrt(x),Format:IQ19 */
#define IQ18sqrt(x)            IQNsqrt(x, 18)/*!< sqrt(x),Format:IQ18 */
#define IQ17sqrt(x)            IQNsqrt(x, 17)/*!< sqrt(x),Format:IQ17 */
#define IQ16sqrt(x)            IQNsqrt(x, 16)/*!< sqrt(x),Format:IQ16 */
#define IQ15sqrt(x)            IQNsqrt(x, 15)/*!< sqrt(x),Format:IQ15 */
#define IQ14sqrt(x)            IQNsqrt(x, 14)/*!< sqrt(x),Format:IQ14 */
#define IQ13sqrt(x)            IQNsqrt(x, 13)/*!< sqrt(x),Format:IQ13 */
#define IQ12sqrt(x)            IQNsqrt(x, 12)/*!< sqrt(x),Format:IQ12 */
#define IQ11sqrt(x)            IQNsqrt(x, 11)/*!< sqrt(x),Format:IQ11 */
#define IQ10sqrt(x)            IQNsqrt(x, 10)/*!< sqrt(x),Format:IQ10 */
#define IQ9sqrt(x)             IQNsqrt(x, 9)/*!< sqrt(x),Format:IQ9 */
#define IQ8sqrt(x)             IQNsqrt(x, 8)/*!< sqrt(x),Format:IQ8 */
#define IQ7sqrt(x)             IQNsqrt(x, 7)/*!< sqrt(x),Format:IQ7 */
#define IQ6sqrt(x)             IQNsqrt(x, 6)/*!< sqrt(x),Format:IQ6 */
#define IQ5sqrt(x)             IQNsqrt(x, 5)/*!< sqrt(x),Format:IQ5 */
#define IQ4sqrt(x)             IQNsqrt(x, 4)/*!< sqrt(x),Format:IQ4 */
#define IQ3sqrt(x)             IQNsqrt(x, 3)/*!< sqrt(x),Format:IQ3 */
#define IQ2sqrt(x)             IQNsqrt(x, 2)/*!< sqrt(x),Format:IQ2 */
#define IQ1sqrt(x)             IQNsqrt(x, 1)/*!< sqrt(x),Format:IQ1 */

#define IQ31sqrt1(x)            IQNsqrt1(x, 31)/*!< sqrt(x),Format:IQ31 */
#define IQ30sqrt1(x)            IQNsqrt1(x, 30)/*!< sqrt(x),Format:IQ30 */
#define IQ29sqrt1(x)            IQNsqrt1(x, 29)/*!< sqrt(x),Format:IQ29 */
#define IQ28sqrt1(x)            IQNsqrt1(x, 28)/*!< sqrt(x),Format:IQ28 */
#define IQ27sqrt1(x)            IQNsqrt1(x, 27)/*!< sqrt(x),Format:IQ27 */
#define IQ26sqrt1(x)            IQNsqrt1(x, 26)/*!< sqrt(x),Format:IQ26 */
#define IQ25sqrt1(x)            IQNsqrt1(x, 25)/*!< sqrt(x),Format:IQ25 */
#define IQ24sqrt1(x)            IQNsqrt1(x, 24)/*!< sqrt(x),Format:IQ24 */
#define IQ23sqrt1(x)            IQNsqrt1(x, 23)/*!< sqrt(x),Format:IQ23 */
#define IQ22sqrt1(x)            IQNsqrt1(x, 22)/*!< sqrt(x),Format:IQ22 */
#define IQ21sqrt1(x)            IQNsqrt1(x, 21)/*!< sqrt(x),Format:IQ21 */
#define IQ20sqrt1(x)            IQNsqrt1(x, 20)/*!< sqrt(x),Format:IQ20 */
#define IQ19sqrt1(x)            IQNsqrt1(x, 19)/*!< sqrt(x),Format:IQ19 */
#define IQ18sqrt1(x)            IQNsqrt1(x, 18)/*!< sqrt(x),Format:IQ18 */
#define IQ17sqrt1(x)            IQNsqrt1(x, 17)/*!< sqrt(x),Format:IQ17 */
#define IQ16sqrt1(x)            IQNsqrt1(x, 16)/*!< sqrt(x),Format:IQ16 */
#define IQ15sqrt1(x)            IQNsqrt1(x, 15)/*!< sqrt(x),Format:IQ15 */
#define IQ14sqrt1(x)            IQNsqrt1(x, 14)/*!< sqrt(x),Format:IQ14 */
#define IQ13sqrt1(x)            IQNsqrt1(x, 13)/*!< sqrt(x),Format:IQ13 */
#define IQ12sqrt1(x)            IQNsqrt1(x, 12)/*!< sqrt(x),Format:IQ12 */
#define IQ11sqrt1(x)            IQNsqrt1(x, 11)/*!< sqrt(x),Format:IQ11 */
#define IQ10sqrt1(x)            IQNsqrt1(x, 10)/*!< sqrt(x),Format:IQ10 */
#define IQ9sqrt1(x)             IQNsqrt1(x, 9)/*!< sqrt(x),Format:IQ9 */
#define IQ8sqrt1(x)             IQNsqrt1(x, 8)/*!< sqrt(x),Format:IQ8 */
#define IQ7sqrt1(x)             IQNsqrt1(x, 7)/*!< sqrt(x),Format:IQ7 */
#define IQ6sqrt1(x)             IQNsqrt1(x, 6)/*!< sqrt(x),Format:IQ6 */
#define IQ5sqrt1(x)             IQNsqrt1(x, 5)/*!< sqrt(x),Format:IQ5 */
#define IQ4sqrt1(x)             IQNsqrt1(x, 4)/*!< sqrt(x),Format:IQ4 */
#define IQ3sqrt1(x)             IQNsqrt1(x, 3)/*!< sqrt(x),Format:IQ3 */
#define IQ2sqrt1(x)             IQNsqrt1(x, 2)/*!< sqrt(x),Format:IQ2 */
#define IQ1sqrt1(x)             IQNsqrt1(x, 1)/*!< sqrt(x),Format:IQ1 */

  /**
  * @}
  */
  
/**
  * @}
  */
  
/*-------------------- IQ Format rotate(x,y)----------------------*/
/** @addtogroup IQMath_Miscellaneous Miscellaneous Functions
  * @{
  */
  

/*! Performance: Compiler Optimization (Obalance): 26 cycles */
#define Qabs(x)                     abs(x)  /*!< Q format abs */

/*! structure ROTATE_TypeDef definition */
typedef struct
{
    IQN X;      /*!< X */
    IQN Y;      /*!< X */
	IQN Angle;  /*!< Angle use rad unit*/
}ROTATE_TypeDef;

#ifdef SINOIQMATH_USE_GENERAL
/*! Performance: Compiler Optimization (Obalance): 150 cycles */
void IQNrotate_G(ROTATE_TypeDef* protate,IQN QN);
/*! Performance: Compiler Optimization (Obalance): 117 cycles */
void IQNrotate_Q24_G(ROTATE_TypeDef* protate);
/*! Performance: Compiler Optimization (Obalance): 150 cycles */
void IQNrotate1_G(ROTATE_TypeDef* protate,IQN QN);
/*! Performance: Compiler Optimization (Obalance): 117 cycles */
void IQNrotate1_Q24_G(ROTATE_TypeDef* protate);
#else
/*! Performance: Compiler Optimization (Obalance): 144 cycles */
void IQNrotate_N(ROTATE_TypeDef* protate,IQN QN);
/*! Performance: Compiler Optimization (Obalance): 112 cycles */
void IQNrotate_Q24_N(ROTATE_TypeDef* protate);
/*! Performance: Compiler Optimization (Obalance): 144 cycles */
void IQNrotate1_N(ROTATE_TypeDef* protate,IQN QN);
/*! Performance: Compiler Optimization (Obalance): 112 cycles */
void IQNrotate1_Q24_N(ROTATE_TypeDef* protate);
#endif

/** @defgroup IQMATH_Arithmetic_rotate_Marcos  Rotate Marcos
  * @{
  */
  
#ifdef SINOIQMATH_USE_GENERAL
#define IQNrotate(p,q)      IQNrotate_G(p,q)   /*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQx */
#define IQNrotate_Q24(p)    IQNrotate_Q24_G(p) /*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ24 */
#define IQNrotate1(p,q)     IQNrotate1_G(p,q)  /*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQx */
#define IQNrotate1_Q24(p)   IQNrotate1_Q24_G(p)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ24 */
#else
#define IQNrotate(p,q)      IQNrotate_N(p,q)   /*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQx */
#define IQNrotate_Q24(p)    IQNrotate_Q24_N(p) /*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ24 */
#define IQNrotate1(p,q)     IQNrotate1_N(p,q)  /*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQx */
#define IQNrotate1_Q24(p)   IQNrotate1_Q24_N(p)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ24 */
#endif

 
#define IQ31rotate(p)            IQNrotate(p, 31)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ31 */
#define IQ30rotate(p)            IQNrotate(p, 30)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ30 */
#define IQ29rotate(p)            IQNrotate(p, 29)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ29 */
#define IQ28rotate(p)            IQNrotate(p, 28)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ28 */
#define IQ27rotate(p)            IQNrotate(p, 27)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ27 */
#define IQ26rotate(p)            IQNrotate(p, 26)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ26 */
#define IQ25rotate(p)            IQNrotate(p, 25)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ25 */
#define IQ24rotate(p)            IQNrotate_Q24(p)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ24 */
#define IQ23rotate(p)            IQNrotate(p, 23)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ23 */
#define IQ22rotate(p)            IQNrotate(p, 22)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ22 */
#define IQ21rotate(p)            IQNrotate(p, 21)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ21 */
#define IQ20rotate(p)            IQNrotate(p, 20)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ20 */
#define IQ19rotate(p)            IQNrotate(p, 19)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ19 */
#define IQ18rotate(p)            IQNrotate(p, 18)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ18 */
#define IQ17rotate(p)            IQNrotate(p, 17)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ17 */
#define IQ16rotate(p)            IQNrotate(p, 16)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ16 */
#define IQ15rotate(p)            IQNrotate(p, 15)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ15 */
#define IQ14rotate(p)            IQNrotate(p, 14)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ14 */
#define IQ13rotate(p)            IQNrotate(p, 13)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ13 */
#define IQ12rotate(p)            IQNrotate(p, 12)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ12 */
#define IQ11rotate(p)            IQNrotate(p, 11)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ11 */
#define IQ10rotate(p)            IQNrotate(p, 10)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ10 */
#define IQ9rotate(p)             IQNrotate(p, 9)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ9 */
#define IQ8rotate(p)             IQNrotate(p, 8)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ8 */
#define IQ7rotate(p)             IQNrotate(p, 7)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ7 */
#define IQ6rotate(p)             IQNrotate(p, 6)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ6 */
#define IQ5rotate(p)             IQNrotate(p, 5)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ5 */
#define IQ4rotate(p)             IQNrotate(p, 4)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ4 */
#define IQ3rotate(p)             IQNrotate(p, 3)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ3 */
#define IQ2rotate(p)             IQNrotate(p, 2)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ2 */
#define IQ1rotate(p)             IQNrotate(p, 1)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ1 */

#define IQ31rotate1(p)            IQNrotate1(p, 31)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ31 */
#define IQ30rotate1(p)            IQNrotate1(p, 30)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ30 */
#define IQ29rotate1(p)            IQNrotate1(p, 29)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ29 */
#define IQ28rotate1(p)            IQNrotate1(p, 28)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ28 */
#define IQ27rotate1(p)            IQNrotate1(p, 27)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ27 */
#define IQ26rotate1(p)            IQNrotate1(p, 26)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ26 */
#define IQ25rotate1(p)            IQNrotate1(p, 25)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ25 */
#define IQ24rotate1(p)            IQNrotate1_Q24(p)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ24 */
#define IQ23rotate1(p)            IQNrotate1(p, 23)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ23 */
#define IQ22rotate1(p)            IQNrotate1(p, 22)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ22 */
#define IQ21rotate1(p)            IQNrotate1(p, 21)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ21 */
#define IQ20rotate1(p)            IQNrotate1(p, 20)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ20 */
#define IQ19rotate1(p)            IQNrotate1(p, 19)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ19 */
#define IQ18rotate1(p)            IQNrotate1(p, 18)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ18 */
#define IQ17rotate1(p)            IQNrotate1(p, 17)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ17 */
#define IQ16rotate1(p)            IQNrotate1(p, 16)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ16 */
#define IQ15rotate1(p)            IQNrotate1(p, 15)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ15 */
#define IQ14rotate1(p)            IQNrotate1(p, 14)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ14 */
#define IQ13rotate1(p)            IQNrotate1(p, 13)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ13 */
#define IQ12rotate1(p)            IQNrotate1(p, 12)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ12 */
#define IQ11rotate1(p)            IQNrotate1(p, 11)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ11 */
#define IQ10rotate1(p)            IQNrotate1(p, 10)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ10 */
#define IQ9rotate1(p)             IQNrotate1(p, 9)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ9 */
#define IQ8rotate1(p)             IQNrotate1(p, 8)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ8 */
#define IQ7rotate1(p)             IQNrotate1(p, 7)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ7 */
#define IQ6rotate1(p)             IQNrotate1(p, 6)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ6 */
#define IQ5rotate1(p)             IQNrotate1(p, 5)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ5 */
#define IQ4rotate1(p)             IQNrotate1(p, 4)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ4 */
#define IQ3rotate1(p)             IQNrotate1(p, 3)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ3 */
#define IQ2rotate1(p)             IQNrotate1(p, 2)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ2 */
#define IQ1rotate1(p)             IQNrotate1(p, 1)/*!< Rotate [p->X,p->Y] Angle:p->Angle, Format:IQ1 */


/**
  * @}
  */
  
/**
  * @}
  */
  
/** @addtogroup IQMath_Motor_Ctrl Motor Control Functions
  * @{
  */
/*-------------------- IQ Format Park(PARK_TypeDef)----------------------*/
/*! structure PARK_TypeDef definition */
typedef struct
{
  IQN  Id;      /*!< Current: Id */  
  IQN  Iq;      /*!< Current: Iq */           
  IQN  Ialpha; /*!< Current: Ialpha */ 
  IQN  Ibeta;  /*!< Current: Ibeta */ 
  IQN  Theta;  /*!< Angle: Theta */   
}PARK_TypeDef; 

/*! Performance: Compiler Optimization (Obalance): 153 cycles */
void IQNpark(PARK_TypeDef* ppark,IQN QN);
/*! Performance: Compiler Optimization (Obalance): 107 cycles */
void IQNpark_Q24(PARK_TypeDef* ppark);
/*! Performance: Compiler Optimization (Obalance): 153 cycles */
void IQNpark1(PARK_TypeDef* ppark,IQN QN);
/*! Performance: Compiler Optimization (Obalance): 107 cycles */
void IQNpark1_Q24(PARK_TypeDef* ppark);

/** @defgroup IQMath_Trigonometric_park PARK Marcos
  * @{
  */
#define IQ31park(x)            IQNpark(x, 31)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ31*/
#define IQ30park(x)            IQNpark(x, 30)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ30 */
#define IQ29park(x)            IQNpark(x, 29)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ29 */
#define IQ28park(x)            IQNpark(x, 28)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ28 */
#define IQ27park(x)            IQNpark(x, 27)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ27 */
#define IQ26park(x)            IQNpark(x, 26)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ26 */
#define IQ25park(x)            IQNpark(x, 25)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ25 */
#define IQ24park(x)            IQNpark_Q24(x)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ24 */
#define IQ23park(x)            IQNpark(x, 23)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ23 */
#define IQ22park(x)            IQNpark(x, 22)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ22 */
#define IQ21park(x)            IQNpark(x, 21)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ21 */
#define IQ20park(x)            IQNpark(x, 20)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ20 */
#define IQ19park(x)            IQNpark(x, 19)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ19 */
#define IQ18park(x)            IQNpark(x, 18)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ18 */
#define IQ17park(x)            IQNpark(x, 17)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ17 */
#define IQ16park(x)            IQNpark(x, 16)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ16 */
#define IQ15park(x)            IQNpark(x, 15)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ15 */
#define IQ14park(x)            IQNpark(x, 14)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ14 */
#define IQ13park(x)            IQNpark(x, 13)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ13 */
#define IQ12park(x)            IQNpark(x, 12)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ12 */
#define IQ11park(x)            IQNpark(x, 11)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ11 */
#define IQ10park(x)            IQNpark(x, 10)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ10 */
#define IQ9park(x)             IQNpark(x, 9)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ9 */
#define IQ8park(x)             IQNpark(x, 8)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ8 */
#define IQ7park(x)             IQNpark(x, 7)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ7 */
#define IQ6park(x)             IQNpark(x, 6)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ6 */
#define IQ5park(x)             IQNpark(x, 5)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ5 */
#define IQ4park(x)             IQNpark(x, 4)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ4 */
#define IQ3park(x)             IQNpark(x, 3)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ3 */
#define IQ2park(x)             IQNpark(x, 2)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ2 */
#define IQ1park(x)             IQNpark(x, 1)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ1 */

#define IQ31park1(x)            IQNpark1(x, 31)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ31*/
#define IQ30park1(x)            IQNpark1(x, 30)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ30 */
#define IQ29park1(x)            IQNpark1(x, 29)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ29 */
#define IQ28park1(x)            IQNpark1(x, 28)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ28 */
#define IQ27park1(x)            IQNpark1(x, 27)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ27 */
#define IQ26park1(x)            IQNpark1(x, 26)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ26 */
#define IQ25park1(x)            IQNpark1(x, 25)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ25 */
#define IQ24park1(x)            IQNpark1_Q24(x)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ24 */
#define IQ23park1(x)            IQNpark1(x, 23)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ23 */
#define IQ22park1(x)            IQNpark1(x, 22)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ22 */
#define IQ21park1(x)            IQNpark1(x, 21)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ21 */
#define IQ20park1(x)            IQNpark1(x, 20)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ20 */
#define IQ19park1(x)            IQNpark1(x, 19)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ19 */
#define IQ18park1(x)            IQNpark1(x, 18)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ18 */
#define IQ17park1(x)            IQNpark1(x, 17)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ17 */
#define IQ16park1(x)            IQNpark1(x, 16)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ16 */
#define IQ15park1(x)            IQNpark1(x, 15)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ15 */
#define IQ14park1(x)            IQNpark1(x, 14)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ14 */
#define IQ13park1(x)            IQNpark1(x, 13)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ13 */
#define IQ12park1(x)            IQNpark1(x, 12)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ12 */
#define IQ11park1(x)            IQNpark1(x, 11)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ11 */
#define IQ10park1(x)            IQNpark1(x, 10)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ10 */
#define IQ9park1(x)             IQNpark1(x, 9)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ9 */
#define IQ8park1(x)             IQNpark1(x, 8)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ8 */
#define IQ7park1(x)             IQNpark1(x, 7)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ7 */
#define IQ6park1(x)             IQNpark1(x, 6)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ6 */
#define IQ5park1(x)             IQNpark1(x, 5)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ5 */
#define IQ4park1(x)             IQNpark1(x, 4)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ4 */
#define IQ3park1(x)             IQNpark1(x, 3)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ3 */
#define IQ2park1(x)             IQNpark1(x, 2)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ2 */
#define IQ1park1(x)             IQNpark1(x, 1)/*!< [x->Id,x->Iq] = Park Transform[x->Ialpha,x->Ibeta,x->Theta]. Format: IQ1 */

/**
  * @}
  */
  
/*-------------------- IQ Format IPark(PARK_TypeDef)----------------------*/
/*! structure IPARK_TypeDef definition*/
typedef struct
{
  IQN  Ud;         /*!< parameter Ud*/  
  IQN  Uq;         /*!< parameter Uq*/         
  IQN  Ualpha;    /*!< parameter Ualpha*/  
  IQN  Ubeta;     /*!< parameter Ubeta*/  
  IQN  Theta;     /*!< parameter Theta*/  
}IPARK_TypeDef;
/*! Performance: Compiler Optimization (Obalance): 145 cycles */
void IQNipark(IPARK_TypeDef* pipark,IQN QN);
/*! Performance: Compiler Optimization (Obalance): 110 cycles */
void IQNipark_Q24(IPARK_TypeDef* pipark);
/*! Performance: Compiler Optimization (Obalance): 145 cycles */
void IQNipark1(IPARK_TypeDef* pipark,IQN QN);
/*! Performance: Compiler Optimization (Obalance): 110 cycles */
void IQNipark1_Q24(IPARK_TypeDef* pipark);

/** @defgroup IQMath_Trigonometric_ipark  IPARK Marcos
  * @{
  */
#define IQ31ipark(x)            IQNipark(x, 31)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ31*/
#define IQ30ipark(x)            IQNipark(x, 30)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ30 */
#define IQ29ipark(x)            IQNipark(x, 29)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ29 */
#define IQ28ipark(x)            IQNipark(x, 28)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ28 */
#define IQ27ipark(x)            IQNipark(x, 27)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ27 */
#define IQ26ipark(x)            IQNipark(x, 26)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ26 */
#define IQ25ipark(x)            IQNipark(x, 25)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ25 */
#define IQ24ipark(x)            IQNipark_Q24(x)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ24 */
#define IQ23ipark(x)            IQNipark(x, 23)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ23 */
#define IQ22ipark(x)            IQNipark(x, 22)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ22 */
#define IQ21ipark(x)            IQNipark(x, 21)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ21 */
#define IQ20ipark(x)            IQNipark(x, 20)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ20 */
#define IQ19ipark(x)            IQNipark(x, 19)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ19 */
#define IQ18ipark(x)            IQNipark(x, 18)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ18 */
#define IQ17ipark(x)            IQNipark(x, 17)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ17 */
#define IQ16ipark(x)            IQNipark(x, 16)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ16 */
#define IQ15ipark(x)            IQNipark(x, 15)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ15 */
#define IQ14ipark(x)            IQNipark(x, 14)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ14 */
#define IQ13ipark(x)            IQNipark(x, 13)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ13 */
#define IQ12ipark(x)            IQNipark(x, 12)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ12 */
#define IQ11ipark(x)            IQNipark(x, 11)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ11 */
#define IQ10ipark(x)            IQNipark(x, 10)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ10 */
#define IQ9ipark(x)             IQNipark(x, 9)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ9 */
#define IQ8ipark(x)             IQNipark(x, 8)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ8 */
#define IQ7ipark(x)             IQNipark(x, 7)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ7 */
#define IQ6ipark(x)             IQNipark(x, 6)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ6 */
#define IQ5ipark(x)             IQNipark(x, 5)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ5 */
#define IQ4ipark(x)             IQNipark(x, 4)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ4 */
#define IQ3ipark(x)             IQNipark(x, 3)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ3 */
#define IQ2ipark(x)             IQNipark(x, 2)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ2 */
#define IQ1ipark(x)             IQNipark(x, 1)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ1 */

#define IQ31ipark1(x)            IQNipark1(x, 31)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ31*/
#define IQ30ipark1(x)            IQNipark1(x, 30)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ30 */
#define IQ29ipark1(x)            IQNipark1(x, 29)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ29 */
#define IQ28ipark1(x)            IQNipark1(x, 28)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ28 */
#define IQ27ipark1(x)            IQNipark1(x, 27)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ27 */
#define IQ26ipark1(x)            IQNipark1(x, 26)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ26 */
#define IQ25ipark1(x)            IQNipark1(x, 25)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ25 */
#define IQ24ipark1(x)            IQNipark1_Q24(x)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ24 */
#define IQ23ipark1(x)            IQNipark1(x, 23)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ23 */
#define IQ22ipark1(x)            IQNipark1(x, 22)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ22 */
#define IQ21ipark1(x)            IQNipark1(x, 21)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ21 */
#define IQ20ipark1(x)            IQNipark1(x, 20)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ20 */
#define IQ19ipark1(x)            IQNipark1(x, 19)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ19 */
#define IQ18ipark1(x)            IQNipark1(x, 18)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ18 */
#define IQ17ipark1(x)            IQNipark1(x, 17)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ17 */
#define IQ16ipark1(x)            IQNipark1(x, 16)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ16 */
#define IQ15ipark1(x)            IQNipark1(x, 15)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ15 */
#define IQ14ipark1(x)            IQNipark1(x, 14)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ14 */
#define IQ13ipark1(x)            IQNipark1(x, 13)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ13 */
#define IQ12ipark1(x)            IQNipark1(x, 12)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ12 */
#define IQ11ipark1(x)            IQNipark1(x, 11)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ11 */
#define IQ10ipark1(x)            IQNipark1(x, 10)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ10 */
#define IQ9ipark1(x)             IQNipark1(x, 9)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ9 */
#define IQ8ipark1(x)             IQNipark1(x, 8)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ8 */
#define IQ7ipark1(x)             IQNipark1(x, 7)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ7 */
#define IQ6ipark1(x)             IQNipark1(x, 6)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ6 */
#define IQ5ipark1(x)             IQNipark1(x, 5)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ5 */
#define IQ4ipark1(x)             IQNipark1(x, 4)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ4 */
#define IQ3ipark1(x)             IQNipark1(x, 3)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ3 */
#define IQ2ipark1(x)             IQNipark1(x, 2)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ2 */
#define IQ1ipark1(x)             IQNipark1(x, 1)/*!<  [x->Ualpha,x->Ubeta] = iPark Transform[x->Ud,x->Uq,x->Theta]. Format: IQ1 */

/**
  * @}
  */
  
/*-------------------- IQ Format Clarke(CLARKE_TypeDef)----------------------*/
/*! structrue CLARK_TypeDef definition*/
typedef struct 
{  
  IQN  Ia; /*!< parameter Ia*/           
  IQN  Ib; /*!< parameter Ib*/            
  IQN  Ic; /*!< parameter Ic*/           
  IQN  Ialpha;/*!< parameter Ialpha*/
  IQN  Ibeta; /*!< parameter Ibeta*/
} CLARKE_TypeDef;  
/*! Performance: Compiler Optimization (Obalance): 80 cycles */
void IQNclarke(CLARKE_TypeDef* pclarke,IQN QN);
/*! Performance: Compiler Optimization (Obalance): 45 cycles */
void IQNclarke_Q24(CLARKE_TypeDef* pclarke);
/** @defgroup IQMath_Trigonometric_clarke  CLARKE Marcos
  * @{
  */
#define IQ31clarke(x)            IQNclarke(x, 31)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ31*/
#define IQ30clarke(x)            IQNclarke(x, 30)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ30 */
#define IQ29clarke(x)            IQNclarke(x, 29)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ29 */
#define IQ28clarke(x)            IQNclarke(x, 28)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ28 */
#define IQ27clarke(x)            IQNclarke(x, 27)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ27 */
#define IQ26clarke(x)            IQNclarke(x, 26)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ26 */
#define IQ25clarke(x)            IQNclarke(x, 25)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ25 */
#define IQ24clarke(x)            IQNclarke_Q24(x)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ24 */
#define IQ23clarke(x)            IQNclarke(x, 23)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ23 */
#define IQ22clarke(x)            IQNclarke(x, 22)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ22 */
#define IQ21clarke(x)            IQNclarke(x, 21)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ21 */
#define IQ20clarke(x)            IQNclarke(x, 20)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ20 */
#define IQ19clarke(x)            IQNclarke(x, 19)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ19 */
#define IQ18clarke(x)            IQNclarke(x, 18)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ18 */
#define IQ17clarke(x)            IQNclarke(x, 17)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ17 */
#define IQ16clarke(x)            IQNclarke(x, 16)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ16 */
#define IQ15clarke(x)            IQNclarke(x, 15)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ15 */
#define IQ14clarke(x)            IQNclarke(x, 14)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ14 */
#define IQ13clarke(x)            IQNclarke(x, 13)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ13 */
#define IQ12clarke(x)            IQNclarke(x, 12)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ12 */
#define IQ11clarke(x)            IQNclarke(x, 11)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ11 */
#define IQ10clarke(x)            IQNclarke(x, 10)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ10 */
#define IQ9clarke(x)             IQNclarke(x, 9)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ9 */
#define IQ8clarke(x)             IQNclarke(x, 8)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ8 */
#define IQ7clarke(x)             IQNclarke(x, 7)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ7 */
#define IQ6clarke(x)             IQNclarke(x, 6)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ6 */
#define IQ5clarke(x)             IQNclarke(x, 5)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ5 */
#define IQ4clarke(x)             IQNclarke(x, 4)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ4 */
#define IQ3clarke(x)             IQNclarke(x, 3)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ3 */
#define IQ2clarke(x)             IQNclarke(x, 2)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ2 */
#define IQ1clarke(x)             IQNclarke(x, 1)/*!<  [x->Ialpha,x->Ibeta] = Clarke Transform[x->Ia,x->Ib,x->Ic]. Format: IQ1 */

/**
  * @}
  */
/*-------------------- IQ Format PID(PARK_TypeDef)----------------------*/
/*! structure PID_TypeDef definition*/
typedef struct {
  IQN  Ref;      /*!< PID: Ref*/
  IQN  Fdb;      /*!< PID: Fdb*/
  IQN  Err;      /*!< PID: Err*/
  IQN  ErrLast;  /*!< PID: ErrLast*/
  IQN  Kp;       /*!< PID: Kp*/    
  IQN  Ki;       /*!< PID: Ki*/
  IQN  Kd;       /*!< PID: Kd*/
  IQN  Up;       /*!< PID: Up*/
  IQN  Ui;       /*!< PID: Ui*/
  IQN  Ud;       /*!< PID: Ud*/
  IQN  Uout;     /*!< PID: Uout*/
  IQN  ErrMax;   /*!< PID: ErrMax*/
  IQN  UiMax;    /*!< PID: UiMax*/
  IQN  UoutMax;  /*!< PID: UoutMax*/
} PID_TypeDef;

/*! Performance: Compiler Optimization (Obalance): 178 cycles */
void IQNpid(PID_TypeDef *ppid,IQN QN);
/*! Performance: Compiler Optimization (Obalance): 153 cycles */
void IQNpid_Q24(PID_TypeDef *ppid);

/** @defgroup IQMath_Trigonometric_pid  PID Marcos
  * @{
  */
  
#define IQ31pid(x)            IQNpid(x, 31)/*!<  PID control arithmetic. Format: IQ31*/
#define IQ30pid(x)            IQNpid(x, 30)/*!<  PID control arithmetic. Format: IQ30 */
#define IQ29pid(x)            IQNpid(x, 29)/*!<  PID control arithmetic. Format: IQ29 */
#define IQ28pid(x)            IQNpid(x, 28)/*!<  PID control arithmetic. Format: IQ28 */
#define IQ27pid(x)            IQNpid(x, 27)/*!<  PID control arithmetic. Format: IQ27 */
#define IQ26pid(x)            IQNpid(x, 26)/*!<  PID control arithmetic. Format: IQ26 */
#define IQ25pid(x)            IQNpid(x, 25)/*!<  PID control arithmetic. Format: IQ25 */
#define IQ24pid(x)            IQNpid_Q24(x)/*!<  PID control arithmetic. Format: IQ24 */
#define IQ23pid(x)            IQNpid(x, 23)/*!<  PID control arithmetic. Format: IQ23 */
#define IQ22pid(x)            IQNpid(x, 22)/*!<  PID control arithmetic. Format: IQ22 */
#define IQ21pid(x)            IQNpid(x, 21)/*!<  PID control arithmetic. Format: IQ21 */
#define IQ20pid(x)            IQNpid(x, 20)/*!<  PID control arithmetic. Format: IQ20 */
#define IQ19pid(x)            IQNpid(x, 19)/*!<  PID control arithmetic. Format: IQ19 */
#define IQ18pid(x)            IQNpid(x, 18)/*!<  PID control arithmetic. Format: IQ18 */
#define IQ17pid(x)            IQNpid(x, 17)/*!<  PID control arithmetic. Format: IQ17 */
#define IQ16pid(x)            IQNpid(x, 16)/*!<  PID control arithmetic. Format: IQ16 */
#define IQ15pid(x)            IQNpid(x, 15)/*!<  PID control arithmetic. Format: IQ15 */
#define IQ14pid(x)            IQNpid(x, 14)/*!<  PID control arithmetic. Format: IQ14 */
#define IQ13pid(x)            IQNpid(x, 13)/*!<  PID control arithmetic. Format: IQ13 */
#define IQ12pid(x)            IQNpid(x, 12)/*!<  PID control arithmetic. Format: IQ12 */
#define IQ11pid(x)            IQNpid(x, 11)/*!<  PID control arithmetic. Format: IQ11 */
#define IQ10pid(x)            IQNpid(x, 10)/*!<  PID control arithmetic. Format: IQ10 */
#define IQ9pid(x)             IQNpid(x, 9)/*!<  PID control arithmetic. Format: IQ9 */
#define IQ8pid(x)             IQNpid(x, 8)/*!<  PID control arithmetic. Format: IQ8 */
#define IQ7pid(x)             IQNpid(x, 7)/*!<  PID control arithmetic. Format: IQ7 */
#define IQ6pid(x)             IQNpid(x, 6)/*!<  PID control arithmetic. Format: IQ6 */
#define IQ5pid(x)             IQNpid(x, 5)/*!<  PID control arithmetic. Format: IQ5 */
#define IQ4pid(x)             IQNpid(x, 4)/*!<  PID control arithmetic. Format: IQ4 */
#define IQ3pid(x)             IQNpid(x, 3)/*!<  PID control arithmetic. Format: IQ3 */
#define IQ2pid(x)             IQNpid(x, 2)/*!<  PID control arithmetic. Format: IQ2 */
#define IQ1pid(x)             IQNpid(x, 1)/*!<  PID control arithmetic. Format: IQ1 */

/**
  * @}
  */
  						
/*-------------------- IQ Format PID(PARK_TypeDef)----------------------*/
/*! structure SVPWMDQ_TypeDef definition*/
typedef struct 
{  
	uint32_t Sector; /*!< SVPWM Parameter: Sector*/
	IQ24  Ualpa;     /*!< SVPWM Parameter: Ualpa*/   
    IQ24  Ubeta;     /*!< SVPWM Parameter: Ubeta*/       
    IQ24  Ta;        /*!< SVPWM Parameter: Ta*/
    IQ24  Tb;        /*!< SVPWM Parameter: Tb*/
    IQ24  Tc;        /*!< SVPWM Parameter: Tc*/
}SVPWMDQ_TypeDef;
/*! Performance: Compiler Optimization (Obalance): 100 cycles */
void IQNsvpwm(SVPWMDQ_TypeDef* psvpwmdq,IQN QN,uint32_t seg);	
/*! Performance: Compiler Optimization (Obalance): 86 cycles */
void IQNsvpwm5_Q24(SVPWMDQ_TypeDef* psvpwmdq);
/*! Performance: Compiler Optimization (Obalance): 89 cycles */
void IQNsvpwm7_Q24(SVPWMDQ_TypeDef* psvpwmdq);

/** @defgroup IQMath_Trigonometric_svpwm  SVPWM Marcos
  * @{
  */

#define IQ30svpwm7(x)            IQNsvpwm(x, 30, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ30*/
#define IQ29svpwm7(x)            IQNsvpwm(x, 29, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ29*/
#define IQ28svpwm7(x)            IQNsvpwm(x, 28, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ28*/
#define IQ27svpwm7(x)            IQNsvpwm(x, 27, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ27*/
#define IQ26svpwm7(x)            IQNsvpwm(x, 26, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ26*/
#define IQ25svpwm7(x)            IQNsvpwm(x, 25, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ25*/
#define IQ24svpwm7(x)            IQNsvpwm7_Q24(x)  /*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ24*/
#define IQ23svpwm7(x)            IQNsvpwm(x, 23, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ23*/
#define IQ22svpwm7(x)            IQNsvpwm(x, 22, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ22*/
#define IQ21svpwm7(x)            IQNsvpwm(x, 21, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ21*/
#define IQ20svpwm7(x)            IQNsvpwm(x, 20, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ20*/
#define IQ19svpwm7(x)            IQNsvpwm(x, 19, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ19*/
#define IQ18svpwm7(x)            IQNsvpwm(x, 18, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ18*/
#define IQ17svpwm7(x)            IQNsvpwm(x, 17, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ17*/
#define IQ16svpwm7(x)            IQNsvpwm(x, 16, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ16*/
#define IQ15svpwm7(x)            IQNsvpwm(x, 15, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ15*/
#define IQ14svpwm7(x)            IQNsvpwm(x, 14, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ14*/
#define IQ13svpwm7(x)            IQNsvpwm(x, 13, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ13*/
#define IQ12svpwm7(x)            IQNsvpwm(x, 12, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ12*/
#define IQ11svpwm7(x)            IQNsvpwm(x, 11, 0)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ11*/

#define IQ30svpwm5(x)            IQNsvpwm(x, 30, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ30 */
#define IQ29svpwm5(x)            IQNsvpwm(x, 29, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ29 */
#define IQ28svpwm5(x)            IQNsvpwm(x, 28, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ28 */
#define IQ27svpwm5(x)            IQNsvpwm(x, 27, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ27 */
#define IQ26svpwm5(x)            IQNsvpwm(x, 26, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ26 */
#define IQ25svpwm5(x)            IQNsvpwm(x, 25, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ25 */
#define IQ24svpwm5(x)            IQNsvpwm5_Q24(x)  /*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ24 */
#define IQ23svpwm5(x)            IQNsvpwm(x, 23, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ23 */
#define IQ22svpwm5(x)            IQNsvpwm(x, 22, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ22 */
#define IQ21svpwm5(x)            IQNsvpwm(x, 21, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ21 */
#define IQ20svpwm5(x)            IQNsvpwm(x, 20, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ20 */
#define IQ19svpwm5(x)            IQNsvpwm(x, 19, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ19 */
#define IQ18svpwm5(x)            IQNsvpwm(x, 18, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ18 */
#define IQ17svpwm5(x)            IQNsvpwm(x, 17, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ17 */
#define IQ16svpwm5(x)            IQNsvpwm(x, 16, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ16 */
#define IQ15svpwm5(x)            IQNsvpwm(x, 15, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ15 */
#define IQ14svpwm5(x)            IQNsvpwm(x, 14, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ14 */
#define IQ13svpwm5(x)            IQNsvpwm(x, 13, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ13 */
#define IQ12svpwm5(x)            IQNsvpwm(x, 12, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ12 */
#define IQ11svpwm5(x)            IQNsvpwm(x, 11, 1)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-5 Transform [x->Ualpha,x->Ubeta]. Format: IQ11 */

#define Iq30Svpwm(x)   IQ30svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ30*/
#define Iq29Svpwm(x)   IQ29svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ29*/
#define Iq28Svpwm(x)   IQ28svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ28*/
#define Iq27Svpwm(x)   IQ27svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ27*/
#define Iq26Svpwm(x)   IQ26svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ26*/
#define Iq25Svpwm(x)   IQ25svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ25*/
#define Iq24Svpwm(x)   IQ24svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ24*/
#define Iq23Svpwm(x)   IQ23svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ23*/
#define Iq22Svpwm(x)   IQ22svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ22*/
#define Iq21Svpwm(x)   IQ21svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ21*/
#define Iq20Svpwm(x)   IQ20svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ20*/
#define Iq19Svpwm(x)   IQ19svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ19*/
#define Iq18Svpwm(x)   IQ18svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ18*/
#define Iq17Svpwm(x)   IQ17svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ17*/
#define Iq16Svpwm(x)   IQ16svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ16*/
#define Iq15Svpwm(x)   IQ15svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ15*/
#define Iq14Svpwm(x)   IQ14svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ14*/
#define Iq13Svpwm(x)   IQ13svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ13*/
#define Iq12Svpwm(x)   IQ12svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ12*/
#define Iq11Svpwm(x)   IQ11svpwm7(x)/*!< [x->Ta,x->Tb,x->Tc,x->Sector] = SVPWM seg-7 Transform [x->Ualpha,x->Ubeta]. Format: IQ11*/

/**
  * @}
  */
  
/**
  * @}
  */


/**
  * @}
  */

#ifdef __cplusplus
}
#endif

#endif /*__IQMATH_H__ */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
