/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_adc.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the ADC firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_ADC_H
#define __SH3xF2xx_SB0_ADC_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup ADC_MODULE ADC
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/

/** @defgroup ADC_Exported_Types Public Types
  * @{
  */
/*! structure ADC_InitTypeDef definition */
typedef struct
{       
    uint16_t ADC_RefVoltage;       /*!< Select the ADC reference voltage sources
                                     This parameter can be a value of ADC_Reference_Voltage_Sources */
    
    uint16_t ADC_ConversionMode;   /*!< Configure the ADC conversion Mode
                                     This parameter can be a value of ADC_Conversion_Mode */
    
    uint16_t ADC_SocOutEn;         /*!< select the ADC SOC flag output 
                                     This parameter can be a value of ADC_SocOutEn */
    
    uint16_t rev_align;            /*!< reserved for structure alignment*/

    uint32_t ADC_SequencePointer;  /*!< Set the ADC channel pointer to select which channel to be converted.
                                     This parameter can be a value of ADC_Channel_Pointer */
    
    uint32_t ADC_NumOfConversion; /*!< Configure the ADC conversion channel numbers
                                     This parameter can be 1 to 8 */
    
    uint32_t ADC_Prescaler;       /*!< Configure the ADC clock prescaler
                                     This parameter can be a value of ADC_Prescaler */
    
    uint32_t ADC_TwoSampleGap;    /*!< Configure the ADC two sample gap time
                                     This parameter can be a value of ADC_Two_Sample_Gap */
                                     
    uint32_t ADC_SampleTime;      /*!< Configure the ADC sample time
                                     This parameter can be a value of ADC_Sample_Times */
}ADC_InitTypeDef;

/**
  * @}
  */

/* Exported constants --------------------------------------------------------*/

/** @defgroup ADC_Exported_Constants Public Constants
  * @{
  */ 

/** @defgroup ADC_Reference_Voltage_Sources Reference Voltage Source
  * @{
  */

#define ADC_RefVoltage_AVDD             (uint16_t)0x0000  /*!< Reference Voltage: AVDD */
#define ADC_RefVoltage_ExtVref          (uint16_t)0x0010  /*!< Reference Voltage: ExtVref */
#define IS_ADC_REF_VOLTAGE(VOLTAGE)     ((VOLTAGE == ADC_RefVoltage_AVDD) \
                                        || (VOLTAGE == ADC_RefVoltage_ExtVref))    /*!< Check reference parameter */
  
/**
  * @}
  */


/** @defgroup ADC_Conversion_Mode Conversion Mode
  * @{
  */
  
#define ADC_ConversionMode_Single            (uint16_t)0x0000  /*!< Conversion Mode: Single */
#define ADC_ConversionMode_Discontinuous     (uint16_t)0x0002  /*!< Conversion Mode: Discontinuous */
#define ADC_ConversionMode_Continuous        (uint16_t)0x0004  /*!< Conversion Mode: Continuous */
#define ADC_ConversionMode_SingleResSample   (uint16_t)0x0006  /*!< Conversion Mode: Single Resistor Sampling */
#define IS_ADC_CONVERSION_MODE(MODE)         ((MODE == ADC_ConversionMode_Single) \
                                             || (MODE == ADC_ConversionMode_Discontinuous) \
                                             || (MODE == ADC_ConversionMode_Continuous)\
                                             || (MODE == ADC_ConversionMode_SingleResSample))    /*!< Check conversion mode parameter */
/**
  * @}
  */
                                               
/** @defgroup ADC_SocOutEn Soc Out Enable
  * @{
  */
#define ADC_SOC_OUT_DISABLE              (uint16_t)0x0000  /*!< SOC Output Disable */
#define ADC_SOC_OUT_ENABLE               (uint16_t)0x0100  /*!< SOC Output Enable */
#define IS_ADC_SOC_OUT_EN(OUT_EN)        ((OUT_EN == ADC_SOC_OUT_DISABLE) \
                                         || (OUT_EN == ADC_SOC_OUT_ENABLE))   /*!< Check SOC output parameter */
/**
  * @}
  */
  
/** @defgroup ADC_Conversion_Numbers Conversion Number
  * @{
  */
  
#define IS_ADC_CONVERSION_NUMBER(NUMBER)   ((NUMBER >= 1) && (NUMBER <= 16))    /*!< Conversion number */
  
/**
  * @}
  */

                                        
/** @defgroup ADC_Prescaler Prescaler 
  * @{
  */
  
#define ADC_Prescaler_1                 (uint32_t)0x0000  /*!< ADC Prescaler: 1 */
#define ADC_Prescaler_2                 (uint32_t)0x0001  /*!< ADC Prescaler: 2 */
#define ADC_Prescaler_3                 (uint32_t)0x0002  /*!< ADC Prescaler: 3 */
#define ADC_Prescaler_4                 (uint32_t)0x0003  /*!< ADC Prescaler: 4 */
#define ADC_Prescaler_5                 (uint32_t)0x0004  /*!< ADC Prescaler: 5 */
#define ADC_Prescaler_6                 (uint32_t)0x0005  /*!< ADC Prescaler: 6 */
#define ADC_Prescaler_8                 (uint32_t)0x0006  /*!< ADC Prescaler: 8 */
#define ADC_Prescaler_12                (uint32_t)0x0007  /*!< ADC Prescaler: 12 */
#define ADC_Prescaler_16                (uint32_t)0x0008  /*!< ADC Prescaler: 16 */
#define ADC_Prescaler_24                (uint32_t)0x0009  /*!< ADC Prescaler: 24 */
#define ADC_Prescaler_32                (uint32_t)0x000A  /*!< ADC Prescaler: 32 */
#define ADC_Prescaler_48                (uint32_t)0x000B  /*!< ADC Prescaler: 48 */
#define ADC_Prescaler_64                (uint32_t)0x000C  /*!< ADC Prescaler: 64 */
#define ADC_Prescaler_128               (uint32_t)0x000D  /*!< ADC Prescaler: 128 */
#define ADC_Prescaler_256               (uint32_t)0x000E  /*!< ADC Prescaler: 256 */
#define ADC_Prescaler_320               (uint32_t)0x000F  /*!< ADC Prescaler: 320 */
#define IS_ADC_CLK_PRESCALER(DIV)       ((DIV == ADC_Prescaler_1) \
                                        || (DIV == ADC_Prescaler_2) \
                                        || (DIV == ADC_Prescaler_3) \
                                        || (DIV == ADC_Prescaler_4) \
                                        || (DIV == ADC_Prescaler_5) \
                                        || (DIV == ADC_Prescaler_6) \
                                        || (DIV == ADC_Prescaler_8) \
                                        || (DIV == ADC_Prescaler_12) \
                                        || (DIV == ADC_Prescaler_16) \
                                        || (DIV == ADC_Prescaler_24) \
                                        || (DIV == ADC_Prescaler_32) \
                                        || (DIV == ADC_Prescaler_48) \
                                        || (DIV == ADC_Prescaler_64) \
                                        || (DIV == ADC_Prescaler_128) \
                                        || (DIV == ADC_Prescaler_256) \
                                        || (DIV == ADC_Prescaler_320))   /*!< Check ADC prescaler parameter */
  
/**
  * @}
  */

                                        
                                        
/** @defgroup ADC_Two_Sample_Gap  Sampling Gap
  * @{
  */

#define ADC_TwoSampleGap_0Cycles       (uint32_t)0x0000  /*!< Sampling Gap: 0 cycles */
#define ADC_TwoSampleGap_2Cycles       (uint32_t)0x1000  /*!< Sampling Gap: 2 cycles */
#define ADC_TwoSampleGap_4Cycles       (uint32_t)0x2000  /*!< Sampling Gap: 4 cycles */
#define ADC_TwoSampleGap_8Cycles       (uint32_t)0x3000  /*!< Sampling Gap: 8 cycles */
#define ADC_TwoSampleGap_16Cycles      (uint32_t)0x4000  /*!< Sampling Gap: 16 cycles */
#define ADC_TwoSampleGap_32Cycles      (uint32_t)0x5000  /*!< Sampling Gap: 32 cycles */
#define ADC_TwoSampleGap_64Cycles      (uint32_t)0x6000  /*!< Sampling Gap: 64 cycles */
#define ADC_TwoSampleGap_128Cycles     (uint32_t)0x7000  /*!< Sampling Gap: 128 cycles */
#define IS_ADC_TWO_SAMPLE_GAP(GAP)     ((GAP == ADC_TwoSampleGap_0Cycles) \
                                       || (GAP == ADC_TwoSampleGap_2Cycles) \
                                       || (GAP == ADC_TwoSampleGap_4Cycles) \
                                       || (GAP == ADC_TwoSampleGap_8Cycles) \
                                       || (GAP == ADC_TwoSampleGap_16Cycles) \
                                       || (GAP == ADC_TwoSampleGap_32Cycles) \
                                       || (GAP == ADC_TwoSampleGap_64Cycles) \
                                       || (GAP == ADC_TwoSampleGap_128Cycles))  /*!< Check sampling gap parameter */

/**
  * @}
  */


/** @defgroup ADC_Sample_Times Sampling Time
  * @{
  */

#define ADC_SampleTime_1Cycles      (uint32_t)0x0000  /*!< Sampling Time: 1 Cycles */
#define ADC_SampleTime_2Cycles      (uint32_t)0x0100  /*!< Sampling Time: 2 Cycles */
#define ADC_SampleTime_3Cycles      (uint32_t)0x0200  /*!< Sampling Time: 3 Cycles */
#define ADC_SampleTime_4Cycles      (uint32_t)0x0300  /*!< Sampling Time: 4 Cycles */
#define ADC_SampleTime_5Cycles      (uint32_t)0x0400  /*!< Sampling Time: 5 Cycles */
#define ADC_SampleTime_6Cycles      (uint32_t)0x0500  /*!< Sampling Time: 6 Cycles */
#define ADC_SampleTime_7Cycles      (uint32_t)0x0600  /*!< Sampling Time: 7 Cycles */
#define ADC_SampleTime_8Cycles      (uint32_t)0x0700  /*!< Sampling Time: 8 Cycles */
#define ADC_SampleTime_9Cycles      (uint32_t)0x0800  /*!< Sampling Time: 9 Cycles */
#define ADC_SampleTime_10Cycles     (uint32_t)0x0900  /*!< Sampling Time: 10 Cycles */
#define ADC_SampleTime_11Cycles     (uint32_t)0x0A00  /*!< Sampling Time: 11 Cycles */
#define ADC_SampleTime_12Cycles     (uint32_t)0x0B00  /*!< Sampling Time: 12 Cycles */
#define ADC_SampleTime_13Cycles     (uint32_t)0x0C00  /*!< Sampling Time: 13 Cycles */
#define ADC_SampleTime_14Cycles     (uint32_t)0x0D00  /*!< Sampling Time: 14 Cycles */
#define ADC_SampleTime_15Cycles     (uint32_t)0x0E00  /*!< Sampling Time: 15 Cycles */
#define IS_ADC_SAMPLE_TIME(TIME)    (  ((uint32_t)TIME == ADC_SampleTime_1Cycles) \
                                    || (TIME == ADC_SampleTime_2Cycles) \
                                    || (TIME == ADC_SampleTime_3Cycles) \
                                    || (TIME == ADC_SampleTime_4Cycles) \
                                    || (TIME == ADC_SampleTime_5Cycles) \
                                    || (TIME == ADC_SampleTime_6Cycles) \
                                    || (TIME == ADC_SampleTime_7Cycles) \
                                    || (TIME == ADC_SampleTime_8Cycles) \
                                    || (TIME == ADC_SampleTime_9Cycles) \
                                    || (TIME == ADC_SampleTime_10Cycles) \
                                    || (TIME == ADC_SampleTime_11Cycles) \
                                    || (TIME == ADC_SampleTime_12Cycles) \
                                    || (TIME == ADC_SampleTime_13Cycles) \
                                    || (TIME == ADC_SampleTime_14Cycles) \
                                    || (TIME == ADC_SampleTime_15Cycles))    /*!< Check sampling time parameter */
  

/**
  * @}
  */

                                    
/** @defgroup ADC_Interrupt_Sources Interrupt Source
  * @{
  */
  
#define ADC_INT_EOC                 (uint16_t)0x0040  /*!< Interrupt source: End Of Conversion */
#define ADC_INT_ADG                 (uint16_t)0x0080  /*!< Interrupt source: Larger than Large-Limit */
#define ADC_INT_ADL                 (uint16_t)0x0020  /*!< Interrupt source: Lower than Low-Limit */
#define IS_ADC_INT(INT)             (((INT & (uint16_t)0xFF1F) == 0x00) && (INT != 0x00))    /*!< Check interrupt source parameter */
                                   
/**
  * @}
  */
                                     
/** @defgroup ADC_Flags Flags
  * @{
  */
  
#define ADC_FLAG_EOC          (uint16_t)0x0004  /*!< Flag: End Of Conversion*/
#define ADC_FLAG_ADG          (uint16_t)0x0002  /*!< Flag: Larger than Large-Limit */
#define ADC_FLAG_ADL          (uint16_t)0x0001  /*!< Flag: Lower than Low-Limit */

#define IS_ADC_FLAG(FLAG)     (((FLAG & (uint16_t)0xFFF8) == 0x00) && (FLAG != 0x00))  /*!< Check flag parameter */

#define IS_ADC_GET_ONE_FLAG(FLAG)   ((FLAG == ADC_FLAG_EOC) \
                                    || (FLAG == ADC_FLAG_ADG) \
                                    || (FLAG == ADC_FLAG_ADL))   /*!< Check one of the flags */
                              
/**
  * @}
  */                                     

/** @defgroup ADC_Sample_Sequence Sampling Sequence
  * @{
  */

#define ADC_Sequence_0              (uint8_t)0x00  /*!< Sampling Sequence: 0 */
#define ADC_Sequence_1              (uint8_t)0x10  /*!< Sampling Sequence: 1 */
#define ADC_Sequence_2              (uint8_t)0x20  /*!< Sampling Sequence: 2 */
#define ADC_Sequence_3              (uint8_t)0x30  /*!< Sampling Sequence: 3 */
#define ADC_Sequence_4              (uint8_t)0x40  /*!< Sampling Sequence: 4 */
#define ADC_Sequence_5              (uint8_t)0x50  /*!< Sampling Sequence: 5 */
#define ADC_Sequence_6              (uint8_t)0x60  /*!< Sampling Sequence: 6 */
#define ADC_Sequence_7              (uint8_t)0x70  /*!< Sampling Sequence: 7 */
#define ADC_Sequence_8              (uint8_t)0x80  /*!< Sampling Sequence: 8 */
#define ADC_Sequence_9              (uint8_t)0x90  /*!< Sampling Sequence: 9 */
#define ADC_Sequence_10             (uint8_t)0xA0  /*!< Sampling Sequence: 10 */
#define ADC_Sequence_11             (uint8_t)0xB0  /*!< Sampling Sequence: 11 */
#define ADC_Sequence_12             (uint8_t)0xC0  /*!< Sampling Sequence: 12 */
#define ADC_Sequence_13             (uint8_t)0xD0  /*!< Sampling Sequence: 13 */
#define ADC_Sequence_14             (uint8_t)0xE0  /*!< Sampling Sequence: 14 */
#define ADC_Sequence_15             (uint8_t)0xF0  /*!< Sampling Sequence: 15 */

#define IS_ADC_SEQUENCE(SEQUENCE)   ((SEQUENCE == ADC_Sequence_0) \
                                    || (SEQUENCE == ADC_Sequence_1) \
                                    || (SEQUENCE == ADC_Sequence_2) \
                                    || (SEQUENCE == ADC_Sequence_3) \
                                    || (SEQUENCE == ADC_Sequence_4) \
                                    || (SEQUENCE == ADC_Sequence_5) \
                                    || (SEQUENCE == ADC_Sequence_6) \
                                    || (SEQUENCE == ADC_Sequence_7) \
                                    || (SEQUENCE == ADC_Sequence_8) \
                                    || (SEQUENCE == ADC_Sequence_9) \
                                    || (SEQUENCE == ADC_Sequence_10) \
                                    || (SEQUENCE == ADC_Sequence_11) \
                                    || (SEQUENCE == ADC_Sequence_12) \
                                    || (SEQUENCE == ADC_Sequence_13) \
                                    || (SEQUENCE == ADC_Sequence_14) \
                                    || (SEQUENCE == ADC_Sequence_15))  /*!< Check sampling sequence parameter */

/**
  * @}
  */



/** @defgroup ADC_Two_Sample_Gap_Cmd Sample Gap Command
  * @{
  */
  
#define ADC_TwoSampleGap_Enable          (uint8_t)0x01  /*!< Sampling Gap Enable */
#define ADC_TwoSampleGap_Disable         (uint8_t)0x00  /*!< Sampling Gap Disable */
#define IS_ADC_TWO_SAMPLE_GAP_CMD(CMD)   ((CMD == ADC_TwoSampleGap_Enable) \
                                         || (CMD == ADC_TwoSampleGap_Disable))    /*!< Check sampling gap command parameter */
  
/**
  * @}
  */                             
                                    
/** @defgroup ADC_Channel Channel
  * @{
  */

#define ADC_Channel_0          (uint16_t)0x0000  /*!< ADC Channel: 0 */
#define ADC_Channel_1          (uint16_t)0x0001  /*!< ADC Channel: 1 */
#define ADC_Channel_2          (uint16_t)0x0002  /*!< ADC Channel: 2 */
#define ADC_Channel_3          (uint16_t)0x0003  /*!< ADC Channel: 3 */
#define ADC_Channel_4          (uint16_t)0x0004  /*!< ADC Channel: 4 */
#define ADC_Channel_5          (uint16_t)0x0005  /*!< ADC Channel: 5 */
#define ADC_Channel_6          (uint16_t)0x0006  /*!< ADC Channel: 6 */
#define ADC_Channel_7          (uint16_t)0x0007  /*!< ADC Channel: 7 */
#define ADC_Channel_8          (uint16_t)0x0008  /*!< ADC Channel: 8 */
#define ADC_Channel_9          (uint16_t)0x0009  /*!< ADC Channel: 9 */
#define ADC_Channel_10         (uint16_t)0x000A  /*!< ADC Channel: 10 */
#define ADC_Channel_OP0OUT     (uint16_t)0x000B  /*!< ADC Channel: OP0OUT */
#define ADC_Channel_OP1OUT     (uint16_t)0x000C  /*!< ADC Channel: OP1OUT */
#define ADC_Channel_OP2OUT     (uint16_t)0x000D  /*!< ADC Channel: OP2OUT */
#define ADC_Channel_OP3OUT     (uint16_t)0x000E  /*!< ADC Channel: OP3OUT */
#define ADC_Channel_VBG        (uint16_t)0x000F  /*!< ADC Channel: VBG */

#define IS_ADC_CHANNEL(CHANNEL)     ((CHANNEL == ADC_Channel_0) \
                                    || (CHANNEL == ADC_Channel_1) \
                                    || (CHANNEL == ADC_Channel_2) \
                                    || (CHANNEL == ADC_Channel_3) \
                                    || (CHANNEL == ADC_Channel_4) \
                                    || (CHANNEL == ADC_Channel_5) \
                                    || (CHANNEL == ADC_Channel_6) \
                                    || (CHANNEL == ADC_Channel_7) \
                                    || (CHANNEL == ADC_Channel_8) \
                                    || (CHANNEL == ADC_Channel_9) \
                                    || (CHANNEL == ADC_Channel_10) \
                                    || (CHANNEL == ADC_Channel_OP0OUT) \
                                    || (CHANNEL == ADC_Channel_OP1OUT) \
                                    || (CHANNEL == ADC_Channel_OP2OUT) \
                                    || (CHANNEL == ADC_Channel_OP3OUT) \
                                    || (CHANNEL == ADC_Channel_VBG))  /*!< Check ADC channel parameter */
/**
  * @}
  */                             
                                         

/** @defgroup ADC_PWM_CMPx Single Resistance Sampling Mode Trigger Source
  * @{
  */

#define ADC_PWMCMP1            (uint16_t)0x0000  /*!< Trigger Source: PWM CMP1 */
#define ADC_PWMCMP2            (uint16_t)0x0001  /*!< Trigger Source: PWM CMP2 */
#define ADC_PWMCMP3            (uint16_t)0x0002  /*!< Trigger Source: PWM CMP3 */
#define ADC_PWMCMP4            (uint16_t)0x0003  /*!< Trigger Source: PWM CMP4 */
#define ADC_PCA0               (uint16_t)0x0004  /*!< Trigger Source: PCA0 */
#define ADC_PCA1               (uint16_t)0x0005  /*!< Trigger Source: PCA1 */
#define ADC_TIM8               (uint16_t)0x0006  /*!< Trigger Source: TIM8 */
#define ADC_IO_ADTRG           (uint16_t)0x0007  /*!< Trigger Source: IO Trigger */

#define IS_ADC_TRIGGER(SOURCE)     ((SOURCE == ADC_PWMCMP1) \
                                    || (SOURCE == ADC_PWMCMP2) \
                                    || (SOURCE == ADC_PWMCMP3) \
                                    || (SOURCE == ADC_PWMCMP4) \
                                    || (SOURCE == ADC_PCA0) \
                                    || (SOURCE == ADC_PCA1) \
                                    || (SOURCE == ADC_TIM8) \
                                    || (SOURCE == ADC_IO_ADTRG))  /*!< Check trigger source parameter */


/**
  * @}
  */ 

/**
  * @}
  */ 

/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 

/** @addtogroup ADC_Exported_Functions Public Functions
  * @{
  */

/** @addtogroup ADC_Group1
  * @{
  */  
void ADC_Reset(void);
void ADC_StructInit(ADC_InitTypeDef* ADC_InitStruct);
void ADC_Init(ADC_InitTypeDef* ADC_InitStruct);
/**
  * @}
  */ 
  
/** @addtogroup ADC_Group2
  * @{
  */  
void ADC_ChannelConfig(uint8_t ADC_Sequence, uint8_t ADC_Channel, uint8_t ADC_TwoSampleGapCmd);
void ADC_OnOff(SH_CmdState OnOffState);
void ADC_SoftwareStartConversion(void);
void ADC_SoftwareStopConversion(void);
SH_FlagStatus ADC_GetSoftwareStartConversionStatus(void);
uint16_t ADC_GetConversionValue(uint16_t ADC_Sequence);
void ADC_SequenceResultCompareConfig(uint16_t ADC_UpLimit, uint16_t ADC_LowerLimit, uint8_t ADC_Sequence);
void ADC_ExtADTRGTriggerCmd(SH_FunctionalState NewState);
void ADC_ExtADTRGOutputStartStatusCmd(SH_FunctionalState NewState);
void ADC_SingleResSampleModeTriggerChannelSet(uint32_t ADC_TriggerSource, uint8_t ChannelStart, uint8_t ChannelNum);
/**
  * @}
  */ 
  
/** @addtogroup ADC_Group3
  * @{
  */    
void ADC_INTConfig(uint16_t IT, SH_FunctionalState NewState);
void ADC_ClearFlag(uint16_t ADC_Flag);
SH_FlagStatus ADC_GetFlagStatus(uint16_t ADC_Flag);
/**
  * @}
  */ 
 
/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_ADC_H */

/**
  * @}
  */ 

/**
  * @}
  */ 


/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
