/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_amoc.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the AMOC firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_AMOC_H
#define __SH3xF2xx_SB0_AMOC_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup AMOC_MODULE AMOC
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/

/** @defgroup AMOC_Exported_Types Public Types
  * @{
  */

/**
  * @brief COMP Init structure definition
  */
  
typedef struct
{
    uint32_t COMP_NRefVoltageSource; /*!< Specifie the comparator none-inverting input voltage source.
                                          This parameter can be a value of @ref COMP_NRefVoltageSource */
                                          
    uint32_t COMP_NRefVoltageLevel;  /*!< Specifie the comparator none-inverting input voltage level.
                                          This parameter can be a value of @ref COMP_None-inverting_Reference_Voltage_Level */
                                          
    uint32_t COMP_NrefOutputCmd;     /*!< Specifie the comparator output function to be enabled or disabled.
                                          This parameter can be a value of @ref COMP_NrefOutput */
                                          
    uint32_t COMP_OutputCmd;         /*!< Specifie the comparator output function to be enabled or disabled.
                                          This parameter can be a value of @ref COMP_Output */
                                          
    uint32_t COMP_SchmittVoltage;    /*!< Specifie the comparator schmitt voltage.
                                          This parameter can be a value of @ref COMP_Schmitt_Voltage_Select */
                                          
    uint32_t COMP_IntSelect;         /*!< Specifie the comparator interrupt select .
                                          This parameter can be a value of COMP_Interrupt_Sources */
                                                                                   
    uint32_t COMP_NSelect;           /*!< Specifie the comparator none-inverting input pin source.
                                          This parameter can be a value of @ref COMP_None-inverting_Input_Select */
                                          
    uint32_t COMP_PSelect;           /*!< Specifie the comparator inverting input pin source.
                                          This parameter can be a value of @ref COMP_Inverting_Input_Select */
                                          
    uint32_t COMP_Filter;            /*!< Specifie the comparator filter value.
                                          This parameter can be a value of @ref Comp_Filter */

    uint32_t COMP_SynPwmSource;      /*!< Specifie the comparator synchronization PWM source.
                                          This parameter can be a value of @ref COMP_SynPwmSource */

    uint32_t COMP_SynPwmPoly;        /*!< Specifie the comparator synchronization PWM poly.
                                          This parameter can be a value of @ref COMP_SynPwmPoly */
 
}COMP_InitTypeDef;

/**
  * @}
  */

/* Exported constants --------------------------------------------------------*/

/** @defgroup AMOC_Exported_Constants Public Constants
  * @{
  */ 


/** @defgroup AMOC_Comp_Peripheral  Comparator Peripheral
  * @{
  */

#define COMP0                       (uint8_t)0x00 /*!< Comparator Module 0 */
#define COMP1                       (uint8_t)0x04 /*!< Comparator Module 1 */
#define IS_COMP_ALL_PERIPH(PERIPH)  ((PERIPH == COMP0) || (PERIPH == COMP1)) /*!< Check comparator module parameter */

/**
  * @}
  */


/** @defgroup AMOC_OP_Peripheral  OP Peripheral
  * @{
  */

#define OP0                       (uint8_t)0x01 /*!< OP module 0 */
#define OP1                       (uint8_t)0x02 /*!< OP module 1 */
#define OP2                       (uint8_t)0x04 /*!< OP module 2 */
#define OP3                       (uint8_t)0x08 /*!< OP module 3 */
#define IS_OP_ALL_PERIPH(PERIPH)  (((PERIPH & 0xF0) == 0x00) && (PERIPH != 0x00)) /*!< Check OP module parameter */

/**
  * @}
  */




/** @defgroup Comp_Filter  Comparator Filter
  * @{
  */

#define COMP_Filter_None          (uint32_t)0x00 /*!< Comparator filter: disable */
#define COMP_Filter_0us5          (uint32_t)0x01 /*!< Comparator filter: 0.5us */
#define COMP_Filter_1us           (uint32_t)0x02 /*!< Comparator filter: 1us */
#define COMP_Filter_2us           (uint32_t)0x03 /*!< Comparator filter: 2us */
#define COMP_Filter_4us           (uint32_t)0x04 /*!< Comparator filter: 4us */
#define COMP_Filter_8us           (uint32_t)0x05 /*!< Comparator filter: 8us */
#define COMP_Filter_12us          (uint32_t)0x06 /*!< Comparator filter: 12us */
#define COMP_Filter_16us          (uint32_t)0x07 /*!< Comparator filter: 16us */
#define IS_COMP_FILTER(FILTER)    ((FILTER == COMP_Filter_None) \
                                  || (FILTER == COMP_Filter_0us5) \
                                  || (FILTER == COMP_Filter_1us) \
                                  || (FILTER == COMP_Filter_2us) \
                                  || (FILTER == COMP_Filter_4us) \
                                  || (FILTER == COMP_Filter_8us) \
                                  || (FILTER == COMP_Filter_12us) \
                                  || (FILTER == COMP_Filter_16us)) /*!< Check comparator filter parameter */

/**
  * @}
  */




/** @defgroup COMP_Inverting_Input_Select Comparator Inverting Input
  * @{
  */

#define COMP_PSelect_P0             (uint32_t)0x0000 /*!< Comparator Inverting Input: P0 */
#define COMP_PSelect_P1             (uint32_t)0x0010 /*!< Comparator Inverting Input: P1 */
#define COMP_PSelect_P2             (uint32_t)0x0020 /*!< Comparator Inverting Input: P2 */
#define COMP_PSelect_OP0OUT         (uint32_t)0x0030 /*!< Comparator Inverting Input: OP0OUT */
#define COMP_PSelect_OP1OUT         (uint32_t)0x0040 /*!< Comparator Inverting Input: OP1OUT */
#define COMP_PSelect_OP2OUT         (uint32_t)0x0050 /*!< Comparator Inverting Input: OP2OUT */
#define COMP_PSelect_OP3OUT         (uint32_t)0x0060 /*!< Comparator Inverting Input: OP3OUT */

#define IS_COMP_0_P_SELECT(SELECT)  ((SELECT == COMP_PSelect_P0) \
                                    || (SELECT == COMP_PSelect_P1) \
                                    || (SELECT == COMP_PSelect_P2) \
                                    || (SELECT == COMP_PSelect_OP1OUT) \
                                    || (SELECT == COMP_PSelect_OP2OUT) \
                                    || (SELECT == COMP_PSelect_OP3OUT)) /*!< Check comparator 0 inverting input parameter */

#define IS_COMP_1_P_SELECT(SELECT)  ((SELECT == COMP_PSelect_P0) \
                                    || (SELECT == COMP_PSelect_P1) \
                                    || (SELECT == COMP_PSelect_P2) \
                                    || (SELECT == COMP_PSelect_OP0OUT) \
                                    || (SELECT == COMP_PSelect_OP1OUT) \
                                    || (SELECT == COMP_PSelect_OP2OUT) \
                                    || (SELECT == COMP_PSelect_OP3OUT)) /*!< Check comparator 1 inverting input parameter */

/**
  * @}
  */



/** @defgroup COMP_None-inverting_Input_Select Comparator None-Inverting Input
  * @{
  */
  
#define COMP_NSelect_NPin             (uint32_t)0x0000 /*!< Comparator None-Inverting Input : NPin */
#define COMP_NSelect_VRef             (uint32_t)0x0080 /*!< Comparator None-Inverting Input : VRef*/
#define IS_COMP_N_SELECT(SELECT)      ((SELECT == COMP_NSelect_NPin) \
                                      || (SELECT == COMP_NSelect_VRef)) /*!< Check None-Inverting Input parameter */

/**
  * @}
  */


/** @defgroup COMP_Schmitt_Voltage_Select Comparator Schmitt Voltage
  * @{
  */

#define COMP_SchmittVoltage_None          (uint32_t)0x0000 /*!< Schmitt Voltage 0 mV */
#define COMP_SchmittVoltage_10mV          (uint32_t)0x0100 /*!< Schmitt Voltage 10 mV */
#define COMP_SchmittVoltage_20mV          (uint32_t)0x0200 /*!< Schmitt Voltage 20 mV */
#define COMP_SchmittVoltage_50mV          (uint32_t)0x0300 /*!< Schmitt Voltage 50 mV */
#define IS_COMP_SCHMITT_VOLTAGE(VOLTAGE)  ((VOLTAGE == COMP_SchmittVoltage_None) \
                                          || (VOLTAGE == COMP_SchmittVoltage_10mV) \
                                          || (VOLTAGE == COMP_SchmittVoltage_20mV) \
                                          || (VOLTAGE == COMP_SchmittVoltage_50mV)) /*!< Check schmitt voltage parameter */
/**
  * @}
  */

/**   @defgroup COMP_NrefOutput Comparator NRef Output
  * @{
  */
  
#define COMP_NrefOutput_Disable        (uint32_t)0x0000 /*!< NRef output disable */
#define COMP_NrefOutput_Enable         (uint32_t)0x2000 /*!< NRef output enable */
#define IS_COMP_NREF_OUTPUT_CMD(CMD)   ((CMD == COMP_NrefOutput_Disable) || (CMD == COMP_NrefOutput_Enable)) /*!< Check NRef output parameter */
/**
  * @}
  */

/** @defgroup COMP_Output  Comparator Output
  * @{
  */

#define COMP_Output_Disable        (uint32_t)0x0000 /*!< Comparator output disable */
#define COMP_Output_Enable         (uint32_t)0x1000 /*!< Comparator output enable */
#define IS_COMP_OUTPUT_CMD(CMD)    ((CMD == COMP_Output_Disable) || (CMD == COMP_Output_Enable)) /*!< Check comparator output control parameter */

/**
  * @}
  */


/** @defgroup COMP_None-inverting_Reference_Voltage_Level Comparator None-Inverting Refernece Voltage Level
  * @{
  */


#define COMP_NRefVoltageLevel_1            (uint32_t)0x00 /*!< NRef Voltage: (1)/64*Vcmp */
#define COMP_NRefVoltageLevel_2            (uint32_t)0x01 /*!< NRef Voltage: (2)/64*Vcmp */
#define COMP_NRefVoltageLevel_3            (uint32_t)0x02 /*!< NRef Voltage: (3)/64*Vcmp */
#define COMP_NRefVoltageLevel_4            (uint32_t)0x03 /*!< NRef Voltage: (4)/64*Vcmp */
#define COMP_NRefVoltageLevel_5            (uint32_t)0x04 /*!< NRef Voltage: (5)/64*Vcmp */
#define COMP_NRefVoltageLevel_6            (uint32_t)0x05 /*!< NRef Voltage: (6)/64*Vcmp */
#define COMP_NRefVoltageLevel_7            (uint32_t)0x06 /*!< NRef Voltage: (7)/64*Vcmp */
#define COMP_NRefVoltageLevel_8            (uint32_t)0x07 /*!< NRef Voltage: (8)/64*Vcmp */
#define COMP_NRefVoltageLevel_9            (uint32_t)0x08 /*!< NRef Voltage: (9)/64*Vcmp */
#define COMP_NRefVoltageLevel_10           (uint32_t)0x09 /*!< NRef Voltage: (10)/64*Vcmp */
#define COMP_NRefVoltageLevel_11           (uint32_t)0x0A /*!< NRef Voltage: (11)/64*Vcmp */
#define COMP_NRefVoltageLevel_12           (uint32_t)0x0B /*!< NRef Voltage: (12)/64*Vcmp */
#define COMP_NRefVoltageLevel_13           (uint32_t)0x0C /*!< NRef Voltage: (13)/64*Vcmp */
#define COMP_NRefVoltageLevel_14           (uint32_t)0x0D /*!< NRef Voltage: (14)/64*Vcmp */
#define COMP_NRefVoltageLevel_15           (uint32_t)0x0E /*!< NRef Voltage: (15)/64*Vcmp */
#define COMP_NRefVoltageLevel_16           (uint32_t)0x0F /*!< NRef Voltage: (16)/64*Vcmp */
#define COMP_NRefVoltageLevel_17           (uint32_t)0x10 /*!< NRef Voltage: (17)/64*Vcmp */
#define COMP_NRefVoltageLevel_18           (uint32_t)0x11 /*!< NRef Voltage: (18)/64*Vcmp */
#define COMP_NRefVoltageLevel_19           (uint32_t)0x12 /*!< NRef Voltage: (19)/64*Vcmp */
#define COMP_NRefVoltageLevel_20           (uint32_t)0x13 /*!< NRef Voltage: (20)/64*Vcmp */
#define COMP_NRefVoltageLevel_21           (uint32_t)0x14 /*!< NRef Voltage: (21)/64*Vcmp */
#define COMP_NRefVoltageLevel_22           (uint32_t)0x15 /*!< NRef Voltage: (22)/64*Vcmp */
#define COMP_NRefVoltageLevel_23           (uint32_t)0x16 /*!< NRef Voltage: (23)/64*Vcmp */
#define COMP_NRefVoltageLevel_24           (uint32_t)0x17 /*!< NRef Voltage: (24)/64*Vcmp */
#define COMP_NRefVoltageLevel_25           (uint32_t)0x18 /*!< NRef Voltage: (25)/64*Vcmp */
#define COMP_NRefVoltageLevel_26           (uint32_t)0x19 /*!< NRef Voltage: (26)/64*Vcmp */
#define COMP_NRefVoltageLevel_27           (uint32_t)0x1A /*!< NRef Voltage: (27)/64*Vcmp */
#define COMP_NRefVoltageLevel_28           (uint32_t)0x1B /*!< NRef Voltage: (28)/64*Vcmp */
#define COMP_NRefVoltageLevel_29           (uint32_t)0x1C /*!< NRef Voltage: (29)/64*Vcmp */
#define COMP_NRefVoltageLevel_30           (uint32_t)0x1D /*!< NRef Voltage: (30)/64*Vcmp */
#define COMP_NRefVoltageLevel_31           (uint32_t)0x1E /*!< NRef Voltage: (31)/64*Vcmp */
#define COMP_NRefVoltageLevel_32           (uint32_t)0x1F /*!< NRef Voltage: (32)/64*Vcmp */
#define COMP_NRefVoltageLevel_33           (uint32_t)0x20 /*!< NRef Voltage: (33)/64*Vcmp */
#define COMP_NRefVoltageLevel_34           (uint32_t)0x21 /*!< NRef Voltage: (34)/64*Vcmp */
#define COMP_NRefVoltageLevel_35           (uint32_t)0x22 /*!< NRef Voltage: (35)/64*Vcmp */
#define COMP_NRefVoltageLevel_36           (uint32_t)0x23 /*!< NRef Voltage: (36)/64*Vcmp */
#define COMP_NRefVoltageLevel_37           (uint32_t)0x24 /*!< NRef Voltage: (37)/64*Vcmp */
#define COMP_NRefVoltageLevel_38           (uint32_t)0x25 /*!< NRef Voltage: (38)/64*Vcmp */
#define COMP_NRefVoltageLevel_39           (uint32_t)0x26 /*!< NRef Voltage: (39)/64*Vcmp */
#define COMP_NRefVoltageLevel_40           (uint32_t)0x27 /*!< NRef Voltage: (40)/64*Vcmp */
#define COMP_NRefVoltageLevel_41           (uint32_t)0x28 /*!< NRef Voltage: (41)/64*Vcmp */
#define COMP_NRefVoltageLevel_42           (uint32_t)0x29 /*!< NRef Voltage: (42)/64*Vcmp */
#define COMP_NRefVoltageLevel_43           (uint32_t)0x2A /*!< NRef Voltage: (43)/64*Vcmp */
#define COMP_NRefVoltageLevel_44           (uint32_t)0x2B /*!< NRef Voltage: (44)/64*Vcmp */
#define COMP_NRefVoltageLevel_45           (uint32_t)0x2C /*!< NRef Voltage: (45)/64*Vcmp */
#define COMP_NRefVoltageLevel_46           (uint32_t)0x2D /*!< NRef Voltage: (46)/64*Vcmp */
#define COMP_NRefVoltageLevel_47           (uint32_t)0x2E /*!< NRef Voltage: (47)/64*Vcmp */
#define COMP_NRefVoltageLevel_48           (uint32_t)0x2F /*!< NRef Voltage: (48)/64*Vcmp */
#define COMP_NRefVoltageLevel_49           (uint32_t)0x30 /*!< NRef Voltage: (49)/64*Vcmp */
#define COMP_NRefVoltageLevel_50           (uint32_t)0x31 /*!< NRef Voltage: (50)/64*Vcmp */
#define COMP_NRefVoltageLevel_51           (uint32_t)0x32 /*!< NRef Voltage: (51)/64*Vcmp */
#define COMP_NRefVoltageLevel_52           (uint32_t)0x33 /*!< NRef Voltage: (52)/64*Vcmp */
#define COMP_NRefVoltageLevel_53           (uint32_t)0x34 /*!< NRef Voltage: (53)/64*Vcmp */
#define COMP_NRefVoltageLevel_54           (uint32_t)0x35 /*!< NRef Voltage: (54)/64*Vcmp */
#define COMP_NRefVoltageLevel_55           (uint32_t)0x36 /*!< NRef Voltage: (55)/64*Vcmp */
#define COMP_NRefVoltageLevel_56           (uint32_t)0x37 /*!< NRef Voltage: (56)/64*Vcmp */
#define COMP_NRefVoltageLevel_57           (uint32_t)0x38 /*!< NRef Voltage: (57)/64*Vcmp */
#define COMP_NRefVoltageLevel_58           (uint32_t)0x39 /*!< NRef Voltage: (58)/64*Vcmp */
#define COMP_NRefVoltageLevel_59           (uint32_t)0x3A /*!< NRef Voltage: (59)/64*Vcmp */
#define COMP_NRefVoltageLevel_60           (uint32_t)0x3B /*!< NRef Voltage: (60)/64*Vcmp */
#define COMP_NRefVoltageLevel_61           (uint32_t)0x3C /*!< NRef Voltage: (61)/64*Vcmp */
#define COMP_NRefVoltageLevel_62           (uint32_t)0x3D /*!< NRef Voltage: (62)/64*Vcmp */
#define COMP_NRefVoltageLevel_63           (uint32_t)0x3E /*!< NRef Voltage: (63)/64*Vcmp */
#define COMP_NRefVoltageLevel_64           (uint32_t)0x3F /*!< NRef Voltage: (64)/64*Vcmp */
                                                
#define IS_COMP_N_REF_VOLTAGE_LEVEL(LEVEL)  (((int)LEVEL >= (int)COMP_NRefVoltageLevel_1) \
                                             && (LEVEL <= COMP_NRefVoltageLevel_64)) /*!< Check NRef voltage parameter */

/**
  * @}
  */


    

/** @defgroup COMP_NRefVoltageSource Comparator NRef Voltage Source
  * @{
  */

#define COMP_NRefVoltage_AVDD          (uint32_t)0x0000 /*!< NRef voltage source: AVCC */
#define COMP_NRefVoltage_External      (uint32_t)0x4000 /*!< NRef voltage source: External */
#define IS_COMP_N_REF_VOLTAGE_SOURCE(SOURCE)  ((SOURCE == COMP_NRefVoltage_AVDD) \
                                              || (SOURCE == COMP_NRefVoltage_External)) /*!< Check NRef voltage source parameter */
                                              
/**
  * @}
  */                                              


/** @defgroup COMP_Interrupt_Sources Comparator Interrupt Sources
  * @{
  */

#define COMP_INT_NONE        (uint16_t)0x0000 /*!< Interrupt source:none */
#define COMP_INT_RISING      (uint16_t)0x0800 /*!< Interrupt source:rising */
#define COMP_INT_FALLING     (uint16_t)0x0400 /*!< Interrupt source:falling */
#define COMP_INT_DOUBLE      (uint16_t)0x0C00 /*!< Interrupt source:rising and falling */
#define IS_COMP_INT(INT)     ((INT == COMP_INT_NONE) \
                                              || (INT == COMP_INT_RISING) \
                                              || (INT == COMP_INT_FALLING)\
                                              || (INT == COMP_INT_DOUBLE)) /*!< Check interrupt source parameter */
/**
  * @}
  */
/** @defgroup COMP0_AUTO Automatic comparison command
  * @{
  */
#define COMP0_AUTO_ENABLE    (uint32_t)0x08000000 /*!< Auto compare enable */
#define COMP0_AUTO_DISABLE   (uint32_t)0x00000000 /*!< Auto compare disable */
#define IS_CMP0_AUTO_ROTATION_CMD(CMD)   ((CMD == COMP0_AUTO_ENABLE) \
                                         || (CMD == COMP0_AUTO_DISABLE))  /*!< Check auto compare parameter */
/**
  * @}
  */
                                           
/** @defgroup COMP0 Automatic comparison GAP time
  * @{
  */
#define COMP0_AUTO_GAP_32CLK    (uint32_t)0x00000000 /*!< Auto GAP 32 clocks */
#define COMP0_AUTO_GAP_48CLK    (uint32_t)0x00400000 /*!< Auto GAP 48 clocks */
#define COMP0_AUTO_GAP_64CLK    (uint32_t)0x00800000 /*!< Auto GAP 64 clocks */
#define COMP0_AUTO_GAP_80CLK    (uint32_t)0x00C00000 /*!< Auto GAP 80 clocks */
#define IS_CMP0_AUTO_ROTATION_GAP(GAP)     ((GAP == COMP0_AUTO_GAP_32CLK) \
                                              || (GAP == COMP0_AUTO_GAP_48CLK)\
                                              || (GAP == COMP0_AUTO_GAP_64CLK)\
                                              || (GAP == COMP0_AUTO_GAP_80CLK)) /*!< Check auto gap parameter */
 /**
  * @}
  */
/** @defgroup COMP0_SYN_PWM Synchronizes PWM
  * @{
  */ 
#define COMP_SYN_PWM_NONE      (uint32_t)0x00000000 /*!< No PWM synchronize */
#define COMP_SYN_PWM_0         (uint32_t)0x01000000 /*!< Synchronize with PWM0 */
#define COMP_SYN_PWM_1         (uint32_t)0x02000000 /*!< Synchronize with PWM1 */
#define COMP_SYN_PWM_2         (uint32_t)0x03000000 /*!< Synchronize with PWM2 */
#define IS_CMP_SYN_PWM_SELECT(CHANNEL)     ((CHANNEL == COMP_SYN_PWM_NONE) \
                                              || (CHANNEL == COMP_SYN_PWM_0)\
                                              || (CHANNEL == COMP_SYN_PWM_1)\
                                              || (CHANNEL == COMP_SYN_PWM_2)) /*!< Check PWM synchronize parameter */
/**
  * @}
  */                                              
/** @defgroup COMP0_SYN_DUTY Synchronizes PWM Duty
  * @{
  */ 
#define COMP_SYN_PWM_DUTY      (uint32_t)0x00000000 /*!< Synchronize at duty time */
#define COMP_SYN_PWM_NODUTY    (uint32_t)0x04000000 /*!< Synchronize at non-duty time */
#define IS_CMP_SYN_PWM_DUTY(SELECT)     ((SELECT == COMP_SYN_PWM_DUTY) \
                                        || (SELECT == COMP_SYN_PWM_NODUTY)) /*!< Check synchronize time parameter */
/**
  * @}
  */
   
/** @defgroup COMP0_AUTO_OUT  Auto output
  * @{
  */ 
#define COMP0_AUTO_OUTPUT0     (uint32_t)0x10000000 /*!< Comparator output 0 */
#define COMP0_AUTO_OUTPUT1     (uint32_t)0x20000000 /*!< Comparator output 1 */
#define COMP0_AUTO_OUTPUT2     (uint32_t)0x40000000 /*!< Comparator output 2 */
#define IS_CMP0_AUTO_OUTPUT_SELECT(OUTPUTx)   ((OUTPUTx == COMP0_AUTO_OUTPUT0) \
                                              || (OUTPUTx == COMP0_AUTO_OUTPUT1)\
                                              || (OUTPUTx == COMP0_AUTO_OUTPUT2)) /*!< Check comparator output parameter */
                                               
/**
  * @}
  */
  
/** @defgroup OP0_GAIN OP0 Gain Multiplication select
  * @{
  */ 
#define OP0_GAIN_MUL_1       (uint16_t)0x0000 /*!< OP0 gain : 1 */
#define OP0_GAIN_MUL_4       (uint16_t)0x0010 /*!< OP0 gain : 4 */
#define OP0_GAIN_MUL_6       (uint16_t)0x0020 /*!< OP0 gain : 6 */
#define OP0_GAIN_MUL_8       (uint16_t)0x0030 /*!< OP0 gain : 8 */
#define OP0_GAIN_MUL_12      (uint16_t)0x0040 /*!< OP0 gain : 12 */
#define OP0_GAIN_MUL_16      (uint16_t)0x0050 /*!< OP0 gain : 16 */
#define OP0_GAIN_MUL_24      (uint16_t)0x0060 /*!< OP0 gain : 24 */
#define OP0_GAIN_MUL_32      (uint16_t)0x0070 /*!< OP0 gain : 32 */

#define IS_OP0_GAIN_MUL(MUL)  ((MUL == OP0_GAIN_MUL_1) \
                              || (MUL == OP0_GAIN_MUL_4) \
                              || (MUL == OP0_GAIN_MUL_6) \
                              || (MUL == OP0_GAIN_MUL_8) \
                              || (MUL == OP0_GAIN_MUL_12) \
                              || (MUL == OP0_GAIN_MUL_16) \
                              || (MUL == OP0_GAIN_MUL_24) \
                              || (MUL == OP0_GAIN_MUL_32)) /*!< Check OP gain parameter */


/**
  * @}
  */ 

/**
  * @}
  */
  
/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 

/** @addtogroup AMOC_Exported_Functions Public Functions
  * @{
  */
  
/** @addtogroup AMOC_Group1
  * @{
  */
extern void COMP_Reset(uint8_t COMPx);
extern void COMP_StructInit(COMP_InitTypeDef* COMP_InitStruct);
extern void COMP_Init(uint8_t COMPx, COMP_InitTypeDef* COMP_InitStruct);
extern void COMP_OnOff(uint8_t COMPx, SH_CmdState OnOffState);
extern SH_FlagStatus COMP_GetOutputLevel(uint8_t COMPx);
/**
  * @}
  */ 
  
/** @addtogroup AMOC_Group2
  * @{
  */
extern void COMP_INTConfig(uint8_t COMPx, uint16_t COMP_INT);
extern SH_FlagStatus COMP_GetFlagStatus(uint8_t COMPx);
extern void COMP_ClearFlag(uint8_t COMPx);
/**
  * @}
  */ 
  
/** @addtogroup AMOC_Group3
  * @{
  */
extern void COMP0_SetAutoRotation(uint32_t AutoRotationCommand, uint32_t AutoRotationGap);
extern SH_FlagStatus COMP0_GetAutoOutLevel(uint32_t Outx);
/**
  * @}
  */
/** @addtogroup AMOC_Group4
  * @{
  */
extern void OP0_GainOnOff(SH_CmdState OnOffState);
extern void OP0_GainConfig(uint8_t OP0_GainSelect);
extern void OP_OnOff(uint8_t OPx, SH_CmdState OnOffState);
/**
  * @}
  */

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_AMOC_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
