/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_can.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the PPP firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_CAN_H
#define __SH3xF2xx_SB0_CAN_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"
/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup CAN_MODULE
  * @{
  */ 



/* Exported constants --------------------------------------------------------*/

/** @defgroup CAN_Exported_Constants Public Constants
  * @{
  */ 

/*!  CAN E_CAN_Frame enumeration */ 
typedef enum
{
    eFrameStd,//standard frame
    eFrameExt,//extend frame
    eFrameStdRt,//standard remote frame
    eFrameExtRt,//extend remote frame    
}E_CAN_Frame;

/*!  CAN E_CAN_CmdSend enumeration */ 
typedef enum
{
    eCANCmd_Send_Data,            //Send data once
    eCANCmd_Send_Wait_Remote,     //Send data then wait remote frame
    eCANCmd_Wait_Remote,          //wait remote frame
}E_CAN_CmdSend;

/*!  CAN E_CAN_Priority enumeration */ 
typedef enum{
    eCAN_Pri_Highest = 0,
    eCAN_Pri_1       = 1,    
    eCAN_Pri_2       = 2,    
    eCAN_Pri_3       = 3,    
    eCAN_Pri_4       = 4,    
    eCAN_Pri_5       = 5,    
    eCAN_Pri_6       = 6,    
    eCAN_Pri_7       = 7,    
    eCAN_Pri_8       = 8,    
    eCAN_Pri_9       = 9,    
    eCAN_Pri_10      = 10,    
    eCAN_Pri_11      = 11,    
    eCAN_Pri_12      = 12,    
    eCAN_Pri_13      = 13,    
    eCAN_Pri_14      = 14,    
    eCAN_Pri_Lowest  = 0xF,
}E_CAN_Priority;

/** @defgroup CAN_Buffer CAN Buffer
  * @{
  */
#define CAN_Buffer_0                    ((uint8_t)0x00)  /*!< CAN DATA buffer 0 */
#define CAN_Buffer_1                    ((uint8_t)0x01)  /*!< CAN DATA buffer 1 */
#define CAN_Buffer_2                    ((uint8_t)0x02)  /*!< CAN DATA buffer 2 */
#define CAN_Buffer_3                    ((uint8_t)0x03)  /*!< CAN DATA buffer 3 */
#define CAN_Buffer_4                    ((uint8_t)0x04)  /*!< CAN DATA buffer 4 */
#define CAN_Buffer_5                    ((uint8_t)0x05)  /*!< CAN DATA buffer 5 */
#define CAN_Buffer_6                    ((uint8_t)0x06)  /*!< CAN DATA buffer 6 */
#define CAN_Buffer_7                    ((uint8_t)0x07)  /*!< CAN DATA buffer 7 */
#define CAN_Buffer_8                    ((uint8_t)0x08)  /*!< CAN DATA buffer 8 */
#define CAN_Buffer_9                    ((uint8_t)0x09)  /*!< CAN DATA buffer 9 */
#define CAN_Buffer_10                   ((uint8_t)0x10)  /*!< CAN DATA buffer 10 */
#define CAN_Buffer_11                   ((uint8_t)0x11)  /*!< CAN DATA buffer 11 */
#define CAN_Buffer_12                   ((uint8_t)0x12)  /*!< CAN DATA buffer 12 */
#define CAN_Buffer_13                   ((uint8_t)0x13)  /*!< CAN DATA buffer 13 */
#define CAN_Buffer_14                   ((uint8_t)0x14)  /*!< CAN DATA buffer 14 */

#define IS_CAN_BUFFER(NUM)        (((NUM) == CAN_Buffer_0 ) || \
                                   ((NUM) == CAN_Buffer_1 ) || \
                                   ((NUM) == CAN_Buffer_2 ) || \
                                   ((NUM) == CAN_Buffer_3 ) || \
                                   ((NUM) == CAN_Buffer_4 ) || \
                                   ((NUM) == CAN_Buffer_5 ) || \
                                   ((NUM) == CAN_Buffer_6 ) || \
                                   ((NUM) == CAN_Buffer_7 ) || \
                                   ((NUM) == CAN_Buffer_8 ) || \
                                   ((NUM) == CAN_Buffer_9 ) || \
                                   ((NUM) == CAN_Buffer_10) || \
                                   ((NUM) == CAN_Buffer_11) || \
                                   ((NUM) == CAN_Buffer_12) || \
                                   ((NUM) == CAN_Buffer_13) || \
                                   ((NUM) == CAN_Buffer_14))   /*!< Check buffer parameters */
/**
  * @}
  */


/** @defgroup CAN_SWJ  CAN SWJ 
  * @{
  */

#define CAN_SJW_1tq                 ((uint8_t)0x00)  /*!< 1 time quantum */
#define CAN_SJW_2tq                 ((uint8_t)0x01)  /*!< 2 time quantum */
#define CAN_SJW_3tq                 ((uint8_t)0x02)  /*!< 3 time quantum */
#define CAN_SJW_4tq                 ((uint8_t)0x03)  /*!< 4 time quantum */

#define IS_CAN_SJW(SJW)         (((SJW) == CAN_SJW_1tq) || ((SJW) == CAN_SJW_2tq)|| \
                                ((SJW) == CAN_SJW_3tq) || ((SJW) == CAN_SJW_4tq))  /*!< Check SJW parameter */
/**
  * @}
  */

/** @defgroup CAN_TSEG1 CAN TSEG1 
  * @{
  */

#define CAN_TSEG1_1tq                 ((uint8_t)0x00)  /*!< 1 time quantum */
#define CAN_TSEG1_2tq                 ((uint8_t)0x01)  /*!< 2 time quantum */
#define CAN_TSEG1_3tq                 ((uint8_t)0x02)  /*!< 3 time quantum */
#define CAN_TSEG1_4tq                 ((uint8_t)0x03)  /*!< 4 time quantum */
#define CAN_TSEG1_5tq                 ((uint8_t)0x04)  /*!< 5 time quantum */
#define CAN_TSEG1_6tq                 ((uint8_t)0x05)  /*!< 6 time quantum */
#define CAN_TSEG1_7tq                 ((uint8_t)0x06)  /*!< 7 time quantum */
#define CAN_TSEG1_8tq                 ((uint8_t)0x07)  /*!< 8 time quantum */
#define CAN_TSEG1_9tq                 ((uint8_t)0x08)  /*!< 9 time quantum */
#define CAN_TSEG1_10tq                ((uint8_t)0x09)  /*!< 10 time quantum */
#define CAN_TSEG1_11tq                ((uint8_t)0x0A)  /*!< 11 time quantum */
#define CAN_TSEG1_12tq                ((uint8_t)0x0B)  /*!< 12 time quantum */
#define CAN_TSEG1_13tq                ((uint8_t)0x0C)  /*!< 13 time quantum */
#define CAN_TSEG1_14tq                ((uint8_t)0x0D)  /*!< 14 time quantum */
#define CAN_TSEG1_15tq                ((uint8_t)0x0E)  /*!< 15 time quantum */
#define CAN_TSEG1_16tq                ((uint8_t)0x0F)  /*!< 16 time quantum */

#define IS_CAN_TSEG1(TSEG1)       (((TSEG1) == CAN_TSET1_1tq) || ((TSEG1) == CAN_TSET1_2tq) || \
                                  ((TSEG1) == CAN_TSET1_3tq) || ((TSEG1) == CAN_TSET1_4tq) || \
                                  ((TSEG1) == CAN_TSET1_5tq) || ((TSEG1) == CAN_TSET1_6tq) || \
                                  ((TSEG1) == CAN_TSET1_7tq) || ((TSEG1) == CAN_TSET1_8tq) || \
                                  ((TSEG1) == CAN_TSET1_9tq) || ((TSEG1) == CAN_TSET1_10tq) || \
                                  ((TSEG1) == CAN_TSET1_11tq) || ((TSEG1) == CAN_TSET1_12tq) || \
                                  ((TSEG1) == CAN_TSET1_13tq) || ((TSEG1) == CAN_TSET1_14tq) || \
                                  ((TSEG1) == CAN_TSET1_15tq) || ((TSEG1) == CAN_TSET1_16tq))  /*!< Check TSEG1 parameter */
/**
  * @}
  */

/** @defgroup CAN_TSEG2 CAN TSEG2
  * @{
  */

#define CAN_TSEG2_1tq                 ((uint8_t)0x00)  /*!< 1 time quantum */
#define CAN_TSEG2_2tq                 ((uint8_t)0x01)  /*!< 2 time quantum */
#define CAN_TSEG2_3tq                 ((uint8_t)0x02)  /*!< 3 time quantum */
#define CAN_TSEG2_4tq                 ((uint8_t)0x03)  /*!< 4 time quantum */
#define CAN_TSEG2_5tq                 ((uint8_t)0x04)  /*!< 5 time quantum */
#define CAN_TSEG2_6tq                 ((uint8_t)0x05)  /*!< 6 time quantum */
#define CAN_TSEG2_7tq                 ((uint8_t)0x06)  /*!< 7 time quantum */
#define CAN_TSEG2_8tq                 ((uint8_t)0x07)  /*!< 8 time quantum */

#define IS_CAN_TSEG2(TSEG2)       (((TSEG2) == CAN_TSEG2_1tq) || ((TSEG2) == CAN_TSEG2_2tq)|| \
                                  ((TSEG2) == CAN_TSEG2_3tq) || ((TSEG2) == CAN_TSEG2_4tq) || \
                                  ((TSEG2) == CAN_TSEG2_5tq) || ((TSEG2) == CAN_TSEG2_6tq) || \
                                  ((TSEG2) == CAN_TSEG2_7tq) || ((TSEG2) == CAN_TSEG2_8tq))  /*!< Check TSEG2 parameter */
/**
  * @}
  */


/** @defgroup CAN_INT_BUFx  CAN Interrupt Flag 
  * @{
  */
#define CAN_INT_BUF0          0  /*!< CAN Buffer 0 interrupt index */
#define CAN_INT_BUF1          1  /*!< CAN Buffer 1 interrupt index */
#define CAN_INT_BUF2          2  /*!< CAN Buffer 2 interrupt index */
#define CAN_INT_BUF3          3  /*!< CAN Buffer 3 interrupt index */
#define CAN_INT_BUF4          4  /*!< CAN Buffer 4 interrupt index */
#define CAN_INT_BUF5          5  /*!< CAN Buffer 5 interrupt index */
#define CAN_INT_BUF6          6  /*!< CAN Buffer 6 interrupt index */
#define CAN_INT_BUF7          7  /*!< CAN Buffer 7 interrupt index */
#define CAN_INT_BUF8          8  /*!< CAN Buffer 8 interrupt index */
#define CAN_INT_BUF9          9  /*!< CAN Buffer 9 interrupt index */
#define CAN_INT_BUF10         10  /*!< CAN Buffer 10 interrupt index */
#define CAN_INT_BUF11         11  /*!< CAN Buffer 11 interrupt index */
#define CAN_INT_BUF12         12  /*!< CAN Buffer 12 interrupt index */
#define CAN_INT_BUF13         13  /*!< CAN Buffer 13 interrupt index */
#define CAN_INT_BUF14         14  /*!< CAN Buffer 14 interrupt index */
#define CAN_INT_ERR           15  /*!< CAN error interrupt index */

#define IS_CAN_INT(INT)  ((INT > 0x00) && (INT <= 0xF)) /*!< Check CAN Interrupt index*/
/**
  * @}
  */

/** @defgroup CAN_FLAG_BUFx CAN Flag
  * @{
  */
#define CAN_FLAG_BUF0          0  /*!< CAN Buffer 0 flag */
#define CAN_FLAG_BUF1          1  /*!< CAN Buffer 1 flag */
#define CAN_FLAG_BUF2          2  /*!< CAN Buffer 2 flag */
#define CAN_FLAG_BUF3          3  /*!< CAN Buffer 3 flag */
#define CAN_FLAG_BUF4          4  /*!< CAN Buffer 4 flag */
#define CAN_FLAG_BUF5          5  /*!< CAN Buffer 5 flag */
#define CAN_FLAG_BUF6          6  /*!< CAN Buffer 6 flag */
#define CAN_FLAG_BUF7          7  /*!< CAN Buffer 7 flag */
#define CAN_FLAG_BUF8          8  /*!< CAN Buffer 8 flag */
#define CAN_FLAG_BUF9          9  /*!< CAN Buffer 9 flag */
#define CAN_FLAG_BUF10         10  /*!< CAN Buffer 10 flag */
#define CAN_FLAG_BUF11         11  /*!< CAN Buffer 11 flag */
#define CAN_FLAG_BUF12         12  /*!< CAN Buffer 12 flag */
#define CAN_FLAG_BUF13         13  /*!< CAN Buffer 13 flag */
#define CAN_FLAG_BUF14         14  /*!< CAN Buffer 14 flag */
#define CAN_FLAG_ERR           15  /*!< CAN error flag */

#define IS_CAN_GET_FLAG(FLAG)  ((FLAG > 0x00) && (FLAG <= 0xF)) /*!< Check CAN flag */
/**
  * @}
  */
  
  
/** @defgroup CAN_BUF_ST CAN Buffer Status
  * @{
  */
#define CAN_ST_RX_NOT_ACTIVE          0x00  /*!< Receive not active */
#define CAN_ST_BUSY                   0x01  /*!< Busy */
#define CAN_ST_RX_READY               0x02  /*!< Receive ready */
#define CAN_ST_RX_FULL                0x04  /*!< Receive full */
#define CAN_ST_RX_OVERRUN             0x06  /*!< Receive over run */
#define CAN_ST_TX_NOT_ACTIVE          0x08  /*!< Transform not active */
#define CAN_ST_TX_ONCE                0x0C  /*!< Transform once */
#define CAN_ST_TX_RTR                 0x0A  /*!< Wait remote frame then transform*/
#define CAN_ST_TX_ONCE_RTR            0x0E  /*!< Transform once then wait remote frame */

#define IS_CAN_STATUS(ST)   ((ST == CAN_ST_RX_NOT_ACTIVE) || \
                             (ST == CAN_ST_BUSY) || \
                             (ST == CAN_ST_RX_READY) || \
                             (ST == CAN_ST_RX_FULL) || \
                             (ST == CAN_ST_RX_OVERRUN) || \
                             (ST == CAN_ST_TX_NOT_ACTIVE) || \
                             (ST == CAN_ST_TX_ONCE) || \
                             (ST == CAN_ST_TX_RTR) || \
                             (ST == CAN_ST_TX_ONCE_RTR) || \) /*!< Check CAN buffer status */
/**
  * @}
  */  
  
#define IS_CAN_ALL_PERIPH(PERIPH)  (PERIPH == CAN0) /*!< Check CAN module pointer */ 

/**
  * @}
  */
    


/* Exported types ------------------------------------------------------------*/

/** @defgroup CAN_Exported_Types Public Types
  * @{
  */
  
/*!  CAN Init structure definition */   
typedef struct
{  
  union{
        uint32_t V32;  /*!< CAN Mode value*/
        struct
        {
            uint32_t enable:1;        /*!< Enable/Disable CAN module*/
            uint32_t receive_level:1; /*!< 0dominant state is 0, recessive state is 1
                                           1dominant state is 1, recessive state is 0 */
            uint32_t send_level:1;    /*!< 0dominant state is 0, recessive state is 1
                                           1dominant state is 1, recessive state is 0 */
            uint32_t buff_lock:1;     /*!< buffer locked upon reception*/
            uint32_t tsync_enable:1;  /*!< time sync enable */
            uint32_t data_dir:1;      /*!< data direction:0:first byte at highest addr */
            uint32_t listen_only:1;   /*!< Linsten Only mode, need diagnostic mode enable*/
            uint32_t ignore_ack:1;    /*!< Ignore acknowledge */
            uint32_t loop_back:1;     /*!< loopback mode*/
            uint32_t internal:1;      /*!< internal mode for Rx & Tx connected internally*/
            uint32_t diag_enable:1;   /*!< Enable diagnostic mode*/
            uint32_t err_int_type:1;  /*!< Error Interrupt Type. 0:for all error, 1: if CSTPND.NS change */
            uint32_t rev:20;            
        }BIT;    /*!< CAN Mode bit fields*/
    }CAN_Mode;   /*!< CAN Mode*/
    union{
        uint32_t V32; /*!< CAN BaudRate value*/
        struct
        {
            uint32_t tseg2:3;        /*!< Specifies the number of time quanta in Bit Segment 2. 0:1tq  1:2tq ...*/
            uint32_t tseg1:4;        /*!< Specifies the number of time quanta in Bit Segment 2. 0:error  1:2tq ...*/
            uint32_t sjw:2;          /*!< Specifies the maximum number of time quanta. 0:1tq  1:2tq ...*/
            uint32_t psc:7;          /*!< Specifies the length of a time quantum. 0:2  1:3 2:4 ...*/
            uint32_t rev:16;            
        }BIT;      /*!< CAN BaudRate bit fields*/
    }CAN_BaudRate; /*!< CAN BaudRate*/
} CAN_InitTypeDef;


/*!  CAN Buffer structure definition */
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT; /*!< CNTSTAT bit fileds*/
    }CNTSTAT;                               /*!< 0000H */
    __IO uint32_t  BUF_TSTP;                               /*!< 0004H */
    union {
        __IO  uint32_t  V32;                                /*!< 0008H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0008H */
    __IO uint32_t  DATAH:8;                                 /*!< 0009H */
    __IO uint32_t  rev0:16;                                 /*!< 000AH */
        }BIT; /*!< DATA 3 bit fileds*/
    }DATA3;                              /*!< 0008H */
    union {
        __IO  uint32_t  V32;                                /*!< 000CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 000CH */
    __IO uint32_t  DATAH:8;                                 /*!< 000DH */
    __IO uint32_t  rev0:16;                                 /*!< 000EH */
        }BIT; /*!< DATA 2 bit fileds*/
    }DATA2;                              /*!< 000CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0010H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0010H */
    __IO uint32_t  DATAH:8;                                 /*!< 0011H */
    __IO uint32_t  rev0:16;                                 /*!< 0012H */
        }BIT; /*!< DATA 1 bit fileds*/
    }DATA1;                              /*!< 0010H */
    union {
        __IO  uint32_t  V32;                                /*!< 0014H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0014H */
    __IO uint32_t  DATAH:8;                                 /*!< 0015H */
    __IO uint32_t  rev0:16;                                 /*!< 0016H */
        }BIT; /*!< DATA 0 bit fileds*/
    }DATA0;                              /*!< 0014H */
    union {
        __IO  uint32_t  V32;                                /*!< 0018H */
        struct {
            __IO  uint32_t  RTR       : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  ID        :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT; /*!< ID0 bit fileds*/
    }ID0;                               /*!< 0018H */
    union {
        __IO  uint32_t  V32;                                /*!< 001CH */
        struct {
            __IO  uint32_t  IDEX      : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  SRR       : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  ID        :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;  /*!< ID1 bit fileds*/
    }ID1;                               /*!< 001CH */
}CAN_BufTypeDef;

/*!  CAN Message structure definition */   
typedef struct{
    uint32_t         id;       /*!< ID*/
    uint16_t         eMsgType; /*!< message type */
    uint16_t         ePri;     /*!< buffer priority */
    uint16_t         len;      /*!< data length*/
    uint16_t         ie;       /*!< Interrupt Enable*/
    uint8_t          data[8];  /*!< data buffer*/
}CAN_MsgTypeDef;

/*!  CAN Mask structure definition */ 
typedef struct{
    uint32_t  idmask;  /*!< id mask bits*/
    uint16_t  idemask; /*!< extend frame enable bit*/
    uint16_t  rtrmask; /*!< remote frame enable bit*/
}CAN_MaskTypeDef;

/*!  CAN Error Code structure definition */ 
typedef union{
    uint32_t V32;/*!< Error Code */
    struct{
    uint32_t  error_field_id :4; /*!< error field in frame */
    uint32_t  error_bit_id   :6; /*!< error bit position*/
    uint32_t  error_in_trans :1; /*!< 0:error occurs while receiving, 1:error occurs while transfering*/
    uint32_t  error_stuff    :1; /*!< error in filled bits */
    uint32_t  error_crc      :1; /*!< crc error */
    uint32_t  error_mon      :1; /*!< error level on rx pin */
    uint32_t  error_drive    :1; /*!< error level on tx pin */
    uint32_t  rev            :17; 
    }BIT; /*!< Error Bit Field */
}CAN_ErrorCode;

/**
  * @}
  */


/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 

/** @defgroup CAN_Exported_Functions Public Functions
  * @{
  */
/*  CAN initial structure initialize */  
void CAN_StructInit(CAN_InitTypeDef* CAN_InitStruct);
/*  CAN Device Initialize */  
extern void CAN_Init(CAN_TypeDef* CANx, const CAN_InitTypeDef* CAN_InitStruct);
/* Set CAN Mask Bits */
extern void CAN_SetMask(CAN_TypeDef* CANx, const CAN_MaskTypeDef* gmask, const CAN_MaskTypeDef* bmask);
/* start send message */
extern void CAN_StartSendMsg(CAN_TypeDef* CANx, uint32_t CAN_Bufferx, const CAN_MsgTypeDef* CAN_Msg,E_CAN_CmdSend eCmd);
/* start receive message */
extern void CAN_StartReceiveMsg(CAN_TypeDef* CANx, uint32_t CAN_Bufferx, const CAN_MsgTypeDef* CAN_Msg);
/* read received message */
extern void CAN_ReadReceivedMsg(CAN_TypeDef* CANx, uint32_t CAN_Bufferx, CAN_MsgTypeDef* CAN_Msg);
/* clear transmit buffer */
extern void CAN_ClearBuffer(CAN_TypeDef* CANx, uint32_t CAN_Bufferx);
/* check buffer status */
extern uint32_t CAN_GetBufferStatus(CAN_TypeDef* CANx, uint32_t CAN_Bufferx);
/* get buffer interrupt status */
extern SH_FlagStatus CAN_INTGetStatus(CAN_TypeDef* CANx, uint32_t CAN_Bufferx);
/* get buffer interrupt code */
extern SH_FlagStatus CAN_INTGetCode(CAN_TypeDef* CANx,uint32_t* CAN_Code);
/* enable or disable buffer lock feature */
extern void CAN_BufferLockCmd(CAN_TypeDef* CANx, SH_FunctionalState NewState);
/* get send error counter */
extern uint32_t CAN_GetTransmitErrorCounter(CAN_TypeDef* CANx);
/* get receive error counter */
extern uint32_t CAN_GetReceiveErrorCounter(CAN_TypeDef* CANx);
/* enable or disable interrupt for buffer */
extern void CAN_INTConfig(CAN_TypeDef* CANx, uint32_t CAN_Bufferx, SH_FunctionalState NewState);
/* enable or disable interrupt code for buffer */
extern void CAN_INTCodeConfig(CAN_TypeDef* CANx, uint32_t CAN_Bufferx, SH_FunctionalState NewState);
/* get CAN timer value */
extern uint32_t CAN_GetTimerCounter(CAN_TypeDef* CANx);
/* get CAN error code */
extern CAN_ErrorCode CAN_GetErrorCode(CAN_TypeDef* CANx);
/* clear buffer interrupt flag */
extern void CAN_ClearFlag(CAN_TypeDef* CANx, uint32_t CAN_Bufferx);
/* turn on or turn off CAN module */
extern void CAN_OnOff(CAN_TypeDef* CANx, SH_CmdState OnOffState);
/* reset CAN module */
extern void CAN_Reset(CAN_TypeDef* CANx);

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_CAN_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
