/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_exti.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the PPP firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_EXTI_H
#define __SH3xF2xx_SB0_EXTI_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup EXTI_MODULE
  * @{
  */ 


/* Exported constants --------------------------------------------------------*/

/** @defgroup EXTI_Exported_Constants Public Constants
  * @{
  */

/** 
  * @brief  EXTI mode enumeration  
  */
typedef enum
{
    EXTI_Mode_Interrupt = 0x00,    /*!< EXTI Mode Interrupt*/
    EXTI_Mode_WakeupEvent = 0x04,  /*!< EXTI Mode wakeup event*/
}EXTIMode_TypeDef;

#define IS_EXTI_MODE(MODE)    ((MODE == EXTI_Mode_Interrupt) \
                              || (MODE == EXTI_Mode_WakeupEvent)) /*!< check EXTI mode*/

/** 
  * @brief  EXTI Trigger enumeration  
  */
typedef enum
{
    EXTI_Trigger_Rising = 0x0C,             /*!< EXTI trigger: Rising edge*/
    EXTI_Trigger_Falling = 0x10,            /*!< EXTI trigger: Falling edge*/
    EXTI_Trigger_Rising_Falling = 0x0F,     /*!< EXTI trigger: Rising or Falling edge*/
    EXTI_Trigger_HighLevel = 0x2C,          /*!< EXTI trigger: High Level*/
    EXTI_Trigger_LowLevel = 0x30,           /*!< EXTI trigger: Low Level*/
    EXTI_Trigger_HighLevel_LowLevel = 0x3F  /*!< EXTI trigger: High or Low Level*/
}EXTITrigger_TypeDef;

#define IS_EXTI_TRIGGER(TRIGGER)   ((TRIGGER == EXTI_Trigger_Rising) \
                                   || (TRIGGER == EXTI_Trigger_Falling) \
                                   || (TRIGGER == EXTI_Trigger_Rising_Falling) \
                                   || (TRIGGER == EXTI_Trigger_HighLevel) \
                                   || (TRIGGER == EXTI_Trigger_LowLevel) \
                                   || (TRIGGER == EXTI_Trigger_HighLevel_LowLevel)) /*!< check EXTI trigger mode*/

/** 
  * @brief  EXTI sample cycle enumeration  
  */
typedef enum
{
    EXTI_SampleCycle_1 = 0x00,  /*!< sampling: 1 time */
    EXTI_SampleCycle_2 = 0x01,  /*!< sampling: 2 times */
    EXTI_SampleCycle_3 = 0x02,  /*!< sampling: 3 times */
    EXTI_SampleCycle_4 = 0x03   /*!< sampling: 4 times */
}EXTISampleCycle_TypeDef;

#define IS_EXTI_SAMPLE_CYCLE(CYCLE)    ((CYCLE == EXTI_SampleCycle_1) \
                                       || (CYCLE == EXTI_SampleCycle_2) \
                                       || (CYCLE == EXTI_SampleCycle_3) \
                                       || (CYCLE == EXTI_SampleCycle_4)) /*!< check sampleing time*/

                                       
/** 
  * @brief  EXTI sample clock division enumeration  
  */
typedef enum
{
    EXTI_SampleClockDivision_1 = 0x00,  /*!< sampling clock: mclk/1 */
    EXTI_SampleClockDivision_4 = 0x01,  /*!< sampling clock: mclk/4 */
    EXTI_SampleClockDivision_16 = 0x02, /*!< sampling clock: mclk/16 */
    EXTI_SampleClockDivision_128 = 0x03 /*!< sampling clock: mclk/128 */
}EXTISampleClockDivision_TypeDef;

#define IS_EXTI_SAMPLE_CLOCK_DIV(DIV)   ((DIV == EXTI_SampleClockDivision_1) \
                                        || (DIV == EXTI_SampleClockDivision_4) \
                                        || (DIV == EXTI_SampleClockDivision_16) \
                                        || (DIV == EXTI_SampleClockDivision_128)) /*!< check EXTI sampling clock */






/** @defgroup EXTI_Lines EXTI Lines
  * @{
  */
  
#define EXTI_Line0       ((uint32_t)0x00001)     /*!< External interrupt line 0 */
#define EXTI_Line1       ((uint32_t)0x00002)     /*!< External interrupt line 1 */
#define EXTI_Line2       ((uint32_t)0x00004)     /*!< External interrupt line 2 */
#define EXTI_Line3       ((uint32_t)0x00008)     /*!< External interrupt line 3 */
#define EXTI_Line4       ((uint32_t)0x00010)     /*!< External interrupt line 4 */
#define EXTI_Line5       ((uint32_t)0x00020)     /*!< External interrupt line 5 */
#define EXTI_Line6       ((uint32_t)0x00040)     /*!< External interrupt line 6 */
#define EXTI_Line7       ((uint32_t)0x00080)     /*!< External interrupt line 7 */

#define IS_EXTI_LINE(LINE)   (((LINE & (uint32_t)0xFFFF0000) == 0x00) && (LINE != 0x00)) /*!< check EXTI line */

#define IS_EXTI_GET_ONE_LINE(LINE)  ((LINE == EXTI_Line0) || (LINE == EXTI_Line1) \
                                    || (LINE == EXTI_Line2) || (LINE == EXTI_Line3) \
                                    || (LINE == EXTI_Line4) || (LINE == EXTI_Line5) \
                                    || (LINE == EXTI_Line6) || (LINE == EXTI_Line7))  /*!< check one EXTI line */
     
/**
  * @}
  */



/** @defgroup EXTI_Pin_Sources Pin Sources
  * @{
  */
  
#define EXTI_PinSource0            ((uint32_t)(1<<0))  /*!< pin0 as EXTI source */    
#define EXTI_PinSource1            ((uint32_t)(1<<1))  /*!< pin1 as EXTI source */ 
#define EXTI_PinSource2            ((uint32_t)(1<<2))  /*!< pin2 as EXTI source */ 
#define EXTI_PinSource3            ((uint32_t)(1<<3))  /*!< pin3 as EXTI source */ 
#define EXTI_PinSource4            ((uint32_t)(1<<4))  /*!< pin4 as EXTI source */ 
#define EXTI_PinSource5            ((uint32_t)(1<<5))  /*!< pin5 as EXTI source */ 
#define EXTI_PinSource6            ((uint32_t)(1<<6))  /*!< pin6 as EXTI source */ 
#define EXTI_PinSource7            ((uint32_t)(1<<7))  /*!< pin7 as EXTI source */ 

#define IS_EXTI_PIN_SOURCE(SOURCE)  ((SOURCE == EXTI_PinSource0) \
                                    || (SOURCE == EXTI_PinSource1) \
                                    || (SOURCE == EXTI_PinSource2) \
                                    || (SOURCE == EXTI_PinSource3) \
                                    || (SOURCE == EXTI_PinSource4) \
                                    || (SOURCE == EXTI_PinSource5) \
                                    || (SOURCE == EXTI_PinSource6) \
                                    || (SOURCE == EXTI_PinSource7)) /*!< check EXTI pin source */

/**
  * @}
  */
  
/**
  * @}
  */

/* Exported types ------------------------------------------------------------*/

/** @defgroup EXTI_Exported_Types Public Types
  * @{
  */

/** 
  * @brief  EXTI Init Structure definition  
  */
typedef struct
{
    uint32_t EXTI_Line;               /*!< Specifies the EXTI lines to be enabled or disabled.
                                         This parameter can be any combination value of @ref EXTI_Lines */
   
    EXTIMode_TypeDef EXTI_Mode;       /*!< Specifies the mode for the EXTI lines.
                                         This parameter can be a value of @ref EXTIMode_TypeDef */

    EXTITrigger_TypeDef EXTI_Trigger; /*!< Specifies the trigger signal active edge for the EXTI lines.
                                         This parameter can be a value of @ref EXTITrigger_TypeDef */
    EXTISampleCycle_TypeDef EXTI_SampleCycle; /*!< Specifies sampling time.
                                         This parameter can be a value of @ref EXTISampleCycle_TypeDef*/
    EXTISampleClockDivision_TypeDef EXTI_SampleClockDivision;/*!< Specifies sampling clock.
                                         This parameter can be a value of @ref EXTISampleClockDivision_TypeDef*/
    
    uint8_t EXTI_LineCmd;     /*!< Specifies the new state of the selected EXTI lines.
                                         This parameter can be set either to SH_ENABLE or SH_DISABLE */ 
	uint8_t reserved_pad[3];   /*!< reserved for structure alignment*/
}EXTI_InitTypeDef;


/**
  * @}
  */ 


/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 

/** @defgroup EXTI_Exported_Functions Public Functions
  * @{
  */
/* EXTI module reset */  
extern void EXTI_Reset(void);
/* EXTI module initialization */  
extern void EXTI_Init(EXTI_InitTypeDef* EXTI_InitStruct);
/* EXTI struture initialization */  
extern void EXTI_StructInit(EXTI_InitTypeDef * EXTI_InitStruct);
/* EXTI pin configuration */  
extern void EXTI_PinConfig(uint8_t EXTI_PinSourcex);
/* generate EXTI interrupt by software */  
extern void EXTI_GenerateSWInterrupt(uint32_t EXTI_Line);
/* get EXTI interrupt pending flag status */  
extern SH_FlagStatus EXTI_GetPendingFlagStatus(uint32_t EXTI_Line);
/* clear EXTI interrupt pending flag */  
extern void EXTI_ClearPendingFlag(uint32_t EXTI_Line);

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_EXTI_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
