/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_fifo.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the PPP firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_FIFO_H
#define __SH3xF2xx_SB0_FIFO_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup FIFO_MODULE FIFO
  * @{
  */ 

/* Exported constants --------------------------------------------------------*/
/** @defgroup FIFO_Exported_Constants Public Constants
  * @{
  */ 
/*! redefine type FIFO8 and FIFO4*/
typedef FIFO8L_TypeDef FIFO_TypeDef;
	 
#define IS_FIFO_ALL_PERIPH(PERIPH)  (((FIFO_TypeDef*)PERIPH == (FIFO_TypeDef*)FIFO0)  \
                                     || ((FIFO_TypeDef*)PERIPH == (FIFO_TypeDef*)FIFO1) \
									 || ((FIFO_TypeDef*)PERIPH == (FIFO_TypeDef*)FIFO2)) /*!< check FIFO poiner*/
	 
	 
/** 
  * @brief  FIFO_TX_Trigger enumeration  
  */
typedef enum
{
    FIFO_TX_Trigger_Quarter 	= 0x0000,   /*!< trigger when 1/4 datas sent*/
    FIFO_TX_Trigger_Half 		= 0x4000,   /*!< trigger when 1/2 datas sent */
    FIFO_TX_Trigger_3Quarters   = 0x8000,   /*!< trigger when 3/4 datas sent */
    FIFO_TX_Trigger_Empty 		= 0xC000    /*!< trigger when empty */
}FIFO_TX_Trigger_TypeDef;

#define IS_FIFO_TX_TRIGGER(TRIGGER)    ((TRIGGER == FIFO_TX_Trigger_Quarter) \
                                       || (TRIGGER == FIFO_TX_Trigger_Half) \
                                       || (TRIGGER == FIFO_TX_Trigger_3Quarters) \
                                       || (TRIGGER == FIFO_TX_Trigger_Empty)) /*!< check data send trigger mode */

 
/** 
  * @brief  FIFO_RX_Trigger enumeration  
  */
typedef enum
{
    FIFO_RX_Trigger_Quarter 	= 0x0000, /*!< trigger when 1/4 datas received*/
    FIFO_RX_Trigger_Half 		= 0x1000, /*!< trigger when 1/4 datas received*/
    FIFO_RX_Trigger_3Quarters   = 0x2000, /*!< trigger when 1/4 datas received*/
    FIFO_RX_Trigger_NotEmpty 	= 0x3000  /*!< trigger when one data received*/
}FIFO_RX_Trigger_TypeDef;

#define IS_FIFO_RX_TRIGGER(TRIGGER)    ((TRIGGER == FIFO_RX_Trigger_Quarter) \
                                       || (TRIGGER == FIFO_RX_Trigger_Half) \
                                       || (TRIGGER == FIFO_RX_Trigger_3Quarters) \
                                       || (TRIGGER == FIFO_RX_Trigger_NotEmpty)) /*!< check data receive trigger mode */

/** 
  * @brief  FIFO_TX_BitWidth enumeration  
  */
typedef enum
{
    FIFO_TX_BitWidth_8 	= 0x0000,  /*!< send data as 8bits width */
    FIFO_TX_BitWidth_16 = 0x0400,  /*!< send data as 16bits width */
    FIFO_TX_BitWidth_32 = 0x0800,  /*!< send data as 32bits width */
}FIFO_TX_BitWidth_TypeDef;


#define IS_FIFO_TX_BITWIDTH(WIDTH)     ((WIDTH == FIFO_TX_BitWidth_8) \
                                       || (WIDTH == FIFO_TX_BitWidth_16) \
                                       || (WIDTH == FIFO_TX_BitWidth_32)) /*!< check send data bitwidth*/

/** 
  * @brief  FIFO_RX_BitWidth enumeration  
  */
typedef enum
{
    FIFO_RX_BitWidth_8 	 = 0x0000,  /*!< receive data as 8bits width */
    FIFO_RX_BitWidth_16  = 0x0100,  /*!< receive data as 16bits width */
    FIFO_RX_BitWidth_32  = 0x0200,  /*!< receive data as 32bits width */
}FIFO_RX_BitWidth_TypeDef;


#define IS_FIFO_RX_BITWIDTH(WIDTH)    	  ((WIDTH == FIFO_RX_BitWidth_8) \
                                       || (WIDTH == FIFO_RX_BitWidth_16) \
                                       || (WIDTH == FIFO_RX_BitWidth_32)) /*!< check receive data bitwidth*/

/** 
  * @brief  FIFO_TX_Map enumeration  
  */
typedef enum
{
    FIFO_TX_MAP_UART0 	= 0x00,  /*!< map to uart0 sending function */
    FIFO_TX_MAP_UART1 	= 0x40,  /*!< map to uart1 sending function */
    FIFO_TX_MAP_UART2   = 0x80,  /*!< map to uart2 sending function */
    FIFO_TX_MAP_SPI  	= 0xC0,  /*!< map to spi sending function*/
	
}FIFO_TX_Map_TypeDef;


#define IS_FIFO_TX_MAP(MAP)    			((MAP == FIFO_TX_MAP_UART0) \
                                       || (MAP == FIFO_TX_MAP_UART1) \
                                       || (MAP == FIFO_TX_MAP_UART2) \
                                       || (MAP == FIFO_TX_MAP_SPI)) /*!< check sending map*/
/** 
  * @brief  FIFO_RX_Map enumeration  
  */
typedef enum
{
    FIFO_RX_MAP_UART0 	= 0x00,  /*!< map to uart0 receiving function */
    FIFO_RX_MAP_UART1 	= 0x10,  /*!< map to uart1 receiving function */
    FIFO_RX_MAP_UART2   = 0x20,  /*!< map to uart2 receiving function */
    FIFO_RX_MAP_SPI  	= 0x30,  /*!< map to spi receiving function */
	
}FIFO_RX_Map_TypeDef;


#define IS_FIFO_RX_MAP(MAP)    			((MAP == FIFO_RX_MAP_UART0) \
                                       || (MAP == FIFO_RX_MAP_UART1) \
                                       || (MAP == FIFO_RX_MAP_UART2) \
                                       || (MAP == FIFO_RX_MAP_SPI))  /*!< check receiving map*/


/** 
  * @brief  FIFO RX Mode enumeration  
  */
typedef enum
{
    FIFO_RX_Mode_8bits 	  = 0x00,  /*!< FIFO rx 8bits mode */
    FIFO_RX_Mode_8Nbits   = 0x08,  /*!< FIFO rx (8+N)bits mode */
}FIFO_RX_Mode_TypeDef;
#define IS_FIFO_RX_Mode(MODE)    			((MODE == FIFO_RX_Mode_8bits)|| (MODE == FIFO_RX_Mode_8Nbits)) /*!< check FIFO rx mode*/

#define FIFO_TXFULL_FLAG     (1<<7)  /*!< FILO Flag: TXFULL :TX buffer full*/
#define FIFO_RXFULL_FLAG     (1<<6)  /*!< FILO Flag: RXFULL :RX buffer full*/
#define FIFO_TXEMPT_FLAG     (1<<5)  /*!< FILO Flag: TXEMPTY:TX buffer empty */
#define FIFO_RXEMPT_FLAG     (1<<4)  /*!< FILO Flag: RXEMPTY:RX buffer empty */
#define FIFO_RXOVF_FLAG      (1<<2)  /*!< FILO Flag: RXOVF  :RX conflict*/
#define FIFO_TXTRIGF_FLAG    (1<<1)  /*!< FILO Flag: TXTRIGF:TX trigger event */
#define FIFO_RXTRIGF_FLAG    (1<<0)  /*!< FILO Flag: RXTRIGF:RX trigger event */

#define IS_FIFO_GET_ONE_FLAG(FLAG)		((FLAG == FIFO_TXFULL_FLAG) \
                                       || (FLAG == FIFO_RXFULL_FLAG) \
                                       || (FLAG == FIFO_TXEMPT_FLAG) \
                                       || (FLAG == FIFO_RXEMPT_FLAG) \
                                       || (FLAG == FIFO_RXOVF_FLAG) \
                                       || (FLAG == FIFO_TXTRIGF_FLAG) \
                                       || (FLAG == FIFO_RXTRIGF_FLAG)) /*!< check FIFO flag */


#define FIFO_RXOVFIE_EN      (1<<2)  /*!< FIFO RX conflict interrupt enable*/
#define FIFO_TXTRIGIE_EN     (1<<1)  /*!< FIFO TX trigger interrupt enable*/
#define FIFO_RXTRIGIE_EN     (1<<0)  /*!< FIFO RX trigger interrupt enable*/

#define IS_FIFO_INT(INT)				  ((INT == FIFO_RXOVFIE_EN) \
                                       || (INT == FIFO_TXTRIGIE_EN) \
                                       || (INT == FIFO_RXTRIGIE_EN)) /*!< check FIFO interrupt enable parameter*/
																			 
#define FIFO_RX_EN      (1<<18)  /*!< FIFO RX enable bit*/
#define FIFO_TX_EN      (1<<19)	 /*!< FIFO TX enable bit*/	

/**
  * @}
  */
/* Exported types ------------------------------------------------------------*/
/** @defgroup FIFO_Exported_Types Public Types
  * @{
  */

/*! structure FIFO_InitTypeDef definition */ 
typedef struct
{
    uint16_t FIFO_TX_Trigger;         /*!< Specifie FIFO TX Trigger mode.
                                              This parameter can be a value of @ref FIFO_TX_Trigger_TypeDef */
    uint16_t FIFO_RX_Trigger;         /*!< Specifie FIFO TX Trigger mode.
                                              This parameter can be a value of @ref FIFO_RX_Trigger_TypeDef */
    uint16_t FIFO_TX_BitWidth;        /*!< Specifie FIFO TX Bitwidth mode.
                                              This parameter can be a value of @ref FIFO_TX_BitWidth_TypeDef */
    uint16_t FIFO_RX_BitWidth;        /*!< Specifie FIFO TX Bitwidth mode.
                                              This parameter can be a value of @ref FIFO_RX_BitWidth_TypeDef */
    uint16_t FIFO_TX_Map;             /*!< Specifie FIFO TX Bitwidth mode.
                                              This parameter can be a value of @ref FIFO_TX_Map_TypeDef */
    uint16_t FIFO_RX_Map;             /*!< Specifie FIFO TX Bitwidth mode.
                                              This parameter can be a value of @ref FIFO_RX_Map_TypeDef */
    uint16_t FIFO_RX_Mode;            /*!< Specifie FIFO RX Bitwidth mode.
                                              This parameter can be a value of @ref FIFO_RX_Mode_TypeDef */
    uint16_t rev_align;               /*!< reserved for data structure alignment */                       
}FIFO_InitTypeDef;

/**
  * @}
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 
/** @addtogroup FIFO_Exported_Functions Public Functions
  * @{
  */
/* Reset the FIFO peripheral registers */
extern void FIFO_Reset(FIFO_TypeDef* FIFOx);
/* Initializes the FIFO peripheral */
extern void FIFO_Init(FIFO_TypeDef* FIFOx, FIFO_InitTypeDef* FIFO_InitStruct);
/* Fills each FIFO_InitStruct member by default value*/
extern void FIFO_StructInit(FIFO_InitTypeDef* FIFO_InitStruct);
/* enable or disable specified FIFO interrupts */
extern void FIFO_INTConfig(FIFO_TypeDef* FIFOx, uint32_t FIFO_INT, SH_FunctionalState NewState);
/* turn on or turn off the specified FIFO peripheral */
extern void FIFO_OnOff(FIFO_TypeDef* FIFOx, uint32_t FIFO_Mode, SH_CmdState OnOffState);
/* Checks whether the specified FIFO flag is set or not */
extern SH_FlagStatus FIFO_GetFlagStatus(FIFO_TypeDef* FIFOx, uint32_t FIFO_Line);
/* Clears the FIFO's pending flags */
extern void FIFO_ClearFlag(FIFO_TypeDef* FIFOx,uint32_t FIFO_Line);
/* Reset the FIFO RX Module */
extern void FIFO_ResetRX(FIFO_TypeDef* FIFOx);
/* Reset the FIFO TX Module */
extern void FIFO_ResetTX(FIFO_TypeDef* FIFOx);

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_FIFO_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
