/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_gpio.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the GPIO firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_GPIO_H
#define __SH3xF2xx_SB0_GPIO_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup GPIO_MODULE
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/** @defgroup GPIO_Exported_Constants Public Constants
  * @{
  */ 
  
  
/** 
  * @brief  GPIO Configuration Mode enumeration 
  */   
typedef enum
{ 
    GPIO_Mode_IN   = 0x00, /*!< GPIO Input Mode */
    GPIO_Mode_OUT  = 0x01, /*!< GPIO Output Mode */
    GPIO_Mode_AF = 0x02    /*!< GPIO Alternate Mode */
}GPIOMode_TypeDef;
#define IS_GPIO_MODE(MODE) (((MODE) == GPIO_Mode_IN)  || ((MODE) == GPIO_Mode_OUT))  /*!< check GPIO mode */


/** 
  * @brief  GPIO Output type enumeration 
  */  
typedef enum
{ 
  GPIO_OType_PP = 0x00, /*!< push pull type */
  GPIO_OType_OD = 0x01  /*!< open drain type*/
}GPIOOType_TypeDef;
#define IS_GPIO_OTYPE(OTYPE) (((OTYPE) == GPIO_OType_PP) || ((OTYPE) == GPIO_OType_OD)) /*!< check GPIO OType */

/** 
  * @brief  GPIO Input Enable enumeration 
  */  
typedef enum
{ 
  GPIO_IE_DIS = 0x00,  /*!< input disable */
  GPIO_IE_EN = 0x01    /*!< input enable */
}GPIOIE_TypeDef;
#define IS_GPIO_IE(IE) (((IE) == GPIO_IE_DIS) || ((IE) == GPIO_IE_EN))  /*!< check GPIO input function */


/** 
  * @brief  GPIO Configuration PullUp PullDown enumeration 
  */ 
typedef enum
{ 
  GPIO_PuPd_NOPULL = 0x00,  /*!< no pull high or low*/
  GPIO_PuPd_UP     = 0x01,  /*!< pull high */
}GPIOPuPd_TypeDef;

#define IS_GPIO_PUPD(PUPD) (((PUPD) == GPIO_PuPd_NOPULL) || ((PUPD) == GPIO_PuPd_UP)) /*!< check GPIO pull status*/



/** 
  * @brief  GPIO Bit SH_SET and Bit RESET enumeration 
  */ 
typedef enum
{ 
  Bit_RESET = 0,  /*!< GPIO low */
  Bit_SET         /*!< GPIO high */
}BitAction;  

#define IS_GPIO_BIT_ACTION(BIT_ACTION)   (((BIT_ACTION) == Bit_RESET) || ((BIT_ACTION) == Bit_SET))  /*!< check GPIO state */

  
/** 
  * @brief   GPIO Init structure definition  
  */ 
typedef struct
{
    uint32_t GPIO_Pin;              /*!< Specifies the GPIO pins to be configured.
                                       This parameter can be any value of @ref GPIO_pins_define */

    GPIOMode_TypeDef GPIO_Mode;     /*!< Specifies the operating mode for the selected pins.
                                       This parameter can be a value of @ref GPIOMode_TypeDef */

    GPIOOType_TypeDef GPIO_OType;   /*!< Specifies the operating output type for the selected pins.
                                       This parameter can be a value of @ref GPIOOType_TypeDef */
	
    GPIOIE_TypeDef GPIO_IE;   /*!< Specifies the operating input enable for the selected pins.
                                       This parameter can be a value of @ref GPIOIE_TypeDef */	

    GPIOPuPd_TypeDef GPIO_PuPd;     /*!< Specifies the operating Pull-up/Pull down for the selected pins.
                                       This parameter can be a value of @ref GPIOPuPd_TypeDef */
}GPIO_InitTypeDef;  


#define IS_GPIO_ALL_PERIPH(PERIPH)    (((PERIPH) == GPIOA) || ((PERIPH) == GPIOB) \
                                       || ((PERIPH) == GPIOC) )  /*!< check GPIO ports */

/** @defgroup GPIO_Bit_Lock GPIO Bit Lock
  * @{
  */
  
#define GPIO_BitLock_Disable       (uint8_t)0x00  /*!< GPIO bit lock disable */
#define GPIO_BitLock_Enable        (uint8_t)0x01  /*!< GPIO bit lock enable */
#define IS_GPIO_BIT_LOCK(LOCK)   ((LOCK == GPIO_BitLock_Disable) || (LOCK == GPIO_BitLock_Enable)) /*!< check GPIO lock bit state */

/**
  * @}
  */
  
/** @defgroup GPIO_Bit_Level GPIO Bit Level
  * @{
  */

#define GPIO_BitLevel_CMOS    (uint8_t)0x00  /*!< GPIO bit level type is CMOS */
#define GPIO_BitLevel_TTL     (uint8_t)0x01  /*!< GPIO bit level type is TTL */
#define IS_GPIO_BIT_LEVEL(LEVEL)  ((LEVEL == GPIO_BitLevel_CMOS) || (LEVEL == GPIO_BitLevel_TTL)) /*!< check GPIO bit level type */

/**
  * @}
  */
	
	
/** @defgroup GPIO_pins_define GPIO pins
  * @{
  */ 
  
#define GPIO_Pin_0                 ((uint16_t)0x0001)  /*!< Pin 0 selected */
#define GPIO_Pin_1                 ((uint16_t)0x0002)  /*!< Pin 1 selected */
#define GPIO_Pin_2                 ((uint16_t)0x0004)  /*!< Pin 2 selected */
#define GPIO_Pin_3                 ((uint16_t)0x0008)  /*!< Pin 3 selected */
#define GPIO_Pin_4                 ((uint16_t)0x0010)  /*!< Pin 4 selected */
#define GPIO_Pin_5                 ((uint16_t)0x0020)  /*!< Pin 5 selected */
#define GPIO_Pin_6                 ((uint16_t)0x0040)  /*!< Pin 6 selected */
#define GPIO_Pin_7                 ((uint16_t)0x0080)  /*!< Pin 7 selected */
#define GPIO_Pin_8                 ((uint16_t)0x0100)  /*!< Pin 8 selected */
#define GPIO_Pin_9                 ((uint16_t)0x0200)  /*!< Pin 9 selected */
#define GPIO_Pin_10                ((uint16_t)0x0400)  /*!< Pin 10 selected */
#define GPIO_Pin_11                ((uint16_t)0x0800)  /*!< Pin 11 selected */
#define GPIO_Pin_12                ((uint16_t)0x1000)  /*!< Pin 12 selected */
#define GPIO_Pin_13                ((uint16_t)0x2000)  /*!< Pin 13 selected */
#define GPIO_Pin_14                ((uint16_t)0x4000)  /*!< Pin 14 selected */
#define GPIO_Pin_15                ((uint16_t)0x8000)  /*!< Pin 15 selected */
#define GPIO_Pin_All               ((uint16_t)0xFFFF)  /*!< All pins selected */

#define IS_GPIO_PIN(PIN) ((((PIN) & (uint16_t)0x00) == 0x00) && ((PIN) != (uint16_t)0x00)) /*!< check pin ids*/
#define IS_GET_GPIO_PIN(PIN)   (((PIN & GPIO_Pin_0) == GPIO_Pin_0) \
                             || ((PIN & GPIO_Pin_1) == GPIO_Pin_1) \
                             || ((PIN & GPIO_Pin_2) == GPIO_Pin_2) \
                             || ((PIN & GPIO_Pin_3) == GPIO_Pin_3) \
                             || ((PIN & GPIO_Pin_4) == GPIO_Pin_4) \
                             || ((PIN & GPIO_Pin_5) == GPIO_Pin_5) \
                             || ((PIN & GPIO_Pin_6) == GPIO_Pin_6) \
                             || ((PIN & GPIO_Pin_7) == GPIO_Pin_7) \
                             || ((PIN & GPIO_Pin_8) == GPIO_Pin_8) \
                             || ((PIN & GPIO_Pin_9) == GPIO_Pin_9) \
                             || ((PIN & GPIO_Pin_10) == GPIO_Pin_10) \
                             || ((PIN & GPIO_Pin_11) == GPIO_Pin_11) \
                             || ((PIN & GPIO_Pin_12) == GPIO_Pin_12) \
                             || ((PIN & GPIO_Pin_13) == GPIO_Pin_13) \
                             || ((PIN & GPIO_Pin_14) == GPIO_Pin_14) \
                             || ((PIN & GPIO_Pin_15) == GPIO_Pin_15))  /*!< check one pin id*/

/**
  * @}
  */ 



/** @defgroup GPIO_Alternat_function_selection_define  GPIO AF Selection
  * @{
  */ 
/** 
  * @brief   AF 0 selection  
  */ 
	
	/** 
  * @brief   AF 1 selection  
  */ 
#define GPIO_AF_GPIO          ((uint8_t)0x01)  /*!< GPIO Alternate Function mapping */

/** 
  * @brief   AF 2 selection  
  */ 
#define GPIO_AF_MCM           ((uint8_t)0x02)  /*!< MCM Alternate Function mapping */
#define GPIO_AF_ADTRG         ((uint8_t)0x02)  /*!< ADTRG Alternate Function mapping */

/** 
  * @brief   AF 3 selection  
  */ 
#define GPIO_AF_PCA0          ((uint8_t)0x03)  /*!< PCA0 Alternate Function mapping */
#define GPIO_AF_PCA1          ((uint8_t)0x03)  /*!< PCA1 Alternate Function mapping */
#define GPIO_AF_TIM7          ((uint8_t)0x03)  /*!< TIM7 Alternate Function mapping */
#define GPIO_AF_TIM8          ((uint8_t)0x03)  /*!< TIM8 Alternate Function mapping */


/** 
  * @brief   AF 4 selection  
  */ 
#define GPIO_AF_UART0        ((uint8_t)0x04)  /*!< UART0 Alternate Function mapping */
#define GPIO_AF_UART1        ((uint8_t)0x04)  /*!< UART1 Alternate Function mapping */
#define GPIO_AF_UART2        ((uint8_t)0x04)  /*!< UART2 Alternate Function mapping */


/** 
  * @brief   AF 5 selection  
  */ 
#define GPIO_AF_SPI          ((uint8_t)0x05)  /*!< SPI Alternate Function mapping */
#define GPIO_AF_TWI          ((uint8_t)0x05)  /*!< TWI Alternate Function mapping */

/** 
  * @brief   AF 6 selection  
  */ 
#define GPIO_AF_QEI          ((uint8_t)0x06)  /*!< QEI Alternate Function mapping */
#define GPIO_AF_CAN          ((uint8_t)0x06)  /*!< CAN Alternate Function mapping */

/** 
  * @brief   AF 7 selection  
  */ 
#define GPIO_AF_ADC      ((uint8_t)0x07)  /*!< ADC Alternate Function mapping */

#define GPIO_AF_OP0      ((uint8_t)0x07)  /*!< OP0 Alternate Function mapping */
#define GPIO_AF_OP1      ((uint8_t)0x07)  /*!< OP1 Alternate Function mapping */
#define GPIO_AF_OP2      ((uint8_t)0x07)  /*!< OP2 Alternate Function mapping */
#define GPIO_AF_OP3      ((uint8_t)0x07)  /*!< OP3 Alternate Function mapping */

#define GPIO_AF_CMP0      ((uint8_t)0x07)  /*!< CMP0 Alternate Function mapping */
#define GPIO_AF_CMP1      ((uint8_t)0x07)  /*!< CMP1 Alternate Function mapping */
#define GPIO_AF_CMP_OUT   ((uint8_t)0x06)  /*!< CMP OUT Alternate Function mapping */



#define IS_GPIO_AF(AF)      (((AF) == GPIO_AF_GPIO)    || ((AF) == GPIO_AF_MCM)  \
                            || ((AF) == GPIO_AF_PCA0)  || ((AF) == GPIO_AF_PCA1)  \
                            || ((AF) == GPIO_AF_TIM7)  || ((AF) == GPIO_AF_TIM8) \
                            || ((AF) == GPIO_AF_UART0) || ((AF) == GPIO_AF_UART1) \
                            || ((AF) == GPIO_AF_UART2) || ((AF) == GPIO_AF_CAN)  \
                            || ((AF) == GPIO_AF_SPI)   || ((AF) == GPIO_AF_TWI) \
                            || ((AF) == GPIO_AF_QEI)   || ((AF) == GPIO_AF_CMP_OUT)\
                            || ((AF) == GPIO_AF_CMP0)  || ((AF) == GPIO_AF_CMP1)\
														|| ((AF) == GPIO_AF_ADTRG) || ((AF) == GPIO_AF_ADC) \
                            || ((AF) == GPIO_AF_OP1)   || ((AF) == GPIO_AF_OP2) \
                            || ((AF) == GPIO_AF_OP3)   || ((AF) == GPIO_AF_OP0)) /*!< check GPIO AF function*/
/**
  * @}
  */ 


  
/**
  * @}
  */ 


/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 

/** @defgroup GPIO_Exported_Functions Public Functions
  * @{
  */
/* GPIO module reset */
extern void GPIO_Reset(GPIO_TypeDef* GPIOx);
/* Initial GPIO */
extern void GPIO_Init(GPIO_TypeDef* GPIOx, GPIO_InitTypeDef* GPIO_InitStruct);
/* Initial GPIO init structure */
extern void GPIO_StructInit(GPIO_InitTypeDef* GPIO_InitStruct);
/* GPIO TTL config*/
extern void GPIO_PinTTLConfig(GPIO_TypeDef* GPIOx, uint16_t GPIO_Pin, uint8_t BitLevel);
/* GPIO Pin Lock function*/
extern void GPIO_PinLock(GPIO_TypeDef* GPIOx, uint16_t GPIO_Pin, uint8_t BitLock);
/* read pin input buffer*/
extern uint8_t GPIO_ReadInputDataBit(GPIO_TypeDef* GPIOx, uint16_t GPIO_Pin);
/* read port input buffer*/
extern uint16_t GPIO_ReadInputData(GPIO_TypeDef* GPIOx);
/* read pin output buffer */
extern uint8_t GPIO_ReadOutputDataBit(GPIO_TypeDef* GPIOx, uint16_t GPIO_Pin);
/* read port output buffer */
extern uint16_t GPIO_ReadOutputData(GPIO_TypeDef* GPIOx);
/* output pins to high */
extern void GPIO_SetBits(GPIO_TypeDef* GPIOx, uint16_t GPIO_Pin);
/* output pins to low */
extern void GPIO_ResetBits(GPIO_TypeDef* GPIOx, uint16_t GPIO_Pin);
/* write to GPIO pins */
extern void GPIO_WriteBits(GPIO_TypeDef* GPIOx, uint16_t GPIO_Pin, BitAction BitVal);
/* write to GPIO port */
extern void GPIO_Write(GPIO_TypeDef* GPIOx, uint16_t PortVal);
/* Toggle GPIO pins */
extern void GPIO_ToggleBits(GPIO_TypeDef* GPIOx, uint16_t GPIO_Pin);
/* GPIO AF function configuration */
extern void GPIO_PinAFConfig(GPIO_TypeDef * GPIOx, uint16_t GPIO_Pin, uint8_t GPIO_AF);
/* GPIO OType configuration */
extern void GPIO_PinOTypeConfig(GPIO_TypeDef* GPIOx, uint16_t GPIO_Pin, uint8_t GPIO_Out_Type);

/**
  * @}
  */



#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_GPIO_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
