/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_lib.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file includes all module's head files
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2017 Sinowealth</center></h2>
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_LIB_H
#define __SH3xF2xx_SB0_LIB_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup LIB_Group Global Constants
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/
/**
    * @brief  Define Boolean data type
    * @arg  TRUE:   logical  true
    * @arg  FALSE:  logical  false
  */    
typedef enum{
    SH_FALSE=0,
    SH_TRUE =!SH_FALSE,
}SH_Bool;

/** 
  *@brief  check the input value is a legal boolean data
  */
#define IS_BOOL_TYPE(var) (((var) == SH_FALSE) || ((var) == SH_TRUE))

/**
    * @brief  define  flag's data type
    * @arg  SET:     the flag is setted
    * @arg  RESET: the flag is cleared
  */    
typedef enum 
{ 
    SH_RESET = 0, 
    SH_SET = !SH_RESET, 
}SH_FlagStatus;

/** 
  *@brief  check the input value is a legal flag data
  */
#define IS_FLAG_STATUS(flag) (((flag) == SH_RESET) || ((flag) == SH_SET))

/**
    * @brief  define the functional state type
    * @arg  ENABLE:    enable the feature
    * @arg  DISABLE:  disable the feature
  */    
typedef enum 
{ 
    SH_DISABLE = 0, 
    SH_ENABLE = !SH_DISABLE, 
}SH_FunctionalState; 
/** 
  *@brief  check the input value is a legal function state data
  */
#define IS_FUNCTION_STATE(state) (((state) == SH_DISABLE) || ((state) == SH_ENABLE))

/**
    * @brief  define the peripheral state type
    * @arg  ON:   peripheral is enabled
    * @arg  OFF:  peripheral is disabled
  */    
typedef enum 
{ 
    SH_OFF = 0, 
    SH_ON = !SH_OFF, 
}SH_CmdState; 
/** 
  *@brief  check the input value is a legal peripheral state data
  */
#define IS_CMD_STATE(state) (((state) == SH_ON) || ((state) == SH_OFF))


/**
    * @brief  define the return data type
    * @arg  ERROR:      error occurs
    * @arg  SUCCESS:   operation succeeded
  */   
typedef enum 
{
    SH_ERROR = 0, 
    SH_SUCCESS = !SH_ERROR
} SH_ErrorStatus;

/** 
  *@brief  check the input value is a legal error status data
  */
#define IS_ERROR_STATUS(status) (((status) == SH_ERROR) || ((status) == SH_SUCCESS))


/* Exported constants --------------------------------------------------------*/
/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 

#ifdef _RTE_
#include "RTE_Components.h"    
#include CMSIS_device_header
#endif

#include "sh3xf2xx_sb0.h"
      
#ifndef   _RTE_
#include "sh3xf2xx_sb0_rcc.h"   
#include "sh3xf2xx_sb0_flash.h"      
#include "sh3xf2xx_sb0_syscfg.h"          
#include "sh3xf2xx_sb0_iwdt.h"      
#include "sh3xf2xx_sb0_wwdt.h"      
#include "sh3xf2xx_sb0_crc.h"      
#include "sh3xf2xx_sb0_gpio.h"
#include "sh3xf2xx_sb0_exti.h"
#include "sh3xf2xx_sb0_mcm.h"
#include "sh3xf2xx_sb0_tim.h" 
#include "sh3xf2xx_sb0_IQmath.h"
#include "sh3xf2xx_sb0_macp.h"
#include "sh3xf2xx_sb0_adc.h"     
#include "sh3xf2xx_sb0_qei.h"
#include "sh3xf2xx_sb0_amoc.h"
#include "sh3xf2xx_sb0_uart.h"
#include "sh3xf2xx_sb0_spi.h"    
#include "sh3xf2xx_sb0_twi.h"
#include "sh3xf2xx_sb0_pca.h"
#include "sh3xf2xx_sb0_can.h"
#include "sh3xf2xx_sb0_fifo.h"
#include "sh3xf2xx_sb0_nvic.h"
#include "sh3xf2xx_sb0_core.h"

#else

#ifdef RTE_MODULE_RCC 
#include "sh3xf2xx_sb0_rcc.h"   
#endif

#ifdef RTE_MODULE_FLASH
#include "sh3xf2xx_sb0_flash.h"      
#endif      

#ifdef RTE_MODULE_SYSCFG
#include "sh3xf2xx_sb0_syscfg.h"      
#endif      
      
#ifdef RTE_MODULE_IWDT
#include "sh3xf2xx_sb0_iwdt.h"      
#endif      

#ifdef RTE_MODULE_WWDT
#include "sh3xf2xx_sb0_wwdt.h"      
#endif      

#ifdef RTE_MODULE_CRC
#include "sh3xf2xx_sb0_crc.h"      
#endif      

#ifdef RTE_MODULE_GPIO
#include "sh3xf2xx_sb0_gpio.h"
#endif

#ifdef RTE_MODULE_EXTI
#include "sh3xf2xx_sb0_exti.h"
#endif

#ifdef RTE_MODULE_MCM
#include "sh3xf2xx_sb0_mcm.h"
#endif
 
#ifdef RTE_MODULE_TIMER
#include "sh3xf2xx_sb0_tim.h"
#endif      
      
#ifdef RTE_MODULE_MACP
#include "sh3xf2xx_sb0_macp.h"
#endif

#ifdef RTE_MODULE_IQMATH
#include "sh3xf2xx_sb0_IQmath.h"
#endif      

#ifdef RTE_MODULE_ADC
#include "sh3xf2xx_sb0_adc.h"
#endif      
      
#ifdef RTE_MODULE_QEI
#include "sh3xf2xx_sb0_qei.h"
#endif      

#ifdef RTE_MODULE_AMOC
#include "sh3xf2xx_sb0_amoc.h"
#endif      

#ifdef RTE_MODULE_UART
#include "sh3xf2xx_sb0_uart.h"
#endif      

#ifdef RTE_MODULE_SPI
#include "sh3xf2xx_sb0_spi.h"
#endif      
      
#ifdef RTE_MODULE_TWI
#include "sh3xf2xx_sb0_twi.h"
#endif      

#ifdef RTE_MODULE_PCA
#include "sh3xf2xx_sb0_pca.h"
#endif      

#ifdef RTE_MODULE_CAN
#include "sh3xf2xx_sb0_can.h"
#endif      

#ifdef RTE_MODULE_FIFO
#include "sh3xf2xx_sb0_fifo.h"
#endif      

#ifdef RTE_MODULE_NVIC
#include "sh3xf2xx_sb0_nvic.h"
#endif

#ifdef RTE_MODULE_CORTEX
#include "sh3xf2xx_sb0_core.h"
#endif
#endif


#ifdef __cplusplus
}
#endif

#endif /*__SH32F2xx_LIB_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/










