/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_macp.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the MACP firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_MACP_H
#define __SH3xF2xx_SB0_MACP_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup MACP_MODULE
  * @{
  */ 

/** @defgroup MACP_Group_Constant  Public Constants
  * @{
  */ 

#ifndef  C_IQ26_1_K
/*! IQ26_1_K constant */     
#define C_IQ26_1_K          ((IQ26)(0x026DD3B6))    
#endif 

#ifndef  C_IQ24_1_K
/*! IQ24_1_K constant */     
#define C_IQ24_1_K          ((IQ24)(0x009B74EE))
#endif

#ifndef  C_IQ15_1_K
/*! IQ15_1_K constant */     
#define C_IQ15_1_K          ((IQ15)(0x004DBA))
#endif 

#ifndef  C_IQ26_1
/*! IQ26_1 constant */     
#define C_IQ26_1            ((IQ26)(0x3FFFFFF))          
#endif

#ifndef  C_IQ24_1
/*! IQ24_1 constant */     
#define C_IQ24_1            ((IQ24)(0xFFFFFF))
#endif

#ifndef  C_IQ15_1
/*! IQ15_1 constant */     
#define C_IQ15_1            ((IQ15)(0x7FFF))
#endif


#ifndef  L_IQ26_1_K
/*! IQ26_1_K constant */     
#define L_IQ26_1_K          ((IQ26)(0X04000000))    
#endif 

#ifndef  L_IQ24_1_K
/*! IQ24_1_K constant */     
#define L_IQ24_1_K          ((IQ24)(0X01000000))
#endif

#ifndef  L_IQ15_1_K
/*! IQ15_1_K constant */     
#define L_IQ15_1_K          ((IQ15)(0x8000))
#endif 

#ifndef  L_IQ26_1
/*! IQ26_1 constant */     
#define L_IQ26_1            ((IQ26)(0X04000000))          
#endif

#ifndef  L_IQ24_1
/*! IQ24_1 constant */     
#define L_IQ24_1            ((IQ24)(0X01000000))
#endif

#ifndef  L_IQ15_1
/*! IQ15_1 constant */     
#define L_IQ15_1            ((IQ15)(0x8000))
#endif


#ifndef  H_IQ26_1_K
/*! IQ26_1_K constant */     
#define H_IQ26_1_K          ((IQ26)(0x04D20F44))    
#endif 

#ifndef  H_IQ24_1_K
/*! IQ24_1_K constant */     
#define H_IQ24_1_K          ((IQ24)(0x13483D1))
#endif

#ifndef  H_IQ15_1_K
/*! IQ15_1_K constant */     
#define H_IQ15_1_K          ((IQ15)(0x9A41))
#endif 

#ifndef  H_IQ26_1
/*! IQ26_1 constant */     
#define H_IQ26_1            ((IQ26)(0x0351B245))          
#endif

#ifndef  H_IQ24_1
/*! IQ24_1 constant */     
#define H_IQ24_1            ((IQ24)(0xD46C91))
#endif

#ifndef  H_IQ15_1
/*! IQ15_1 constant */     
#define H_IQ15_1            ((IQ15)(0x6A36))
#endif


#ifndef PI
/*! PI CONSTANT */
#define PI  3.141593
#endif
    
/*! define CORDIC0 device pointer*/
#define CORDIC0  ((CORDIC_TypeDef *)(uint32_t)&(MACP->CORDCSR0.V32))
/*! define CORDIC1 device pointer*/
#define CORDIC1  ((CORDIC_TypeDef *)(uint32_t)&(MACP->CORDCSR1.V32))
/*! check CORDIC device pointer */
#define IS_CORDIC_MODULE(CORDICx) ((CORDICx == CORDIC0) || (CORDICx == CORDIC1))
   
/*!  CORDIC K Adjust*/   
typedef enum
{
   CORDIC_KADJ_NONE = 0,  /*!< Result do nothing */
   CORDIC_KADJ_DIVK  = 1  /*!< Result /= K */   
}CORDIC_KADJ_Type;
/*! check CORDIC K adjust type */
#define IS_CORDIC_KADJ_TYPE(type) (((type) == CORDIC_KADJ_NONE) || ((type) == CORDIC_KADJ_DIVK))
     
/*!  CORDIC XY Adjust */   
typedef enum
{
   CORDIC_XYMRS_NONE = 0, /*!< X,Y do nothing */
   CORDIC_XYMRS_DIV2 = 1  /*!< X/=2 Y/=2 */   
}CORDIC_XYMRS_Type;
/*! check CORDIC XY adjust type */
#define IS_CORDIC_XYMRS_TYPE(type) (((type) == CORDIC_XYMRS_NONE) || ((type) == CORDIC_XYMRS_DIV2))

/*!  CORDIC data Format */   
typedef enum
{
   CORDIC_FMT_IQ26 = 0, /*!< IQ26 Format */
   CORDIC_FMT_IQ24 = 1, /*!< IQ24 Format */
   CORDIC_FMT_IQ15 = 2  /*!< IQ15 Format */
}CORDIC_FMT_Type;
/*! check CORDIC data format */
#define IS_CORDIC_FMT_TYPE(type) (((type) == CORDIC_FMT_IQ26) \
                               || ((type) == CORDIC_FMT_IQ24) \
                               || ((type) == CORDIC_FMT_IQ15))

/*!  CORDIC MODE */   
typedef enum
{
   CORDIC_MODE_ROTATE = 0, /*!< rotate conversion*/
   CORDIC_MODE_VECTOR = 1  /*!< vector conversion*/
}CORDIC_MODE_Type;
/*! check CORDIC transform mode */
#define IS_CORDIC_MODE_TYPE(type) (((type) == CORDIC_MODE_ROTATE) || ((type) == CORDIC_MODE_VECTOR))


/*!  CORDIC Iteration Algorithm */  
typedef enum
{
   CORDIC_ARITH_CIRCULAR  = 0,    /*!< Use circular iteration algorithm*/
   CORDIC_ARITH_LINEAR    = 1,    /*!< Use linear iteration algorithm*/
   CORDIC_ARITH_HYPERBOLA = 2,    /*!< Use hyperbola iteration algorithm*/
}CORDIC_ARITH_Type;
/*! check CORDIC transform mode */
#define IS_CORDIC_ARITH_TYPE(type) (((type) == CORDIC_ARITH_CIRCULAR) || ((type) == CORDIC_ARITH_LINEAR)|| ((type) == CORDIC_ARITH_HYPERBOLA))


/*!  SVPWM  Type */   
typedef enum
{
    SVPWM_SVTYPE_7 = 0, /*!< 7 segment type */
    SVPWM_SVTYPE_5 = 1  /*!< 5 segment type */  
}SVPWM_SVTYPE_Type;
/*! check SVPWM  Type */
#define IS_SVPWM_SVTYPE_TYPE(type) (((type) == SVPWM_SVTYPE_7) || ((type) == SVPWM_SVTYPE_5))


#define  SVPWM_SATEN_DISBALE      0x0000 /*!< SVPWM SAT Disable */
#define  SVPWM_SATEN_ENBALE       0x0200 /*!< SVPWM SAT Enable */     
/*! check SVPWM  Type */
#define IS_SVPWM_SATEN(saten) (((saten) == SVPWM_SATEN_DISBALE) || ((saten) == SVPWM_SATEN_ENBALE))


/**
  * @}
  */ 

/** @defgroup MACP_Group_Types  Public Types
  * @{
  */   


/*! @struct  CORDIC_TypeDef
  *  this structure for CORDIC device registers
  */      
typedef struct {
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  RUN       : 1;  /*!< run control bit */
            __I   uint32_t  OVF       : 1;  /*!< overflow flag */
            __IO  uint32_t  KADJ      : 1;  /*!< K value adjust @ref CORDIC_KADJ_Type*/
            __IO  uint32_t  XYMRS     : 1;  /*!< result adjust @ref CORDIC_XYMRS_Type*/
                  uint32_t  rev0      : 1;  /*!< reserved*/
            __IO  uint32_t  FORMAT    : 2;  /*!< Data format: @ref CORDIC_FMT_Type*/
            __IO  uint32_t  MODE      : 1;  /*!< Mode rotation or vector @ref CORDIC_MODE_Type*/
            __IO  uint32_t  ITERA     : 5;  /*!< Iteration times*/
            __IO  uint32_t  ARITH     : 2;  /*!< Iteration algorithm*/
                  uint32_t  rev       : 17;  /*!< reserved*/
        }BIT;
    }CSR;                               /*!< 0000H */
    __IO uint32_t  OPRDX;               /*!< operation data X */
    __IO uint32_t  OPRDY;               /*!< operation data Y */
    __IO uint32_t  OPRDZ;               /*!< operation data Z */
}CORDIC_TypeDef;


/*! @struct  CORDIC_InitTypeDef
  *  CORDIC initial structure
  */  
typedef struct {
    uint32_t  RunCtrl            : 1;  /*!< run control bit : SH_ENABLE or SH_DISABLE */
    uint32_t  rev0               : 1;  /*!< reserved */
    uint32_t  KAdjust            : 1;  /*!< K value adjust @ref CORDIC_KADJ_Type*/
    uint32_t  XYAmplitude        : 1;  /*!< X,Y amplitude adjustment @ref CORDIC_XYMRS_Type*/
    uint32_t  rev1               : 1;  /*!< reserved*/
    uint32_t  Format             : 2;  /*!< Data format: @ref CORDIC_FMT_Type*/
    uint32_t  TransformMode      : 1;  /*!< Transform method: rotation or vector @ref CORDIC_MODE_Type*/
	uint32_t  IteTimes           : 5;  /*!< reserved, for alignment pad */
	uint32_t  IteAlgorithm       : 2;  /*!< reserved, for alignment pad */
	uint32_t  rev2               : 17; /*!< reserved, for alignment pad */
}CORDIC_InitTypeDef;

/*! @struct  CORDIC_DataTypeDef
  *  this structure for IQDIV device registers
  */  
typedef struct{
    int32_t X; /*!< Cordic opeartion data or result X */
    int32_t Y; /*!< Cordic opeartion data or result Y */
    int32_t Z; /*!< Cordic opeartion data or result Z */
}CORDIC_DataTypeDef;


/*! @struct  SVPWM_DataTypeDef
  *  this structure for IQDIV device registers
  */  
typedef struct {
    int32_t     UAlpha;	        /*!< Input uAlpha */
    int32_t     UBeta;	        /*!< Input uBeta */		
    int32_t     Ta;             /*!< transform result Ta */
    int32_t     Tb;             /*!< transform result Tb */ 
    int32_t     Tc;             /*!< transform result Tc */ 
    uint16_t    SVType;         /*!< Input SVType :SVPWM_SVTYPE_7 or SVPWM_SVTYPE_5*/
    uint16_t    SATEN;          /*!< saturation enable Bit */ 
    uint16_t    SVIQN;          /*!< IQ data format 0~31 */
    uint8_t     Sector;         /*!< transform result sector */ 
    uint8_t     FlagOverAL;     /*!< transform result overflag Ta<0 */
    uint8_t     FlagOverAH;     /*!< transform result overflag Ta>IQN(1) */
    uint8_t     FlagOverBL;     /*!< transform result overflag Tb<0 */
    uint8_t     FlagOverBH;     /*!< transform result overflag Tb>IQN(1) */
    uint8_t     FlagOverCL;     /*!< transform result overflag Tc<0 */
    uint8_t     FlagOverCH;     /*!< transform result overflag Tc>IQN(1) */
    uint8_t     rev_align0;      /*!< reserved for structure alignment*/ 
    uint8_t     rev_align1;      /*!< reserved for structure alignment*/ 
    uint8_t     rev_align2;      /*!< reserved for structure alignment*/ 
}SVPWM_DataTypeDef;


/**
  * @}
  */ 

/* Exported macro ------------------------------------------------------------*/
/** @defgroup MACP_Group_Macro  Public Macros
  * @{
  */ 


/** 
  *@brief  set CORDIC format use CORDIC_FMT_Type
  *   @arg CORDIC_FMT_IQ26
  *   @arg CORDIC_FMT_IQ24
  *   @arg CORDIC_FMT_IQ15
  */
#define CORDIC_SetFormat(CORDICx,fmt)     ((CORDICx)->CSR.BIT.FORMAT = (fmt))

/** 
  *@brief set CORDIC mode use CORDIC_MODE_Type
  *   @arg CORDIC_MODE_ROTATE
  *   @arg CORDIC_MODE_VECTOR  
  */
#define CORDIC_SetMode(CORDICx,mode)     ((CORDICx)->CSR.BIT.MODE = (mode))

/** 
  *@brief set CORDIC XYMRS use CORDIC_XYMRS_Type
  *   @arg CORDIC_XYMRS_NONE
  *   @arg CORDIC_XYMRS_DIV2  
  */
#define CORDIC_SetXYMRS(CORDICx,xymrs)     ((CORDICx)->CSR.BIT.XYMRS = (xymrs))

/** 
  *@brief set CORDIC mode use CORDIC_KADJ_Type
  *   @arg CORDIC_KADJ_NONE
  *   @arg CORDIC_KADJ_DIVK  
  */
#define CORDIC_SetKADJ(CORDICx,kadj)     ((CORDICx)->CSR.BIT.KADJ = (kadj))

/** 
  *@brief set CORDIC iteration times (1~31)
  */
#define CORDIC_SetITERA(CORDICx,itera)     ((CORDICx)->CSR.BIT.ITERA = (itera))

/** 
  *@brief set CORDIC iteration algorithm use CORDIC_ARITH_Type
  *   @arg CORDIC_ARITH_CIRCULAR
  *   @arg CORDIC_ARITH_LINEAR  
  *   @arg CORDIC_ARITH_HYPERBOLA  
  */
#define CORDIC_SetARITH(CORDICx,arith)     ((CORDICx)->CSR.BIT.ARITH = (arith))

/** 
  *@brief  check CORDIC busy flag
  */
#define CORDIC_IS_BUSY(CORDICx)     ((CORDICx)->CSR.BIT.RUN)


/** 
  *@brief  check CORDIC Overflow flag
  */
#define CORDIC_IS_OVERFLOW(CORDICx)  ((CORDICx)->CSR.BIT.OVF)

/** 
  *@brief  start CORDIC
  */
#define CORDIC_START(CORDICx)     (CORDICx)->CSR.BIT.RUN = 1

/** 
  *@brief  start IQDIV
  */
#define SVPWM_IS_BUSY()     (MACP->SVCON == 1)


/** 
  *@brief  start IQDIV
  */
#define SVPWM_START()        (MACP->SVCON = 1)

      
/**
  * @}
  */ 

/* Exported functions --------------------------------------------------------*/ 
/** @addtogroup MACP_Group_Pub_Funcs
  * @{
  */     
  
/** @addtogroup MACP_Group_Cordic_Funcs
  * @{
  */

/* CORDIC Module Init */
void CORDIC_Init(CORDIC_TypeDef* CORDICx, const CORDIC_InitTypeDef* InitCfg);

/* Fills each InitStruct member with its default value*/
void CORDIC_StructInit(CORDIC_InitTypeDef* InitStruct);

/* Deinitializes the CORDICx registers to their default reset */
void CORDIC_Reset(CORDIC_TypeDef* CORDICx);

/* CORDIC transform then return the result */
SH_Bool CORDIC_Transform(CORDIC_TypeDef* CORDICx, CORDIC_DataTypeDef* CordicData);

/* start CORDIC transform then return immediately */
void CORDIC_Run(CORDIC_TypeDef* CORDICx, CORDIC_DataTypeDef* CordicData);
   
/* get CORDIC result */
SH_Bool CORDIC_GetResult(CORDIC_TypeDef* CORDICx, CORDIC_DataTypeDef* CordicData);

/**
  * @}
  */ 

/** @addtogroup MACP_Group_SVPWM_Funcs
  * @{
  */ 
/* SVPWM Transform function */
void SVPWM_Transform(SVPWM_DataTypeDef* SVPWMData);
/**
  * @}
  */ 

     
/**
  * @}
  */ 


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_MACP_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
