/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_mcm.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the MCM firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_MCM_H
#define __SH3xF2xx_SB0_MCM_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup MCM_MODULE
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/

/** @defgroup MCM_Exported_Types Public Types
  * @{
  */

/*! structure MCM_TimeBaseInitTypeDef definition*/
typedef struct
{
    uint16_t CounterMode;    /*!< Specifie the MCM's Counter mode.
                                This parameter can be a value of @ref MCM_Counter_Mode */
    
    uint16_t PWMSymmetry;    /*!< Specifie the MCM PWM output wave symmetry or asymmetry with Complementary mode.
                                  This parameter can be a value of @ref MCM_PWM_Symmetry */
                                    
    uint16_t PWMOutMode;     /*!< Specifie the MCM PWM output mode.
                                  This parameter can be a value of MCM_PWM_OUT_Mode */
                                        
    uint16_t PosTPS;        /*!< Specifie the MCM's Post frequency division Register value.
                                This parameter can be 0 to 7. */
    
    uint16_t Prescaler;    /*!< Specifie the MCM's Prescaler Register value.
                                This parameter can be 0 to 0xFFFF. */
                                    
    uint16_t Period;       /*!< Specifie the MCM's Period Register value.
                                This parameter can be 0 to 0xFFFF. */
    
    uint16_t DutyActivePoint; /*!< Speckifie the Duty register value active timing
                                 This parameter can be any combination of @ref MCM_Duty_Active_Point */   

    uint16_t AdcCmpActivePoint; /*!< Speckifie the compare trigger ADC register value active timing
                                 This parameter can be any combination of MCM_AdcCmp_Active_Point */   
}MCM_TimeBaseInitTypeDef;

/*! structure MCM_PWMxPWMx1InitTypeDef definition*/
typedef struct
{
    uint16_t DutyArea;      /*!< Specifie the MCM PWM duty area.
                                 This parameter can be a value of @ref MCM_Duty_Area */
                                        
    uint16_t PWMxDutyPolarity;  /*!< Specifie the MCM PWMx duty polarity.
                                 This parameter can be a value of @ref MCM_Duty_Polarity */
                                        
    uint16_t PWMx1DutyPolarity;  /*!< Specifie the MCM PWMx1 duty polarity.
                                 This parameter can be a value of @ref MCM_Duty_Polarity */
    
    uint16_t PWMxDutyValue;      /*!< Specifie the MCM PWM Duty Register value.
                                     This parameter can be 0 to 0xFFFF */
    
    uint16_t PWMx1DutyValue;     /*!< Specifie the MCM PWM Duty Register value.
                                     This parameter can be 0 to 0xFFFF */
    
    uint16_t DTx0Value;         /*!< Specifie the MCM PWM rising edge dead time Register value.
                                     This parameter can be 0 to 0xFFFF */
    
    uint16_t DTx1Value;         /*!< Specifie the MCM PWM falling edge dead time Register value.
                                     This parameter can be 0 to 0xFFFF */
}MCM_PWMxPWMx1InitTypeDef;
    
/*! structure MCM_SCInitTypeDef definition*/
typedef struct
{
    uint16_t SC_InputSource;   /*!< Specifie the MCM Stoppage Check(SC) module input source.
                                   This parameter can be a value of @ref MCM_SC_Input_Source */
    uint16_t SC_InputLevel;   /*!< Specifie the MCM Stoppage Check(SC) module input level.
                                   This parameter can be a value of @ref MCM_SC_Input_Level */
                                    
    uint16_t SC_ProtectPWM0;   /*!< Specifie the MCM Stoppage Check(SC) module protect pwm0.
                                   This parameter can be any combination of  MCM_SC_Protect_PWM0 */
                                    
    uint16_t SC_ProtectPWM1;   /*!< Specifie the MCM Stoppage Check(SC) module protect pwm1.
                                   This parameter can be any combination of  MCM_SC_Protect_PWM1 */
                                    
    uint16_t SC_ProtectPWM2;   /*!< Specifie the MCM Stoppage Check(SC) module protect pwm2.
                                   This parameter can be any combination of MCM_SC_Protect_PWM2 */
                                    
    uint16_t SC_Filter;       /*!< Specifie the MCM Stoppage Check(SC) module filter.
                                   This parameter can be a value of @ref MCM_SC_Filter */
                                    
    uint16_t SC_ProtectTime;  /*!< Specifie the MCM Stoppage Check(SC) module protect time.
                                   This parameter can be a value of @ref MCM_SC_Protect_Time */
}MCM_SCInitTypeDef;

/**
  * @}
  */

/* Exported constants --------------------------------------------------------*/

/** @defgroup MCM_Exported_Constants Public Constants
  * @{
  */ 

/** @defgroup MCM_REG_LOCK  Register State Control
  * @{
  */
#define MCM_REG_LOCK              (MCM->PWMRLDEN = 0xAA)  /*!< Lock PWM reload */
#define MCM_REG_UNLOCK            (MCM->PWMRLDEN = 0x55)  /*!< Unlock PWM reload */

#define MCM_FLT_REG_LOCK          (MCM->FLTWEN = 0x0000)  /*!< Lock fault register */
#define MCM_FLT_REG_UNLOCK        (MCM->FLTWEN = 0x33CC)  /*!< Unlock fault register */

/*! enumeration MCM_REG_LOCK_RELOAD_State definition*/   
typedef enum 
{ 
    MCM_REG_WRITE_EN = 0x55,   /*!< Write enable code */
    MCM_REG_RELOAD_EN = 0xAA,  /*!< Reload enable code */
}MCM_REG_LOCK_RELOAD_State; 

/** 
  *@brief  check the input value is a legal mcm register lock or reload state
  */
#define IS_MCM_REG_STATE(state) (((state) == MCM_REG_WRITE_EN) || ((state) == MCM_REG_RELOAD_EN))
/**
  * @}
  */

/** @defgroup MCM_Counter_Mode Counter Mode
  * @{
  */
#define MCM_CounterMode_Edge         (uint16_t)0x0000  /*!< Counter Mode: Edge */
#define MCM_CounterMode_Center       (uint16_t)0x0400  /*!< Counter Mode: Center */
#define MCM_CounterMode_Single       (uint16_t)0x0800  /*!< Counter Mode: Single */
#define IS_MCM_COUNTER_MODE(MODE)    ((MODE == MCM_CounterMode_Edge) \
                                     || (MODE == MCM_CounterMode_Center) \
                                     || (MODE == MCM_CounterMode_Single))  /*!< Check counter mode parameter */

/**
  * @}
  */


/** @defgroup MCM_PWM_Mode PWM Mode
  * @{
  */

#define MCM_PWMOutMode_Complementary    (uint16_t)0x0000  /*!< PWM output mode: complementary */
#define MCM_PWMOutMode_Standalone       (uint16_t)0x8000  /*!< PWM output mode: standalone */
#define IS_MCM_PWM_OUT_MODE(MODE)       ((MODE == MCM_PWMOutMode_Complementary) \
                                     || (MODE == MCM_PWMOutMode_Standalone))  /*!< Check PWM output mode */
/**
  * @}
  */


/** @defgroup MCM_PWM_Symmetry PWM Symmetry
  * @{
  */

#define MCM_PWM_Symmetry                (uint16_t)0x0000  /*!< PWM Symmetry: Symmetry */
#define MCM_PWM_Asymmetry               (uint16_t)0x0200  /*!< PWM Symmetry: Asymmetry */
#define IS_MCM_PWM_SYMMETRY(SYMMETRY)   ((SYMMETRY == MCM_PWM_Symmetry) \
                                        || (SYMMETRY == MCM_PWM_Asymmetry))  /*!< Check PWM symmetry parameter */

/**
  * @}
  */

/** @defgroup MCM_Duty_Area Duty Area
  * @{
  */

#define MCM_DutyArea_1     (uint16_t)0x0000  /*!< PWM dutyduty start */
#define MCM_DutyArea_2     (uint16_t)0x0040  /*!< PWM duty: non-duty start*/
#define IS_MCM_DUTY_AREA(AREA)  ((AREA == MCM_DutyArea_1) \
                                || (AREA == MCM_DutyArea_2))  /*!< Check MCM duty parameter */

/**
  * @}
  */


/** @defgroup MCM_Duty_Polarity Duty Polarity
  * @{
  */

#define MCM_DutyPolarity_High            (uint16_t)0x0002  /*!< Duty Polarity: High */
#define MCM_DutyPolarity_Low             (uint16_t)0x0001  /*!< Duty Polarity: Low */
#define IS_MCM_DUTY_POLARITY(POLARITY)   ((POLARITY == MCM_DutyPolarity_High) \
                                         || (POLARITY == MCM_DutyPolarity_Low))  /*!< Check duty polarity parameter */
/**
  * @}
  */


/** @defgroup MCM_Duty_Active_Point Active Point
  * @{
  */

#define MCM_DutyActivePoint_Now           (uint16_t)0x0200  /*!< Duty active: Now */
#define MCM_DutyActivePoint_Zero          (uint16_t)0x0800  /*!< Duty active: Zero matched */
#define MCM_DutyActivePoint_Period        (uint16_t)0x1000  /*!< Duty active: Period matched */
#define IS_MCM_DUTY_ACTIVE_POINT(POINT)   (((POINT & (uint16_t)0xE5FF) == 0x00) && (POINT != 0x00))  /*!< Check duty active parameter*/

/**
  * @}
  */

/** @defgroup MCM_Interrupt_Event_Flag_Division Interrupt Event Flag Division
  * @{
  */

#define MCM_INT_EVENT_FLAG_DIV_1         (uint16_t)0x0000  /*!< Post Division: 1 */
#define MCM_INT_EVENT_FLAG_DIV_2         (uint16_t)0x1000  /*!< Post Division: 2 */
#define MCM_INT_EVENT_FLAG_DIV_3         (uint16_t)0x2000  /*!< Post Division: 3 */
#define MCM_INT_EVENT_FLAG_DIV_4         (uint16_t)0x3000  /*!< Post Division: 4 */
#define MCM_INT_EVENT_FLAG_DIV_5         (uint16_t)0x4000  /*!< Post Division: 5 */
#define MCM_INT_EVENT_FLAG_DIV_6         (uint16_t)0x5000  /*!< Post Division: 6 */
#define MCM_INT_EVENT_FLAG_DIV_7         (uint16_t)0x6000  /*!< Post Division: 7 */
#define MCM_INT_EVENT_FLAG_DIV_8         (uint16_t)0x7000  /*!< Post Division: 8 */
#define IS_MCM_INT_EVENT_FLAG_DIV(DIV)   ((DIV == MCM_INT_EVENT_FLAG_DIV_1) \
                                         || (DIV == MCM_INT_EVENT_FLAG_DIV_2) \
                                         || (DIV == MCM_INT_EVENT_FLAG_DIV_3) \
                                         || (DIV == MCM_INT_EVENT_FLAG_DIV_4) \
                                         || (DIV == MCM_INT_EVENT_FLAG_DIV_5) \
                                         || (DIV == MCM_INT_EVENT_FLAG_DIV_6) \
                                         || (DIV == MCM_INT_EVENT_FLAG_DIV_7) \
                                         || (DIV == MCM_INT_EVENT_FLAG_DIV_8))  /*!< Check post division parameter */

/**
  * @}
  */


/** @defgroup MCM_CMP_Active ADC CMP Active
  * @{
  */
#define MCM_ADC_CMP_Active_Now          (uint16_t)0x0400  /*!< CMP Active: Now */
#define MCM_ADC_CMP_Active_Zero         (uint16_t)0x2000  /*!< CMP Active: Zero Match */
#define MCM_ADC_CMP_Active_Period       (uint16_t)0x4000  /*!< CMP Active: Period Match */
#define IS_MCM_ADC_CMP_ACTIVE(ACTIVE)   (((ACTIVE & (uint16_t)0x9BFF) == 0x00) && (ACTIVE != 0x00))  /*!< Check CMP active parameter */
/**
  * @}
  */


/** @defgroup MCM_Interrupt_Sources Interrupt Source
  * @{
  */

#define MCM_INT_PWM0_UP           (uint16_t)0x0001  /*!< Interrupt source: PWM0 UP */
#define MCM_INT_PWM0_DOWN         (uint16_t)0x0002  /*!< Interrupt source: PWM0 DOWN */
#define MCM_INT_PWM1_UP           (uint16_t)0x0004  /*!< Interrupt source: PWM1 UP */
#define MCM_INT_PWM1_DOWN         (uint16_t)0x0008  /*!< Interrupt source: PWM1 DOWN */
#define MCM_INT_PWM2_UP           (uint16_t)0x0010  /*!< Interrupt source: PWM2 UP */
#define MCM_INT_PWM2_DOWN         (uint16_t)0x0020  /*!< Interrupt source: PWM2 DOWN */
#define MCM_INT_ZERO_MATCH        (uint16_t)0x0040  /*!< Interrupt source: ZERO MATCH */
#define MCM_INT_PERIOD_MATCH      (uint16_t)0x0080  /*!< Interrupt source: PERIOD MATCH */
#define MCM_INT_FLT_IO            (uint16_t)0x0100  /*!< Interrupt source: FAULT IO */
#define MCM_INT_FLTCMP0           (uint16_t)0x0200  /*!< Interrupt source: FAULT CMP0 */
#define MCM_INT_FLTCMP1           (uint16_t)0x0400  /*!< Interrupt source: FAULT CMP1 */
#define MCM_INT_OUT               (uint16_t)0x0800  /*!< Interrupt source: OUT */
#define MCM_INT_OSC               (uint16_t)0x1000  /*!< Interrupt source: OSC */
#define IS_MCM_INT(INT)           (((INT & (uint16_t)0xE00) == 0x00) && (INT != 0x00)) /*!< Check interrupt source parameter */

/**
  * @}
  */


/** @defgroup MCM_Flags MCM Flags
  * @{
  */

#define MCM_FLAG_PWM0_UP           (uint16_t)0x0001  /*!< MCM Flag: PWM0 UP */
#define MCM_FLAG_PWM0_DOWN         (uint16_t)0x0002  /*!< MCM Flag: PWM0 DOWN */
#define MCM_FLAG_PWM1_UP           (uint16_t)0x0004  /*!< MCM Flag: PWM1 UP */
#define MCM_FLAG_PWM1_DOWN         (uint16_t)0x0008  /*!< MCM Flag: PWM1 DOWN */
#define MCM_FLAG_PWM2_UP           (uint16_t)0x0010  /*!< MCM Flag: PWM2 UP */
#define MCM_FLAG_PWM2_DOWN         (uint16_t)0x0020  /*!< MCM Flag: PWM2 DOWN */
#define MCM_FLAG_ZERO_MATCH        (uint16_t)0x0040  /*!< MCM Flag: ZERO MATCH */
#define MCM_FLAG_PERIOD_MATCH      (uint16_t)0x0080  /*!< MCM Flag: PERIOD MATCH */
#define MCM_FLAG_FLT_IO            (uint16_t)0x0100  /*!< MCM Flag: FAULT IO */
#define MCM_FLAG_FLTCMP0           (uint16_t)0x0200  /*!< MCM Flag: FAULT CMP0 */
#define MCM_FLAG_FLTCMP1           (uint16_t)0x0400  /*!< MCM Flag: FAULT CMP1 */
#define MCM_FLAG_OUT               (uint16_t)0x0800  /*!< MCM Flag: OUT */
#define MCM_FLAG_OSC               (uint16_t)0x1000  /*!< MCM Flag: OSC */

#define IS_MCM_GET_ONE_FLAG(FLAG)  (FLAG != 0x0000)  /*!< Check MCM flag parameter */

/**
  * @}
  */

/** @defgroup MCM_Manual_Active_Timing Manual Active Timing
  * @{
  */

#define MCM_ManualActiveTiming_Now              (uint16_t)0x0000  /*!< Manual Active: Now */
#define MCM_ManualActiveTiming_PeriodUpdate     (uint16_t)0x0100  /*!< Manual Active: Period Update */
#define IS_MCM_MANUAL_ACTIVE_TIMING(TIMING)      ((TIMING == MCM_ManualActiveTiming_Now) \
                                                 || (TIMING == MCM_ManualActiveTiming_PeriodUpdate))  /*!< Check manual active parameter */

/**
  * @}
  */


/** @defgroup MCM_Manual_Output_Port Manual Output Port
  * @{
  */

#define MCM_MANUAL_PWM0         (uint8_t)0x01  /*!< Manual out: PWM0 */
#define MCM_MANUAL_PWM1         (uint8_t)0x02  /*!< Manual out: PWM1 */
#define MCM_MANUAL_PWM2         (uint8_t)0x04  /*!< Manual out: PWM2 */
#define MCM_MANUAL_PWM01        (uint8_t)0x08  /*!< Manual out: PWM01 */
#define MCM_MANUAL_PWM11        (uint8_t)0x10  /*!< Manual out: PWM11 */
#define MCM_MANUAL_PWM21        (uint8_t)0x20  /*!< Manual out: PWM21 */
#define IS_MCM_MANUAL_PWM(PWM)  (((PWM & 0xC0) == 0x00) && (PWM != 0x00))  /*!< Check manual out parameter */

/**
  * @}
  */
  
/** @defgroup MCM_Manual_Output_Level Manual Output Level
  * @{
  */
  
/*! enumeration MCM_MANUAL_OUT_LEVEL_State definition*/
typedef enum 
{ 
    PwmManualOutLow = 0x0,    /*!< Manual output low */
    PwmManualOutHigh = 0x1,   /*!< Manual output high */
}MCM_MANUAL_OUT_LEVEL_State; 
#define IS_MCM_OUTPUT_LEVEL(LEVEL)    ((LEVEL == PwmManualOutLow) \
                                      || (LEVEL == PwmManualOutHigh))  /*!< Check manual output parameter*/
/**
  * @}
  */  
/** @defgroup MCM_FLT_input Fault Input
  * @{
  */

#define MCM_FLT2_Pin               (uint32_t)0x00000008  /*!< Fault2 Pin */
#define MCM_FLT1_COMP1             (uint32_t)0x00000800  /*!< Fault1 COMP1 */
#define MCM_FLT0_COMP0             (uint32_t)0x00008000  /*!< Fault0 COMP0 */
#define IS_MCM_FLT_INPUT(INPUT)    ((INPUT == MCM_FLT2_Pin) \
                                 || (INPUT == MCM_FLT1_COMP1) \
                                 || (INPUT == MCM_FLT0_COMP0))  /*!< Check fault parameter */

/**
  * @}
  */

/** @defgroup MCM_FLT0_Detect_Mode Fault0 Detect Mode
  * @{
  */
#define MCM_FLT0_DETECT_Latch           (uint32_t)0x00000000  /*!< Fault0 detect mode: Latch */
#define MCM_FLT0_DETECT_Each            (uint32_t)0x00002000  /*!< Fault0 detect mode: Each */
#define IS_MCM_FLT0_DETECT_MODE(MODE)    ((MODE == MCM_FLT0_DETECT_Latch) \
                                        || (MODE == MCM_FLT0_DETECT_Each))  /*!< Check fault0 detect mode parameter */
/**
  * @}
  */

/** @defgroup MCM_FLT0_Active_Level Fault0 Active Level
  * @{
  */
#define MCM_FLT0_ActiveLevel_High        (uint32_t) 0x00000000  /*!< Fault0 active level: high */
#define MCM_FLT0_ActiveLevel_Low         (uint32_t) 0x00004000  /*!< Fault0 active level: low */
#define IS_MCM_FLT0_ACTIVE_LEVEL(LEVEL)  ((LEVEL == MCM_FLT0_ActiveLevel_High) \
                                         || (LEVEL == MCM_FLT0_ActiveLevel_Low))  /*!< Check fault0 active level parameter */
/**
  * @}
  */

/** @defgroup MCM_FLT1_Detect_Mode Fault1 Detect Mode
  * @{
  */
#define MCM_FLT1_DETECT_Latch           (uint32_t)0x00000000  /*!< Fault1 detect mode: Latch */
#define MCM_FLT1_DETECT_Each            (uint32_t)0x00000200  /*!< Fault1 detect mode: Each */
#define IS_MCM_FLT1_DETECT_MODE(MODE)    ((MODE == MCM_FLT1_DETECT_Latch) \
                                        || (MODE == MCM_FLT1_DETECT_Each))  /*!< Check fault1 detect mode parameter */
/**
  * @}
  */

/** @defgroup MCM_FLT1_Active_Level Fault1 Active Level
  * @{
  */
#define MCM_FLT1_ActiveLevel_High        (uint32_t) 0x00000000  /*!< Fault1 active level: High */
#define MCM_FLT1_ActiveLevel_Low         (uint32_t) 0x00000400  /*!< Fault1 active level: Low */
#define IS_MCM_FLT1_ACTIVE_LEVEL(LEVEL)  ((LEVEL == MCM_FLT1_ActiveLevel_High) \
                                         || (LEVEL == MCM_FLT1_ActiveLevel_Low))  /*!< Check fault1 active level parameter */
 /**
  * @}
  */
                                        
/** @defgroup MCM_FLT2_Detect_Mode Fault2 Detect Mode
  * @{
  */
#define MCM_FLT2_DETECT_Latch           (uint32_t)0x00000000  /*!< Fault2 detect mode: Latch */
#define MCM_FLT2_DETECT_Each            (uint32_t)0x00000002  /*!< Fault2 detect mode: Each */
#define IS_MCM_FLT2_DETECT_MODE(MODE)    ((MODE == MCM_FLT2_DETECT_Latch) \
                                        || (MODE == MCM_FLT2_DETECT_Each))  /*!< Check fault2 detect mode parameter */
/**
  * @}
  */

/** @defgroup MCM_FLT2_Active_Level Fault2 Active Level
  * @{
  */
#define MCM_FLT2_ActiveLevel_High        (uint32_t) 0x00000000  /*!< Fault2 active level: High */
#define MCM_FLT2_ActiveLevel_Low         (uint32_t) 0x00000004  /*!< Fault2 active level: Low */
#define IS_MCM_FLT2_ACTIVE_LEVEL(LEVEL)  ((LEVEL == MCM_FLT2_ActiveLevel_High) \
                                         || (LEVEL == MCM_FLT2_ActiveLevel_Low))  /*!< Check fault2 actie level parameter */
/**
  * @}
  */



/** @defgroup MCM_FLT2_Filter  Fault2 Filter
  * @{
  */

#define MCM_FLT2_Filter_None         (uint32_t)0x00000000  /*!< Fault2 filterNone */
#define MCM_FLT2_Filter_0dot5us      (uint32_t)0x00000010  /*!< Fault2 filter0.5us */
#define MCM_FLT2_Filter_1us          (uint32_t)0x00000020  /*!< Fault2 filter1us */
#define MCM_FLT2_Filter_1dot5us      (uint32_t)0x00000030  /*!< Fault2 filter1.5us */
#define MCM_FLT2_Filter_2us          (uint32_t)0x00000040  /*!< Fault2 filter2us */
#define MCM_FLT2_Filter_3us          (uint32_t)0x00000050  /*!< Fault2 filter3us */
#define MCM_FLT2_Filter_4us          (uint32_t)0x00000060  /*!< Fault2 filter4us */
#define MCM_FLT2_Filter_6us          (uint32_t)0x00000070  /*!< Fault2 filter6us */
#define MCM_FLT2_Filter_8us          (uint32_t)0x00000080  /*!< Fault2 filter8us */
#define MCM_FLT2_Filter_10us         (uint32_t)0x00000090  /*!< Fault2 filter10us */
#define MCM_FLT2_Filter_12us         (uint32_t)0x000000A0  /*!< Fault2 filter12us */
#define MCM_FLT2_Filter_14us         (uint32_t)0x000000B0  /*!< Fault2 filter14us */
#define MCM_FLT2_Filter_16us         (uint32_t)0x000000C0  /*!< Fault2 filter16us */
#define MCM_FLT2_Filter_20us         (uint32_t)0x000000D0  /*!< Fault2 filter20us */
#define MCM_FLT2_Filter_24us         (uint32_t)0x000000E0  /*!< Fault2 filter24us */
#define MCM_FLT2_Filter_32us         (uint32_t)0x000000F0  /*!< Fault2 filter32us */
#define IS_MCM_FLT2_FILTER(FILTER)   ((FILTER == MCM_FLT2_Filter_None) \
                                     || (FILTER == MCM_FLT2_Filter_0dot5us) \
                                     || (FILTER == MCM_FLT2_Filter_1us) \
                                     || (FILTER == MCM_FLT2_Filter_1dot5us) \
                                     || (FILTER == MCM_FLT2_Filter_2us) \
                                     || (FILTER == MCM_FLT2_Filter_3us) \
                                     || (FILTER == MCM_FLT2_Filter_4us) \
                                     || (FILTER == MCM_FLT2_Filter_6us) \
                                     || (FILTER == MCM_FLT2_Filter_8us) \
                                     || (FILTER == MCM_FLT2_Filter_10us) \
                                     || (FILTER == MCM_FLT2_Filter_12us) \
                                     || (FILTER == MCM_FLT2_Filter_14us) \
                                     || (FILTER == MCM_FLT2_Filter_16us) \
                                     || (FILTER == MCM_FLT2_Filter_20us) \
                                     || (FILTER == MCM_FLT2_Filter_24us) \
                                     || (FILTER == MCM_FLT2_Filter_32us))  /*!< Check fault2 filter parameter */
/**
  * @}
  */
                                     
/** @defgroup MCM_FLT_STAT Fault State
  * @{
  */

#define MCM_FLT0_STAT             (uint32_t)0x00001000  /*!< Fault0 state */
#define MCM_FLT1_STAT             (uint32_t)0x00000100  /*!< Fault1 state */
#define MCM_FLT2_STAT             (uint32_t)0x00000001  /*!< Fault2 state */
#define IS_MCM_FLT_STATUS(INPUT)  ((INPUT == MCM_FLT0_STAT) \
                                      || (INPUT == MCM_FLT1_STAT) \
                                      || (INPUT == MCM_FLT2_STAT))  /*!< Check fault state parameter */
/**
  * @}
  */

/** @defgroup MCM_FLT_CLEAR_STAT Fault Clear State
  * @{
  */

#define MCM_CLEAR_FLT0_STAT             (uint32_t)0x00040000  /*!< Clear fault0 state */
#define MCM_CLEAR_FLT1_STAT             (uint32_t)0x00020000  /*!< Clear fault1 state */
#define MCM_CLEAR_FLT2_STAT             (uint32_t)0x00010000  /*!< Clear fault2 state */
#define IS_MCM_FLT_CLEAR_STATUS(INPUT)  ((INPUT == MCM_CLEAR_FLT0_STAT) \
                                      || (INPUT == MCM_CLEAR_FLT1_STAT) \
                                      || (INPUT == MCM_CLEAR_FLT2_STAT))  /*!< Check clear fault state parameter */
                                      
/**
  * @}
  */


/** @defgroup MCM_FLT_PWMx_Pin_Output_Status Fault PWMx Pin Status
  * @{
  */

#define MCM_FLT_PWMx_PinStatus_Hiz            (uint32_t)0x00000000  /*!< Fault PWMx Pin Status: Hiz */
#define MCM_FLT_PWMx_PinStatus_Low            (uint32_t)0x00200000  /*!< Fault PWMx Pin Status: Low */
#define MCM_FLT_PWMx_PinStatus_High           (uint32_t)0x00300000  /*!< Fault PWMx Pin Status: High */
#define IS_MCM_FLT_PWMx_PIN_STATUS(STATUS)    ((STATUS == MCM_FLT_PWMx_PinStatus_Hiz) \
                                              || (STATUS == MCM_FLT_PWMx_PinStatus_Low) \
                                              || (STATUS == MCM_FLT_PWMx_PinStatus_High))  /*!< Check fault PWMx pin status parameter */

/**
  * @}
  */


/** @defgroup MCM_FLT_PWMx1_Pin_Output_Status Fault PWMx1 Pin Status
  * @{
  */

#define MCM_FLT_PWMx1_PinStatus_Hiz            (uint32_t)0x00000000  /*!< Fault PWMx1 Pin Status: Hiz */
#define MCM_FLT_PWMx1_PinStatus_Low            (uint32_t)0x00800000  /*!< Fault PWMx1 Pin Status: Low */
#define MCM_FLT_PWMx1_PinStatus_High           (uint32_t)0x00C00000  /*!< Fault PWMx1 Pin Status: High */
#define IS_MCM_FLT_PWMx1_PIN_STATUS(STATUS)    ((STATUS == MCM_FLT_PWMx1_PinStatus_Hiz) \
                                               || (STATUS == MCM_FLT_PWMx1_PinStatus_Low) \
                                               || (STATUS == MCM_FLT_PWMx1_PinStatus_High))  /*!< Check fault PWMx1 pin status parameter */

/**
  * @}
  */


/** @defgroup MCM_ADC_Trigger_Source ADC Trigger Source
  * @{
  */

#define MCM_TRIGGER_CMP1_None                 (uint16_t)0x0000  /*!< Trigger CMP1: None */
#define MCM_TRIGGER_CMP1_RisingFalling        (uint16_t)0x0001  /*!< Trigger CMP1: Rising and Falling */
#define MCM_TRIGGER_CMP1_Rising               (uint16_t)0x0002  /*!< Trigger CMP1: Rising */
#define MCM_TRIGGER_CMP1_Falling              (uint16_t)0x0003  /*!< Trigger CMP1: Falling */
#define IS_MCM_ADC_TRIGGER1_SOURCE(SOURCE)     ((SOURCE == MCM_TRIGGER_CMP1_None) \
                                              || (SOURCE == MCM_TRIGGER_CMP1_RisingFalling) \
                                              || (SOURCE == MCM_TRIGGER_CMP1_Rising) \
                                              || (SOURCE == MCM_TRIGGER_CMP1_Falling))  /*!< Check trigger CMP1 parameter */

#define MCM_TRIGGER_CMP2_None                 (uint16_t)0x0000  /*!< Trigger CMP2: None */
#define MCM_TRIGGER_CMP2_RisingFalling        (uint16_t)0x0004  /*!< Trigger CMP2: Rising and Falling */
#define MCM_TRIGGER_CMP2_Rising               (uint16_t)0x0008  /*!< Trigger CMP2: Rising */
#define MCM_TRIGGER_CMP2_Falling              (uint16_t)0x000C  /*!< Trigger CMP2: Falling */
#define IS_MCM_ADC_TRIGGER2_SOURCE(SOURCE)     ((SOURCE == MCM_TRIGGER_CMP2_None) \
                                              || (SOURCE == MCM_TRIGGER_CMP2_RisingFalling) \
                                              || (SOURCE == MCM_TRIGGER_CMP2_Rising) \
                                              || (SOURCE == MCM_TRIGGER_CMP2_Falling))  /*!< Check trigger CMP2 parameter */


#define MCM_TRIGGER_CMP3_None                 (uint16_t)0x0000  /*!< Trigger CMP3: None */
#define MCM_TRIGGER_CMP3_RisingFalling        (uint16_t)0x0010  /*!< Trigger CMP3: Rising and Falling */
#define MCM_TRIGGER_CMP3_Rising               (uint16_t)0x0020  /*!< Trigger CMP3: Rising */
#define MCM_TRIGGER_CMP3_Falling              (uint16_t)0x0030  /*!< Trigger CMP3: Falling */
#define IS_MCM_ADC_TRIGGER3_SOURCE(SOURCE)     ((SOURCE == MCM_TRIGGER_CMP3_None) \
                                              || (SOURCE == MCM_TRIGGER_CMP3_RisingFalling) \
                                              || (SOURCE == MCM_TRIGGER_CMP3_Rising) \
                                              || (SOURCE == MCM_TRIGGER_CMP3_Falling)) /*!< Check trigger CMP3 parameter */


#define MCM_TRIGGER_CMP4_None                 (uint16_t)0x0000  /*!< Trigger CMP4: None */
#define MCM_TRIGGER_CMP4_RisingFalling        (uint16_t)0x0040  /*!< Trigger CMP4: Rising and Falling */
#define MCM_TRIGGER_CMP4_Rising               (uint16_t)0x0080  /*!< Trigger CMP4: Rising */
#define MCM_TRIGGER_CMP4_Falling              (uint16_t)0x00C0  /*!< Trigger CMP4: Falling */
#define IS_MCM_ADC_TRIGGER4_SOURCE(SOURCE)     ((SOURCE == MCM_TRIGGER_CMP4_None) \
                                              || (SOURCE == MCM_TRIGGER_CMP4_RisingFalling) \
                                              || (SOURCE == MCM_TRIGGER_CMP4_Rising) \
                                              || (SOURCE == MCM_TRIGGER_CMP4_Falling))  /*!< Check trigger CMP4 parameter */


/**
  * @}
  */


/** @defgroup MCM_Duty_Saturation_Maximum_Selection Duty Saturation Maximum
  * @{
  */

#define MCM_MaxSelect_None          (uint16_t)0x0000  /*!< Duty MAX saturation method: None */
#define MCM_MaxSelect_ToMax         (uint16_t)0x0100  /*!< Duty MAX saturation method: To Max */
#define MCM_MaxSelect_ToPeriod      (uint16_t)0x0200  /*!< Duty MAX saturation method: To Period */
#define IS_MCM_MAX_SELECT(SELECT)   ((SELECT == MCM_MaxSelect_None) \
                                    || (SELECT == MCM_MaxSelect_ToMax) \
                                    || (SELECT == MCM_MaxSelect_ToPeriod)) /*!< Check duty MAX saturation method parameter */

/**
  * @}
  */


/** @defgroup MCM_Duty_Saturation_Minimum_Selection Duty Saturation Minimum
  * @{
  */

#define MCM_MinSelect_None          (uint16_t)0x0000  /*!< Duty MIN saturation method: None */
#define MCM_MinSelect_ToMin         (uint16_t)0x0400  /*!< Duty MIN saturation method: To Min */
#define MCM_MinSelect_ToZero        (uint16_t)0x0800  /*!< Duty MIN saturation method: To Zero */
#define IS_MCM_MIN_SELECT(SELECT)   ((SELECT == MCM_MinSelect_None) \
                                    || (SELECT == MCM_MinSelect_ToZero) \
                                    || (SELECT == MCM_MinSelect_ToMin))  /*!< Check duty MIN saturation method parameter */

/**
  * @}
  */


/** @defgroup MCM_Short_Circuit_Pin Short Circuit Pin
  * @{
  */

#define MCM_ShortCircuit_PWM0Pin              (uint8_t)0x01  /*!< Short Circuit Pin: PWM0Pin */
#define MCM_ShortCircuit_PWM1Pin              (uint8_t)0x02  /*!< Short Circuit Pin: PWM1Pin */
#define MCM_ShortCircuit_PWM2Pin              (uint8_t)0x04  /*!< Short Circuit Pin: PWM2Pin */
#define MCM_ShortCircuit_PWM01Pin             (uint8_t)0x08  /*!< Short Circuit Pin: PWM01Pin */
#define MCM_ShortCircuit_PWM11Pin             (uint8_t)0x10  /*!< Short Circuit Pin: PWM11Pin */
#define MCM_ShortCircuit_PWM21Pin             (uint8_t)0x20  /*!< Short Circuit Pin: PWM21Pin */
#define IS_MCM_SHORT_CIRCUIT_PIN(PIN)         (((PIN & 0xC0) == 0x00) && (PIN != 0x00))  /*!< Check short circuit pin parameter */

/**
  * @}
  */


/** @defgroup MCM_Short_Circuit_Output_Level Short Circuit Level
  * @{
  */

#define MCM_ShortCircuit_Level_Low              (uint8_t)0x00  /*!< Short Circuit Level: Low */
#define MCM_ShortCircuit_Level_High             (uint8_t)0x01  /*!< Short Circuit Level: High */
#define IS_MCM_SHORT_CIRCUIT_LEVEL(LEVEL)       ((LEVEL == MCM_ShortCircuit_Level_Low) \
                                                || (LEVEL == MCM_ShortCircuit_Level_High))  /*!< Check short circuit level parameter */
/**
  * @}
  */


/** @defgroup MCM_SC_Input_Source SC Input Source
  * @{
  */

#define MCM_SC_InputSource_DISABLE     (uint16_t)0x0000  /*!< SC input source: Disable */
#define MCM_SC_InputSource_IO          (uint16_t)0x1000  /*!< SC input source: IO */
#define MCM_SC_InputSource_CMP0        (uint16_t)0x2000  /*!< SC input source: CMP0 */
#define MCM_SC_InputSource_CMP1        (uint16_t)0x3000  /*!< SC input source: CMP1 */
#define IS_MCM_SC_INPUT_SOURCE(SOURCE)  ((SOURCE == MCM_SC_InputSource_DISABLE) \
                                      || (SOURCE == MCM_SC_InputSource_IO) \
                                      || (SOURCE == MCM_SC_InputSource_CMP0) \
                                      || (SOURCE == MCM_SC_InputSource_CMP1))  /*!< Check SC input source parameter */


/**
  * @}
  */

/** @defgroup MCM_SC_Input_Level SC Input Level
  * @{
  */

#define MCM_SC_InputLevel_High        (uint16_t)0x0000  /*!< SC Input Level: High */
#define MCM_SC_InputLevel_Low         (uint16_t)0x0800  /*!< SC Input Level: Low */
#define IS_MCM_SC_INPUT_LEVEL(LEVEL)  ((LEVEL == MCM_SC_InputLevel_High) \
                                      || (LEVEL == MCM_SC_InputLevel_Low))  /*!< Check SC input level parameter */

/**
  * @}
  */


/** @defgroup MCM_SC_Protect_PWM SC Protect PWM
  * @{
  */

#define MCM_SC_Protect_PWM0_DISABLE        (uint16_t)0x0000  /*!< SC Protect PWM0: Disable */
#define MCM_SC_Protect_PWM0_ENABLE         (uint16_t)0x0100  /*!< SC Protect PWM0: Enable */
#define IS_MCM_SCx_PROTECT_PWM0(PWM0)      ((PWM0 == MCM_SC_Protect_PWM0_DISABLE) \
                                        || (PWM0 == MCM_SC_Protect_PWM0_ENABLE))  /*!< Check SC protect PWM0 parameter */


#define MCM_SC_Protect_PWM1_DISABLE        (uint16_t)0x0000  /*!< SC Protect PWM1: Disable */
#define MCM_SC_Protect_PWM1_ENABLE         (uint16_t)0x0200  /*!< SC Protect PWM1: Enable */
#define IS_MCM_SCx_PROTECT_PWM1(PWM1)      ((PWM1 == MCM_SC_Protect_PWM1_DISABLE) \
                                        || (PWM1 == MCM_SC_Protect_PWM1_ENABLE))  /*!< Check SC protect PWM1 parameter */


#define MCM_SC_Protect_PWM2_DISABLE        (uint16_t)0x0000  /*!< SC Protect PWM2: Disable */
#define MCM_SC_Protect_PWM2_ENABLE         (uint16_t)0x0400  /*!< SC Protect PWM2: Enable */
#define IS_MCM_SCx_PROTECT_PWM2(PWM2)      ((PWM2 == MCM_SC_Protect_PWM2_DISABLE) \
                                        || (PWM2 == MCM_SC_Protect_PWM2_ENABLE))  /*!< Check SC protect PWM2 parameter */

/**
  * @}
  */


/** @defgroup MCM_SC_Filter SC Filter
  * @{
  */

#define MCM_SC_Filter_None            (uint16_t)0x0000  /*!< SC Filter: None */
#define MCM_SC_Filter_40CLK           (uint16_t)0x0010  /*!< SC Filter: 40 Clocks */
#define MCM_SC_Filter_80CLK           (uint16_t)0x0020  /*!< SC Filter: 80 Clocks */
#define MCM_SC_Filter_120CLK          (uint16_t)0x0030  /*!< SC Filter: 120 Clocks */
#define MCM_SC_Filter_160CLK          (uint16_t)0x0040  /*!< SC Filter: 160 Clocks */
#define MCM_SC_Filter_240CLK          (uint16_t)0x0050  /*!< SC Filter: 240 Clocks */
#define MCM_SC_Filter_320CLK          (uint16_t)0x0060  /*!< SC Filter: 320 Clocks */
#define MCM_SC_Filter_480CLK          (uint16_t)0x0070  /*!< SC Filter: 480 Clocks */
#define MCM_SC_Filter_640CLK          (uint16_t)0x0080  /*!< SC Filter: 640 Clocks */
#define MCM_SC_Filter_800CLK          (uint16_t)0x0090  /*!< SC Filter: 800 Clocks */
#define MCM_SC_Filter_960CLK          (uint16_t)0x00A0  /*!< SC Filter: 960 Clocks */
#define MCM_SC_Filter_1120CLK         (uint16_t)0x00B0  /*!< SC Filter: 1120 Clocks */
#define MCM_SC_Filter_1280CLK         (uint16_t)0x00C0  /*!< SC Filter: 1280 Clocks */
#define MCM_SC_Filter_1600CLK         (uint16_t)0x00D0  /*!< SC Filter: 1600 Clocks */
#define MCM_SC_Filter_1920CLK         (uint16_t)0x00E0  /*!< SC Filter: 1920 Clocks */
#define MCM_SC_Filter_2560CLK         (uint16_t)0x00F0  /*!< SC Filter: 2560 Clocks */
#define IS_MCM_SC_FILTER(FILTER)      ((FILTER == MCM_SC_Filter_None) \
                                      || (FILTER == MCM_SC_Filter_40CLK) \
                                      || (FILTER == MCM_SC_Filter_80CLK) \
                                      || (FILTER == MCM_SC_Filter_120CLK) \
                                      || (FILTER == MCM_SC_Filter_160CLK) \
                                      || (FILTER == MCM_SC_Filter_240CLK) \
                                      || (FILTER == MCM_SC_Filter_320CLK) \
                                      || (FILTER == MCM_SC_Filter_480CLK) \
                                      || (FILTER == MCM_SC_Filter_640CLK) \
                                      || (FILTER == MCM_SC_Filter_800CLK) \
                                      || (FILTER == MCM_SC_Filter_960CLK) \
                                      || (FILTER == MCM_SC_Filter_1120CLK) \
                                      || (FILTER == MCM_SC_Filter_1280CLK) \
                                      || (FILTER == MCM_SC_Filter_1600CLK) \
                                      || (FILTER == MCM_SC_Filter_1920CLK) \
                                      || (FILTER == MCM_SC_Filter_2560CLK))  /*!< Check SC filter parameter */

/**
  * @}
  */

                                     
/** @defgroup MCM_SC_Protect_Time SC Protect Time
  * @{
  */

#define MCM_SC_ProtectTime_ZMATCH       (uint16_t)0x0000  /*!< SC Protect Time: Next Zero Match */
#define MCM_SC_ProtectTime_1200CLK      (uint16_t)0x0001  /*!< SC Protect Time: 1200 clocks */
#define MCM_SC_ProtectTime_1600CLK      (uint16_t)0x0002  /*!< SC Protect Time: 1600 clocks */
#define MCM_SC_ProtectTime_2000CLK      (uint16_t)0x0003  /*!< SC Protect Time: 2000 clocks */
#define MCM_SC_ProtectTime_2400CLK      (uint16_t)0x0004  /*!< SC Protect Time: 2400 clocks */
#define MCM_SC_ProtectTime_2800CLK      (uint16_t)0x0005  /*!< SC Protect Time: 2800 clocks */
#define MCM_SC_ProtectTime_3200CLK      (uint16_t)0x0006  /*!< SC Protect Time: 3200 clocks */
#define MCM_SC_ProtectTime_4000CLK      (uint16_t)0x0007  /*!< SC Protect Time: 4000 clocks */
#define MCM_SC_ProtectTime_4800CLK      (uint16_t)0x0008  /*!< SC Protect Time: 4800 clocks */
#define MCM_SC_ProtectTime_6400CLK      (uint16_t)0x0009  /*!< SC Protect Time: 6400 clocks */
#define MCM_SC_ProtectTime_8000CLK      (uint16_t)0x000A  /*!< SC Protect Time: 8000 clocks */
#define MCM_SC_ProtectTime_16000CLK     (uint16_t)0x000B  /*!< SC Protect Time: 16000 clocks */
#define MCM_SC_ProtectTime_32000CLK     (uint16_t)0x000C  /*!< SC Protect Time: 32000 clocks */
#define MCM_SC_ProtectTime_48000CLK     (uint16_t)0x000D  /*!< SC Protect Time: 48000 clocks */
#define MCM_SC_ProtectTime_64000CLK     (uint16_t)0x000E  /*!< SC Protect Time: 64000 clocks */
#define MCM_SC_ProtectTime_MANUAL       (uint16_t)0x000F  /*!< SC Protect Time: Manual */
#define IS_MCM_SC_PROTECT_TIME(TIME)    ((TIME == MCM_SC_ProtectTime_ZMATCH) \
                                        || (TIME == MCM_SC_ProtectTime_1200CLK) \
                                        || (TIME == MCM_SC_ProtectTime_1600CLK) \
                                        || (TIME == MCM_SC_ProtectTime_2000CLK) \
                                        || (TIME == MCM_SC_ProtectTime_2400CLK) \
                                        || (TIME == MCM_SC_ProtectTime_2800CLK) \
                                        || (TIME == MCM_SC_ProtectTime_3200CLK) \
                                        || (TIME == MCM_SC_ProtectTime_4000CLK) \
                                        || (TIME == MCM_SC_ProtectTime_4800CLK) \
                                        || (TIME == MCM_SC_ProtectTime_6400CLK) \
                                        || (TIME == MCM_SC_ProtectTime_8000CLK) \
                                        || (TIME == MCM_SC_ProtectTime_16000CLK) \
                                        || (TIME == MCM_SC_ProtectTime_32000CLK) \
                                        || (TIME == MCM_SC_ProtectTime_48000CLK) \
                                        || (TIME == MCM_SC_ProtectTime_64000CLK) \
                                        || (TIME == MCM_SC_ProtectTime_MANUAL))  /*!< Chect SC protect time parameter */

/**
  * @}
  */


/** @defgroup MCM_SC_STAT SC State
  * @{
  */

#define MCM_SC0_STAT                    (uint32_t)0x2000  /*!< SC0 State */
#define MCM_SC1_STAT                    (uint32_t)0x4000  /*!< SC1 State */
#define MCM_SC2_STAT                    (uint32_t)0x8000  /*!< SC2 State */
#define IS_MCM_SCxSTAT(MCM_SCx_STAT)    ((MCM_SCx_STAT == MCM_SC0_STAT) \
                                      || (MCM_SCx_STAT == MCM_SC1_STAT) \
                                      || (MCM_SCx_STAT == MCM_SC2_STAT))  /*!< Check SC state parameter */

/**
  * @}
  */


/**
  * @}
  */ 


/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 

/** @addtogroup MCM_Exported_Functions
  * @{
  */
  
/** @addtogroup MCM_Group1
  * @{
  */
void MCM_TimeBaseStructInit(MCM_TimeBaseInitTypeDef* InitStruct);
void MCM_TimeBaseInit(MCM_TimeBaseInitTypeDef* InitCfg);
void MCM_PWMxPWMx1StructInit(MCM_PWMxPWMx1InitTypeDef* InitStruct);
void MCM_PWM0PWM01Init(MCM_PWMxPWMx1InitTypeDef* InitCfg);
void MCM_PWM1PWM11Init(MCM_PWMxPWMx1InitTypeDef* InitCfg);
void MCM_PWM2PWM21Init(MCM_PWMxPWMx1InitTypeDef* InitCfg);
void MCM_Reset(void);
void MCM_OnOff(SH_CmdState OnOffState);
/**
  * @}
  */ 
/** @addtogroup MCM_Group2
  * @{
  */
void MCM_DutyEventActiveConfig(uint16_t MCM_DUTY_Active, SH_FunctionalState NewState);
uint16_t MCM_GetCounter(void);
uint16_t MCM_GetPrescaler(void);
uint16_t MCM_GetPeriod(void);
uint16_t MCM_GetPWMDuty0(void);
uint16_t MCM_GetPWMDuty01(void);
uint16_t MCM_GetPWMDuty1(void);
uint16_t MCM_GetPWMDuty11(void);
uint16_t MCM_GetPWMDuty2(void);
uint16_t MCM_GetPWMDuty21(void);
void MCM_IntEventFlagDivConfig(uint16_t MCM_Division);
void MCM_PWM0DeadTimeConfig(uint16_t PWM0DT,uint16_t PWM01DT);
void MCM_PWM1DeadTimeConfig(uint16_t PWM1DT,uint16_t PWM11DT);
void MCM_PWM2DeadTimeConfig(uint16_t PWM2DT,uint16_t PWM21DT);
void MCM_RegWritReloadLock(MCM_REG_LOCK_RELOAD_State NewState);
void MCM_SetCounter(uint16_t Counter);
void MCM_SetPeriod(uint16_t Period);
void MCM_SetPrescaler(uint16_t Prescaler);
void MCM_SetPWMDuty0(uint16_t Duty0);
void MCM_SetPWMDuty01(uint16_t Duty01);
void MCM_SetPWMDuty1(uint16_t Duty1);
void MCM_SetPWMDuty11(uint16_t Duty11);
void MCM_SetPWMDuty2(uint16_t Duty2);
void MCM_SetPWMDuty21(uint16_t Duty21);
/**
  * @}
  */
/** @addtogroup MCM_Group3
  * @{
  */
void MCM_INTConfig(uint16_t MCM_INT, SH_FunctionalState NewState);
SH_FlagStatus MCM_GetFlagStatus(uint16_t MCM_Flag);
void MCM_ClearFlag(uint16_t MCM_Flag);
/**
  * @}
  */
/** @addtogroup MCM_Group4
  * @{
  */
void MCM_ADCTrigger1Config(uint16_t MCM_ADCTrigger1);
void MCM_ADCTrigger2Config(uint16_t MCM_ADCTrigger2);
void MCM_ADCTrigger3Config(uint16_t MCM_ADCTrigger3);
void MCM_ADCTrigger4Config(uint16_t MCM_ADCTrigger4);
void MCM_SetADCTriggerValue1(uint16_t Value1);
void MCM_SetADCTriggerValue2(uint16_t Value2);
void MCM_SetADCTriggerValue3(uint16_t Value3);
void MCM_SetADCTriggerValue4(uint16_t Value4);
void MCM_CompareEventActiveConfig(uint16_t MCM_CMP_Active, SH_FunctionalState NewState);
/**
  * @}
  */
/** @addtogroup MCM_Group5
  * @{
  */
void MCM_ManualPWMOutRegSync(uint16_t MCM_ActiveTiming);
void MCM_ManualPWMOutOnOff(uint8_t MCM_PWMx, SH_CmdState OnOffState);
void MCM_ManualPWMOutLevel(uint8_t MCM_PWMx, MCM_MANUAL_OUT_LEVEL_State NewState);
/**
  * @}
  */
/** @addtogroup MCM_Group6
  * @{
  */
void MCM_FLTWriteLock(SH_FunctionalState NewState);
void MCM_FLTOnOff(uint32_t MCM_FLT, SH_CmdState OnOffState);
void MCM_FLT0Config(uint32_t MCM_FLT0DetectMode, uint32_t MCM_FLT0ActiveLevel);
void MCM_FLT1Config(uint32_t MCM_FLT1DetectMode, uint32_t MCM_FLT1ActiveLevel);
void MCM_FLT2Config(uint32_t MCM_FLT2DetectMode, uint32_t MCM_FLT2ActiveLevel, uint32_t MCM_FLT2Filter);
void MCM_FLTOutLevelConfig(uint32_t MCM_PWMxPinStatus, uint32_t MCM_PWMx1PinStatus);
SH_FlagStatus MCM_GetFLTStatus(uint32_t MCM_FLTx_STAT);
void MCM_ClearFLTStatusFlag(uint32_t FltClearStat);
void MCM_OSCStopDetectOnOff(SH_CmdState OnOffState);
void MCM_ShortCircuitProtectOnOff(SH_CmdState OnOffState);
void MCM_ShortCircuitOutPutLevel(uint8_t MCM_PWMxPin, uint8_t MCM_OutputLevel);
void MCM_SCStructInit(MCM_SCInitTypeDef* InitStruct);
void MCM_SC0Init(MCM_SCInitTypeDef* InitCfg);
void MCM_SC1Init(MCM_SCInitTypeDef* InitCfg);
void MCM_SC2Init(MCM_SCInitTypeDef* InitCfg);
SH_FlagStatus MCM_GetSCxStatus(uint32_t MCM_SCx_STAT);
void MCM_ClearSCxStatus(uint32_t MCM_SCx_STAT);
/**
  * @}
  */
/** @addtogroup MCM_Group7
  * @{
  */
void MCM_DutySaturationMinMaxValue(uint16_t MCM_PWMMin, uint16_t MCM_PWMMax);
void MCM_DutySaturationConfig(uint16_t MCM_MinSelect, uint16_t MCM_MaxSelect);
void MCM_DutySaturationRun(void);
void MCM_PhaseShiftRun(void);
void MCM_PhaseShiftSatRun(void);
void MCM_PhaseShiftConfig(uint16_t MCM_Shift1, uint16_t MCM_Shift2);
SH_FlagStatus MCM_GetPhaseShiftOver(void);
uint8_t MCM_GetPhaseShiftSector(void);
/**
  * @}
  */
/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_MCM_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/

