/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_nvic.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the PPP firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_NVIC_H
#define __SH3xF2xx_SB0_NVIC_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup NVIC_MODULE NVIC
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/** @defgroup NVIC_Exported_Constants Public Constants
  * @{
  */ 

    
#define NVIC_VectTab_RAM             ((uint32_t)0x20000000)   /*!<RAM Start Address*/
#define NVIC_VectTab_FLASH           ((uint32_t)0x00000000)   /*!<Flash Start Address*/
  
/*! NVIC initial structure */    
typedef struct
{
    uint8_t NVIC_IRQChannel;                    /*!< Specifies the IRQ channel to be enabled or disabled.
                                                   This parameter can be an enumerator of IRQn_Type 
                                                   enumeration (please refer to sh3xf2xx_sb0.h file) */
                                                   
    uint8_t NVIC_IRQChannelPreemptionPriority;  /*!< Specifies the pre-emption priority for the IRQ channel
                                                   specified in NVIC_IRQChannel. */
                                                    
    uint8_t NVIC_IRQChannelSubPriority;         /*!< Specifies the subpriority level for the IRQ channel specified
                                                   in NVIC_IRQChannel. */
    uint8_t NVIC_IRQChannelCmd;         /*!< Specifies whether the IRQ channel defined in NVIC_IRQChannel
                                                   will be enabled or disabled. This parameter can be set either 
                                                   to SH_ENABLE or SH_DISABLE */
}NVIC_InitTypeDef;
    
#define NVIC_LP_SEVONPEND            ((uint8_t)0x10)  /*!< SEV pending control bit*/
#define NVIC_LP_SLEEPDEEP            ((uint8_t)0x04)  /*!< Sleep deep (stop mode) control bit*/
#define NVIC_LP_SLEEPONEXIT          ((uint8_t)0x02)  /*!< Sleep on exit control bit*/

/** @defgroup NVIC_Priority_Group  NVIC Priority Group
  * @{
  */ 

#define NVIC_PriorityGroup_Preemption3   ((uint32_t)0x400) /*!< 3 bits for pre-emption priority
                                                            0 bits for subpriority */
#define NVIC_PriorityGroup_Preemption2   ((uint32_t)0x500) /*!< 2 bits for pre-emption priority
                                                            1 bits for subpriority */
#define NVIC_PriorityGroup_Preemption1   ((uint32_t)0x600) /*!< 1 bits for pre-emption priority
                                                            2 bits for subpriority */
#define NVIC_PriorityGroup_Preemption0   ((uint32_t)0x700) /*!< 0 bits for pre-emption priority
                                                            3 bits for subpriority */
#define IS_NVIC_PRIORITY_GROUP(GROUP)   ((GROUP == NVIC_PriorityGroup_Preemption3) \
                                        || (GROUP == NVIC_PriorityGroup_Preemption2) \
                                        || (GROUP == NVIC_PriorityGroup_Preemption1) \
                                        || (GROUP == NVIC_PriorityGroup_Preemption0))  /*!< check NVIC Priority Group*/

/**
  * @}
  */
   

/**
  * @}
  */ 


/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 
/** @defgroup NVIC_Exported_Functions Public Fuctions
  * @{
  */ 
/* NVIC Initial function */
void NVIC_Init(NVIC_InitTypeDef* NVIC_InitStruct);
/* Configures the priority grouping: pre-emption priority and subpriority. */
void NVIC_PriorityGroupConfig(uint32_t NVIC_PriorityGroup);
/* Sets the vector table location and Offset*/
void NVIC_SetVectorTable(uint32_t NVIC_VectTab, uint32_t Offset);
/* Config SysTick timer */
void SysTick_TimeConfig(uint16_t MilliSecond);
/* Get the SysTick Counter value.*/
uint32_t SysTick_GetCounter(void);
/* turn on or turn off SysTick module*/
void SysTick_OnOff(SH_CmdState OnOffState);
/* enable or disable SysTick interrupt*/
void SysTick_INTConfig(SH_FunctionalState NewState);

/**
  * @}
  */ 

#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_NVIC_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
