/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_pca.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the PPP firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_PCA_H
#define __SH3xF2xx_SB0_PCA_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup PCA_MODULE PCA
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/
/** @defgroup PCA_Group_Types  Public Types
  * @{
  */ 
	
/*! @struct  PCA_TimeBaseInitTypeDef
  *   structure for PCA TimeBase Function
  */  
typedef struct
{
	uint32_t PCAMode;			/*!< Specifie the PCAx's Mode.
                                This parameter can be 0 to 0xFFFF. */
	
	uint32_t Prescaler;    /*!< Specifie the PCAx's Prescaler Register value.
                                This parameter can be 0 to 0xFFFF. */
                                    
	uint32_t Period;	   	/*!< Specifie the PCAx's Period Register value.
                                This parameter can be 0 to 0xFFFF. */
	
	uint32_t CounterMode;  /*!< Specifie the PCAx's Counter mode.
                                This parameter can be a value of PCA_Counter_Mode */
                                    
  uint32_t InitialLevel;			/*!< Specifie the PCAx's Initial Level.
                                This parameter can be 0 to 0xFFFF. */
	
  uint32_t Count;			/*!< Specifie the PCAx's CNT Register value.
                                This parameter can be 0 to 0xFFFF. */
	
	uint32_t InitA_Data;			/*!< Specifie the PCAxA's CCR0L Register value.
                                This parameter can be 0 to 0xFFFF. */ 
	
	uint32_t ReloadA_Data;			/*!< Specifie the PCAxA's CCR0H  Register value.
                                This parameter can be 0 to 0xFFFF. */ 
	
	uint32_t InitB_Data;			/*!< Specifie the PCAxB's CCR1L Register value.
                                This parameter can be 0 to 0xFFFF. */ 
	
	uint32_t ReloadB_Data;			/*!< Specifie the PCAxB's CCR1H  Register value.
                                This parameter can be 0 to 0xFFFF. */ 
	
	uint32_t InitC_Data;			/*!< Specifie the PCAxC's CCR2L Register value.
                                This parameter can be 0 to 0xFFFF. */ 
	
	uint32_t ReloadC_Data;			/*!< Specifie the PCAxC's CCR2H  Register value.
                                This parameter can be 0 to 0xFFFF. */ 														
}PCA_TimeBaseInitTypeDef;


/*! @struct  PCA_CMPInitTypeDef
  *   structure for PCA Compare Function
  */ 

typedef struct
{
	uint32_t Prescaler;    /*!< Specifie the PCAx's Prescaler Register value.
                                This parameter can be 0 to 0xFFFF. */
                                    
	uint32_t Period;	   	/*!< Specifie the PCAx's Period Register value.
                                This parameter can be 0 to 0xFFFF. */
	
	uint32_t PCAMode;			/*!< Specifie the PCAx's Mode.
                                This parameter can be 1. */
	
	uint32_t CMPMode;			/*!< Specifie the PCAx's Mode.
                                This parameter can be 1. */
	
	uint32_t CounterMode;  /*!< Specifie the PCAx's Counter mode.
                                This parameter can be a value of PCA_Counter_Mode */
                                    
  uint32_t InitialLevel;			/*!< Specifie the PCAx's Initial Level.
                                This parameter can be 0 to 0xFFFF. */
	
  uint32_t Count;			/*!< Specifie the PCAx's CNT Register value.
                                This parameter can be 0 to 0xFFFF. */
                                        
	uint32_t CMPA_Value;         /*!< Specifie the PCAx PWM Duty Register value.
                                     This parameter can be 0 to 0xFFFFFFFF */
																		 
	uint32_t CMPB_Value;         /*!< Specifie the PCAx PWM Duty Register value.
                                     This parameter can be 0 to 0xFFFFFFFF */
																		 
	uint32_t CMPC_Value;         /*!< Specifie the PCAx PWM Duty Register value.
                                     This parameter can be 0 to 0xFFFFFFFF */																		 
																		 
}PCA_CMPInitTypeDef;


/*! @struct  PCA_CaptureInitTypeDef
  *   structure for PCA Capture Function
  */ 
typedef struct
{
	uint32_t CounterMode;  /*!< Specifie the PCAx's Counter mode.
                                This parameter can be a value of PCA_Counter_Mode */
                                    
	uint32_t Prescaler;    /*!< Specifie the PCAx's Prescaler Register value.
                                This parameter can be 0 to 0xFFFF. */
                                    
	uint32_t Period;	   	/*!< Specifie the PCAx's Period Register value.
                                This parameter can be 0 to 0xFFFF. */
	
	uint32_t PCAMode;			/*!< Specifie the PCAx's Mode.
                                This parameter can be 0. */
	
	uint32_t CaptureSelect;			/*!< Specifie the PCAx's Capture souse.
                                This parameter can be 0 to 3. */	
	
  uint32_t TriggerLevel;			/*!< Specifie the PCAx's Initial Level.
                                This parameter can be 0 to 0xFFFF. */
	
  uint32_t 	InputFilter;		/*!< Specifie the PCAx's Input Filter.
                                This parameter can be a value of  PCA_Capture_Filter */
	
	uint32_t CaptureClear;		/*!< Specifie the PCAx's Capture Clear Mode.
                                This parameter can be a value of PCA_Capture_Clear_Select */
	
  uint32_t Count;			/*!< Specifie the PCAx's CNT Register value.
                                This parameter can be 0 to 0xFFFF. */
	
	uint32_t CaptureA_Value;         /*!< Specifie the PCAx CCR0 Register value.
                                     This parameter can be 0 to 0xFFFFFFFF */
																		 
	uint32_t CaptureB_Value;         /*!< Specifie the PCAx CCR1 Register value.
                                     This parameter can be 0 to 0xFFFFFFFF */
																		 
	uint32_t CaptureC_Value;         /*!< Specifie the PCAx CCR2 Register value.
                                     This parameter can be 0 to 0xFFFFFFFF */
	
}PCA_CaptureInitTypeDef;


/*! @struct  PCA_PWMInitTypeDef
  *   structure for PCA PWM Function
  */ 

typedef struct
{
	uint32_t PCAMode;        /*!< Specifie the PCAx mode.
                                  This parameter can be a value of  CCMR_SM_PWM */
	
	uint32_t PWMMode;        /*!< Specifie the PCAx PWM output mode.
                                  This parameter can be a value of PCA_PWM_Mode */
                                        
	uint32_t CounterMode;  /*!< Specifie the PCAx's Counter mode.
                                This parameter can be a value of  PCA_COUNTER_MODE */
                                    
	uint32_t Prescaler;    /*!< Specifie the PCAx's Prescaler Register value.
                                This parameter can be 0 to 0xFFFF. */
                                    
	uint32_t Period;	   	/*!< Specifie the PCAx's Period Register value.
                                This parameter can be 0 to 0xFFFFFFFF. */
	
  uint32_t InitialLevel;			/*!< Specifie the PCAx's Initial Level.
                                This parameter can be 0 to 0xFFFF. */
	
  uint32_t Count;			/*!< Specifie the PCAx's CNT Register value.
                                This parameter can be 0 to 0xFFFF. */
																
	uint32_t DutyA_Value;         /*!< Specifie the PCAxA PWM Duty Register value.
                                     This parameter can be 0 to 0xFFFFFFFF */
	
	uint32_t DutyB_Value;         /*!< Specifie the PCAxB PWM Duty Register value.
                                     This parameter can be 0 to 0xFFFFFFFF */
	
	uint32_t DutyC_Value;         /*!< Specifie the PCAxC PWM Duty Register value.
                                     This parameter can be 0 to 0xFFFFFFFF */	
	
	uint32_t InitA_Data;			/*!< Specifie the PCAxA's CCR0L Register value.
                                This parameter can be 0 to 0xFFFF. */ 
	
	uint32_t ReloadA_Data;			/*!< Specifie the PCAxA's CCR0H  Register value.
                                This parameter can be 0 to 0xFFFF. */ 
	
	uint32_t InitB_Data;			/*!< Specifie the PCAxB's CCR1L Register value.
                                This parameter can be 0 to 0xFFFF. */ 
	
	uint32_t ReloadB_Data;			/*!< Specifie the PCAxB's CCR1H  Register value.
                                This parameter can be 0 to 0xFFFF. */ 
	
	uint32_t InitC_Data;			/*!< Specifie the PCAxC's CCR2L Register value.
                                This parameter can be 0 to 0xFFFF. */ 
	
	uint32_t ReloadC_Data;			/*!< Specifie the PCAxC's CCR2H  Register value.
                                This parameter can be 0 to 0xFFFF. */ 																	 
																		 
}PCA_PWMInitTypeDef;


/*! @struct  PCA_FLTInitTypeDef
  *   structure for PCA Fault Function
  */ 
	

typedef struct
{
	uint32_t FLT_ProtectPWM;   				/*!< Specifie the PCAx Stoppage Check(SC) module protect pwm.
                                   This parameter can be any combination of  PCA_SC_Protect_PWM */
                                    
	uint32_t FLT_Filter;       				/*!< Specifie the PCAx Stoppage Check(SC) module filter.
                                   This parameter can be a value of PCA_SC_Filter */
	
  uint32_t FLT_Mode;           			/*!< Fault Mode */
  uint32_t FLT_Int;                 /*!< Fault Interrupt */
  uint32_t FLT_OutputState;         /*!< Output status selection bit after the fault occurs */
  uint32_t FLT_Syn;                 /*!< Fault detection synchronous control */
  
  uint32_t FLT1_InputSel;      			/*!< Fault detection 1 input source selection control */
  uint32_t FLT1_OnOff;    					/*!< Fault detection 1 function control */
  
  uint32_t FLT2_Filter;    					/*!< Fault detection 2 input filter parameter selection */
  uint32_t FLT2_ActiveLevel;    		/*!< Fault detection 2 valid level selection */
  uint32_t FLT2_OnOff;         			/*!< Fault detection 2 function control */                               
}PCA_FLTInitTypeDef;

/**
  * @}
  */
 
/** @defgroup PCA_Group_Macro  Public Macros
  * @{
  */

/*!  PCA_Update*/
#define PCA_PUE		0x01 /*!< periodic update*/
#define PCA_CC0UE   0x02 /*!< PACxA Module update control */
#define PCA_CC1UE   0x04 /*!< PACxB Module update control */
#define PCA_CC2UE   0x08 /*!< PACxC Module update control */	
#define IS_PCA_UPDATE(PCA_UPDATE)   (((PCA_UPDATE & PCA_PUE)== PCA_PUE) \
																		|| ((PCA_UPDATE & PCA_CC0UE) == PCA_CC0UE) \
																		|| ((PCA_UPDATE & PCA_CC1UE) == PCA_CC1UE) \
																		|| ((PCA_UPDATE & PCA_CC2UE) == PCA_CC2UE)) /*!< check the parameters */
																		
#define PCA_REG_LOCK(PCAx)        (PCAx->LCKR = 0x0)    /*!< Lock PCAx register */
#define PCA_REG_UNLOCK(PCAx)      (PCAx->LCKR = 0x33CC) /*!< Unlock PCAx register */

#define PCA_FLT_REG_LOCK(PCAx)    (PCAx->FLTWPR = 0x0)     /*!< Lock PCAx Fault register */
#define PCA_FLT_REG_UNLOCK(PCAx)  (PCAx->FLTWPR = 0x33CC)  /*!< Unlock PCAx Fault register */

#define IS_PCA_ALL_PERIPH(PERIPH)  ((PERIPH == PCA0) || (PERIPH == PCA1))  /*!< check the parameters */

#define IS_PCA_MODE(mode)   ((uint32_t)(mode) <= 0xFFFF) /*!< check the parameters */



/*!<  PCA_Update_Mode*/
#define PCA_UPDATE_NEXT_CIRCLE 0  /*!< Update in the next cycle */
#define PCA_UPDATE_NOW 1          /*!< Update Immediately */
#define IS_PCA_UPDATE_MODE(PCA_UPDATE_MODE)  ((PCA_UPDATE_MODE == PCA_UPDATE_NEXT_CIRCLE) \
																							|| (PCA_UPDATE_MODE == PCA_UPDATE_NOW))  /*!< check the parameters */


/*!< PCA_INT_Mode*/
#define PCA_INT_CIE	  		0x01  /*!< PCAxA Capture/Compare Interrupt */
#define PCA_INT_PIE	  		0x02  /*!< PCAx time base periodic matching interrupt Interrupt*/
#define PCA_INT_CCIE0	  	0x04  /*!< PCAxA Capture/Compare Interrupt*/
#define PCA_INT_CCIE1	  	0x08  /*!< PCAxB Capture/Compare Interrupt*/
#define PCA_INT_CCIE2	  	0x10  /*!< PCAxC Capture/Compare Interrupt*/
#define IS_PCA_INT(PCA_INT)   (((PCA_INT & PCA_INT_CIE)== PCA_INT_CIE) \
																		|| ((PCA_INT & PCA_INT_PIE) == PCA_INT_PIE) \
																		|| ((PCA_INT & PCA_INT_CCIE0) == PCA_INT_CCIE0) \
																		|| ((PCA_INT & PCA_INT_CCIE1) == PCA_INT_CCIE1) \
																		|| ((PCA_INT & PCA_INT_CCIE2) == PCA_INT_CCIE2))  /*!< check the parameters */

/*!< PCA_Flag*/
#define PCA_FLAG_CC0IF  0x01  /*!< PCAxA Capture/Compare Flag */
#define PCA_FLAG_CC1IF  0x02  /*!< PCAxB Capture/Compare Flag */          
#define PCA_FLAG_CC2IF  0x04  /*!< PCAxC Capture/Compare Flag */
#define PCA_FLAG_FLTIF  0x08  /*!< Fault Detection Interrupt Flag */
#define PCA_FLAG_PIF    0x10  /*!< PCAx time base periodic matching interrupt flag(only valid in center aligned mode) */
#define PCA_FLAG_CIF	  0x80  /*!< PCA time base zero matching interrupt flag */
#define IS_PCA_GET_ONE_FLAG(PCA_FLAG)   (((PCA_FLAG & PCA_FLAG_CIF)== PCA_FLAG_CIF) \
																		|| ((PCA_FLAG & PCA_FLAG_PIF) == PCA_FLAG_PIF) \
																		|| ((PCA_FLAG & PCA_FLAG_FLTIF) == PCA_FLAG_FLTIF) \
																		|| ((PCA_FLAG & PCA_FLAG_CC2IF) == PCA_FLAG_CC2IF) \
																		|| ((PCA_FLAG & PCA_FLAG_CC1IF) == PCA_FLAG_CC1IF) \
																		|| ((PCA_FLAG & PCA_FLAG_CC0IF) == PCA_FLAG_CC0IF))  /*!< check the parameters */
																		
	
	
/*!< PCA_FORCE_Pin*/
#define PCAxA_FORCE			0x01  /*!< PCAxA force output */
#define PCAxB_FORCE			0x02  /*!< PCAxB force output */
#define PCAxC_FORCE			0x04  /*!< PCAxC force output */
#define IS_PCA_FORCE_PIN(PCA_FORCE_PIN)   (((PCA_FORCE_PIN & PCAxA_FORCE)== PCAxA_FORCE) \
																		|| ((PCA_FORCE_PIN & PCAxB_FORCE) == PCAxB_FORCE) \
																		|| ((PCA_FORCE_PIN & PCAxC_FORCE) == PCAxC_FORCE))  /*!< check the parameters */
	
/*!< PCAx counter / timer clock select*/
#define CFGR_CPS_PCLK 				   	0   /*!< Select PCLK */
#define CFGR_CPS_ECI 				   	  1  /*!< PCAxECI Falling edge */
#define CFGR_CPS_RC128K 			   	2  /*!< RC128K */
	
	
/*!< PCA counter working mode selection bit */
#define CFGR_SDEN_UP 				     	0  /*!< PCA works in Edge-aligned mode(Capture mode,  Compare mode, Frequency output mode,PWM1,PWM2) */
#define CFGR_SDEN_CENTRAL 	     	(1<<6)     /*!< PCA works in Center-aligned mode( For PWM3, PWM4) */
#define IS_PCA_COUNTER_MODE(PCA_COUNTER_MODE) ((PCA_COUNTER_MODE == CFGR_SDEN_UP) || (PCA_COUNTER_MODE == CFGR_SDEN_CENTRAL))  /*!< check the parameters */
	
	
/*!< PCAx Counter/timer overflow interrupt enable bit*/
#define CFGR_CIE_DIS 				     	0  /*!< Disable counter/timer overflow interrupt */
#define CFGR_CIE_EN 							(1<<7)  /*!< when the CIF is set, the counter/timer overflow interrupt is enable */
	
	
/*!< PCAx Counter/timer period interrupt enable bit*/
#define CFGR_PIE_DIS 				     	0  /*!< Disable counter/timer overflow interrupt */
#define CFGR_PIE_EN 							(1<<8)  /*!< when the PIF is set, the counter/timer overflow interrupt is enable */
	
	
/*!< PCA_Update*/
#define CFGR_CC0UE_DIS 						0   /*!< The value written to CCR0 takes effect in the next cycle */
#define CFGR_CC0UE_EN 						(1<<12)  /*!< The value written to CCR0 takes effect immediately */

#define CFGR_CC1UE_DIS 						0   /*!< The value written to CCR1 takes effect in the next cycle */
#define CFGR_CC1UE_EN 						(1<<13)   /*!< The value written to CCR1 takes effect immediately */

#define CFGR_CC2UE_DIS 						0   /*!< The value written to CCR2 takes effect in the next cycle */
#define CFGR_CC2UE_EN 						(1<<14)   /*!< The value written to CCR2 takes effect immediately */

#define CFGR_PUE_DIS 							0   /*!< The value written to PR takes effect in the next cycle */
#define CFGR_PUE_EN 							(1<<15)  /*!<  The value written to PR takes effect immediately */
	
/*!< PCAx_ECI Input signal filter time */
#define CFGR_ECF_NONE 						0   /*!< No filter */
#define CFGR_ECF_8PCLK 						(1<<16)  /*!< Filter time constant is 8*PCLK */
#define CFGR_ECF_16PCLK 					(2<<16)  /*!< Filter time constant is 16*PCLK */
#define CFGR_ECF_32PCLK 					(3<<16)  /*!< Filter time constant is 32*PCLK */
#define IS_PCA_ECI_FILTER(PCA_ECF)  ((PCA_ECF == CFGR_ECF_NONE) \
																				|| (PCA_ECF == CFGR_ECF_8PCLK)\
																				|| (PCA_ECF == CFGR_ECF_16PCLK)\
																				|| (PCA_ECF == CFGR_ECF_32PCLK))  /*!< check the parameters */

	
/*!< PCA_SYS_Mode*/
#define CFGR_SYN_NONE 						0   /*!< No synchronization */
#define CFGR_SYN_PCA 							(1<<18)  /*!< Be set or cleared by MCM synchronously. */
#define CFGR_SYN_MCM							(2<<18)  /*!< Be set or cleared by MCM synchronously */
#define IS_PCA_SYS_MODE(PCA_SYS)  ((PCA_SYS == CFGR_SYN_NONE) \
																	|| (PCA_SYS == CFGR_SYN_PCA)\
																	|| (PCA_SYS == CFGR_SYN_MCM))  /*!< check the parameters */
	
/*!< PCA_Interrupt*/
#define CCMR_CCIE_DIS							0       /*!< Disable capture/compare interrupt */
#define CCMR_CCIE_EN							1       /*!< Enable capture/compare interrupt */


/*  PCA_Capture_Edge*/
#define CCMR_TCP_FALLEDGE 				0       /*!< Capture at the falling edge of PCAx */
#define CCMR_TCP_UPEDGE 					4   		/*!< Capture at the rising edge of PCAx */

/*!< PCA_Initial_Level*/
#define CCMR_TCP_HIGHLEVEL 				0       /*!< The initial level is high */
#define CCMR_TCP_LOWLEVEL					4  			/*!< The initial level is low. */
#define IS_PCA_INIT_LEVEL(PCA_INIT_LEVEL)  ((PCA_INIT_LEVEL == CCMR_TCP_HIGHLEVEL) \
																				|| (PCA_INIT_LEVEL == CCMR_TCP_LOWLEVEL))  /*!< check the parameters */


/*!< PCA_DUTY_LEVEL*/
#define CCMR_TCP_DUTYLOW 					0       /*!< The initial level is high */
#define CCMR_TCP_DUTYHIGH					4       /*!< The initial level is low. */
																		
/*!< PCA_CEN_BIT*/
#define CCMR_CEN_EN								8 /*!< Disable capture/compare module  */
#define CCMR_CEN_DIS							0 /*!< Enable capture/compare module */


/*!< PCA_Capture_Mode*/
#define CCMR_FS_UP_CAPTURE				0       /*!< Trigger at the rising edge */
#define CCMR_FS_DOWN_CAPTURE 			(2<<4)  /*!< Trigger at the falling edge */
#define CCMR_FS_UP_DOWN_CAPTURE 	(3<<4)  /*!< Trigger at the rising and falling edges */

/*!< PCA_CMP_Mode*/
#define CCMR_FS_CONTINUE_CMP 			0       /*!< Continuous match */
#define CCMR_FS_SINGLE_CMP 				(2<<4)  /*!< Single match */
	
/*!< PCA_PWM_Mode*/
#define CCMR_FS_PWM1							0       /*!< 16-bit PWM1 mode */
#define CCMR_FS_PWM2							(1<<4)  /*!< 32-bit PWM2 mode */
#define CCMR_FS_PWM3	  					(2<<4)  /*!< 32-bit PWM3 mode */
#define CCMR_FS_PWM4	  					(3<<4)  /*!< 32-bit PWM4 mode */
#define IS_PCA_PWM_MODE(PCA_PWM_MODE)  ((PCA_PWM_MODE == CCMR_FS_PWM1) \
																				|| (PCA_PWM_MODE == CCMR_FS_PWM2)\
																				|| (PCA_PWM_MODE == CCMR_FS_PWM3)\
																				|| (PCA_PWM_MODE == CCMR_FS_PWM4))  /*!< check the parameters */
/*!< PCA_PCA_Mode*/
#define CCMR_SM_CAPTURE						 0      /*!< Capture mode */
#define CCMR_SM_CMP								(1<<6)  /*!< Compare mode */
#define CCMR_SM_FREQ  						(2<<6)  /*!< Frequency output mode */
#define CCMR_SM_PWM	  						(3<<6)  /*!< PWM mode */

/*!< The Enable bit of Clearing Counter, after capture occurs*/
#define CCMR_CC_EN								(1<<8) /*!< No clear, after capture occurs */
#define CCMR_CC_DIS								(1<<8) /*!< Clear counter, after capture occurs */

 
/*!< PCA_Capture_Filter*/
#define CCMR_ICF_NONE							0 /*!< No filter */
#define CCMR_ICF_40PCLK						(1<<9)  /*!< Filter time constant is 40*PCLK */
#define CCMR_ICF_80PCLK						(2<<9)  /*!< Filter time constant is 80*PCLK */
#define CCMR_ICF_160PCLK					(3<<9)  /*!< Filter time constant is 160*PCLK */
#define CCMR_ICF_320PCLK					(4<<9)  /*!< Filter time constant is 320*PCLK */
#define CCMR_ICF_640PCLK					(5<<9)  /*!< Filter time constant is 640*PCLK */
#define CCMR_ICF_1280PCLK					(6<<9)  /*!< Filter time constant is 1280*PCLK */
#define CCMR_ICF_2560PCLK					(7<<9) /*!< Filter time constant is 2560*PCLK */
#define IS_PCA_CAPTURE_FILTER(PCA_FILTER)  ((PCA_FILTER == CCMR_ICF_NONE) \
																				|| (PCA_FILTER == CCMR_ICF_40PCLK)\
																				|| (PCA_FILTER == CCMR_ICF_80PCLK)\
																				|| (PCA_FILTER == CCMR_ICF_160PCLK)\
																				|| (PCA_FILTER == CCMR_ICF_320PCLK)\
																				|| (PCA_FILTER == CCMR_ICF_640PCLK)\
																				|| (PCA_FILTER == CCMR_ICF_1280PCLK)\
																				|| (PCA_FILTER == CCMR_ICF_2560PCLK)) /*!< check the parameters */

	
	
/*!< PCA_Capture_Clear_Select*/
#define CCMR_CSSEL_PCAxA 					0  /*!< PCAxA is used as the capture input source */
#define CCMR_CSSEL_C0OUT0					(1<<12)  /*!< CMP0_C0OUT0 is used as the capture input source */
#define IS_PCA_CAPTURE_SELECT(PCA_CSSEL) ((PCA_CSSEL == CCMR_CSSEL_PCAxA) \
																				|| (PCA_CSSEL == CCMR_CSSEL_C0OUT0))  /*!< check the parameters */

	
/*!< PCAx trigger ADC selection bit */
#define PCA_ADC_TRIGGER_None									(uint32_t)0x0000 /*!< No trigger */
#define PCA_ADC_TRIGGER_Up										(uint32_t)0x0200 /*!< Trigger ADC when counter is incremented */
#define PCA_ADC_TRIGGER_Down									(uint32_t)0x0400 /*!< Trigger ADC when counter is decremented */
#define PCA_ADC_TRIGGER_UpandDown             (uint32_t)0x0600 /*!< Trigger ADC when counter is incremented or decremented */
#define IS_PCA_ADC_TRIGGER_SOURCE(SOURCE)     ((SOURCE == PCA_ADC_TRIGGER_None) \
                                              || (SOURCE == PCA_ADC_TRIGGER_Up) \
                                              || (SOURCE == PCA_ADC_TRIGGER_Down) \
                                              || (SOURCE == PCA_ADC_TRIGGER_UpandDown)) /*!< check the parameters */
																							

	
/*!PCA_FLT_Mode*/
#define PCA_FLT1 1  /*!< PCAx Fault 1 */
#define PCA_FLT2 2  /*!< PCAx Fault 2 */
#define IS_PCA_FLT_MODE(MODE)           ((MODE == PCA_FLT1) \
																				|| (MODE == PCA_FLT2))	/*!< check the parameters */																						
                                          

/*!< Detection function mode selection*/                                        
#define FLTCR_FLTM_LOCK_MODE			0       /*!< Latch mode */
#define FLTCR_FLTM_TIME_MODE			2   /*!<  Sequential mode */
#define IS_PCA_FLT_STATE_MODE(Mode) 		((Mode == FLTCR_FLTM_LOCK_MODE) \
																				|| (Mode == FLTCR_FLTM_TIME_MODE)) /*!< check the parameters */
	
	
/*!< Fault detection 2 valid level selection bit*/                                         
#define FLTCR_FLT2S_HIGH_LEVEL		0       /*!< Fault detection 2 FLT input is valid on high level */
#define FLTCR_FLT2S_LOW_LEVEL			4  /*!< Fault detection 2 FLT input is valid on low level */
#define IS_PCA_FLT2_ACTIVE_LEVEL(PCA_FLT2_ACTIVE_LEVEL) ((PCA_FLT2_ACTIVE_LEVEL == FLTCR_FLT2S_HIGH_LEVEL) \
																				|| (PCA_FLT2_ACTIVE_LEVEL == FLTCR_FLT2S_LOW_LEVEL)) /*!< check the parameters */

	
/*!< Fault detection 2 function control bit */
#define FLTCR_FLT2EN_ON						8       /*!< Fault detection 2 function disables */
#define FLTCR_FLT2EN_OFF					0       /*!< Fault detection 2 function enables, the input source is FLT pin */


/*!< Fault detection 2 input filter parameter selection*/
#define FLTCR_FLT2DEB_0US				  0       /*!< No filter */
#define FLTCR_FLT2DEB_0P5US				(1<<4)  /*!< 0.5us */
#define FLTCR_FLT2DEB_1US					(2<<4)  /*!< 1us */
#define FLTCR_FLT2DEB_1P5US				(3<<4)  /*!< 1.5us */
#define FLTCR_FLT2DEB_2US					(4<<4)  /*!< 2us */
#define FLTCR_FLT2DEB_3US					(5<<4)  /*!< 3us */
#define FLTCR_FLT2DEB_4US					(6<<4)  /*!< 4us */
#define FLTCR_FLT2DEB_6US					(7<<4)  /*!< 6us */
#define FLTCR_FLT2DEB_8US					(8<<4)  /*!< 8us */
#define FLTCR_FLT2DEB_10US				(9<<4)  /*!< 10us */
#define FLTCR_FLT2DEB_12US				(10<<4) /*!< 12us */
#define FLTCR_FLT2DEB_14US				(11<<4) /*!< 14us */
#define FLTCR_FLT2DEB_16US				(12<<4) /*!< 16us */
#define FLTCR_FLT2DEB_20US				(13<<4) /*!< 20us */
#define FLTCR_FLT2DEB_24US				(14<<4)  /*!< 24us */
#define FLTCR_FLT2DEB_32US				(15<<4)  /*!< 32us */
#define IS_PCA_FLT2_FILTER(PCA_FLT2_FILTER)  ((PCA_FLT2_FILTER == FLTCR_FLT2DEB_0US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_0P5US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_1US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_1P5US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_2US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_3US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_4US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_6US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_8US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_10US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_12US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_14US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_16US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_20US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_24US)\
																				|| (PCA_FLT2_FILTER == FLTCR_FLT2DEB_32US)) /*!< check the parameters */


	
	
/*!< PCA_Fault1_Source*/
#define FLTCR_FLT1SEL_CMP0				0       /*!< Output filtered by comparator 0 is used as input source of PCA fault detection 1, high level valid */
#define FLTCR_FLT1SEL_CMP1				(1<<8)  /*!< Output filtered by comparator 1 is used as input source of PCA fault detection 1, high level valid */
#define IS_PCA_FLT1_SOURCE(PCA_FLT_SOURCE) ((PCA_FLT_SOURCE == FLTCR_FLT1SEL_CMP0) \
										 || (PCA_FLT_SOURCE == FLTCR_FLT1SEL_CMP1)) /*!< check the parameters */

	
/*!< Fault detection 1 input source selection control bit*/
#define FLTCR_FLT1EN_ON						(1<<10) /*!< Fault detection 1 function enables */
#define FLTCR_FLT1EN_OFF					0       /*!< Fault detection 1 function disables */
	

/*!< PCA_Fault_Synchronous*/                                                                                 
#define FLTCR_FLTSYN_DIS					0 /*!< Fault detection synchronous disable */
#define FLTCR_FLTSYN_EN						(1<<11) /*!< Fault detection synchronous enable */
#define IS_PCA_FLT_SYS(PCA_FLT_SYS)	        ((PCA_FLT_SYS == FLTCR_FLTSYN_DIS) \
											|| (PCA_FLT_SYS == FLTCR_FLTSYN_EN)) /*!< check the parameters */
	
	
/*!< Output status selection bit after the fault occurs*/                                          
#define FLTCR_FOUT_HIZ						(0<<12) /*!< Outputs high resistance state */
#define FLTCR_FOUT_LOW						(2<<12) /*!< Outputs low level */
#define FLTCR_FOUT_HIGH						(3<<12) /*!< Outputs high level */
#define IS_PCA_FLT_OUTPUT_LEVEL(PCA_FLT_OutputLevel)((PCA_FLT_OutputLevel == FLTCR_FOUT_HIZ) \
                                              || (PCA_FLT_OutputLevel == FLTCR_FOUT_LOW) \
                                              || (PCA_FLT_OutputLevel == FLTCR_FOUT_HIGH))/*!< check the parameters */

	
	
/*!< PCA_Fault_Interrupt*/                                        
#define FLTCR_FLTIE_DIS						0 /*!< Fault detection interrupt control disable */
#define FLTCR_FLTIE_EN						(1<<14) /*!< Fault detection interrupt control enable */
#define IS_PCA_FLT_INT(PCA_FLT_INT)			((PCA_FLT_INT == FLTCR_FLTIE_DIS) \
										 || (PCA_FLT_INT == FLTCR_FLTIE_EN))/*!< check the parameters */

	
/**
  * @}
  */

/* Exported functions --------------------------------------------------------*/ 
/** @defgroup PCA_Public_Functions Public Functions
  * @{
  */ 
/* Reset the PCAx peripheral registers to their default reset values */
void PCA_Reset(PCA_TypeDef* PCAx);
/* Enables or disables the PCA's registers protection */
void PCA_RegisterWriteLock(PCA_TypeDef* PCAx, SH_FunctionalState NewState);
/* On or off the specified PCA peripheral */
void PCA_OnOff(PCA_TypeDef* PCAx, SH_CmdState OnOffState);
/* Fills each PCA_TimeBaseInitStruct member with its default value */
void PCA_TimeBaseStructInit(PCA_TimeBaseInitTypeDef* PCA_TimeBaseInitStruct);
/* Initializes the PCAx Time Base Unit peripheral according to 
  *         the specified parameters in the PCA_TimeBaseInitStruct */
void PCA_TimeBaseInit(PCA_TypeDef* PCAx, PCA_TimeBaseInitTypeDef* PCA_TimeBaseInitStruct);
/* Fills each PCA_CaptureInitStruct member with its default value */
void PCA_CaptureStructInit(PCA_CaptureInitTypeDef* PCA_CaptureInitStruct);
/* Initializes the PCAx Capture Unit peripheral according to 
  *         the specified parameters in the PCA_CaptureInitStruct. */
void PCA_CaptureInit(PCA_TypeDef* PCAx, PCA_CaptureInitTypeDef* PCA_CaptureInitStruct);
/* Fills each PCA_CMPInitStruct member with its default value */
void PCA_CMPStructInit(PCA_CMPInitTypeDef* PCA_CMPInitStruct);
/* Initializes the PCAx Compare Unit peripheral according to 
  *         the specified parameters in the PCA_CMPInitStruct */
void PCA_CMPInit(PCA_TypeDef* PCAx, PCA_CMPInitTypeDef* PCA_CMPInitStruct);
/* Fills each PCA_PWMInitStruct member with its default value */
void PCA_PWMStructInit(PCA_PWMInitTypeDef* PCA_PWMInitStruct);
/* Initializes the PCAx Time Base Unit peripheral according to 
  *         the specified parameters in the PCA_TimeBaseInitStruct */
void PCA_PWMInit(PCA_TypeDef* PCAx, PCA_PWMInitTypeDef* PCA_PWMInitStruct);
/* Initialize the PCAxA function according to 
  *         the specified parameters in the PCA_PWMInitStruct */
void PCA_PCAxAPWMConfig(PCA_TypeDef* PCAx, PCA_PWMInitTypeDef* PCA_PWMInitStruct);
/* Initialize the PCAxB function according to 
  *         the specified parameters in the PCA_PWMInitStruct */
void PCA_PCAxBPWMConfig(PCA_TypeDef* PCAx, PCA_PWMInitTypeDef* PCA_PWMInitStruct);
/* Initialize the PCAxC function according to 
  *         the specified parameters in the PCA_PWMInitStruct */
void PCA_PCAxCPWMConfig(PCA_TypeDef* PCAx, PCA_PWMInitTypeDef* PCA_PWMInitStruct);
/* Sets the PCAx Counter Register value */
void PCA_SetCounter(PCA_TypeDef* PCAx, uint32_t Counter);
/* Sets the PCAx Prescaler Register value */
void PCA_SetPrescaler(PCA_TypeDef* PCAx, uint32_t Prescaler);
/* Sets the PCAx Period Register value */
void PCA_SetPeriod(PCA_TypeDef* PCAx, uint32_t Period);

/* Get the PCAx Counter Register value */
uint32_t PCA_GetCounter(PCA_TypeDef* PCAx);
/* Get the PCAx Prescaler Register value */
uint32_t PCA_GetPrescaler(PCA_TypeDef* PCAx);
/* Get the PCAx Period Register value */
uint32_t PCA_GetPeriod(PCA_TypeDef* PCAx);
/* Set the PCAxA Duty Register value */
void PCA_SetCCR0(PCA_TypeDef* PCAx, uint32_t Duty);
/* Set the PCAxB Duty Register value */
void PCA_SetCCR1(PCA_TypeDef* PCAx, uint32_t Duty);
/* Set the PCAxC Duty Register value */
void PCA_SetCCR2(PCA_TypeDef* PCAx, uint32_t Duty);
/* Get the PCAxA Duty Register value */
uint32_t PCA_GetCCR0(PCA_TypeDef* PCAx);
/* Get the PCAxB Duty Register value */
uint32_t PCA_GetCCR1(PCA_TypeDef* PCAx);
/* Get the PCAxC Duty Register value */
uint32_t PCA_GetCCR2(PCA_TypeDef* PCAx);
/* Enable or Disable specified PCA interrupts */
void PCA_INTConfig(PCA_TypeDef* PCAx, uint32_t PCA_INT, SH_FunctionalState NewState);
/* Set the specified of PCA update moment */
void PCA_UpdateConfig(PCA_TypeDef* PCAx, uint32_t PCA_Update, SH_FunctionalState NewState);
/* Check whether the specified PCA flag is set or not */
SH_FlagStatus PCA_GetFlagStatus(PCA_TypeDef* PCAx, uint32_t PCA_Flag);
/* Clear the PCAx's pending flags */
void PCA_ClearFlag(PCA_TypeDef* PCAx, uint32_t PCA_Flag);
/* Enable force manual output mode of the specified PWM port */
void PCA_SetForceOut(PCA_TypeDef* PCAx, uint8_t PCAxPin);
/* Set the PCAx Trigger ADC Register value */
void PCA_SetADCTriggerValue(PCA_TypeDef* PCAx, uint32_t Value);
/* Set the PCAx clock source */
void PCA_SetPCAClock(PCA_TypeDef* PCAx, uint32_t Source);
/* Set the filter time, when the PCAx clock source is PCAxECI */
void PCA_SetPCAxECIFilter(PCA_TypeDef* PCAx, uint32_t Filter);
/* Set the synchronization mode of PCAx */
void PCA_SetSYNSource(PCA_TypeDef* PCAx, uint32_t SYN_Source);
/* Configure the PCAx ADC trigger timing */
void PCA_ADCTriggerConfig(PCA_TypeDef* PCAx, uint32_t PCA_ADCTrigger);
/* Fills each PCA_FLTInitStruct member with its default value */
void PCA_FLTStructInit(PCA_FLTInitTypeDef* PCA_FLTInitStruct);
/* Initialize the PCAx Fault module according to 
  *         the specified parameters in the PCA_FLTInitStruct */
void PCA_FLTInit(PCA_TypeDef* PCAx, PCA_FLTInitTypeDef* PCA_FLTInitStruct);
/* Enable or disable FLT module registers write protection */
void PCA_FLTWriteLock(PCA_TypeDef* PCAx, SH_FunctionalState NewState);
/* Configure the PCAx FLT mode and output pin status */
void PCA_FLTConfig(PCA_TypeDef* PCAx, uint32_t PCA_FLT_STATE_Mode, uint32_t PCA_FLT_Int, uint32_t PCA_FLT_OutputLevel, uint32_t PCA_FLT_Syn);
/* Configure input source of the PCAx FLT1 module */
void PCA_FLT1Config(PCA_TypeDef* PCAx, uint32_t PCA_FLTSource);
/* Configure filter and active level of the PCAx FLT2 module */
void PCA_FLT2Config(PCA_TypeDef* PCAx, uint32_t PCA_FLT2Filter, uint32_t PCA_FLT2ActiveLevel);
/* Clear the PCAx's FLT pending flag */
void PCA_ClearFLTStatusFlag(PCA_TypeDef* PCAx);
/* Check whether the specified PCA FLT status flag is set or not */
SH_FlagStatus PCA_GetFLTStatus(PCA_TypeDef* PCAx);
/* Enable or disable the PCAx's Stoppage Check(SC) module */
void PCA_FLTOnOff(PCA_TypeDef* PCAx, uint32_t FLTx, SH_CmdState OnOffState);	

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_PCA_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
