/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_qei.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the qei firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_QEI_H
#define __SH3xF2xx_SB0_QEI_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup QEI_MODULE QEI
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/** @defgroup QEI_Exported_Constants Public Constants
  * @{
  */ 

/*! structure QEI_InitTypeDef definition */
typedef struct
{
    uint16_t QEI_PosCntMode;             /*!< Specifie QEI position counter mode.
                                              This parameter can be a value of QEI_Position_Counter_Mode */
                                                
    uint16_t QEI_PosCntMaxValue;         /*!< Specifie QEI position counter maximum value.
                                              This parameter can be 0 to 0xFFFF */
                                                
    uint16_t QEI_IndexRSTPosConterCmd;   /*!< Specifie QEI index signal reset position counter.
                                              This parameter can be a value of QEI_Index_Reset_Position_Counter */
                                                
    uint16_t QEI_ABSwapCmd;              /*!< Specifie whether QEI A and B signals swap or not.
                                              This parameter can be a value of QEI_AB_Swap */
                                                
    uint16_t QEI_IndexFilterCmd;         /*!< Specifie QEI index signal fliter function to be enabled or disabled.
                                              This parameter can be a value of QEI_Index_Filter */
                                                
    uint16_t QEI_IndexFilterPrescaler;   /*!< Specifie QEI index signal fliter prescaler.
                                              This parameter can be a value of QEI_Index_Filter_Prescaler */
                                                
    uint16_t QEI_QEABFilterCmd;          /*!< Specifie QEI A and B signals filter function to be enabled or disabled.
                                              This parameter can be a value of QEI_AB_Filter */
                                                
    uint16_t QEI_QEABFilterPrescaler;    /*!< Specifie QEI A and B signals filter prescaler.
                                              This parameter can be a value of QEI_QEABFilterPrescaler_1 */
                                                
    uint16_t QEI_PosCntPrescaler;        /*!< Specifie QEI QTimer prescaler.
                                              This parameter can be a value of QEI_QTimer_Prescaler */
                                                                                            
    uint16_t QEI_PosCounterMinValue;         /*!< Specifie QEI position counter minimum value.
                                              This parameter can be 0 to 0xFFFF */
                                                                                            
    uint32_t QEI_TimerPrescaler;              /*!< Specifie QEI position counter prescaler.
                                              This parameter can be 1 to 0x10000 */
                                                
    uint32_t QEI_QTimerPeriod;           /*!< Specifie QEI QTimer period value.
                                              This parameter can be 0 to 0xFFFFFFFF */
}QEI_InitTypeDef;



/** @defgroup QEI_Position_Counter_Mode Position Counter Mode
  * @{
  */ 

#define QEI_PosCntMode_2Edge_IndexRST        (uint16_t)0x0000   /*!< Position Counter Mode 2edge index reset */
#define QEI_PosCntMode_2Edge_SelfContinue    (uint16_t)0x0001   /*!< Position Counter Mode 2edge self continue*/
#define QEI_PosCntMode_4Edge_IndexRST        (uint16_t)0x0002   /*!< Position Counter Mode 4edge index reset */
#define QEI_PosCntMode_4Edge_SelfContinue    (uint16_t)0x0003   /*!< Position Counter Mode 4edge self continue*/
#define IS_QEI_POS_CNT_MODE(MODE)            ((MODE == QEI_PosCntMode_2Edge_IndexRST) \
                                             || (MODE == QEI_PosCntMode_2Edge_SelfContinue) \
                                             || (MODE == QEI_PosCntMode_4Edge_IndexRST) \
                                             || (MODE == QEI_PosCntMode_4Edge_SelfContinue)) /*!< Check QEI Position Counter Mode */

/**
  * @}
  */


/** @defgroup QEI_Index_Reset_Position_Counter Index Reset Position Counter
  * @{
  */ 

#define QEI_IndexRSTPosConter_Enable       (uint16_t)0x0010  /*!< index reset position counter enable*/
#define QEI_IndexRSTPosConter_Disable      (uint16_t)0x0000  /*!< index reset position counter disable*/
#define IS_QEI_INDEX_RST_POS_COUNTER(CMD)  ((CMD == QEI_IndexRSTPosConter_Enable) \
                                           || (CMD == QEI_IndexRSTPosConter_Disable)) /*!< check QEI index reset position counter */

/**
  * @}
  */




/** @defgroup QEI_AB_Swap  AB Swap
  * @{
  */ 

#define QEI_ABSwap_Enable           (uint16_t)0x0020 /*!< AB Swap Enable*/
#define QEI_ABSwap_Disable          (uint16_t)0x0000 /*!< AB Swap Disable */
#define IS_QEI_AB_SWAP(CMD)   ((CMD == QEI_ABSwap_Enable) || (CMD == QEI_ABSwap_Disable)) /*!< Check Swap parameter */

/**
  * @}
  */

 

/** @defgroup QEI_Index_Filter  Index Filter
  * @{
  */ 

#define QEI_IndexFilter_Enable       (uint16_t)0x0080/*!< Index Filter Enable */
#define QEI_IndexFilter_Disable      (uint16_t)0x0000/*!< Index Filter Disable */
#define IS_QEI_INDEX_FILTER(CMD)    ((CMD == QEI_IndexFilter_Enable) \
                                    || (CMD == QEI_IndexFilter_Disable))/*!< Check index filter control parameter */

/**
  * @}
  */



/** @defgroup QEI_Index_Filter_Prescaler  Index Filter Prescaler
  * @{
  */ 

#define QEI_IndexFilterPrescaler_1          (uint16_t)0x0000 /*!< Index Filter Prescaler : 1 */
#define QEI_IndexFilterPrescaler_2          (uint16_t)0x0010 /*!< Index Filter Prescaler : 2 */
#define QEI_IndexFilterPrescaler_4          (uint16_t)0x0020 /*!< Index Filter Prescaler : 4 */
#define QEI_IndexFilterPrescaler_16         (uint16_t)0x0030 /*!< Index Filter Prescaler : 16 */
#define QEI_IndexFilterPrescaler_32         (uint16_t)0x0040 /*!< Index Filter Prescaler : 32 */
#define QEI_IndexFilterPrescaler_64         (uint16_t)0x0050 /*!< Index Filter Prescaler : 64 */
#define QEI_IndexFilterPrescaler_128        (uint16_t)0x0060 /*!< Index Filter Prescaler : 128 */
#define QEI_IndexFilterPrescaler_256        (uint16_t)0x0070 /*!< Index Filter Prescaler : 256 */
#define IS_QEI_INDEX_FILTER_PRESCALER(DIV)   ((DIV == QEI_IndexFilterPrescaler_1) \
                                             || (DIV == QEI_IndexFilterPrescaler_2) \
                                             || (DIV == QEI_IndexFilterPrescaler_4) \
                                             || (DIV == QEI_IndexFilterPrescaler_16) \
                                             || (DIV == QEI_IndexFilterPrescaler_32) \
                                             || (DIV == QEI_IndexFilterPrescaler_64) \
                                             || (DIV == QEI_IndexFilterPrescaler_128) \
                                             || (DIV == QEI_IndexFilterPrescaler_256))/*!< Check index filter prescaler parameter */

/**
  * @}
  */


/** @defgroup QEI_AB_Filter AB Filter
  * @{
  */ 

#define QEI_QEABFilter_Enable      (uint16_t)0x0008/*!< QEAB filter enable */
#define QEI_QEABFilter_Disable     (uint16_t)0x0000/*!< QEAB filter disable */
#define IS_QEI_AB_FILTER(CMD)     ((CMD == QEI_QEABFilter_Enable) \
                                  || (CMD == QEI_QEABFilter_Disable))/*!< Check QEAB filter control parameter */

/**
  * @}
  */                                             



/** @defgroup QEI_AB_Filter_Prescaler AB Filter Prescaler
  * @{
  */ 

#define QEI_QEABFilterPrescaler_1          (uint16_t)0x0000 /*!< QEAB Filter Prescaler : 1 */
#define QEI_QEABFilterPrescaler_2          (uint16_t)0x0001 /*!< QEAB Filter Prescaler : 2 */
#define QEI_QEABFilterPrescaler_4          (uint16_t)0x0002 /*!< QEAB Filter Prescaler : 4 */
#define QEI_QEABFilterPrescaler_16         (uint16_t)0x0003 /*!< QEAB Filter Prescaler : 16 */
#define QEI_QEABFilterPrescaler_32         (uint16_t)0x0004 /*!< QEAB Filter Prescaler : 32 */
#define QEI_QEABFilterPrescaler_64         (uint16_t)0x0005 /*!< QEAB Filter Prescaler : 64 */
#define QEI_QEABFilterPrescaler_128        (uint16_t)0x0006 /*!< QEAB Filter Prescaler : 128 */
#define QEI_QEABFilterPrescaler_256        (uint16_t)0x0007 /*!< QEAB Filter Prescaler : 256 */
#define IS_QEI_QEAB_FILTER_PRESCALER(DIV)   ((DIV == QEI_QEABFilterPrescaler_1) \
                                             || (DIV == QEI_QEABFilterPrescaler_2) \
                                             || (DIV == QEI_QEABFilterPrescaler_4) \
                                             || (DIV == QEI_QEABFilterPrescaler_16) \
                                             || (DIV == QEI_QEABFilterPrescaler_32) \
                                             || (DIV == QEI_QEABFilterPrescaler_64) \
                                             || (DIV == QEI_QEABFilterPrescaler_128) \
                                             || (DIV == QEI_QEABFilterPrescaler_256))/*!< Check QEAB filter prescaler parameter */

/**
  * @}
  */



/** @defgroup QEI_PosCnt_Prescaler Position Counter Prescaler
  * @{
  */ 

#define QEI_PosCntPrescaler_1           (uint16_t)0x0000 /*!< Position Counter Prescaler : 1 */
#define QEI_PosCntPrescaler_2           (uint16_t)0x0100 /*!< Position Counter Prescaler : 2 */
#define QEI_PosCntPrescaler_4           (uint16_t)0x0200 /*!< Position Counter Prescaler : 4 */
#define QEI_PosCntPrescaler_8           (uint16_t)0x0300 /*!< Position Counter Prescaler : 8 */
#define QEI_PosCntPrescaler_16          (uint16_t)0x0400 /*!< Position Counter Prescaler : 16 */
#define QEI_PosCntPrescaler_32          (uint16_t)0x0500 /*!< Position Counter Prescaler : 32 */
#define QEI_PosCntPrescaler_64          (uint16_t)0x0600 /*!< Position Counter Prescaler : 64 */
#define QEI_PosCntPrescaler_128         (uint16_t)0x0700 /*!< Position Counter Prescaler : 128 */
#define QEI_PosCntPrescaler_256         (uint16_t)0x0800 /*!< Position Counter Prescaler : 256 */
#define QEI_PosCntPrescaler_512         (uint16_t)0x0900 /*!< Position Counter Prescaler : 512 */
#define QEI_PosCntPrescaler_1024        (uint16_t)0x0A00 /*!< Position Counter Prescaler : 1024 */
#define QEI_PosCntPrescaler_2048        (uint16_t)0x0B00 /*!< Position Counter Prescaler : 2048 */
#define IS_QEI_POSCNT_PRESCALER(DIV)     ((DIV == QEI_PosCntPrescaler_1) \
                                         || (DIV == QEI_PosCntPrescaler_2) \
                                         || (DIV == QEI_PosCntPrescaler_4) \
                                         || (DIV == QEI_PosCntPrescaler_8) \
                                         || (DIV == QEI_PosCntPrescaler_16) \
                                         || (DIV == QEI_PosCntPrescaler_32) \
                                         || (DIV == QEI_PosCntPrescaler_64) \
                                         || (DIV == QEI_PosCntPrescaler_128) \
                                         || (DIV == QEI_PosCntPrescaler_256) \
                                         || (DIV == QEI_PosCntPrescaler_512) \
                                         || (DIV == QEI_PosCntPrescaler_1024) \
                                         || (DIV == QEI_PosCntPrescaler_2048))/*!< Check position counter prescaler parameter */

/**
  * @}
  */


                                         
                                         
                                         
/** @defgroup QEI_Flag Flags
  * @{
  */ 

#define QEI_FLAG_PE               (uint16_t)0x0001 /*!< QEI Flag: Phase Error */
#define QEI_FLAG_CE               (uint16_t)0x0002 /*!< QEI Flag: Counter Error */
#define QEI_FLAG_Update           (uint16_t)0x0004 /*!< QEI Flag: Function */
#define QEI_FLAG_CAP              (uint16_t)0x0008 /*!< QEI Flag: Capture*/
#define QEI_FLAG_OV               (uint16_t)0x0010 /*!< QEI Flag: QTimer overflow */
#define IS_QEI_FLAG(FLAG)         ((FLAG & (uint16_t)0xFFE0) == (uint16_t)0x00 \
                                   && (FLAG != (uint16_t)0x00))/*!< Check QEI flag parameter */

#define IS_QEI_GET_ONE_FLAG(FLAG)  ((FLAG == QEI_FLAG_PE) \
                                   || (FLAG == QEI_FLAG_CE) \
                                   || (FLAG == QEI_FLAG_Update) \
                                   || (FLAG == QEI_FLAG_CAP) \
                                   || (FLAG == QEI_FLAG_OV))/*!< Check one of QEI flag parameter */
/**
  * @}
  */                                         


/** @defgroup QEI_Interrupt_Sources Interrupt Sources
  * @{
  */ 

#define QEI_INT_PE            (uint16_t)0x0001 /*!< QEI Interrupt Flag: Phase Error */
#define QEI_INT_CE            (uint16_t)0x0002 /*!< QEI Interrupt Flag: Counter Error */
#define QEI_INT_Update        (uint16_t)0x0004 /*!< QEI Interrupt Flag: Function */
#define QEI_INT_CAP           (uint16_t)0x0008 /*!< QEI Interrupt Flag: Capture */
#define QEI_INT_OV            (uint16_t)0x0010 /*!< QEI Interrupt Flag: QTimer overflow */
#define IS_QEI_INT(INT)       ((INT & (uint16_t)0xFFE0) == (uint16_t)0x00 \
                              && (INT != (uint16_t)0x00)) /*!< Check QEI interrupt flag parameter */

/**
  * @}
  */

/** @defgroup QEI_Index_Level Index Level
  * @{
  */ 
/*! enumeration E_QEI_INDEX_LEVEL definition*/
typedef enum{
    eQEIIndexLow = 0,  /*!< INDEX input is level low.*/
    eQEIIndexHigh = 1, /*!< INDEX input is level high.*/
}E_QEI_INDEX_LEVEL;

/**
  * @}
  */
  
/** @defgroup QEI_COUNTER_DIR  Counter direction
  * @{
  */ 
/*! enumeration E_QEI_COUNTER_DIR definition*/
typedef enum{
    eQEICounterDirDec = 0, /*!< The phase of QEA signal lags behind QEB.The encoder rotates reversely and the position counter counts down.*/
    eQEICounterDirInc = 1, /*!< The phase of QEA signal is ahead of  QEB.The encoder rotates forward and the position counter increases the count.*/
}E_QEI_COUNTER_DIR;

/**
  * @}
  */

/**
  * @}
  */ 


/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 

/** @addtogroup QEI_Exported_Functions Public Functions
  * @{
  */
/* QEI module reset */
extern void QEI_Reset(void);
/* Initialize QEI structure */
extern void QEI_StructInit(QEI_InitTypeDef* QEI_InitStruct);
/* Initialize QEI module */
extern void QEI_Init(QEI_InitTypeDef* QEI_InitStruct);
/* Turn on or turn off QEI module */
extern void QEI_OnOff(SH_CmdState OnOffState);
/* Turn on or turn off QEI Timer */
extern void QEI_QTimerOnOff(SH_CmdState OnOffState);
/* Set postion counter */
extern void QEI_SetPositionCounter(uint16_t QEI_PosCounter);
/* Get position counter */
extern uint16_t QEI_GetPositonCounter(void);
/* Set QEI Timer counter */
extern void QEI_SetQTimerCounter(uint32_t QEI_QTimerCounter);
/* Get QEI Timer counter */
extern uint32_t QEI_GetQTimerCounter(void);
/* Set QEI Timer period */
extern void QEI_SetQTimerPeriod(uint32_t QEI_QTimerPeriod);
/* Get QEI Timer period */
extern uint32_t QEI_GetQTimerPeriod(void);
/* Set QEI prescaler */
extern void QEI_SetPrescaler(uint16_t Prescaler);
/* Get QEI prescaler */
extern uint16_t QEI_GetPrescaler(void);
/* Get capture latch value */
extern uint32_t QEI_GetCaptureLatchValue(void);
/* Config QEI interrupt */
extern void QEI_INTConfig(uint16_t QEI_INT, SH_FunctionalState NewState);
/* Get position counter direction */
extern E_QEI_COUNTER_DIR QEI_GetPosCounterDir(void);
/* Get QEI flag status */
extern SH_FlagStatus QEI_GetFlagStatus(uint16_t QEI_Flag);
/* Get QEI index level */
extern E_QEI_INDEX_LEVEL QEI_GetIndexLevel(void);
/* Clear QEI flags */
extern void QEI_ClearFlag(uint16_t QEI_Flag);

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_QEI_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
