/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_syscfg.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the PPP firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_SYSCFG_H
#define __SH3xF2xx_SB0_SYSCFG_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup SYSCFG_MODULE SYSCFG
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/** @defgroup SYSCFG_Exported_Constants Public Constants
  * @{
  */ 
  
/** @defgroup LVR_Level LVR Voltage Level
  * @{
  */ 
#define LVR_VoltageLevel_4V1          (uint16_t)0x0000   /*!< LVR level 4.1V */
#define LVR_VoltageLevel_2V8          (uint16_t)0x0100   /*!< LVR level 2.8V */

#define IS_LVR_VOLTAGE_LEVEL(LEVEL)   ((LEVEL == LVR_VoltageLevel_4V1) \
                                       || (LEVEL == LVR_VoltageLevel_2V8)) /*!< check LVR level */
/**
  * @}
  */ 
                   
                                                                                
/*! BOD mode enumeration */
typedef enum
{
    SYSCFG_BOD_Mode_Rising = 0x00,          /*!< BOD occurs while rising*/
    SYSCFG_BOD_Mode_Falling = 0x01,         /*!< BOD occurs while falling*/
    SYSCFG_BOD_Mode_RisingFalling = 0x02,   /*!< BOD occurs whenever rising or falling*/
}SYSCFGBODMode_Type;   
 
#define IS_SYSCFG_BOD_MODE(MODE)   ((MODE == SYSCFG_BOD_Mode_Rising) \
                                   || (MODE == SYSCFG_BOD_Mode_Falling) \
                                   || (MODE == SYSCFG_BOD_Mode_RisingFalling)) /*!< check BOD parameter*/


/*! BOD Level enumeration */
typedef enum
{
    SYSCFG_BOD_Level_2V8 = 0x00,  /*!< BOD level 2.8V */
    SYSCFG_BOD_Level_2V9 = 0x01,  /*!< BOD level 2.9V */
    SYSCFG_BOD_Level_3V0 = 0x02,  /*!< BOD level 3.0V */
    SYSCFG_BOD_Level_3V1 = 0x03,  /*!< BOD level 3.1V */
    SYSCFG_BOD_Level_3V2 = 0x04,  /*!< BOD level 3.2V */
    SYSCFG_BOD_Level_3V3 = 0x05,  /*!< BOD level 3.3V */
    SYSCFG_BOD_Level_3V4 = 0x06,  /*!< BOD level 3.4V */
    SYSCFG_BOD_Level_3V5 = 0x07,  /*!< BOD level 3.5V */
    SYSCFG_BOD_Level_3V6 = 0x08,  /*!< BOD level 3.6V */
    SYSCFG_BOD_Level_3V7 = 0x09,  /*!< BOD level 3.7V */
    SYSCFG_BOD_Level_3V8 = 0x0A,  /*!< BOD level 3.8V */
    SYSCFG_BOD_Level_3V9 = 0x0B,  /*!< BOD level 3.9V */
    SYSCFG_BOD_Level_4V0 = 0x0C,  /*!< BOD level 4.0V */
    SYSCFG_BOD_Level_4V1 = 0x0D,  /*!< BOD level 4.1V */
    SYSCFG_BOD_Level_4V2 = 0x0E,  /*!< BOD level 4.2V */
    SYSCFG_BOD_Level_4V3 = 0x0F,  /*!< BOD level 4.3V */
}SYSCFGBODLevel_Type;    

#define IS_SYSCFG_BOD_LEVEL(BOD_LEVEL)  ((BOD_LEVEL == SYSCFG_BOD_Level_2V8) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_2V9) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_3V0) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_3V1) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_3V2) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_3V3) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_3V4) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_3V5) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_3V6) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_3V7) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_3V8) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_3V9) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_4V0) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_4V1) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_4V2) \
                                        || (BOD_LEVEL == SYSCFG_BOD_Level_4V3))   /*!< Check BOD level*/     

/** @defgroup BOD_FLAG BOD Flag
  * @{
  */ 
#define SYSCFG_BOD_FLAG_BODIF      (uint8_t)0x01     /*!< BOD interrupt flag */
#define SYSCFG_BOD_FLAG_BODF       (uint8_t)0x02     /*!< BOD event flag: rising or falling */

#define IS_SYSCFG_BOD_FLAG(FLAG)   ((FLAG == SYSCFG_BOD_FLAG_BODIF) \
                                   || (FLAG == SYSCFG_BOD_FLAG_BODF)) /*!< check BOD flag parameter*/
/**
  * @}
  */ 
                                     
/** @defgroup SYSCFG_SLEEP Sleep Method
  * @{
  */ 
#define SYSCFG_SLEEPEntry_WFI   (uint8_t)0x00      /*!< using WFI to enter sleep mode*/
#define SYSCFG_SLEEPEntry_WFE   (uint8_t)0x01      /*!< using WFE to enter sleep mode*/

#define IS_SYSCFG_SLEEP_ENTRY(ENTRY)   ((ENTRY == SYSCFG_SLEEPEntry_WFI) \
                                       || (ENTRY == SYSCFG_SLEEPEntry_WFE)) /*!< check enter sleep method */
/**
  * @}
  */ 


/** @defgroup SYSCFG_STOP Stop Method
  * @{
  */ 
#define SYSCFG_STOPEntry_WFI   (uint8_t)0x00      /*!< using WFI to enter stop mode*/
#define SYSCFG_STOPEntry_WFE   (uint8_t)0x01      /*!< using WFE to enter stop mode*/

#define IS_SYSCFG_SLOP_ENTRY(ENTRY)   ((ENTRY == SYSCFG_STOPEntry_WFI) \
                                       || (ENTRY == SYSCFG_STOPEntry_WFE)) /*!< check enter stop method */
/**
  * @}
  */ 
                                         
/** @defgroup SWJ_Pins_Mode SWJ Pins Mode
  * @{
  */ 
#define SYSCFG_SWD_DBG_Func      (uint8_t)0x00      /*!< SWJ pins used for debugging */
#define SYSCFG_SWD_GPIO_Func     (uint8_t)0x04      /*!< SWJ pins used for GPIO */

#define IS_SYSCFG_SWJ_PIN_MODE(MODE)   ((MODE == SYSCFG_SWD_DBG_Func) \
                                       || (MODE == SYSCFG_SWD_GPIO_Func))      /*!< check SWJ pins mode*/
/**
  * @}
  */ 

/*! OSC Pin Type enumeration */
typedef enum
{
    SYSCFG_OSC_GPIO = 0x00,       /*!< OSC pins used for GPIO */
    SYSCFG_OSC_Crystal = 0x01,    /*!< OSC pins used for Crystal */
    SYSCFG_OSC_ExtClock = 0x02    /*!< OSC pins used for External Clock */
}SYSCFG_OSCPin_Type;

#define IS_SYSCFG_OSC_PIN_MODE(MODE)   ((MODE == SYSCFG_OSC_GPIO) \
                                       || (MODE == SYSCFG_OSC_Crystal) \
                                       || (MODE == SYSCFG_OSC_ExtClock)) /*!< check OSC pin mode */


/** @defgroup NMI_Trigger NMI Trigger Source
  * @{
  */
#define SYSCFG_NMI_TRIGGER_CSM       (uint16_t)0x0080  /*!< CSM used as NMI source */
#define SYSCFG_NMI_TRIGGER_BOD       (uint16_t)0x0040  /*!< BOD used as NMI source */
#define SYSCFG_NMI_TRIGGER_EXTI0     (uint16_t)0x0020  /*!< EXTI0 used as NMI source */

#define IS_SYSCFG_NMI_TRIGGER_SOURCE(SOURCE)  (((SOURCE & (uint16_t)0xFF1F) == 0x00) \
                                              && (SOURCE != 0x00)) /*!< check NMI source */
/**
  * @}
  */                                               
                                              
/** @defgroup DBG_Periph_Option  Peripheral debug option
  * @{
  */                                               
#define DBG_Periph_QEI     (uint16_t)0x0080  /*!< QEI debug option */
#define DBG_Periph_IWDT    (uint16_t)0x0100  /*!< IWDT debug option */
#define DBG_Periph_WWDT    (uint16_t)0x0200  /*!< WWDT debug option */
#define DBG_Periph_PCA     (uint16_t)0x0400  /*!< PCA debug option */
#define DBG_Periph_TIM     (uint16_t)0x0800  /*!< TIM debug option */
#define DBG_Periph_MCM     (uint16_t)0x1000  /*!< MCM debug option */
#define DBG_Periph_UART    (uint16_t)0x2000  /*!< UART debug option */
#define DBG_Periph_SPI     (uint16_t)0x4000  /*!< SPI debug option */
#define DBG_Periph_TWI     (uint16_t)0x8000  /*!< TWI debug option */

#define IS_DBG_PERIPH(PERIPH)  (((PERIPH & (uint16_t)0x003F) == 0x00) && (PERIPH != 0x00)) /*!< check debug option */
/**
  * @}
  */ 
                                                 
/*! stop mode while debugging */  
#define DBG_LOWPOWER_STOP           (uint32_t)0x0002              /*!< debug stop option */      
#define IS_DBG_STOP_MODE(MODE)      (MODE == DBG_LOWPOWER_STOP)   /*!< check low power stop option */                                     


/**
  * @}
  */ 


/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 
/** @defgroup SYSCFG_Exported_Functions Public Functions
  * @{
  */ 
/* turn on or turn off LVR */
extern void SYSCFG_LVROnOff(SH_CmdState OnOffState);
/* LVR level configuration */
extern void SYSCFG_LVRVoltageLevelConfig(uint16_t LVR_VoltageLevel);
/* Initial BOD */
extern void SYSCFG_BODInit(SYSCFGBODMode_Type SYSCFG_BOD_Mode, SYSCFGBODLevel_Type SYSCFG_BOD_Level);
/* BOD interrupt configuration */
extern void SYSCFG_BODINTConfig(SH_FunctionalState NewState);
/* turn on or turn off BOD */
extern void SYSCFG_BODOnOff(SH_CmdState OnOffState);
/* get BOD flag status */
extern SH_FlagStatus SYSCFG_BODGetFlagStatus(uint8_t BOD_Flag);
/* clear BOD flag */
extern void SYSCFG_BODClearFlag(void);
/* enter sleep mode */
extern void SYSCFG_EnterSLEEPMode(uint8_t PWR_SLEEPEntry);
/* enter stop mode */
extern void SYSCFG_EnterSTOPMode(uint8_t PWR_STOPEntry);
/* NMI interrupt trigger source config */
extern void SYSCFG_NMIInterruptTriggerConfig(uint16_t TriggerSource, SH_FunctionalState NewState);
/* SWJ pins config */
extern void SYSCFG_SWJPinConfig(uint8_t SWJPin_Mode);
/* OSC pins config */
extern void SYSCFG_OSCPinConfig(SYSCFG_OSCPin_Type OSCPin_Mode);
/* debug option config */
extern void SYSCFG_DBGPeriphConfig(uint16_t DBG_Periph, SH_FunctionalState NewState);
/* stop mode in debug config */
extern void SYSCFG_DBGPowerStopConfig(SH_FunctionalState NewState);

/**
  * @}
  */ 

#ifdef __cplusplus
}
#endif

#endif /* __SH3xF2xx_SB0_SYSCFG_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
