/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_uart.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file contains all the functions prototypes for the PPP firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2022 Sinowealth
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH3xF2xx_SB0_UART_H
#define __SH3xF2xx_SB0_UART_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh3xf2xx_sb0_lib.h"

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/** @addtogroup UART_MODULE UART
  * @{
  */ 


	
	/* Exported types ------------------------------------------------------------*/
/** @defgroup UART_Group_Types  Public Types
  * @{
  */  


/*! @struct  UART_InitTypeDef
  *   structure for UART Init Structure definition 
  */ 
typedef struct
{
    uint32_t UART_Mode;  /*!< UART Working Mode */
    uint32_t UART_BaudRate;/*!< UART BaudRate */
    uint32_t UART_DataLength; /*!< The length of Data */
    uint32_t UART_StopBits;/*!< the length of stop bits */
    uint32_t UART_Parity;/*!< the parity of UART */
    uint32_t UART_TX_FIFO_Func;/*!< TX FIFO control bit */
    uint32_t UART_RX_FIFO_Func;/*!< RX FIFO control bit */
    uint32_t UART_Enable; /*!< Start the UART */
}UART_InitTypeDef;

 
/**
  * @}
  */

/** @defgroup UART_Group_Macro  Public Macros
  * @{
  */ 
#define IS_UART_ALL_PERIPH(PERIPH)  ((PERIPH == UART0) || (PERIPH == UART1) \
                                    || (PERIPH == UART2))/*!< check the parameters */


/*!< UART_Mode */ 
#define UART_Mode_0        (uint16_t)0x0000/*!< Mode 0: synchronous mode, fixed baud rate */
#define UART_Mode_1        (uint16_t)0x2000/*!< Mode 1: 8-bit asynchronous mode, variable baud rate */
#define UART_Mode_2        (uint16_t)0x4000/*!< Mode 2: 9-bit asynchronous mode, fixed baud rate */
#define UART_Mode_3        (uint16_t)0x6000/*!< Mode 3: 9-bit asynchronous mode, variable baud rate */
#define IS_UART_MODE(MODE)   ((MODE == UART_Mode_0) || (MODE == UART_Mode_1) \
                             || (MODE == UART_Mode_2) || (MODE == UART_Mode_3))  /*!< check the parameters */



/*!< UART_BaudRate */ 
#define UART_BaudRate_DIV_12          (uint32_t)0x80000000 /*!< Only available for UART_Mode_0 */
#define UART_BaudRate_DIV_48          (uint32_t)0x40000000 /*!< Only available for UART_Mode_0 */
#define UART_BaudRate_DIV_128         (uint32_t)0x20000000 /*!< Only available for UART_Mode_2 */
#define UART_BaudRate_DIV_256         (uint32_t)0x10000000 /*!< Only available for UART_Mode_2 */

#define IS_UART_MODE_0_BAUDRATE(BAUDRATE)   ((BAUDRATE == UART_BaudRate_DIV_12) \
                                            || (BAUDRATE == UART_BaudRate_DIV_48))/*!< check the parameters  */

#define IS_UART_MODE_2_BAUDRATE(BAUDRATE)   ((BAUDRATE == UART_BaudRate_DIV_128) \
                                            || (BAUDRATE == UART_BaudRate_DIV_256))/*!< check the parameters  */

#define IS_UART_MODE_13_BAUDRATE(BAUDRATE)  ((BAUDRATE != UART_BaudRate_DIV_12) \
                                            && (BAUDRATE != UART_BaudRate_DIV_48) \
                                            && (BAUDRATE != UART_BaudRate_DIV_128) \
                                            && (BAUDRATE != UART_BaudRate_DIV_256))  /*!< check the parameters  */



/*!< UART_FIFO_Function */ 
  
#define UART_TX_Standard          (uint32_t)0x00000000 /*!< Standard UART */
#define UART_TX_FIFO              (uint32_t)0x04000000 /*!< UART with TX FIFO */

#define IS_UART_TX_FIFO(FIFO) ((FIFO == UART_TX_Standard) || (FIFO == UART_TX_FIFO))/*!< check the parameters  */

#define UART_RX_Standard          (uint32_t)0x00000000 /*!< Standard UART */
#define UART_RX_FIFO              (uint32_t)0x02000000 /*!< UART with TX FIFO */

#define IS_UART_RX_FIFO(FIFO) ((FIFO == UART_RX_Standard) || (FIFO == UART_RX_FIFO))/*!< check the parameters  */



/*!< UART_Data_Length */ 
  
#define UART_DataLength_8Bit      (uint16_t)0x0000 /*!< For UART_Mode_0 and  UART_Mode_1 */
#define UART_DataLength_9Bit      (uint16_t)0x0200 /*!< Not available for UART_Mode_0 and  UART_Mode_1 */

#define IS_UART_MODE_01_DATALENGTH(LENGTH)  (LENGTH == UART_DataLength_8Bit)/*!< check the parameters  */
#define IS_UART_MODE_23_DATALENGTH(LENGTH)  ((LENGTH == UART_DataLength_8Bit) \
                                            || (LENGTH == UART_DataLength_9Bit))  /*!< check the parameters  */


/*!< UART_Stop_Bits */ 
#define UART_StopBits_1            (uint16_t)0x0001/*!< 1 stop bit */
#define UART_StopBits_2            (uint16_t)0x0002/*!< 2 stop bits */
#define UART_StopBits_None         (uint16_t)0x0000 /*!< Only available for UART_Mode_0 */

#define IS_UART_MODE_0_STOP_BITS(BITS)    (BITS == UART_StopBits_None)/*!< check the parameters  */

#define IS_UART_MODE_123_STOP_BITS(BITS)    ((BITS == UART_StopBits_1) \
                                            || (BITS == UART_StopBits_2))  /*!< check the parameters  */

/*!< UART_Parity */ 
#define UART_Parity_None           (uint16_t)0x0000/*!< No parity */
#define UART_Parity_Even           (uint16_t)0x0C00/*!< Even parity */
#define UART_Parity_Odd            (uint16_t)0x0800/*!< Odd parity */

#define IS_UART_MODE_01_PARITY(PARITY)  (PARITY == UART_Parity_None)/*!< check the parameters  */

#define IS_UART_MODE_23_PARITY(PARITY)  ((PARITY == UART_Parity_None) \
                                        || (PARITY == UART_Parity_Even) \
                                        || (PARITY == UART_Parity_Odd))   /*!< check the parameters  */


/*!< UART_Enable */ 
#define UART_Enable_Tx       (uint32_t)0x00040000/*!< UART transmit function enable */
#define UART_Enable_Rx       (uint32_t)0x00020000/*!< UART receive function enable */
#define IS_UART_ENABLE(SH_ENABLE)   ((SH_ENABLE & (uint32_t)0xFFF9FFFF) == 0x00) \
                                 && (SH_ENABLE != (uint32_t)0x00))  /*!< check the parameters  */


/*!< UART_Interrupt_Definition */ 
#define UART_INT_RX           (uint16_t)0x0008/*!< UART one byte data receive interrupt */
#define UART_INT_TX           (uint16_t)0x0010/*!< UART one byte data transmit interrupt */
#define UART_INT_TC           (uint16_t)0x0020/*!< UART all one frame data transmitting completion interrupt */
#define UART_INT_LBD          (uint16_t)0x0040/*!< LIN synchronous interval interrupt */
#define IS_UART_INT(INT)      (((INT & (uint16_t)0xFF87) == 0x00) && (INT != 0x00))/*!< check the parameters  */ 


/*!< UART_Flags */ 
#define UART_FLAG_RI      (uint16_t)0x0001/*!< UART one byte data receive interrupt flag */
#define UART_FLAG_TI      (uint16_t)0x0002/*!< UART one byte data transmit interrupt flag */
#define UART_FLAG_TC      (uint16_t)0x0004/*!< UART all one frame data transmitting completion interrupt flag*/
#define UART_FLAG_TXCOL   (uint16_t)0x0008/*!< UART transmit collision flag */
#define UART_FLAG_RXOV    (uint16_t)0x0010/*!< UART receive overflow flag  */
#define UART_FLAG_FE      (uint16_t)0x0020/*!< UART frame error flag */
#define UART_FLAG_PE      (uint16_t)0x0040/*!< UART parity error flag */
#define UART_FLAG_LBD     (uint16_t)0x0080/*!< LIN synchronous interval interrupt flag */

#define IS_UART_FLAG(FLAG)   (((FLAG & (uint16_t)0xFF00) == 0x00) && (FLAG != 0x00))/*!< check the parameters  */

#define IS_UART_GET_ONE_FLAG(FLAG)  ((FLAG == UART_FLAG_RI) || (FLAG == UART_FLAG_TI) \
                                || (FLAG == UART_FLAG_TC) || (FLAG == UART_FLAG_TXCOL) \
                                || (FLAG == UART_FLAG_RXOV) || (FLAG == UART_FLAG_FE) \
                                || (FLAG == UART_FLAG_PE) || (FLAG == UART_FLAG_LBD))/*!< check the parameters  */


/*!< UART_LIN_Detect_Length */ 
#define UART_LINDetectLength_10b             (uint16_t)0x0000/*!< Low level length is greater than 10 bit low level */
#define UART_LINDetectLength_11b             (uint16_t)0x0080/*!< Low level length is greater than 11 bit low level */
#define IS_UART_LIN_DETECT_LENGTH(LENGTH)    ((LENGTH == UART_LINDetectLength_10b) \
                                             || (LENGTH == UART_LINDetectLength_11b))/*!< check the parameters  */



/*!< UART_Bit9_Function */ 
#define UART_BIT9_Software             (uint16_t)0x0000/*!< Software customization */
#define UART_BIT9_MultComm             (uint16_t)0x0800/*!< Multi - machine communication flag bit */
#define UART_BIT9_Parity               (uint16_t)0x1000/*!< Parity check bit */
#define IS_UART_BIT9CONFIG(BIT9)    ((BIT9 == UART_BIT9_Software) \
                              || (BIT9 == UART_BIT9_MultComm) \
                              || (BIT9 == UART_BIT9_Parity))/*!< check the parameters  */


/* UART_Polarity_Function */ 
#define UART_TX_Polarity_DISABLE             SH_DISABLE/*!< UART Send polarity control disable */
#define UART_TX_Polarity_ENABLE              SH_ENABLE/*!< UART Send polarity control enable */

#define IS_UART_TX_POLARITY(POLARITY)    ((POLARITY == UART_TX_Polarity_DISABLE) \
                                         || (POLARITY == UART_TX_Polarity_ENABLE))/*!< check the parameters  */
                              
#define UART_RX_Polarity_DISABLE             SH_DISABLE/*!< UART Receiving polarity control disable */
#define UART_RX_Polarity_ENABLE              SH_ENABLE/*!< UART Receiving polarity control enable */

#define IS_UART_RX_POLARITY(POLARITY)    ((POLARITY == UART_RX_Polarity_DISABLE) \
                                         || (POLARITY == UART_RX_Polarity_ENABLE))/*!< check the parameters  */
 
/**
  * @}
  */ 
	
/** @addtogroup UART_Public_Functions Public Functions
  * @{
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/ 

/** @addtogroup UART_Group1
  * @{
  */
/* Initializes the UARTx peripheral according to the specified */
extern void UART_Init(UART_TypeDef* UARTx,UART_InitTypeDef* UART_InitStruct);
/* Reset the UART peripheral */
extern void UART_Reset(UART_TypeDef* UARTx);
/* Fills each UART_InitStruct member with its default value. */
extern void UART_StructInit(UART_InitTypeDef* UART_InitStruct);
/**
  * @}
  */
/** @addtogroup UART_Group2
  * @{
  */
/* Enables or disables the specified UART interrupts. */
extern void UART_INTConfig(UART_TypeDef* UARTx, uint8_t UART_INT, SH_FunctionalState NewState);
/* Sets the Polarity of the UART mode. */
extern void UART_PolarityConfig(UART_TypeDef* UARTx, uint8_t UART_TX_Polarity, uint8_t UART_RX_Polarity);
/* Checks whether the specified UART flag has occurred or not. */
extern SH_FlagStatus UART_GetFlagStatus(UART_TypeDef* UARTx, uint8_t UART_Flag);
/* Clears the UARTx's pending bits. */
extern void UART_ClearFlag(UART_TypeDef* UARTx, uint8_t UART_Flag);
/* Transmits single data through the UARTx peripheral. */
extern void UART_SendData(UART_TypeDef* UARTx, uint16_t SendData);
/* Returns the most recent received data by the UARTx peripheral. */
extern uint16_t UART_ReceiveData(UART_TypeDef* UARTx);
/* Returns the most recent received data by the UARTx peripheral. */
extern uint8_t UART_ReceiveData8(UART_TypeDef* UARTx);
/* Returns the bit 9 of recent received data by the UARTx peripheral */
extern uint16_t UART_GetBit9(UART_TypeDef* UARTx);
/* Sets the address of the UART mode. */
extern void UART_SetAddress(UART_TypeDef* UARTx, uint8_t UART_Address);
/* Sets the Shield address of the UART node. */
extern void UART_AddressShieldConfig(UART_TypeDef* UARTx, uint8_t UART_AddressShield);
/* Enables or disables the UART's Send mode. */
extern void UART_SendOnOff(UART_TypeDef* UARTx, SH_CmdState OnOffState);
/* Enables or disables the UART's Received mode */
extern void UART_ReceiveOnOff(UART_TypeDef* UARTx, SH_CmdState OnOffState);
/* Sets the specified UART's 9bit Function. */
extern void UART_Bit9Config(UART_TypeDef* UARTx, uint16_t Bit9Mode);
/* Sets the specified UART Parity. */
extern void UART_SetParity(UART_TypeDef* UARTx, uint16_t Parity);
/**
  * @}
  */
/** @addtogroup UART_Group3
  * @{
  */
/* Transmits to FIFO. */
extern void UART_SendToFIFO(UART_TypeDef* UARTx, uint32_t FIFO_Data);
/* Returns the most recent received data by FIFO. */
extern uint32_t UART_ReceiveFromFIFO(UART_TypeDef* UARTx);
/* Enables or disables the UART's FIFO Receive mode */
extern void UART_RxFIFOOnOff(UART_TypeDef* UARTx, SH_CmdState OnOffState);
/* Enables or disables the UART's FIFO Send mode */
extern void UART_TxFIFOOnOff(UART_TypeDef* UARTx, SH_CmdState OnOffState);
/**
  * @}
  */
/** @addtogroup UART_Group4
  * @{
  */
/* Enables or disables the UART Lin */
extern void UART_LINOnOff(UART_TypeDef* UARTx, SH_CmdState OnOffState);
/* Sets the UART LIN Break detection length. */
extern void UART_LINDetectLengthConfig(UART_TypeDef* UARTx, uint16_t UART_LINDetectLength);
/* Transmits break characters. */
extern void UART_SendBreak(UART_TypeDef* UARTx);

/**
  * @}
  */

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /*__SH3xF2xx_SB0_UART_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
