/*
            Copyright(C) 1997-2022.  Sinowealth Tech. Co., Ltd.
********************************************************************************
* @file    CFG32F2053.h  
* @author  
* @version V1.0.3
* @date    8-May-2022
* @brief   Keil configuration Wizard file.
********************************************************************************
*/
#ifndef __CFG32F2053_H__
#define __CFG32F2053_H__

/*****************************************************************************
//--------- <<< Use Configuration Wizard in Context Menu >>> -----------------
*****************************************************************************/
//<h>Debug Options
/**********************
//Debug Printf Options
//====== Debug Printf ========    
//<o>Debug Printf Device
//   <0=>No Printf support
//   <1=>ITM
//   <2=>UART

**********************/     
#define USE_MODULE_DBG_PRINTF 1
#if USE_MODULE_DBG_PRINTF
#define _MODULE_DBG_PRINTF
#endif

/**********************
// <h> UART Options
**********************/     
#if USE_MODULE_DBG_PRINTF == 2
#define _DBG_DEVICE_UART
/**********************
//       <o>UART SELECT
//             <1=>UART 1 PA[11,12]
//             <2=>UART 2 PA[8,9]
//             <3=>UART 3 PA[0,1]
**********************/     
#define PTN_DBG_UART_NO 3
/**********************
//       <o>Baudrate
//             <115200=> 115200
//             <57600=>  57600
//             <38400=>  38400
//             <19200=>  19200
//             <9600=>   9600
**********************/     
#define PTN_DBG_UART_BAUDRATE 115200

#if PTN_DBG_UART_NO==1
#define PTN_DBG_UART            UART1
#define PTN_DBG_UART_CLKGATE()  RCC->APB1ENR.BIT.UART1EN = 1;RCC->AHBENR.BIT.IODATEN = 1;RCC->AHBENR.BIT.IOCFGEN = 1
#define PTN_DBG_UART_PORT       GPIOA
#define PTN_DBG_UART_RX         GPIO_Pin_11
#define PTN_DBG_UART_TX         GPIO_Pin_12
#define PTN_DBG_UART_IOAF()     GPIOA_CFG->AFRH.BIT.AFR11 = 7;GPIOA_CFG->AFRH.BIT.AFR12 = 7; GPIOA_CFG->PUPDR.BIT.PUPDR11=1;GPIOA_CFG->PUPDR.BIT.PUPDR11=1
#endif
#if PTN_DBG_UART_NO==2
#define PTN_DBG_UART           UART2
#define PTN_DBG_UART_CLKGATE() RCC->APB1ENR.BIT.UART2EN = 1;RCC->AHBENR.BIT.IODATEN = 1;RCC->AHBENR.BIT.IOCFGEN = 1
#define PTN_DBG_UART_PORT      GPIOA
#define PTN_DBG_UART_RX        GPIO_Pin_8
#define PTN_DBG_UART_TX        GPIO_Pin_9
#define PTN_DBG_UART_IOAF()    GPIOA_CFG->AFRH.BIT.AFR8 = 7;GPIOA_CFG->AFRH.BIT.AFR9 = 7; GPIOA_CFG->PUPDR.BIT.PUPDR8=1;GPIOA_CFG->PUPDR.BIT.PUPDR9=1
#endif
#if PTN_DBG_UART_NO==3
#define PTN_DBG_UART           UART3
#define PTN_DBG_UART_CLKGATE() RCC->APB1ENR.BIT.UART3EN = 1;RCC->AHBENR.BIT.IODATEN = 1;RCC->AHBENR.BIT.IOCFGEN = 1
#define PTN_DBG_UART_PORT      GPIOA
#define PTN_DBG_UART_RX        GPIO_Pin_0
#define PTN_DBG_UART_TX        GPIO_Pin_1
#define PTN_DBG_UART_IOAF()    GPIOA_CFG->AFRL.BIT.AFR0 = 7;GPIOA_CFG->AFRL.BIT.AFR1 = 7; GPIOA_CFG->PUPDR.BIT.PUPDR0=1;GPIOA_CFG->PUPDR.BIT.PUPDR1=1
#endif


#endif

/**********************
//   </h>     
//   <h>ITM Options
**********************/     
#if USE_MODULE_DBG_PRINTF == 1
#define _DBG_DEVICE_ITM
/**********************
//       <o> ITM Frequency
//       <500000=>500KHz
//       <1000000=>1MHz
**********************/     
#define ITM_FREQ_DEFAULT 1000000
/**********************
//    </h>
**********************/     
#endif

/**********************
// debug printf
**********************/     
#ifdef    _USING_MDK_PACK
#include "RTE_Components.h"
#endif


/**********************
//<o> Default Assert Function
//  <0=>DISABLE    
//  <1=>ENABLE
**********************/     
#define ASSERT_ENABLE 0

#if ASSERT_ENABLE==1
#define DEFAULT_ASSERT_ENABLE
#endif    
//</h>

#ifdef __cplusplus
extern "C" {
extern void RetargetInit(void);
}
#else
extern void RetargetInit(void);
#endif


/***********************
//<e>Use Default SystemInit
************************/
#define USE_DEFAULT_SYSTEMINIT 1
#if USE_DEFAULT_SYSTEMINIT
#define DEFAULT_SYSTEMINIT
#endif

/***********************
//<o> Clock Source  
//    <0=>HSI (8MHz)
//    <1=>HSE       
//    <2=>PLL       
**********************/     
#define CLK_SRC 2
/*********************
//<o> HSI CLK 
**********************/
#define HSI_CLK 8000000
/*********************
//<o> HSE CLK 
**********************/
#define HSE_CLK 8000000


/*********************
//<e> Use PLL
**********************/

#define PLL_EN  1
/***********************
//<o> PLL Clock Source  
//    <0=>HSI (8MHz)
//    <1=>HSE       
**********************/
#define PLL_CLK_SRC 0

/*********************
//<q> CLK/2 TO PLL
**********************/
#define PLL_XTPRE 1
#define PLL_IN PLL_CLK_SRC
/*********************
//<o> PLL MUL
**********************/
#define PLL_MUL 60
/*********************
//<o> PLL DIV
**********************/
#define PLL_DIV 1
/*********************
//</e>
**********************/
#if PLL_MUL < 15
#error "PLL MUL Need 15~78"
#endif
#if PLL_MUL > 78
#error "PLL MUL Need 15~78"
#endif

#if PLL_DIV < 1
#error "PLL DIV Need 1~8"
#endif

/*********************
//<o>AHB CLOCK (HCLK)
//    <0=>FCLK/1
//    <1=>FCLK/2
//    <2=>FCLK/4
//    <3=>FCLK/8
//    <4=>FCLK/16
//    <5=>FCLK/32
**********************/
#define CLK_AHB 0

/*********************
//<o>APB1 CLOCK
//    <0=>HCLK/1
//    <4=>HCLK/2
//    <5=>HCLK/4
//    <6=>HCLK/8
//    <7=>HCLK/16
**********************/
#define CLK_APB1 5

/*********************
//<o>APB2 CLOCK
//    <0=>HCLK/1
//    <4=>HCLK/2
//    <5=>HCLK/4
//    <6=>HCLK/8
//    <7=>HCLK/16
**********************/
#define CLK_APB2 4

/*********************
//<o>FLASH Latency
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
**********************/
#define FLASH_LATENCY 3
/*********************
//<q> FLASH Prefetch
**********************/
#define PREFETCH_EN 1
/*********************
//<q> FLASH Instruction Cache
**********************/
#define ICACHE_EN 1
/*********************
//<q> FLASH Data Cache
**********************/
#define DCACHE_EN 1

/***********************
//</e>
************************/


#if  (CLK_SRC == 0)
#define CLK_HZ   HSI_CLK
#elif (CLK_SRC == 1)
#define CLK_HZ   HSE_CLK
#else
#if (PLL_EN == 0)
#error ("System Clock Source is PLL, so PLL must enable")
#endif
#if (PLL_CLK_SRC == 0)
#define CLK_HZ   HSI_CLK
#else
#define CLK_HZ   HSE_CLK
#endif
#endif


#if PLL_EN
#define SYS_CLK  ((CLK_HZ/(PLL_XTPRE+1) * PLL_MUL / PLL_DIV / 2)/(1<<CLK_AHB))
#else
#define SYS_CLK  CLK_HZ/(1<<CLK_AHB)
#endif



#if SYS_CLK > 35000000  && FLASH_LATENCY < 1
#error ("Flash Latency need >= 1")
#endif
#if SYS_CLK > 70000000  && FLASH_LATENCY < 2
#error ("Flash Latency need >= 2")
#endif
#if SYS_CLK > 110000000  && FLASH_LATENCY < 3
#error ("Flash Latency need >= 3")
#endif
#if SYS_CLK > 150000000  && FLASH_LATENCY < 4
#error ("Flash Latency need >= 4")
#endif
#if SYS_CLK > 180000000  && FLASH_LATENCY < 5
#error ("Flash Latency need >= 5")
#endif


#if (CLK_AHB == 0)
#define AHB_F 1
#elif (CLK_AHB == 1)
#define AHB_F 2
#elif (CLK_AHB == 2)
#define AHB_F 4
#elif (CLK_AHB == 3)
#define AHB_F 8
#elif (CLK_AHB == 4)
#define AHB_F 16
#elif (CLK_AHB == 5)
#define AHB_F 32
#endif

#if (CLK_APB1 == 4)
#define APB1_F 2
#elif (CLK_APB1 == 0)
#define APB1_F 1
#elif (CLK_APB1 == 5)
#define APB1_F 4
#elif (CLK_APB1 == 6)
#define APB1_F 8
#elif (CLK_APB1 == 7)
#define APB1_F 16
#endif

#if (CLK_APB2 == 4)
#define APB2_F 2
#elif (CLK_APB2 == 0)
#define APB2_F 1
#elif (CLK_APB2 == 5)
#define APB2_F 4
#elif (CLK_APB2 == 6)
#define APB2_F 8
#elif (CLK_APB2 == 7)
#define APB2_F 16
#endif

//<e>NVIC
#define CFG_PRI_EN 0

//<e>SysTick
#define CFG_SYSTICK_EN	0
// <o1>SysTickʼֵ <0-0xFFFFFF>
// <o2>SysTickֵ(us) <0-100000000>
// <o3>SysTickʱѡ
//    <0=>ⲿοʱHCLK/8
//    <1=>ںʱHCLK
// <q0>SysTickжʹλ
// <q4>SysTickϵʼʱ

#define CFG_SYSTICK_INT_EN 0x0	
#define CFG_SYSTICK_VAL_INIT 0x0
#define CFG_SYSTICK_RL_VALUE 1000
#define CFG_SYSTICK_CR_CLK 0x1	
#define CFG_SYSTICK_START_EN 0x1	


#if CFG_SYSTICK_CR_CLK
#define CFG_SYSTICK_CLK SYS_CLK
#else
#define CFG_SYSTICK_CLK SYS_CLK/8
#endif
#define CFG_SYSTICK_LOAD_INIT ((unsigned long)(CFG_SYSTICK_RL_VALUE*(CFG_SYSTICK_CLK/1000000.0)))
//</e>


//<o0.8..10>жȼλ
//<i>PRIGROUP ȼвǿռʽȼ
//<0=>4λռʽȼ, 0λȼ
//<4=>3λռʽȼ, 1λȼ
//<5=>2λռʽȼ, 2λȼ
//<6=>1λռʽȼ, 3λȼ
//<7=>0λռʽȼ, 4λȼ
#define CFG_SCB_PRIGROUP_INIT 0

//<h>жȼ
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.4..7>PRI_4 洢 fault ȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.12..15>PRI_5  fault ȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>PRI_6 ÷ fault ȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_SCB_SHP0_INIT 0x0

//<o0.28..31>PRI_11 SVC ȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

#define CFG_SCB_SHP1_INIT 0x0

//<o0.4..7>PRI_12 Լȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>PRI_14 PendSV ȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.28..31>PRI_15 SysTick ȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

#define CFG_SCB_SHP2_INIT 0x0

                                           
//<o0.4..7>HWINT_0 WWDTжϵȼ <0-15>  
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.12..15>HWINT_1 BODжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_NVIC_IP0_INIT 0x0

                                           
//<o0.4..7>		HWINT_4 RCCжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.12..15>	HWINT_5 EXTI0жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>	HWINT_6 EXTI1жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.28..31>	HWINT_7 EXTI2жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

#define CFG_NVIC_IP1_INIT 0x00


//<o0.4..7>		HWINT_8 EXTI3жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.12..15>	HWINT_9 EXTI4жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>	HWINT_10 DMA_CH0жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.28..31>	HWINT_11 DMA_CH1жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_NVIC_IP2_INIT 0x0


//<o0.4..7>		HWINT_12 DMA_CH2_7жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.12..15>	HWINT_13 MCM1_FLTжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>	HWINT_14 MCM1_PWMжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.28..31>	HWINT_15 MCM2_FLTжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_NVIC_IP3_INIT 0x0


//<o0.4..7>		HWINT_16 MCM2_PWMжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.12..15>	HWINT_17 ADC1жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>	HWINT_18 ADC2жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.28..31>	HWINT_19 ADC3жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_NVIC_IP4_INIT 0x0


//<o0.20..23>	HWINT_22 GPT0_GTCIVжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.28..31>	HWINT_23 GPT0_GTCINжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_NVIC_IP5_INIT 0x0

//<o0.4..7>		HWINT_24 GPT1_GTCIVжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.12..15>	HWINT_25 GPT1_GTCINжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>	HWINT_26 GPT2_GTCIVжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.28..31>	HWINT_27 GPT2_GTCINжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_NVIC_IP6_INIT 0x0

//<o0.4..7>		HWINT_28 GPT3_GTCIVжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.12..15>	HWINT_29 GPT3_GTCINжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>	HWINT_30 GPT_POEжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.28..31>	HWINT_31 EXTI9_5жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_NVIC_IP7_INIT 0x0

//<o0.4..7>		HWINT_32 CMP1жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.12..15>	HWINT_33 CMP2жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>	HWINT_34 CMP3жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.28..31>	HWINT_35 QEIжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_NVIC_IP8_INIT 0x0

//<o0.4..7>		HWINT_36 TWIжϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>	HWINT_38 SPI1жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.28..31>	HWINT_39 SPI2жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_NVIC_IP9_INIT 0x0

//<o0.4..7>		HWINT_40 UART1жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.12..15>	HWINT_41 UART2жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

//<o0.20..23>	HWINT_42 UART3жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ

#define CFG_NVIC_IP10_INIT 0x0


//<o0.4..7>		HWINT_44 EXTI15_10жϵȼ <0-15> 
//<i>4BitȼΧ0-16
//<i>ѡ4λռʽȼ, 0λȼ4Bitݱʾ16ռȼ
//<i>3λռʽȼ, 1λȼ3Bitݱʾ8ռȼ1bitʾ2ȼ
//<i>2λռʽȼ, 2λȼ2Bitݱʾ4ռȼ2bitʾ4ȼ
//<i>1λռʽȼ, 3λȼ1Bitݱʾ2ռȼ3bitʾ8ȼ
//<i>0λռʽȼ, 4λȼ4bitʾ16ȼ
#define CFG_NVIC_IP11_INIT 0x0
//</h>

//</e>

//<e>IWDT
#define CFG_IWDT_EN	0
// <q0.15> IWDTON_Źʹ
//    0:
//    1:IWDT
//<i>CR_ŹƼĴ
//<i>0x000 b31~16 b15    b14~12 b11~0   
//<i>CR    LOCK   IWDTON IWDTPR IWDTRLR 
//<i>˿λֻOP_IWDT=0101bʱЧ
//<i>˿λĿͨOptionرտŹͨʽ򿪡
//<i>λá1Ӳڸλ塯0
// <o0.0..11> IWDTRLR_ŹؼĴ<0-4096>
//    ڶ忴Źװֵ 
#define CFG_IWDTRLR_INIT	0x8FFF
// <o0.12..14> IWDTPR_Źʱ
//<0=>ֵ128ms
//<1=>ֵ256ms
//<2=>ֵ512ms
//<3=>ֵ1.024s (Ĭ)
//<4=>ֵ2.048s
//<5=>ֵ4.096s 
//<6=>ֵ8.192s
//<7=>ֵ16.384s
//<i>IWDTPR[2:0]ϵĬֵ011b
#define CFG_IWDTPR_INIT	0x3000

//***********************************************************/
//</e>

//<e>WWDT
#define CFG_WWDT_EN	0
//<h>CR_ڿŹƼĴ
//<i>0x000 b31~16 b15    b14    b13~11 b10~8  b7~0    
//<i>CR    LOCK   WWDTON WWDTIE -      WWDTPR WWDTRLR 
// <o0.0..7> WWDTRLR_ڿŹؼĴ<0-255>
//    ڶ忴Źװֵ
// <o0.8..10> WWDTPR_ڿŹʱԤƵ
//    <0=>ԤƵ=1x256
//    <1=>ԤƵ=2x256
//    <2=>ԤƵ=4x256
//    <3=>ԤƵ=8x256
//    <4=>ԤƵ=16x256
//    <5=>ԤƵ=32x256
//    <6=>ԤƵ=64x256
//    <7=>ԤƵ=128x256
// <q0.14> WWDTIE_ڿŹιжʹ
//    0: ֹWWDTж
//    1: WWDTж
// <q0.15> WWDTON_ڿŹʹ
//    0: ֹWWDT
//    1: WWDT
//<i>λá1Ӳڸλ塯0
//</h>
#define CFG_WWDT_CR_INIT	0x0000

#if ((CFG_WWDT_CR_INIT & (1<<14)) == 1)
	#define CFG_WWDT_INT_EN 1
#else
	#define CFG_WWDT_INT_EN 0
#endif

//<h>WTR_ڿŹڼĴ
//<i>0x00C b31~16 b15~8 b7~0    
//<i>WTR   LOCK   -     WWDTWTR 
// <o0.0..7> WWDTWTR_ڿŹֵĴ<0-255>
//    ڶ忴ŹĴֵ
//    üĴдֻLOCKλΪ0x5AA5ʱд룬ơ
//</h>
#define CFG_WWDT_WTR_INIT	0x0
//***********************************************************/
//</e>


//<e>GPIO
#define     CFG_GPIO_EN     0
//<e>GPIOA  
#define     CFG_GPIOA_EN     0
// <h> Pin0  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PA0_MODER   0
#define     CFG_PA0_OT      0
#define     CFG_PA0_ODR     0
#define     CFG_PA0_ODRVR   0
#define     CFG_PA0_PUPDR   0
#define     CFG_PA0_AFR     0
#define     CFG_PA0_LOCK    0
#define     CFG_PA0_EN      0

// <h> Pin1  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA1_MODER   0
#define     CFG_PA1_OT      0
#define     CFG_PA1_ODR     0
#define     CFG_PA1_ODRVR   0
#define     CFG_PA1_PUPDR   0
#define     CFG_PA1_AFR     0
#define     CFG_PA1_LOCK    0
#define     CFG_PA1_EN      0
// <h> Pin2  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> PA2_TTL/CMOSѡ
//    <0=> ѡCMOS
//    <1=> ѡTTL
// <o7> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PA2_MODER   0
#define     CFG_PA2_OT      0
#define     CFG_PA2_ODR     0
#define     CFG_PA2_ODRVR   0
#define     CFG_PA2_PUPDR   0
#define     CFG_PA2_AFR     0
#define     CFG_PA2_TTLEN   0
#define     CFG_PA2_LOCK    0


// <h> Pin3  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> PA3_TTL/CMOSѡ
//    <0=> ѡCMOS
//    <1=> ѡTTL
// <o7> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA3_MODER   0
#define     CFG_PA3_OT      0
#define     CFG_PA3_ODR     0
#define     CFG_PA3_ODRVR   0
#define     CFG_PA3_PUPDR   0
#define     CFG_PA3_AFR     0
#define     CFG_PA3_TTLEN   0
#define     CFG_PA3_LOCK    0

// <h> Pin4  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PA4_MODER   0
#define     CFG_PA4_OT      0
#define     CFG_PA4_ODR     0
#define     CFG_PA4_ODRVR   0
#define     CFG_PA4_PUPDR   0
#define     CFG_PA4_AFR     0
#define     CFG_PA4_LOCK    0

// <h> Pin5  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA5_MODER   0
#define     CFG_PA5_OT      0
#define     CFG_PA5_ODR     0
#define     CFG_PA5_ODRVR   0
#define     CFG_PA5_PUPDR   0
#define     CFG_PA5_AFR     0
#define     CFG_PA5_LOCK    0

// <h> Pin6  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PA6_MODER   0
#define     CFG_PA6_OT      0
#define     CFG_PA6_ODR     0
#define     CFG_PA6_ODRVR   0
#define     CFG_PA6_PUPDR   0
#define     CFG_PA6_AFR     0
#define     CFG_PA6_LOCK    0


// <h> Pin7  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA7_MODER   0
#define     CFG_PA7_OT      0
#define     CFG_PA7_ODR     0
#define     CFG_PA7_ODRVR   0
#define     CFG_PA7_PUPDR   0
#define     CFG_PA7_AFR     0
#define     CFG_PA7_LOCK    0

// <h>Pin8  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> PA8_TTL/CMOSѡ
//    <0=> ѡCMOS
//    <1=> ѡTTL
// <o7> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA8_MODER   0
#define     CFG_PA8_OT      0
#define     CFG_PA8_ODR     0
#define     CFG_PA8_ODRVR   0
#define     CFG_PA8_PUPDR   0
#define     CFG_PA8_AFR     0
#define     CFG_PA8_TTLEN   0
#define     CFG_PA8_LOCK    0

// <h> Pin9  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA9_MODER   0
#define     CFG_PA9_OT      0
#define     CFG_PA9_ODR     0
#define     CFG_PA9_ODRVR   0
#define     CFG_PA9_PUPDR   0
#define     CFG_PA9_AFR     0
#define     CFG_PA9_LOCK    0

// <h> Pin10  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA10_MODER   0
#define     CFG_PA10_OT      0
#define     CFG_PA10_ODR     0
#define     CFG_PA10_ODRVR   0
#define     CFG_PA10_PUPDR   0
#define     CFG_PA10_AFR     0
#define     CFG_PA10_LOCK    0

// <h>Pin11  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> PA11_TTL/CMOSѡ
//    <0=> ѡCMOS
//    <1=> ѡTTL
// <o7> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA11_MODER   0
#define     CFG_PA11_OT      0
#define     CFG_PA11_ODR     0
#define     CFG_PA11_ODRVR   0
#define     CFG_PA11_PUPDR   0
#define     CFG_PA11_AFR     0
#define     CFG_PA11_TTLEN   0
#define     CFG_PA11_LOCK    0

// <h> Pin12  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA12_MODER   0
#define     CFG_PA12_OT      0
#define     CFG_PA12_ODR     0
#define     CFG_PA12_ODRVR   0
#define     CFG_PA12_PUPDR   0
#define     CFG_PA12_AFR     0
#define     CFG_PA12_LOCK    0

// <h> Pin13  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA13_MODER   0
#define     CFG_PA13_OT      0
#define     CFG_PA13_ODR     0
#define     CFG_PA13_ODRVR   0
#define     CFG_PA13_PUPDR   0
#define     CFG_PA13_AFR     0
#define     CFG_PA13_LOCK    0

// <h> Pin14  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA14_MODER   0
#define     CFG_PA14_OT      0
#define     CFG_PA14_ODR     0
#define     CFG_PA14_ODRVR   0
#define     CFG_PA14_PUPDR   0
#define     CFG_PA14_AFR     0
#define     CFG_PA14_LOCK    0

// <h> Pin15  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PA15_MODER   0
#define     CFG_PA15_OT      0
#define     CFG_PA15_ODR     0
#define     CFG_PA15_ODRVR   0
#define     CFG_PA15_PUPDR   0
#define     CFG_PA15_AFR     0
#define     CFG_PA15_LOCK    0

//</e>

#define CFG_GPIO_OTYPER_A_INIT     (((uint32_t)CFG_PA15_OT<<15)\
																		|(CFG_PA14_OT<<14)\
																		|(CFG_PA13_OT<<13)\
																		|(CFG_PA12_OT<<12)\
																		|(CFG_PA11_OT<<11)\
																		|(CFG_PA10_OT<<10)\
																		|(CFG_PA9_OT<<9)\
																		|(CFG_PA8_OT<<8)\
																		|(CFG_PA7_OT<<7)\
																		|(CFG_PA6_OT<<6)\
																		|(CFG_PA5_OT<<5)\
																		|(CFG_PA4_OT<<4)\
																		|(CFG_PA3_OT<<3)\
																		|(CFG_PA2_OT<<2)\
																		|(CFG_PA1_OT<<1)\
																		|CFG_PA0_OT)
																	
#define CFG_GPIO_ODRVR_A_INIT     	(((uint32_t)CFG_PA15_ODRVR<<30)\
																		|(CFG_PA14_ODRVR<<28)\
																		|(CFG_PA13_ODRVR<<26)\
																		|(CFG_PA12_ODRVR<<24)\
																		|(CFG_PA11_ODRVR<<22)\
																		|(CFG_PA10_ODRVR<<20)\
																		|(CFG_PA9_ODRVR<<18)\
																		|(CFG_PA8_ODRVR<<16)\
																		|(CFG_PA7_ODRVR<<14)\
																		|(CFG_PA6_ODRVR<<12)\
																		|(CFG_PA5_ODRVR<<10)\
																		|(CFG_PA4_ODRVR<<8)\
																		|(CFG_PA3_ODRVR<<6)\
																		|(CFG_PA2_ODRVR<<4)\
																		|(CFG_PA1_ODRVR<<2)\
																		|CFG_PA0_ODRVR)
																		
#define CFG_GPIO_PUPDR_A_INIT     	(((uint32_t)CFG_PA15_PUPDR<<30)\
																		|(CFG_PA14_PUPDR<<28)\
																		|(CFG_PA13_PUPDR<<26)\
																		|(CFG_PA12_PUPDR<<24)\
																		|(CFG_PA11_PUPDR<<22)\
																		|(CFG_PA10_PUPDR<<20)\
																		|(CFG_PA9_PUPDR<<18)\
																		|(CFG_PA8_PUPDR<<16)\
																		|(CFG_PA7_PUPDR<<14)\
																		|(CFG_PA6_PUPDR<<12)\
																		|(CFG_PA5_PUPDR<<10)\
																		|(CFG_PA4_PUPDR<<8)\
																		|(CFG_PA3_PUPDR<<6)\
																		|(CFG_PA2_PUPDR<<4)\
																		|(CFG_PA1_PUPDR<<2)\
																		|CFG_PA0_PUPDR)
																		
#define CFG_GPIO_AFRH_A_INIT     		(((uint32_t)CFG_PA15_AFR<<28)\
																		|(CFG_PA14_AFR<<24)\
																		|(CFG_PA13_AFR<<20)\
																		|(CFG_PA12_AFR<<16)\
																		|(CFG_PA11_AFR<<12)\
																		|(CFG_PA10_AFR<<8)\
																		|(CFG_PA9_AFR<<4)\
																		|CFG_PA8_AFR)
															
#define CFG_GPIO_AFRL_A_INIT				(((uint32_t)CFG_PA7_AFR<<28)\
																		|(CFG_PA6_AFR<<24)\
																		|(CFG_PA5_AFR<<20)\
																		|(CFG_PA4_AFR<<16)\
																		|(CFG_PA3_AFR<<12)\
																		|(CFG_PA2_AFR<<8)\
																		|(CFG_PA1_AFR<<4)\
																		|CFG_PA0_AFR)																		
																		
#define CFG_GPIO_ODR_A_INIT         (((uint32_t)CFG_PA15_ODR<<15)\
																		|(CFG_PA14_ODR<<14)\
																		|(CFG_PA13_ODR<<13)\
																		|(CFG_PA12_ODR<<12)\
																		|(CFG_PA11_ODR<<11)\
																		|(CFG_PA10_ODR<<10)\
																		|(CFG_PA9_ODR<<9)\
																		|(CFG_PA8_ODR<<8)\
																		|(CFG_PA7_ODR<<7)\
																		|(CFG_PA6_ODR<<6)\
																		|(CFG_PA5_ODR<<5)\
																		|(CFG_PA4_ODR<<4)\
																		|(CFG_PA3_ODR<<3)\
																		|(CFG_PA2_ODR<<2)\
																		|(CFG_PA1_ODR<<1)\
																		|CFG_PA0_ODR)																		
																		
#define CFG_GPIO_MODER_A_INIT     	(((uint32_t)CFG_PA15_MODER<<15)\
																		|(CFG_PA14_MODER<<14)\
																		|(CFG_PA13_MODER<<13)\
																		|(CFG_PA12_MODER<<12)\
																		|(CFG_PA11_MODER<<11)\
																		|(CFG_PA10_MODER<<10)\
																		|(CFG_PA9_MODER<<9)\
																		|(CFG_PA8_MODER<<8)\
																		|(CFG_PA7_MODER<<7)\
																		|(CFG_PA6_MODER<<6)\
																		|(CFG_PA5_MODER<<5)\
																		|(CFG_PA4_MODER<<4)\
																		|(CFG_PA3_MODER<<3)\
																		|(CFG_PA2_MODER<<2)\
																		|(CFG_PA1_MODER<<1)\
																		|CFG_PA0_MODER)	
																		
#define CFG_GPIO_TTLEN_A_INIT     	(((uint32_t)CFG_PA11_TTLEN<<11)\
																		|(CFG_PA8_TTLEN<<8)\
																		|(CFG_PA3_TTLEN<<3)\
																		|(CFG_PA2_TTLEN<<2))																		

#define CFG_GPIO_LCKR_A_INIT     	  (((uint32_t)CFG_PA15_LOCK<<15)\
																		|(CFG_PA14_LOCK<<14)\
																		|(CFG_PA13_LOCK<<13)\
																		|(CFG_PA12_LOCK<<12)\
																		|(CFG_PA11_LOCK<<11)\
																		|(CFG_PA10_LOCK<<10)\
																		|(CFG_PA9_LOCK<<9)\
																		|(CFG_PA8_LOCK<<8)\
																		|(CFG_PA7_LOCK<<7)\
																		|(CFG_PA6_LOCK<<6)\
																		|(CFG_PA5_LOCK<<5)\
																		|(CFG_PA4_LOCK<<4)\
																		|(CFG_PA3_LOCK<<3)\
																		|(CFG_PA2_LOCK<<2)\
																		|(CFG_PA1_LOCK<<1)\
																		|CFG_PA0_LOCK)	
																		
//<e>GPIOB  
#define     CFG_GPIOB_EN     0
// <h>Pin0  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> PB0_TTL/CMOSѡ
//    <0=> ѡCMOS
//    <1=> ѡTTL
// <o7> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PB0_MODER   0
#define     CFG_PB0_OT      0
#define     CFG_PB0_ODR     0
#define     CFG_PB0_ODRVR   0
#define     CFG_PB0_PUPDR   0
#define     CFG_PB0_AFR     0
#define     CFG_PB0_TTLEN   0
#define     CFG_PB0_LOCK    0

// <h>Pin1  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> PB1_TTL/CMOSѡ
//    <0=> ѡCMOS
//    <1=> ѡTTL
// <o7> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB1_MODER   0
#define     CFG_PB1_OT      0
#define     CFG_PB1_ODR     0
#define     CFG_PB1_ODRVR   0
#define     CFG_PB1_PUPDR   0
#define     CFG_PB1_AFR     0
#define     CFG_PB1_TTLEN   0
#define     CFG_PB1_LOCK    0

// <h> Pin2  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PB2_MODER   0
#define     CFG_PB2_OT      0
#define     CFG_PB2_ODR     0
#define     CFG_PB2_ODRVR   0
#define     CFG_PB2_PUPDR   0
#define     CFG_PB2_AFR     0
#define     CFG_PB2_LOCK    0

// <h> Pin3  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB3_MODER   0
#define     CFG_PB3_OT      0
#define     CFG_PB3_ODR     0
#define     CFG_PB3_ODRVR   0
#define     CFG_PB3_PUPDR   0
#define     CFG_PB3_AFR     0
#define     CFG_PB3_LOCK    0

// <h>Pin4  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <15=>AF15_Closed
// <o6> PB4_TTL/CMOSѡ
//    <0=> ѡCMOS
//    <1=> ѡTTL
// <o7> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PB4_MODER   0
#define     CFG_PB4_OT      0
#define     CFG_PB4_ODR     0
#define     CFG_PB4_ODRVR   0
#define     CFG_PB4_PUPDR   0
#define     CFG_PB4_AFR     0
#define     CFG_PB4_TTLEN   0
#define     CFG_PB4_LOCK    0

// <h>Pin5  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <15=>AF15_Closed
// <o6> PB5_TTL/CMOSѡ
//    <0=> ѡCMOS
//    <1=> ѡTTL
// <o7> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB5_MODER   0
#define     CFG_PB5_OT      0
#define     CFG_PB5_ODR     0
#define     CFG_PB5_ODRVR   0
#define     CFG_PB5_PUPDR   0
#define     CFG_PB5_AFR     0
#define     CFG_PB5_TTLEN   0
#define     CFG_PB5_LOCK    0
// <h> Pin6  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PB6_MODER   0
#define     CFG_PB6_OT      0
#define     CFG_PB6_ODR     0
#define     CFG_PB6_ODRVR   0
#define     CFG_PB6_PUPDR   0
#define     CFG_PB6_AFR     0
#define     CFG_PB6_LOCK    0

// <h> Pin7  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB7_MODER   0
#define     CFG_PB7_OT      0
#define     CFG_PB7_ODR     0
#define     CFG_PB7_ODRVR   0
#define     CFG_PB7_PUPDR   0
#define     CFG_PB7_AFR     0
#define     CFG_PB7_LOCK    0

// <h> Pin8  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB8_MODER   0
#define     CFG_PB8_OT      0
#define     CFG_PB8_ODR     0
#define     CFG_PB8_ODRVR   0
#define     CFG_PB8_PUPDR   0
#define     CFG_PB8_AFR     0
#define     CFG_PB8_LOCK    0

// <h> Pin9  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB9_MODER   0
#define     CFG_PB9_OT      0
#define     CFG_PB9_ODR     0
#define     CFG_PB9_ODRVR   0
#define     CFG_PB9_PUPDR   0
#define     CFG_PB9_AFR     0
#define     CFG_PB9_LOCK    0

// <h> Pin10  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB10_MODER   0
#define     CFG_PB10_OT      0
#define     CFG_PB10_ODR     0
#define     CFG_PB10_ODRVR   0
#define     CFG_PB10_PUPDR   0
#define     CFG_PB10_AFR     0
#define     CFG_PB10_LOCK    0

// <h> Pin11  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB11_MODER   0
#define     CFG_PB11_OT      0
#define     CFG_PB11_ODR     0
#define     CFG_PB11_ODRVR   0
#define     CFG_PB11_PUPDR   0
#define     CFG_PB11_AFR     0
#define     CFG_PB11_LOCK    0

// <h> Pin12  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB12_MODER   0
#define     CFG_PB12_OT      0
#define     CFG_PB12_ODR     0
#define     CFG_PB12_ODRVR   0
#define     CFG_PB12_PUPDR   0
#define     CFG_PB12_AFR     0
#define     CFG_PB12_LOCK    0

// <h> Pin13  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB13_MODER   0
#define     CFG_PB13_OT      0
#define     CFG_PB13_ODR     0
#define     CFG_PB13_ODRVR   0
#define     CFG_PB13_PUPDR   0
#define     CFG_PB13_AFR     0
#define     CFG_PB13_LOCK    0

// <h> Pin14  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB14_MODER   0
#define     CFG_PB14_OT      0
#define     CFG_PB14_ODR     0
#define     CFG_PB14_ODRVR   0
#define     CFG_PB14_PUPDR   0
#define     CFG_PB14_AFR     0
#define     CFG_PB14_LOCK    0

// <h> Pin15  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PB15_MODER   0
#define     CFG_PB15_OT      0
#define     CFG_PB15_ODR     0
#define     CFG_PB15_ODRVR   0
#define     CFG_PB15_PUPDR   0
#define     CFG_PB15_AFR     0
#define     CFG_PB15_LOCK    0

//</e>

#define CFG_GPIO_OTYPER_B_INIT      (((uint32_t)CFG_PB15_OT<<15)\
																		|(CFG_PB14_OT<<14)\
																		|(CFG_PB13_OT<<13)\
																		|(CFG_PB12_OT<<12)\
																		|(CFG_PB11_OT<<11)\
																		|(CFG_PB10_OT<<10)\
																		|(CFG_PB9_OT<<9)\
																		|(CFG_PB8_OT<<8)\
																		|(CFG_PB7_OT<<7)\
																		|(CFG_PB6_OT<<6)\
																		|(CFG_PB5_OT<<5)\
																		|(CFG_PB4_OT<<4)\
																		|(CFG_PB3_OT<<3)\
																		|(CFG_PB2_OT<<2)\
																		|(CFG_PB1_OT<<1)\
																		|CFG_PB0_OT)
																	
#define CFG_GPIO_ODRVR_B_INIT     	(((uint32_t)CFG_PB15_ODRVR<<30)\
																		|(CFG_PB14_ODRVR<<28)\
																		|(CFG_PB13_ODRVR<<26)\
																		|(CFG_PB12_ODRVR<<24)\
																		|(CFG_PB11_ODRVR<<22)\
																		|(CFG_PB10_ODRVR<<20)\
																		|(CFG_PB9_ODRVR<<18)\
																		|(CFG_PB8_ODRVR<<16)\
																		|(CFG_PB7_ODRVR<<14)\
																		|(CFG_PB6_ODRVR<<12)\
																		|(CFG_PB5_ODRVR<<10)\
																		|(CFG_PB4_ODRVR<<8)\
																		|(CFG_PB3_ODRVR<<6)\
																		|(CFG_PB2_ODRVR<<4)\
																		|(CFG_PB1_ODRVR<<2)\
																		|CFG_PB0_ODRVR)
																		
#define CFG_GPIO_PUPDR_B_INIT     	(((uint32_t)CFG_PB15_PUPDR<<30)\
																		|(CFG_PB14_PUPDR<<28)\
																		|(CFG_PB13_PUPDR<<26)\
																		|(CFG_PB12_PUPDR<<24)\
																		|(CFG_PB11_PUPDR<<22)\
																		|(CFG_PB10_PUPDR<<20)\
																		|(CFG_PB9_PUPDR<<18)\
																		|(CFG_PB8_PUPDR<<16)\
																		|(CFG_PB7_PUPDR<<14)\
																		|(CFG_PB6_PUPDR<<12)\
																		|(CFG_PB5_PUPDR<<10)\
																		|(CFG_PB4_PUPDR<<8)\
																		|(CFG_PB3_PUPDR<<6)\
																		|(CFG_PB2_PUPDR<<4)\
																		|(CFG_PB1_PUPDR<<2)\
																		|CFG_PB0_PUPDR)
																		
#define CFG_GPIO_AFRH_B_INIT     		(((uint32_t)CFG_PB15_AFR<<28)\
																		|(CFG_PB14_AFR<<24)\
																		|(CFG_PB13_AFR<<20)\
																		|(CFG_PB12_AFR<<16)\
																		|(CFG_PB11_AFR<<12)\
																		|(CFG_PB10_AFR<<8)\
																		|(CFG_PB9_AFR<<4)\
																		|CFG_PB8_AFR)
															
#define CFG_GPIO_AFRL_B_INIT				(((uint32_t)CFG_PB7_AFR<<28)\
																		|(CFG_PB6_AFR<<24)\
																		|(CFG_PB5_AFR<<20)\
																		|(CFG_PB4_AFR<<16)\
																		|(CFG_PB3_AFR<<12)\
																		|(CFG_PB2_AFR<<8)\
																		|(CFG_PB1_AFR<<4)\
																		|CFG_PB0_AFR)																		
																		
#define CFG_GPIO_ODR_B_INIT     		(((uint32_t)CFG_PB15_ODR<<15)\
																		|(CFG_PB14_ODR<<14)\
																		|(CFG_PB13_ODR<<13)\
																		|(CFG_PB12_ODR<<12)\
																		|(CFG_PB11_ODR<<11)\
																		|(CFG_PB10_ODR<<10)\
																		|(CFG_PB9_ODR<<9)\
																		|(CFG_PB8_ODR<<8)\
																		|(CFG_PB7_ODR<<7)\
																		|(CFG_PB6_ODR<<6)\
																		|(CFG_PB5_ODR<<5)\
																		|(CFG_PB4_ODR<<4)\
																		|(CFG_PB3_ODR<<3)\
																		|(CFG_PB2_ODR<<2)\
																		|(CFG_PB1_ODR<<1)\
																		|CFG_PB0_ODR)																		
																		
#define CFG_GPIO_MODER_B_INIT     	(((uint32_t)CFG_PB15_MODER<<15)\
																		|(CFG_PB14_MODER<<14)\
																		|(CFG_PB13_MODER<<13)\
																		|(CFG_PB12_MODER<<12)\
																		|(CFG_PB11_MODER<<11)\
																		|(CFG_PB10_MODER<<10)\
																		|(CFG_PB9_MODER<<9)\
																		|(CFG_PB8_MODER<<8)\
																		|(CFG_PB7_MODER<<7)\
																		|(CFG_PB6_MODER<<6)\
																		|(CFG_PB5_MODER<<5)\
																		|(CFG_PB4_MODER<<4)\
																		|(CFG_PB3_MODER<<3)\
																		|(CFG_PB2_MODER<<2)\
																		|(CFG_PB1_MODER<<1)\
																		|CFG_PB0_MODER)	

#define CFG_GPIO_TTLEN_B_INIT     	(((uint32_t)CFG_PB5_TTLEN<<5)\
																		|(CFG_PB4_TTLEN<<4)\
																		|(CFG_PB1_TTLEN<<1)\
																		|CFG_PB0_TTLEN)
																		
#define CFG_GPIO_LCKR_B_INIT     	  (((uint32_t)CFG_PB15_LOCK<<15)\
																		|(CFG_PB14_LOCK<<14)\
																		|(CFG_PB13_LOCK<<13)\
																		|(CFG_PB12_LOCK<<12)\
																		|(CFG_PB11_LOCK<<11)\
																		|(CFG_PB10_LOCK<<10)\
																		|(CFG_PB9_LOCK<<9)\
																		|(CFG_PB8_LOCK<<8)\
																		|(CFG_PB7_LOCK<<7)\
																		|(CFG_PB6_LOCK<<6)\
																		|(CFG_PB5_LOCK<<5)\
																		|(CFG_PB4_LOCK<<4)\
																		|(CFG_PB3_LOCK<<3)\
																		|(CFG_PB2_LOCK<<2)\
																		|(CFG_PB1_LOCK<<1)\
																		|CFG_PB0_LOCK)												
	
//<e>GPIOC  
#define     CFG_GPIOC_EN     0
// <h> Pin0  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PC0_MODER   0
#define     CFG_PC0_OT      0
#define     CFG_PC0_ODR     0
#define     CFG_PC0_ODRVR   0
#define     CFG_PC0_PUPDR   0
#define     CFG_PC0_AFR     0
#define     CFG_PC0_LOCK    0

// <h> Pin1  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC1_MODER   0
#define     CFG_PC1_OT      0
#define     CFG_PC1_ODR     0
#define     CFG_PC1_ODRVR   0
#define     CFG_PC1_PUPDR   0
#define     CFG_PC1_AFR     0
#define     CFG_PC1_LOCK    0

// <h> Pin2  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PC2_MODER   0
#define     CFG_PC2_OT      0
#define     CFG_PC2_ODR     0
#define     CFG_PC2_ODRVR   0
#define     CFG_PC2_PUPDR   0
#define     CFG_PC2_AFR     0
#define     CFG_PC2_LOCK    0

// <h> Pin3  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC3_MODER   0
#define     CFG_PC3_OT      0
#define     CFG_PC3_ODR     0
#define     CFG_PC3_ODRVR   0
#define     CFG_PC3_PUPDR   0
#define     CFG_PC3_AFR     0
#define     CFG_PC3_LOCK    0

// <h> Pin4  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PC4_MODER   0
#define     CFG_PC4_OT      0
#define     CFG_PC4_ODR     0
#define     CFG_PC4_ODRVR   0
#define     CFG_PC4_PUPDR   0
#define     CFG_PC4_AFR     0
#define     CFG_PC4_LOCK    0

// <h> Pin5  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC5_MODER   0
#define     CFG_PC5_OT      0
#define     CFG_PC5_ODR     0
#define     CFG_PC5_ODRVR   0
#define     CFG_PC5_PUPDR   0
#define     CFG_PC5_AFR     0
#define     CFG_PC5_LOCK    0

// <h> Pin6  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PC6_MODER   0
#define     CFG_PC6_OT      0
#define     CFG_PC6_ODR     0
#define     CFG_PC6_ODRVR   0
#define     CFG_PC6_PUPDR   0
#define     CFG_PC6_AFR     0
#define     CFG_PC6_LOCK    0

// <h> Pin7  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC7_MODER   0
#define     CFG_PC7_OT      0
#define     CFG_PC7_ODR     0
#define     CFG_PC7_ODRVR   0
#define     CFG_PC7_PUPDR   0
#define     CFG_PC7_AFR     0
#define     CFG_PC7_LOCK    0

// <h> Pin8  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC8_MODER   0
#define     CFG_PC8_OT      0
#define     CFG_PC8_ODR     0
#define     CFG_PC8_ODRVR   0
#define     CFG_PC8_PUPDR   0
#define     CFG_PC8_AFR     0
#define     CFG_PC8_LOCK    0

// <h> Pin9  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC9_MODER   0
#define     CFG_PC9_OT      0
#define     CFG_PC9_ODR     0
#define     CFG_PC9_ODRVR   0
#define     CFG_PC9_PUPDR   0
#define     CFG_PC9_AFR     0
#define     CFG_PC9_LOCK    0

// <h> Pin10  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC10_MODER   	0
#define     CFG_PC10_OT      	0
#define     CFG_PC10_ODR     	0
#define     CFG_PC10_ODRVR   	0
#define     CFG_PC10_PUPDR   	0
#define     CFG_PC10_AFR			0
#define     CFG_PC10_LOCK     0

// <h> Pin11  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC11_MODER   0
#define     CFG_PC11_OT      0
#define     CFG_PC11_ODR     0
#define     CFG_PC11_ODRVR   0
#define     CFG_PC11_PUPDR   0
#define     CFG_PC11_AFR     0
#define     CFG_PC11_LOCK    0

// <h> Pin12  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC12_MODER		0
#define     CFG_PC12_OT				0
#define     CFG_PC12_ODR     	0
#define     CFG_PC12_ODRVR   	0
#define     CFG_PC12_PUPDR   	0
#define     CFG_PC12_AFR     	0
#define     CFG_PC12_LOCK     0

// <h> Pin13  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC13_MODER   	0
#define     CFG_PC13_OT      	0
#define     CFG_PC13_ODR     	0
#define     CFG_PC13_ODRVR   	0
#define     CFG_PC13_PUPDR   	0
#define     CFG_PC13_AFR     	0
#define     CFG_PC13_LOCK     0

// <h> Pin14  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC14_MODER   	0
#define     CFG_PC14_OT      	0
#define     CFG_PC14_ODR     	0
#define     CFG_PC14_ODRVR   	0
#define     CFG_PC14_PUPDR   	0
#define     CFG_PC14_AFR     	0
#define     CFG_PC14_LOCK     0

// <h> Pin15  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PC15_MODER   	0
#define     CFG_PC15_OT      	0
#define     CFG_PC15_ODR     	0
#define     CFG_PC15_ODRVR   	0
#define     CFG_PC15_PUPDR   	0
#define     CFG_PC15_AFR     	0
#define     CFG_PC15_LOCK     0

//</e>

#define CFG_GPIO_OTYPER_C_INIT      (((uint32_t)CFG_PC15_OT<<15)\
																		|(CFG_PC14_OT<<14)\
																		|(CFG_PC13_OT<<13)\
																		|(CFG_PC12_OT<<12)\
																		|(CFG_PC11_OT<<11)\
																		|(CFG_PC10_OT<<10)\
																		|(CFG_PC9_OT<<9)\
																		|(CFG_PC8_OT<<8)\
																		|(CFG_PC7_OT<<7)\
																		|(CFG_PC6_OT<<6)\
																		|(CFG_PC5_OT<<5)\
																		|(CFG_PC4_OT<<4)\
																		|(CFG_PC3_OT<<3)\
																		|(CFG_PC2_OT<<2)\
																		|(CFG_PC1_OT<<1)\
																		|CFG_PC0_OT)
																	
#define CFG_GPIO_ODRVR_C_INIT     	(((uint32_t)CFG_PC15_ODRVR<<30)\
																		|(CFG_PC14_ODRVR<<28)\
																		|(CFG_PC13_ODRVR<<26)\
																		|(CFG_PC12_ODRVR<<24)\
																		|(CFG_PC11_ODRVR<<22)\
																		|(CFG_PC10_ODRVR<<20)\
																		|(CFG_PC9_ODRVR<<18)\
																		|(CFG_PC8_ODRVR<<16)\
																		|(CFG_PC7_ODRVR<<14)\
																		|(CFG_PC6_ODRVR<<12)\
																		|(CFG_PC5_ODRVR<<10)\
																		|(CFG_PC4_ODRVR<<8)\
																		|(CFG_PC3_ODRVR<<6)\
																		|(CFG_PC2_ODRVR<<4)\
																		|(CFG_PC1_ODRVR<<2)\
																		|CFG_PC0_ODRVR)
																		
#define CFG_GPIO_PUPDR_C_INIT     	(((uint32_t)CFG_PC15_PUPDR<<30)\
																		|(CFG_PC14_PUPDR<<28)\
																		|(CFG_PC13_PUPDR<<26)\
																		|(CFG_PC12_PUPDR<<24)\
																		|(CFG_PC11_PUPDR<<22)\
																		|(CFG_PC10_PUPDR<<20)\
																		|(CFG_PC9_PUPDR<<18)\
																		|(CFG_PC8_PUPDR<<16)\
																		|(CFG_PC7_PUPDR<<14)\
																		|(CFG_PC6_PUPDR<<12)\
																		|(CFG_PC5_PUPDR<<10)\
																		|(CFG_PC4_PUPDR<<8)\
																		|(CFG_PC3_PUPDR<<6)\
																		|(CFG_PC2_PUPDR<<4)\
																		|(CFG_PC1_PUPDR<<2)\
																		|CFG_PC0_PUPDR)
																		
#define CFG_GPIO_AFRH_C_INIT     		(((uint32_t)CFG_PC15_AFR<<28)\
																		|(CFG_PC14_AFR<<24)\
																		|(CFG_PC13_AFR<<20)\
																		|(CFG_PC12_AFR<<16)\
																		|(CFG_PC11_AFR<<12)\
																		|(CFG_PC10_AFR<<8)\
																		|(CFG_PC9_AFR<<4)\
																		|CFG_PC8_AFR)
															
#define CFG_GPIO_AFRL_C_INIT				(((uint32_t)CFG_PC7_AFR<<28)\
																		|(CFG_PC6_AFR<<24)\
																		|(CFG_PC5_AFR<<20)\
																		|(CFG_PC4_AFR<<16)\
																		|(CFG_PC3_AFR<<12)\
																		|(CFG_PC2_AFR<<8)\
																		|(CFG_PC1_AFR<<4)\
																		|CFG_PC0_AFR)																		
																		
#define CFG_GPIO_ODR_C_INIT     		(((uint32_t)CFG_PC15_ODR<<15)\
																		|(CFG_PC14_ODR<<14)\
																		|(CFG_PC13_ODR<<13)\
																		|(CFG_PC12_ODR<<12)\
																		|(CFG_PC11_ODR<<11)\
																		|(CFG_PC10_ODR<<10)\
																		|(CFG_PC9_ODR<<9)\
																		|(CFG_PC8_ODR<<8)\
																		|(CFG_PC7_ODR<<7)\
																		|(CFG_PC6_ODR<<6)\
																		|(CFG_PC5_ODR<<5)\
																		|(CFG_PC4_ODR<<4)\
																		|(CFG_PC3_ODR<<3)\
																		|(CFG_PC2_ODR<<2)\
																		|(CFG_PC1_ODR<<1)\
																		|CFG_PC0_ODR)																		
																		
#define CFG_GPIO_MODER_C_INIT     	(((uint32_t)CFG_PC15_MODER<<15)\
																		|(CFG_PC14_MODER<<14)\
																		|(CFG_PC13_MODER<<13)\
																		|(CFG_PC12_MODER<<12)\
																		|(CFG_PC11_MODER<<11)\
																		|(CFG_PC10_MODER<<10)\
																		|(CFG_PC9_MODER<<9)\
																		|(CFG_PC8_MODER<<8)\
																		|(CFG_PC7_MODER<<7)\
																		|(CFG_PC6_MODER<<6)\
																		|(CFG_PC5_MODER<<5)\
																		|(CFG_PC4_MODER<<4)\
																		|(CFG_PC3_MODER<<3)\
																		|(CFG_PC2_MODER<<2)\
																		|(CFG_PC1_MODER<<1)\
																		|CFG_PC0_MODER)
																		
#define CFG_GPIO_LCKR_C_INIT     	  (((uint32_t)CFG_PC15_LOCK<<15)\
																		|(CFG_PC14_LOCK<<14)\
																		|(CFG_PC13_LOCK<<13)\
																		|(CFG_PC12_LOCK<<12)\
																		|(CFG_PC11_LOCK<<11)\
																		|(CFG_PC10_LOCK<<10)\
																		|(CFG_PC9_LOCK<<9)\
																		|(CFG_PC8_LOCK<<8)\
																		|(CFG_PC7_LOCK<<7)\
																		|(CFG_PC6_LOCK<<6)\
																		|(CFG_PC5_LOCK<<5)\
																		|(CFG_PC4_LOCK<<4)\
																		|(CFG_PC3_LOCK<<3)\
																		|(CFG_PC2_LOCK<<2)\
																		|(CFG_PC1_LOCK<<1)\
																		|CFG_PC0_LOCK)	


//<e>GPIOD 
#define     CFG_GPIOD_EN     0
// <h> Pin0  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PD0_MODER   0
#define     CFG_PD0_OT      0
#define     CFG_PD0_ODR     0
#define     CFG_PD0_ODRVR   0
#define     CFG_PD0_PUPDR   0
#define     CFG_PD0_AFR     0
#define     CFG_PD0_LOCK    0

// <h> Pin1  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD1_MODER   0
#define     CFG_PD1_OT      0
#define     CFG_PD1_ODR     0
#define     CFG_PD1_ODRVR   0
#define     CFG_PD1_PUPDR   0
#define     CFG_PD1_AFR     0
#define     CFG_PD1_LOCK    0

// <h> Pin2  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PD2_MODER   0
#define     CFG_PD2_OT      0
#define     CFG_PD2_ODR     0
#define     CFG_PD2_ODRVR   0
#define     CFG_PD2_PUPDR   0
#define     CFG_PD2_AFR     0
#define     CFG_PD2_LOCK    0

// <h> Pin3  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD3_MODER   0
#define     CFG_PD3_OT      0
#define     CFG_PD3_ODR     0
#define     CFG_PD3_ODRVR   0
#define     CFG_PD3_PUPDR   0
#define     CFG_PD3_AFR     0
#define     CFG_PD3_LOCK    0

// <h> Pin4  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PD4_MODER   0
#define     CFG_PD4_OT      0
#define     CFG_PD4_ODR     0
#define     CFG_PD4_ODRVR   0
#define     CFG_PD4_PUPDR   0
#define     CFG_PD4_AFR     0
#define     CFG_PD4_LOCK    0

// <h> Pin5  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD5_MODER   0
#define     CFG_PD5_OT      0
#define     CFG_PD5_ODR     0
#define     CFG_PD5_ODRVR   0
#define     CFG_PD5_PUPDR   0
#define     CFG_PD5_AFR     0
#define     CFG_PD5_LOCK    0

// <h> Pin6  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PD6_MODER   0
#define     CFG_PD6_OT      0
#define     CFG_PD6_ODR     0
#define     CFG_PD6_ODRVR   0
#define     CFG_PD6_PUPDR   0
#define     CFG_PD6_AFR     0
#define     CFG_PD6_LOCK    0

// <h> Pin7  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD7_MODER   0
#define     CFG_PD7_OT      0
#define     CFG_PD7_ODR     0
#define     CFG_PD7_ODRVR   0
#define     CFG_PD7_PUPDR   0
#define     CFG_PD7_AFR     0
#define     CFG_PD7_LOCK    0

// <h> Pin8  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD8_MODER   0
#define     CFG_PD8_OT      0
#define     CFG_PD8_ODR     0
#define     CFG_PD8_ODRVR   0
#define     CFG_PD8_PUPDR   0
#define     CFG_PD8_AFR     0
#define     CFG_PD8_LOCK    0

// <h> Pin9  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD9_MODER   0
#define     CFG_PD9_OT      0
#define     CFG_PD9_ODR     0
#define     CFG_PD9_ODRVR   0
#define     CFG_PD9_PUPDR   0
#define     CFG_PD9_AFR     0
#define     CFG_PD9_LOCK    0

// <h> Pin10  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD10_MODER   	0
#define     CFG_PD10_OT      	0
#define     CFG_PD10_ODR     	0
#define     CFG_PD10_ODRVR   	0
#define     CFG_PD10_PUPDR   	0
#define     CFG_PD10_AFR			0
#define     CFG_PD10_LOCK     0

// <h> Pin11  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD11_MODER   0
#define     CFG_PD11_OT      0
#define     CFG_PD11_ODR     0
#define     CFG_PD11_ODRVR   0
#define     CFG_PD11_PUPDR   0
#define     CFG_PD11_AFR     0
#define     CFG_PD11_LOCK    0

// <h> Pin12  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD12_MODER		0
#define     CFG_PD12_OT				0
#define     CFG_PD12_ODR     	0
#define     CFG_PD12_ODRVR   	0
#define     CFG_PD12_PUPDR   	0
#define     CFG_PD12_AFR     	0
#define     CFG_PD12_LOCK     0

// <h> Pin13  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD13_MODER   	0
#define     CFG_PD13_OT      	0
#define     CFG_PD13_ODR     	0
#define     CFG_PD13_ODRVR   	0
#define     CFG_PD13_PUPDR   	0
#define     CFG_PD13_AFR     	0
#define     CFG_PD13_LOCK     0

// <h> Pin14  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD14_MODER   	0
#define     CFG_PD14_OT      	0
#define     CFG_PD14_ODR     	0
#define     CFG_PD14_ODRVR   	0
#define     CFG_PD14_PUPDR   	0
#define     CFG_PD14_AFR     	0
#define     CFG_PD14_LOCK     0

// <h> Pin15  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PD15_MODER   	0
#define     CFG_PD15_OT      	0
#define     CFG_PD15_ODR     	0
#define     CFG_PD15_ODRVR   	0
#define     CFG_PD15_PUPDR   	0
#define     CFG_PD15_AFR     	0
#define     CFG_PD15_LOCK     0

//</e>

#define CFG_GPIO_OTYPER_D_INIT      (((uint32_t)CFG_PD15_OT<<15)\
																		|(CFG_PD14_OT<<14)\
																		|(CFG_PD13_OT<<13)\
																		|(CFG_PD12_OT<<12)\
																		|(CFG_PD11_OT<<11)\
																		|(CFG_PD10_OT<<10)\
																		|(CFG_PD9_OT<<9)\
																		|(CFG_PD8_OT<<8)\
																		|(CFG_PD7_OT<<7)\
																		|(CFG_PD6_OT<<6)\
																		|(CFG_PD5_OT<<5)\
																		|(CFG_PD4_OT<<4)\
																		|(CFG_PD3_OT<<3)\
																		|(CFG_PD2_OT<<2)\
																		|(CFG_PD1_OT<<1)\
																		|CFG_PD0_OT)
																	
#define CFG_GPIO_ODRVR_D_INIT     	(((uint32_t)CFG_PD15_ODRVR<<30)\
																		|(CFG_PD14_ODRVR<<28)\
																		|(CFG_PD13_ODRVR<<26)\
																		|(CFG_PD12_ODRVR<<24)\
																		|(CFG_PD11_ODRVR<<22)\
																		|(CFG_PD10_ODRVR<<20)\
																		|(CFG_PD9_ODRVR<<18)\
																		|(CFG_PD8_ODRVR<<16)\
																		|(CFG_PD7_ODRVR<<14)\
																		|(CFG_PD6_ODRVR<<12)\
																		|(CFG_PD5_ODRVR<<10)\
																		|(CFG_PD4_ODRVR<<8)\
																		|(CFG_PD3_ODRVR<<6)\
																		|(CFG_PD2_ODRVR<<4)\
																		|(CFG_PD1_ODRVR<<2)\
																		|CFG_PD0_ODRVR)
																		
#define CFG_GPIO_PUPDR_D_INIT     	(((uint32_t)CFG_PD15_PUPDR<<30)\
																		|(CFG_PD14_PUPDR<<28)\
																		|(CFG_PD13_PUPDR<<26)\
																		|(CFG_PD12_PUPDR<<24)\
																		|(CFG_PD11_PUPDR<<22)\
																		|(CFG_PD10_PUPDR<<20)\
																		|(CFG_PD9_PUPDR<<18)\
																		|(CFG_PD8_PUPDR<<16)\
																		|(CFG_PD7_PUPDR<<14)\
																		|(CFG_PD6_PUPDR<<12)\
																		|(CFG_PD5_PUPDR<<10)\
																		|(CFG_PD4_PUPDR<<8)\
																		|(CFG_PD3_PUPDR<<6)\
																		|(CFG_PD2_PUPDR<<4)\
																		|(CFG_PD1_PUPDR<<2)\
																		|CFG_PD0_PUPDR)
																		
#define CFG_GPIO_AFRH_D_INIT     		(((uint32_t)CFG_PD15_AFR<<28)\
																		|(CFG_PD14_AFR<<24)\
																		|(CFG_PD13_AFR<<20)\
																		|(CFG_PD12_AFR<<16)\
																		|(CFG_PD11_AFR<<12)\
																		|(CFG_PD10_AFR<<8)\
																		|(CFG_PD9_AFR<<4)\
																		|CFG_PD8_AFR)
															
#define CFG_GPIO_AFRL_D_INIT				(((uint32_t)CFG_PD7_AFR<<28)\
																		|(CFG_PD6_AFR<<24)\
																		|(CFG_PD5_AFR<<20)\
																		|(CFG_PD4_AFR<<16)\
																		|(CFG_PD3_AFR<<12)\
																		|(CFG_PD2_AFR<<8)\
																		|(CFG_PD1_AFR<<4)\
																		|CFG_PD0_AFR)																		
																		
#define CFG_GPIO_ODR_D_INIT     		(((uint32_t)CFG_PD15_ODR<<15)\
																		|(CFG_PD14_ODR<<14)\
																		|(CFG_PD13_ODR<<13)\
																		|(CFG_PD12_ODR<<12)\
																		|(CFG_PD11_ODR<<11)\
																		|(CFG_PD10_ODR<<10)\
																		|(CFG_PD9_ODR<<9)\
																		|(CFG_PD8_ODR<<8)\
																		|(CFG_PD7_ODR<<7)\
																		|(CFG_PD6_ODR<<6)\
																		|(CFG_PD5_ODR<<5)\
																		|(CFG_PD4_ODR<<4)\
																		|(CFG_PD3_ODR<<3)\
																		|(CFG_PD2_ODR<<2)\
																		|(CFG_PD1_ODR<<1)\
																		|CFG_PD0_ODR)																		
																		
#define CFG_GPIO_MODER_D_INIT     	(((uint32_t)CFG_PD15_MODER<<15)\
																		|(CFG_PD14_MODER<<14)\
																		|(CFG_PD13_MODER<<13)\
																		|(CFG_PD12_MODER<<12)\
																		|(CFG_PD11_MODER<<11)\
																		|(CFG_PD10_MODER<<10)\
																		|(CFG_PD9_MODER<<9)\
																		|(CFG_PD8_MODER<<8)\
																		|(CFG_PD7_MODER<<7)\
																		|(CFG_PD6_MODER<<6)\
																		|(CFG_PD5_MODER<<5)\
																		|(CFG_PD4_MODER<<4)\
																		|(CFG_PD3_MODER<<3)\
																		|(CFG_PD2_MODER<<2)\
																		|(CFG_PD1_MODER<<1)\
																		|CFG_PD0_MODER)	

#define CFG_GPIO_LCKR_D_INIT      	(((uint32_t)CFG_PD15_LOCK<<15)\
																		|(CFG_PD14_LOCK<<14)\
																		|(CFG_PD13_LOCK<<13)\
																		|(CFG_PD12_LOCK<<12)\
																		|(CFG_PD11_LOCK<<11)\
																		|(CFG_PD10_LOCK<<10)\
																		|(CFG_PD9_LOCK<<9)\
																		|(CFG_PD8_LOCK<<8)\
																		|(CFG_PD7_LOCK<<7)\
																		|(CFG_PD6_LOCK<<6)\
																		|(CFG_PD5_LOCK<<5)\
																		|(CFG_PD4_LOCK<<4)\
																		|(CFG_PD3_LOCK<<3)\
																		|(CFG_PD2_LOCK<<2)\
																		|(CFG_PD1_LOCK<<1)\
																		|CFG_PD0_LOCK)	

//<e>GPIOE  
#define     CFG_GPIOE_EN     0
// <h> Pin0  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PE0_MODER   0
#define     CFG_PE0_OT      0
#define     CFG_PE0_ODR     0
#define     CFG_PE0_ODRVR   0
#define     CFG_PE0_PUPDR   0
#define     CFG_PE0_AFR     0
#define     CFG_PE0_LOCK    0
#define     CFG_PE0_EN   		0


// <h> Pin1  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE1_MODER   0
#define     CFG_PE1_OT      0
#define     CFG_PE1_ODR     0
#define     CFG_PE1_ODRVR   0
#define     CFG_PE1_PUPDR   0
#define     CFG_PE1_AFR     0
#define     CFG_PE1_LOCK    0
#define     CFG_PE1_EN   		0
// <h> Pin2  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PE2_MODER   0
#define     CFG_PE2_OT      0
#define     CFG_PE2_ODR     0
#define     CFG_PE2_ODRVR   0
#define     CFG_PE2_PUPDR   0
#define     CFG_PE2_AFR     0
#define     CFG_PE2_LOCK    0


// <h> Pin3  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE3_MODER   0
#define     CFG_PE3_OT      0
#define     CFG_PE3_ODR     0
#define     CFG_PE3_ODRVR   0
#define     CFG_PE3_PUPDR   0
#define     CFG_PE3_AFR     0
#define     CFG_PE3_LOCK    0

// <h> Pin4  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PE4_MODER   0
#define     CFG_PE4_OT      0
#define     CFG_PE4_ODR     0
#define     CFG_PE4_ODRVR   0
#define     CFG_PE4_PUPDR   0
#define     CFG_PE4_AFR     0
#define     CFG_PE4_LOCK    0

// <h> Pin5  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE5_MODER   0
#define     CFG_PE5_OT      0
#define     CFG_PE5_ODR     0
#define     CFG_PE5_ODRVR   0
#define     CFG_PE5_PUPDR   0
#define     CFG_PE5_AFR     0
#define     CFG_PE5_LOCK    0

// <h> Pin6  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>

#define     CFG_PE6_MODER   0
#define     CFG_PE6_OT      0
#define     CFG_PE6_ODR     0
#define     CFG_PE6_ODRVR   0
#define     CFG_PE6_PUPDR   0
#define     CFG_PE6_AFR     0
#define     CFG_PE6_LOCK    0


// <h> Pin7  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <10=>AF10_ADTRGx_CPxOUT
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE7_MODER   0
#define     CFG_PE7_OT      0
#define     CFG_PE7_ODR     0
#define     CFG_PE7_ODRVR   0
#define     CFG_PE7_PUPDR   0
#define     CFG_PE7_AFR     0
#define     CFG_PE7_LOCK    0

// <h> Pin8  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE8_MODER   0
#define     CFG_PE8_OT      0
#define     CFG_PE8_ODR     0
#define     CFG_PE8_ODRVR   0
#define     CFG_PE8_PUPDR   0
#define     CFG_PE8_AFR     0
#define     CFG_PE8_LOCK    0

// <h> Pin9  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE9_MODER   0
#define     CFG_PE9_OT      0
#define     CFG_PE9_ODR     0
#define     CFG_PE9_ODRVR   0
#define     CFG_PE9_PUPDR   0
#define     CFG_PE9_AFR     0
#define     CFG_PE9_LOCK    0

// <h> Pin10  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE10_MODER   	0
#define     CFG_PE10_OT      	0
#define     CFG_PE10_ODR     	0
#define     CFG_PE10_ODRVR   	0
#define     CFG_PE10_PUPDR   	0
#define     CFG_PE10_AFR			0
#define     CFG_PE10_LOCK     0

// <h> Pin11  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE11_MODER   0
#define     CFG_PE11_OT      0
#define     CFG_PE11_ODR     0
#define     CFG_PE11_ODRVR   0
#define     CFG_PE11_PUPDR   0
#define     CFG_PE11_AFR     0
#define     CFG_PE11_LOCK    0

// <h> Pin12  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE12_MODER		0
#define     CFG_PE12_OT				0
#define     CFG_PE12_ODR     	0
#define     CFG_PE12_ODRVR   	0
#define     CFG_PE12_PUPDR   	0
#define     CFG_PE12_AFR     	0
#define     CFG_PE12_LOCK    	0

// <h> Pin13  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE13_MODER   	0
#define     CFG_PE13_OT      	0
#define     CFG_PE13_ODR     	0
#define     CFG_PE13_ODRVR   	0
#define     CFG_PE13_PUPDR   	0
#define     CFG_PE13_AFR     	0
#define     CFG_PE13_LOCK    	0

// <h> Pin14  
// <o0> MODER_˿ģʽ
//    <0=>
//    <1=> 
// <o1> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
// <o2> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o3> ODRVR_˿ 
//    <0=>ͨ״̬λ״̬
//    <1=>
//    <2=>
//    <3=>ǿ
// <o4> PUPDR_˿
//    <0=>λ״̬
//    <1=>
//    <2=>
//    <3=>ͬʱ
// <o5> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_GPIO
//    <1=>AF1_MCM1
//    <2=>AF2_MCM2
//    <3=>AF3_GPT0_GPT1_GPT2
//    <4=>AF4_GPT3
//    <5=>AF5_TIM
//    <6=>AF6_QEI
//    <7=>AF7_UART
//    <8=>AF8_SPI
//    <9=>AF9_TWI
//    <14=>AF14_Analog
//    <15=>AF15_Closed
// <o6> LCKy_˿Aλ
//    <0=>˿λδ
//    <1=>˿λ
// </h>
#define     CFG_PE14_MODER   	0
#define     CFG_PE14_OT      	0
#define     CFG_PE14_ODR     	0
#define     CFG_PE14_ODRVR   	0
#define     CFG_PE14_PUPDR   	0
#define     CFG_PE14_AFR     	0
#define     CFG_PE14_LOCK    	0

//</e>

#define CFG_GPIO_OTYPER_E_INIT      (((uint32_t)CFG_PE14_OT<<14)\
																		|(CFG_PE13_OT<<13)\
																		|(CFG_PE12_OT<<12)\
																		|(CFG_PE11_OT<<11)\
																		|(CFG_PE10_OT<<10)\
																		|(CFG_PE9_OT<<9)\
																		|(CFG_PE8_OT<<8)\
																		|(CFG_PE7_OT<<7)\
																		|(CFG_PE6_OT<<6)\
																		|(CFG_PE5_OT<<5)\
																		|(CFG_PE4_OT<<4)\
																		|(CFG_PE3_OT<<3)\
																		|(CFG_PE2_OT<<2)\
																		|(CFG_PE1_OT<<1)\
																		|CFG_PE0_OT)
																	
#define CFG_GPIO_ODRVR_E_INIT     	(((uint32_t)CFG_PE14_ODRVR<<28)\
																		|(CFG_PE13_ODRVR<<26)\
																		|(CFG_PE12_ODRVR<<24)\
																		|(CFG_PE11_ODRVR<<22)\
																		|(CFG_PE10_ODRVR<<20)\
																		|(CFG_PE9_ODRVR<<18)\
																		|(CFG_PE8_ODRVR<<16)\
																		|(CFG_PE7_ODRVR<<14)\
																		|(CFG_PE6_ODRVR<<12)\
																		|(CFG_PE5_ODRVR<<10)\
																		|(CFG_PE4_ODRVR<<8)\
																		|(CFG_PE3_ODRVR<<6)\
																		|(CFG_PE2_ODRVR<<4)\
																		|(CFG_PE1_ODRVR<<2)\
																		|CFG_PE0_ODRVR)
																		
#define CFG_GPIO_PUPDR_E_INIT     	(((uint32_t)CFG_PE14_PUPDR<<28)\
																		|(CFG_PE13_PUPDR<<26)\
																		|(CFG_PE12_PUPDR<<24)\
																		|(CFG_PE11_PUPDR<<22)\
																		|(CFG_PE10_PUPDR<<20)\
																		|(CFG_PE9_PUPDR<<18)\
																		|(CFG_PE8_PUPDR<<16)\
																		|(CFG_PE7_PUPDR<<14)\
																		|(CFG_PE6_PUPDR<<12)\
																		|(CFG_PE5_PUPDR<<10)\
																		|(CFG_PE4_PUPDR<<8)\
																		|(CFG_PE3_PUPDR<<6)\
																		|(CFG_PE2_PUPDR<<4)\
																		|(CFG_PE1_PUPDR<<2)\
																		|CFG_PE0_PUPDR)
																		
#define CFG_GPIO_AFRH_E_INIT     		(((uint32_t)CFG_PE14_AFR<<24)\
																		|(CFG_PE13_AFR<<20)\
																		|(CFG_PE12_AFR<<16)\
																		|(CFG_PE11_AFR<<12)\
																		|(CFG_PE10_AFR<<8)\
																		|(CFG_PE9_AFR<<4)\
																		|CFG_PE8_AFR)
															
#define CFG_GPIO_AFRL_E_INIT				(((uint32_t)CFG_PE7_AFR<<28)\
																		|(CFG_PE6_AFR<<24)\
																		|(CFG_PE5_AFR<<20)\
																		|(CFG_PE4_AFR<<16)\
																		|(CFG_PE3_AFR<<12)\
																		|(CFG_PE2_AFR<<8)\
																		|(CFG_PE1_AFR<<4)\
																		|CFG_PE0_AFR)																		
																		
#define CFG_GPIO_ODR_E_INIT     		(((uint32_t)CFG_PE14_ODR<<14)\
																		|(CFG_PE13_ODR<<13)\
																		|(CFG_PE12_ODR<<12)\
																		|(CFG_PE11_ODR<<11)\
																		|(CFG_PE10_ODR<<10)\
																		|(CFG_PE9_ODR<<9)\
																		|(CFG_PE8_ODR<<8)\
																		|(CFG_PE7_ODR<<7)\
																		|(CFG_PE6_ODR<<6)\
																		|(CFG_PE5_ODR<<5)\
																		|(CFG_PE4_ODR<<4)\
																		|(CFG_PE3_ODR<<3)\
																		|(CFG_PE2_ODR<<2)\
																		|(CFG_PE1_ODR<<1)\
																		|CFG_PE0_ODR)																		
																		
#define CFG_GPIO_MODER_E_INIT     	(((uint32_t)CFG_PE14_MODER<<14)\
																		|(CFG_PE13_MODER<<13)\
																		|(CFG_PE12_MODER<<12)\
																		|(CFG_PE11_MODER<<11)\
																		|(CFG_PE10_MODER<<10)\
																		|(CFG_PE9_MODER<<9)\
																		|(CFG_PE8_MODER<<8)\
																		|(CFG_PE7_MODER<<7)\
																		|(CFG_PE6_MODER<<6)\
																		|(CFG_PE5_MODER<<5)\
																		|(CFG_PE4_MODER<<4)\
																		|(CFG_PE3_MODER<<3)\
																		|(CFG_PE2_MODER<<2)\
																		|(CFG_PE1_MODER<<1)\
																		|CFG_PE0_MODER)	
																		
#define CFG_GPIO_LCKR_E_INIT     		(((uint32_t)CFG_PE14_LOCK<<14)\
																		|(CFG_PE13_LOCK<<13)\
																		|(CFG_PE12_LOCK<<12)\
																		|(CFG_PE11_LOCK<<11)\
																		|(CFG_PE10_LOCK<<10)\
																		|(CFG_PE9_LOCK<<9)\
																		|(CFG_PE8_LOCK<<8)\
																		|(CFG_PE7_LOCK<<7)\
																		|(CFG_PE6_LOCK<<6)\
																		|(CFG_PE5_LOCK<<5)\
																		|(CFG_PE4_LOCK<<4)\
																		|(CFG_PE3_LOCK<<3)\
																		|(CFG_PE2_LOCK<<2)\
																		|(CFG_PE1_LOCK<<1)\
																		|CFG_PE0_LOCK)																			
//</e>	

																	
//<e>EXTI
#define CFG_EXTI_EN     			0
//<e9>EXTI0
// <q0> IMR0_EXTI0ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR0_EXTI0ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR0_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR0_EXTI0ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR0_EXTI0ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI0_EXTI0 
//   These bits are written by software to select the source input for the EXTI0 external interrupt. 
//    <0=>PA[0] pin 
//    <1=>PB[0] pin
//    <2=>PC[0] pin
//    <3=>PD[0] pin
//    <4=>PE[0] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS0_EXTI0ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN0_EXTI0ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR0_EXTI0ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI0_IMR_BIT		0x0
#define CFG_EXTI0_EMR_BIT		0x0
#define CFG_EXTI0_TMR_BIT		0x0
#define CFG_EXTI0_RTR_BIT		0x0
#define CFG_EXTI0_FTR_BIT		0x0
#define CFG_EXTI0_PIN_CFG		0x0
#define CFG_EXTI0_PS_BIT		0x0
#define CFG_EXTI0_SN_BIT		0x0
#define CFG_EXTI0_DMR_BIT		0x0
#define CFG_EXTI0_EN      		0

//<e9>EXTI1
// <q0> IMR1_EXTI1ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR1_EXTI1ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR1_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR1_EXTI1ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR1_EXTI1ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI1_EXTI1 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[1] pin 
//    <1=>PB[1] pin
//    <2=>PC[1] pin
//    <3=>PD[1] pin
//    <4=>PE[1] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS1_EXTI1ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN1_EXTI1ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR1_EXTI1ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI1_IMR_BIT		0x0
#define CFG_EXTI1_EMR_BIT		0x0
#define CFG_EXTI1_TMR_BIT		0x0
#define CFG_EXTI1_RTR_BIT		0x0
#define CFG_EXTI1_FTR_BIT		0x0
#define CFG_EXTI1_PIN_CFG		0x0
#define CFG_EXTI1_PS_BIT		0x0
#define CFG_EXTI1_SN_BIT		0x0
#define CFG_EXTI1_DMR_BIT		0x0
#define CFG_EXTI1_EN      		0


//<e9>EXTI2
// <q0> IMR2_EXTI2ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR2_EXTI2ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR2_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//<i>شΪone-shotʽͨclear pending flag־λ
//<i>ƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR2_EXTI2ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR2_EXTI2ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI2_EXTI2 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[2] pin 
//    <1=>PB[2] pin
//    <2=>PC[2] pin
//    <3=>PD[2] pin
//    <4=>PE[2] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS2_EXTI2ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN2_EXTI2ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR2_EXTI2ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI2_IMR_BIT		0x0
#define CFG_EXTI2_EMR_BIT		0x0
#define CFG_EXTI2_TMR_BIT		0x0
#define CFG_EXTI2_RTR_BIT		0x0
#define CFG_EXTI2_FTR_BIT		0x0
#define CFG_EXTI2_PIN_CFG		0x0
#define CFG_EXTI2_PS_BIT		0x0
#define CFG_EXTI2_SN_BIT		0x0
#define CFG_EXTI2_DMR_BIT		0x0
#define CFG_EXTI2_EN      		0


//<e9>EXTI3
// <q0> IMR3_EXTI3ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR3_EXTI3ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR3_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//<i>شΪone-shotʽͨclear pending flag־λ
//<i>ƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR3_EXTI3ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR3_EXTI3ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI3_EXTI3 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[3] pin 
//    <1=>PB[3] pin
//    <2=>PC[3] pin
//    <3=>PD[3] pin
//    <4=>PE[3] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS3_EXTI3ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN3_EXTI3ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR3_EXTI3ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>


#define CFG_EXTI3_IMR_BIT		0x0
#define CFG_EXTI3_EMR_BIT		0x0
#define CFG_EXTI3_TMR_BIT		0x0
#define CFG_EXTI3_RTR_BIT		0x0
#define CFG_EXTI3_FTR_BIT		0x0
#define CFG_EXTI3_PIN_CFG		0x0
#define CFG_EXTI3_PS_BIT		0x0
#define CFG_EXTI3_SN_BIT		0x0
#define CFG_EXTI3_DMR_BIT		0x0
#define CFG_EXTI3_EN      		0

//<e9>EXTI4
// <q0> IMR4_EXTI4ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR4_EXTI4ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR4_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λ
//<i>ƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR4_EXTI4ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR4_EXTI4ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI4_EXTI4 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[4] pin 
//    <1=>PB[4] pin
//    <2=>PC[4] pin
//    <3=>PD[4] pin
//    <4=>PE[4] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS4_EXTI4ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN4_EXTI4ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR4_EXTI4ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI4_IMR_BIT		0x0
#define CFG_EXTI4_EMR_BIT		0x0
#define CFG_EXTI4_TMR_BIT		0x0
#define CFG_EXTI4_RTR_BIT		0x0
#define CFG_EXTI4_FTR_BIT		0x0
#define CFG_EXTI4_PIN_CFG		0x0
#define CFG_EXTI4_PS_BIT		0x0
#define CFG_EXTI4_SN_BIT		0x0
#define CFG_EXTI4_DMR_BIT		0x0
#define CFG_EXTI4_EN      		0

//<e9>EXTI5
// <q0> IMR5_EXTI5ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR5_EXTI5ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR5_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λ
//<i>ƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR5_EXTI5ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR5_EXTI5ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI5_EXTI5 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[5] pin 
//    <1=>PB[5] pin
//    <2=>PC[5] pin
//    <3=>PD[5] pin
//    <4=>PE[5] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS5_EXTI5ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN5_EXTI5ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR5_EXTI5ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI5_IMR_BIT		0x0
#define CFG_EXTI5_EMR_BIT		0x0
#define CFG_EXTI5_TMR_BIT		0x0
#define CFG_EXTI5_RTR_BIT		0x0
#define CFG_EXTI5_FTR_BIT		0x0
#define CFG_EXTI5_PIN_CFG		0x0
#define CFG_EXTI5_PS_BIT		0x0
#define CFG_EXTI5_SN_BIT		0x0
#define CFG_EXTI5_DMR_BIT		0x0
#define CFG_EXTI5_EN      		0

//<e9>EXTI6
// <q0> IMR6_EXTI6ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR6_EXTI6ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR6_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR6_EXTI6ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR6_EXTI6ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI6_EXTI6 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[6] pin 
//    <1=>PB[6] pin
//    <2=>PC[6] pin
//    <3=>PD[6] pin
//    <4=>PE[6] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS6_EXTI6ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN6_EXTI6ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR6_EXTI6ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI6_IMR_BIT		0x0
#define CFG_EXTI6_EMR_BIT		0x0
#define CFG_EXTI6_TMR_BIT		0x0
#define CFG_EXTI6_RTR_BIT		0x0
#define CFG_EXTI6_FTR_BIT		0x0
#define CFG_EXTI6_PIN_CFG		0x0
#define CFG_EXTI6_PS_BIT		0x0
#define CFG_EXTI6_SN_BIT		0x0
#define CFG_EXTI6_DMR_BIT		0x0
#define CFG_EXTI6_EN      		0

//<e9>EXTI7
// <q0> IMR7_EXTI7ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR7_EXTI7ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR7_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR7_EXTI7ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR7_EXTI7ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI7_EXTI7 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[7] pin 
//    <1=>PB[7] pin
//    <2=>PC[7] pin
//    <3=>PD[7] pin
//    <4=>PE[7] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS7_EXTI7ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN7_EXTI7ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR7_EXTI7ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI7_IMR_BIT		0x0
#define CFG_EXTI7_EMR_BIT		0x0
#define CFG_EXTI7_TMR_BIT		0x0
#define CFG_EXTI7_RTR_BIT		0x0
#define CFG_EXTI7_FTR_BIT		0x0
#define CFG_EXTI7_PIN_CFG		0x0
#define CFG_EXTI7_PS_BIT		0x0
#define CFG_EXTI7_SN_BIT		0x0
#define CFG_EXTI7_DMR_BIT		0x0
#define CFG_EXTI7_EN      		0

//<e9>EXTI8
// <q0> IMR8_EXTI8ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR8_EXTI8ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR8_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR8_EXTI8ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR8_EXTI8ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI8_EXTI8 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[8] pin 
//    <1=>PB[8] pin
//    <2=>PC[8] pin
//    <3=>PD[8] pin
//    <4=>PE[8] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS8_EXTI8ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN8_EXTI8ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR8_EXTI8ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI8_IMR_BIT		0x0
#define CFG_EXTI8_EMR_BIT		0x0
#define CFG_EXTI8_TMR_BIT		0x0
#define CFG_EXTI8_RTR_BIT		0x0
#define CFG_EXTI8_FTR_BIT		0x0
#define CFG_EXTI8_PIN_CFG		0x0
#define CFG_EXTI8_PS_BIT		0x0
#define CFG_EXTI8_SN_BIT		0x0
#define CFG_EXTI8_DMR_BIT		0x0
#define CFG_EXTI8_EN      		0

//<e9>EXTI9
// <q0> IMR9_EXTI9ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR9_EXTI9ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR9_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR9_EXTI9ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR9_EXTI9ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI9_EXTI9 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[9] pin 
//    <1=>PB[9] pin
//    <2=>PC[9] pin
//    <3=>PD[9] pin
//    <4=>PE[9] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS9_EXTI9ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN9_EXTI9ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR9_EXTI9ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI9_IMR_BIT		0x0
#define CFG_EXTI9_EMR_BIT		0x0
#define CFG_EXTI9_TMR_BIT		0x0
#define CFG_EXTI9_RTR_BIT		0x0
#define CFG_EXTI9_FTR_BIT		0x0
#define CFG_EXTI9_PIN_CFG		0x0
#define CFG_EXTI9_PS_BIT		0x0
#define CFG_EXTI9_SN_BIT		0x0
#define CFG_EXTI9_DMR_BIT		0x0
#define CFG_EXTI9_EN      		0

//<e9>EXTI10
// <q0> IMR10_EXTI10ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR10_EXTI10ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR10_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR10_EXTI10ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR10_EXTI10ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI10_EXTI10 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[10] pin 
//    <1=>PB[10] pin
//    <2=>PC[10] pin
//    <3=>PD[10] pin
//    <4=>PE[10] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS10_EXTI10ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN10_EXTI10ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR10_EXTI10ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI10_IMR_BIT		0x0
#define CFG_EXTI10_EMR_BIT		0x0
#define CFG_EXTI10_TMR_BIT		0x0
#define CFG_EXTI10_RTR_BIT		0x0
#define CFG_EXTI10_FTR_BIT		0x0
#define CFG_EXTI10_PIN_CFG		0x0
#define CFG_EXTI10_PS_BIT			0x0
#define CFG_EXTI10_SN_BIT			0x0
#define CFG_EXTI10_DMR_BIT		0x0
#define CFG_EXTI10_EN      		0

//<e9>EXTI11
// <q0> IMR11_EXTI11ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR11_EXTI11ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR11_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR11_EXTI11ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR11_EXTI11ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI11_EXTI11 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[11] pin 
//    <1=>PB[11] pin
//    <2=>PC[11] pin
//    <3=>PD[11] pin
//    <4=>PE[11] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS11_EXTI11ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN11_EXTI11ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR11_EXTI11ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI11_IMR_BIT		0x0
#define CFG_EXTI11_EMR_BIT		0x0
#define CFG_EXTI11_TMR_BIT		0x0
#define CFG_EXTI11_RTR_BIT		0x0
#define CFG_EXTI11_FTR_BIT		0x0
#define CFG_EXTI11_PIN_CFG		0x0
#define CFG_EXTI11_PS_BIT			0x0
#define CFG_EXTI11_SN_BIT			0x0
#define CFG_EXTI11_DMR_BIT		0x0
#define CFG_EXTI11_EN      		0

//<e9>EXTI12
// <q0> IMR12_EXTI12ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR12_EXTI12ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR12_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR12_EXTI12ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR12_EXTI12ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI12_EXTI12 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[12] pin 
//    <1=>PB[12] pin
//    <2=>PC[12] pin
//    <3=>PD[12] pin
//    <4=>PE[12] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS12_EXTI12ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN12_EXTI12ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR12_EXTI12ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI12_IMR_BIT		0x0
#define CFG_EXTI12_EMR_BIT		0x0
#define CFG_EXTI12_TMR_BIT		0x0
#define CFG_EXTI12_RTR_BIT		0x0
#define CFG_EXTI12_FTR_BIT		0x0
#define CFG_EXTI12_PIN_CFG		0x0
#define CFG_EXTI12_PS_BIT			0x0
#define CFG_EXTI12_SN_BIT			0x0
#define CFG_EXTI12_DMR_BIT		0x0
#define CFG_EXTI12_EN      		0


//<e9>EXTI13
// <q0> IMR13_EXTI13ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR13_EXTI13ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR13_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR13_EXTI13ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR13_EXTI13ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI13_EXTI13 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[13] pin 
//    <1=>PB[13] pin
//    <2=>PC[13] pin
//    <3=>PD[13] pin
//    <4=>PE[13] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS13_EXTI13ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN13_EXTI13ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR13_EXTI13ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI13_IMR_BIT		0x0
#define CFG_EXTI13_EMR_BIT		0x0
#define CFG_EXTI13_TMR_BIT		0x0
#define CFG_EXTI13_RTR_BIT		0x0
#define CFG_EXTI13_FTR_BIT		0x0
#define CFG_EXTI13_PIN_CFG		0x0
#define CFG_EXTI13_PS_BIT			0x0
#define CFG_EXTI13_SN_BIT			0x0
#define CFG_EXTI13_DMR_BIT		0x0
#define CFG_EXTI13_EN      		0

//<e9>EXTI14
// <q0> IMR14_EXTI14ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR14_EXTI14ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR14_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR14_EXTI14ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR14_EXTI14ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI14_EXTI14 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[14] pin 
//    <1=>PB[14] pin
//    <2=>PC[14] pin
//    <3=>PD[14] pin
//    <4=>PE[14] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS14_EXTI14ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN14_EXTI14ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR14_EXTI14ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI14_IMR_BIT		0x0
#define CFG_EXTI14_EMR_BIT		0x0
#define CFG_EXTI14_TMR_BIT		0x0
#define CFG_EXTI14_RTR_BIT		0x0
#define CFG_EXTI14_FTR_BIT		0x0
#define CFG_EXTI14_PIN_CFG		0x0
#define CFG_EXTI14_PS_BIT			0x0
#define CFG_EXTI14_SN_BIT			0x0
#define CFG_EXTI14_DMR_BIT		0x0
#define CFG_EXTI14_EN      		0

//<e9>EXTI15
// <q0> IMR15_EXTI15ϵж
//     0: yϵж
//     1: yϵж
// <q1> EMR15_EXTI15ϵ¼
//     0: yϵ¼
//     1: yϵ¼
// <o2> TMR15_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR15_EXTI15ϵ/ߵƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <q4> FTR15_EXTI15ϵ½/͵ƽжϺ¼
//     0: ֹyϵ½/͵ƽ(жϺ¼)
//     1: yϵ½/͵ƽ(жϺ¼)
// <o5> EXTI15_EXTI15 
//   These bits are written by software to select the source input for the EXTI1 external interrupt. 
//    <0=>PA[15] pin 
//    <1=>PB[15] pin
//    <2=>PC[15] pin
//    <3=>PD[15] pin
//    <4=>PE[15] pin
//    <5=>Reserved
//    <6=>Reserved
//    <7=>Reserved
// <o6> PS15_EXTI15ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o7> SN15_EXTI15ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <q8> DMR15_EXTI15ϵDMA
//     0: yϵDMA
//     1: yϵDMA
//</e>
#define CFG_EXTI15_IMR_BIT		0x0
#define CFG_EXTI15_EMR_BIT		0x0
#define CFG_EXTI15_TMR_BIT		0x0
#define CFG_EXTI15_RTR_BIT		0x0
#define CFG_EXTI15_FTR_BIT		0x0
#define CFG_EXTI15_PIN_CFG		0x0
#define CFG_EXTI15_PS_BIT			0x0
#define CFG_EXTI15_SN_BIT			0x0
#define CFG_EXTI15_DMR_BIT		0x0
#define CFG_EXTI15_EN      		0


//</e>
#define CFG_EXTI_IMR_INIT     (((uint32_t)CFG_EXTI15_IMR_BIT<<15)\
															|(CFG_EXTI14_IMR_BIT<<14)\
															|(CFG_EXTI13_IMR_BIT<<13)\
															|(CFG_EXTI12_IMR_BIT<<12)\
															|(CFG_EXTI11_IMR_BIT<<11)\
															|(CFG_EXTI10_IMR_BIT<<10)\
															|(CFG_EXTI9_IMR_BIT<<9)\
															|(CFG_EXTI8_IMR_BIT<<8)\
															|(CFG_EXTI7_IMR_BIT<<7)\
															|(CFG_EXTI6_IMR_BIT<<6)\
															|(CFG_EXTI5_IMR_BIT<<5)\
															|(CFG_EXTI4_IMR_BIT<<4)\
															|(CFG_EXTI3_IMR_BIT<<3)\
															|(CFG_EXTI2_IMR_BIT<<2)\
															|(CFG_EXTI1_IMR_BIT<<1)\
															|CFG_EXTI0_IMR_BIT)

#define CFG_EXTI_EMR_INIT     (((uint32_t)CFG_EXTI15_EMR_BIT<<15)\
															|(CFG_EXTI14_EMR_BIT<<14)\
															|(CFG_EXTI13_EMR_BIT<<13)\
															|(CFG_EXTI12_EMR_BIT<<12)\
															|(CFG_EXTI11_EMR_BIT<<11)\
															|(CFG_EXTI10_EMR_BIT<<10)\
															|(CFG_EXTI9_EMR_BIT<<9)\
															|(CFG_EXTI8_EMR_BIT<<8)\
															|(CFG_EXTI7_EMR_BIT<<7)\
															|(CFG_EXTI6_EMR_BIT<<6)\
															|(CFG_EXTI5_EMR_BIT<<5)\
															|(CFG_EXTI4_EMR_BIT<<4)\
															|(CFG_EXTI3_EMR_BIT<<3)\
															|(CFG_EXTI2_EMR_BIT<<2)\
															|(CFG_EXTI1_EMR_BIT<<1)\
															|CFG_EXTI0_EMR_BIT)
															
#define CFG_EXTI_TMSR_INIT     (((uint32_t)CFG_EXTI15_TMR_BIT<<15)\
															|(CFG_EXTI14_TMR_BIT<<14)\
															|(CFG_EXTI13_TMR_BIT<<13)\
															|(CFG_EXTI12_TMR_BIT<<12)\
															|(CFG_EXTI11_TMR_BIT<<11)\
															|(CFG_EXTI10_TMR_BIT<<10)\
															|(CFG_EXTI9_TMR_BIT<<9)\
															|(CFG_EXTI8_TMR_BIT<<8)\
															|(CFG_EXTI7_TMR_BIT<<7)\
															|(CFG_EXTI6_TMR_BIT<<6)\
															|(CFG_EXTI5_TMR_BIT<<5)\
															|(CFG_EXTI4_TMR_BIT<<4)\
															|(CFG_EXTI3_TMR_BIT<<3)\
															|(CFG_EXTI2_TMR_BIT<<2)\
															|(CFG_EXTI1_TMR_BIT<<1)\
															|CFG_EXTI0_TMR_BIT)
															
#define CFG_EXTI_RTSR_INIT    (((uint32_t)CFG_EXTI15_RTR_BIT<<15)\
															|(CFG_EXTI14_RTR_BIT<<14)\
															|(CFG_EXTI13_RTR_BIT<<13)\
															|(CFG_EXTI12_RTR_BIT<<12)\
															|(CFG_EXTI11_RTR_BIT<<11)\
															|(CFG_EXTI10_RTR_BIT<<10)\
															|(CFG_EXTI9_RTR_BIT<<9)\
															|(CFG_EXTI8_RTR_BIT<<8)\
															|(CFG_EXTI7_RTR_BIT<<7)\
															|(CFG_EXTI6_RTR_BIT<<6)\
															|(CFG_EXTI5_RTR_BIT<<5)\
															|(CFG_EXTI4_RTR_BIT<<4)\
															|(CFG_EXTI3_RTR_BIT<<3)\
															|(CFG_EXTI2_RTR_BIT<<2)\
															|(CFG_EXTI1_RTR_BIT<<1)\
															|CFG_EXTI0_RTR_BIT)															

#define CFG_EXTI_FTSR_INIT    (((uint32_t)CFG_EXTI15_FTR_BIT<<15)\
															|(CFG_EXTI14_FTR_BIT<<14)\
															|(CFG_EXTI13_FTR_BIT<<13)\
															|(CFG_EXTI12_FTR_BIT<<12)\
															|(CFG_EXTI11_FTR_BIT<<11)\
															|(CFG_EXTI10_FTR_BIT<<10)\
															|(CFG_EXTI9_FTR_BIT<<9)\
															|(CFG_EXTI8_FTR_BIT<<8)\
															|(CFG_EXTI7_FTR_BIT<<7)\
															|(CFG_EXTI6_FTR_BIT<<6)\
															|(CFG_EXTI5_FTR_BIT<<5)\
															|(CFG_EXTI4_FTR_BIT<<4)\
															|(CFG_EXTI3_FTR_BIT<<3)\
															|(CFG_EXTI2_FTR_BIT<<2)\
															|(CFG_EXTI1_FTR_BIT<<1)\
															|CFG_EXTI0_FTR_BIT)		
															
#define CFG_EXTI_CFGL_INIT		(((uint32_t)CFG_EXTI7_PIN_CFG<<28)\
															|(CFG_EXTI6_PIN_CFG<<24)\
															|(CFG_EXTI5_PIN_CFG<<20)\
															|(CFG_EXTI4_PIN_CFG<<16)\
															|(CFG_EXTI3_PIN_CFG<<12)\
															|(CFG_EXTI2_PIN_CFG<<8)\
															|(CFG_EXTI1_PIN_CFG<<4)\
															|CFG_EXTI0_PIN_CFG)	
															
#define CFG_EXTI_CFGH_INIT		(((uint32_t)CFG_EXTI15_PIN_CFG<<28)\
															|(CFG_EXTI14_PIN_CFG<<24)\
															|(CFG_EXTI13_PIN_CFG<<20)\
															|(CFG_EXTI12_PIN_CFG<<16)\
															|(CFG_EXTI11_PIN_CFG<<12)\
															|(CFG_EXTI10_PIN_CFG<<8)\
															|(CFG_EXTI9_PIN_CFG<<4)\
															|CFG_EXTI8_PIN_CFG)												
															
															
#define CFG_EXTI_SAMPL_INIT   (((uint32_t)CFG_EXTI7_PS_BIT<<30)\
															|(CFG_EXTI7_SN_BIT<<28)\
															|(CFG_EXTI6_PS_BIT<<26)\
															|(CFG_EXTI6_SN_BIT<<24)\
															|(CFG_EXTI5_PS_BIT<<22)\
															|(CFG_EXTI5_SN_BIT<<20)\
															|(CFG_EXTI4_PS_BIT<<18)\
															|(CFG_EXTI4_SN_BIT<<16)\
															|(CFG_EXTI3_PS_BIT<<14)\
															|(CFG_EXTI3_SN_BIT<<12)\
															|(CFG_EXTI2_PS_BIT<<10)\
															|(CFG_EXTI2_SN_BIT<<8)\
															|(CFG_EXTI1_PS_BIT<<6)\
															|(CFG_EXTI1_SN_BIT<<4)\
															|(CFG_EXTI0_PS_BIT<<2)\
															|CFG_EXTI0_SN_BIT)	
															
#define CFG_EXTI_SAMPH_INIT   (((uint32_t)CFG_EXTI15_PS_BIT<<30)\
															|(CFG_EXTI15_SN_BIT<<28)\
															|(CFG_EXTI14_PS_BIT<<26)\
															|(CFG_EXTI14_SN_BIT<<24)\
															|(CFG_EXTI13_PS_BIT<<22)\
															|(CFG_EXTI13_SN_BIT<<20)\
															|(CFG_EXTI12_PS_BIT<<18)\
															|(CFG_EXTI12_SN_BIT<<16)\
															|(CFG_EXTI11_PS_BIT<<14)\
															|(CFG_EXTI11_SN_BIT<<12)\
															|(CFG_EXTI10_PS_BIT<<10)\
															|(CFG_EXTI10_SN_BIT<<8)\
															|(CFG_EXTI9_PS_BIT<<6)\
															|(CFG_EXTI9_SN_BIT<<4)\
															|(CFG_EXTI8_PS_BIT<<2)\
															|CFG_EXTI8_SN_BIT)															
															
															

#define CFG_EXTI_DMR_INIT     (((uint32_t)CFG_EXTI15_DMR_BIT<<15)\
															|(CFG_EXTI14_DMR_BIT<<14)\
															|(CFG_EXTI13_DMR_BIT<<13)\
															|(CFG_EXTI12_DMR_BIT<<12)\
															|(CFG_EXTI11_DMR_BIT<<11)\
															|(CFG_EXTI10_DMR_BIT<<10)\
															|(CFG_EXTI9_DMR_BIT<<9)\
															|(CFG_EXTI8_DMR_BIT<<8)\
															|(CFG_EXTI7_DMR_BIT<<7)\
															|(CFG_EXTI6_DMR_BIT<<6)\
															|(CFG_EXTI5_DMR_BIT<<5)\
															|(CFG_EXTI4_DMR_BIT<<4)\
															|(CFG_EXTI3_DMR_BIT<<3)\
															|(CFG_EXTI2_DMR_BIT<<2)\
															|(CFG_EXTI1_DMR_BIT<<1)\
															|CFG_EXTI0_DMR_BIT)

#define CFG_EXTI0_INT_EN CFG_EXTI0_EN
#define CFG_EXTI1_INT_EN CFG_EXTI1_EN
#define CFG_EXTI2_INT_EN CFG_EXTI2_EN
#define CFG_EXTI3_INT_EN CFG_EXTI3_EN
#define CFG_EXTI4_INT_EN CFG_EXTI4_EN
#define CFG_EXTI9_5_INT_EN (CFG_EXTI5_EN | CFG_EXTI6_EN | CFG_EXTI7_EN | CFG_EXTI8_EN | CFG_EXTI9_EN)
#define CFG_EXTI15_10_INT_EN (CFG_EXTI15_EN | CFG_EXTI14_EN | CFG_EXTI13_EN | CFG_EXTI12_EN | CFG_EXTI11_EN| CFG_EXTI10_EN)




//<e>DMA
#define CFG_DMA_EN 0
//<h>CSR_DMA״̬Ĵ
//<i>0x008 b31     b30     b29     b28     b27     b26     b25     b24     b19~16    b15~8         b7~0          
//<i>CSR   RELOAD7 RELOAD6 RELOAD5 RELOAD4 RELOAD3 RELOAD2 RELOAD1 RELOAD0 BURSTIDLE DBUSYy(y=7~0) SWTRGy(y=7~0) 
// <o0.16..19> BURSTIDLE_DMAͻͷλ
//λú
//    <0=>ͷ1
//    <1=>ͷ2
//    <2=>ͷ3
//    <3=>ͷ4
//    <4=>ͷ5
//    <5=>ͷ6
//    <6=>ͷ7
//    <7=>ͷ8
//    <8=>ͷ9
//    <9=>ͷ10
//    <10=>ͷ12
//    <11=>ͷ16
//    <12=>ͷ20
//    <13=>ͷ24
//    <14=>ͷ28
//    <15=>ͷ32

// <q0.0> SWTRG0_DMAͨ0ʹ
// <q0.1> SWTRG1_DMAͨ1ʹ
// <q0.2> SWTRG2_DMAͨ2ʹ
// <q0.3> SWTRG3_DMAͨ3ʹ
// <q0.4> SWTRG4_DMAͨ4ʹ
// <q0.5> SWTRG5_DMAͨ5ʹ
// <q0.6> SWTRG6_DMAͨ6ʹ
// <q0.7> SWTRG7_DMAͨ7ʹ

//<i>DMAͨyλãӲ
//<i>    0ɶ0д0
//<i>   1λDMAӦԶ0

// <q0.24> RELOAD0_DMAͨ0ؿλ
//    0: رԶ
//    1: Զ
// <q0.25> RELOAD1_DMAͨ1ؿλ
//    0: رԶ
//    1: Զ
// <q0.26> RELOAD2_DMAͨ2ؿλ
//    0: رԶ
//    1: Զ
// <q0.27> RELOAD3_DMAͨ3ؿλ
//    0: رԶ
//    1: Զ
// <q0.28> RELOAD4_DMAͨ4ؿλ
//    0: رԶ
//    1: Զ
// <q0.29> RELOAD5_DMAͨ5ؿλ
//    0: رԶ
//    1: Զ
// <q0.30> RELOAD6_DMAͨ6ؿλ
//    0: رԶ
//    1: Զ
// <q0.31> RELOAD7_DMAͨ7ؿλ
//    0: رԶ
//    1: Զ
//</h>
#define CFG_DMA_CSR_INIT 0

//<e>DMA_CH0
#define CFG_DMA_CH0_EN 0
	
//<h>CCR0_DMAͨ0üĴ
//<i>0x010 b31~24 b23     b22~20  b19~16   b15~14 b13~12 b11~10 b9~8  b7~6  b5 b4   b3   b2   b1   b0 
//<i>CCR0  -      TRGMODE STRMSEL BURSTLEN PL     SSIZE  DSIZE  SPTYP DPTYP -  TEIE BEIE HTIE TCIE EN 
// <q0.1> TCIE_ж
//    0: ֹTCж
//    1: TCж
// <q0.2> HTIE_봫ж 
//    0: ֹHTж
//    1: HTж
// <q0.3> BEIE_burstж
//    0: ֹBEж 
//    1: BEж
//    <i>burstΪ1ʱsingleģʽͬBEжϡ
// <q0.4> TEIE_ж
//    0: ֹTEж
//    1: TEж
// <o0.6..7> DPTYP_Ŀָ޸ķʽ
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.8..9> SPTYP_Դָ޸ķʽ
//λú
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.10..11> DSIZE_Ŀݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ 
//    <3=>
// <o0.12..13> SSIZE_Դݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ  
//    <3=>
// <o0.14..15> PL_ͨȼ
//Щλú
//    <0=>
//    <1=>
//    <2=> 
//    <3=>
// <o0.16..19> BURSTLEN_DMAͻλ
//λú
//    <0=>ÿburst1ݣsingle䣩
//    <1=>ÿburst2
//    <2=>ÿburst3
//    <3=>ÿburst4
//    <4=>ÿburst5
//    <5=>ÿburst6
//    <6=>ÿburst7
//    <7=>ÿburst8
//    <8=>ÿburst9
//    <9=>ÿburst10
//    <10=>ÿburst11
//    <11=>ÿburst12
//    <12=>ÿburst13
//    <13=>ÿburst14
//    <14=>ÿburst15
//    <15=>ÿburst16
//    <i>SIZEõĲͬ1ݴܰ1ֽ/2ֽ/4ֽڡ
// <o0.20..22> STRMSEL_DMAͨԴѡλ
//<i>Channel		CH0	CH1	CH2	CH3	CH4	CH5	CH6	CH7
//<i>stream0_UART	UART2_TX	UART2_RX	UART1_TX	UART1_RX	UART1_TX	UART1_RX	UART3_RX	UART3_TX
//<i>stream1_SPI/TWI	SPI1_TX	SPI1_RX	SPI2_RX	SPI2_TX	UART2_TX	UART2_RX	SPI1_TX	SPI1_RX
//<i>stream2_EXTI	EXTI0/1	EXTI2/3	EXTI4/5	EXTI6/7	EXTI8/9	EXTI10/11	EXTI12/13	EXTI14/15
//<i>stream3_ADC	ADC1	ADC2	ADC3	ADC1	ADC1	ADC2	ADC3	ADC2
//<i>stream4_MCM	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2
//<i>stream5_GPT	GPT0	GPT1	GPT2	GPT3	GPT0	GPT1	GPT2	GPT3
//<i>stream6_QEI	CMP1	QEI	GPT	CMP2	QEI	CMP	CMP3	GPT
//<i>stream7_TIM	TIM5	TIM6	TIM7	TIM8	TIM5	TIM6	TIM7	TIM8
//    <0=>ѡstream0
//    <1=>ѡstream1
//    <2=>ѡstream2
//    <3=>ѡstream3
//    <4=>ѡstream4
//    <5=>ѡstream5
//    <6=>ѡstream6
//    <7=>ѡstream7
// <o0.23> TRGMODE_DMAģʽѡλ
//λú
//    <0=>one-shotʽ
//    <1=>to-endʽ
//</h>
#define CFG_DMA_CCR0_INIT	0x000000

#if ((CFG_DMA_CCR0_INIT & 0xF) != 0)
	#define CFG_DMA_CH0_INT_EN 1
#else
	#define CFG_DMA_CH0_INT_EN 0
#endif

//<h>NPKT0_DMAͨ0Ĵ
//<i>0x014 b31~11 b10~0 
//<i>NPKT0 -      NPKT  
// <o0.0..10> NPKT_ͨ0ݴburst<0-511>
//    ݴΪNPKT÷Χ0511ʾburst1512Ĵֻͨ(DMA_CCRxEN=0)ʱд롣ͨüĴΪֻ
//</h>
#define CFG_DMA_NPKT0_INIT	0x1FF

//<h>SAR0_DMAͨ0ԴַĴ
//<i>0x01C b31~0 
//<i>SAR0  SAR   
// <o0.0..31> SAR_DMAԴַĴ
//<i>  ԴݼĴĻַ
//<i>  SSIZE=01(16λ)ʹSARλԶֵַ롣
//<i>  SSIZE=10(32λ)ʹSARλԶֵַ롣
//<i>  ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_SAR0_INIT	0x00

//<h>DAR0_DMAͨ0ĿַĴ
//<i>0x020 b31~0 
//<i>DAR0  DAR   
// <o0.0..31> DAR_DMAĿַĴ
// <i>ĿݼĴĻַ
// <i>DSIZE=01(16λ)ʹDARλԶֵַ롣
// <i>DSIZE=10(32λ)ʹDARλԶֵַ롣
// <i>ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_DAR0_INIT	0x0


//</e>
//<e>DMA_CH1
#define CFG_DMA_CH1_EN 0

//<h>CCR1_DMAͨ1üĴ
//<i>0x030 b31~24 b23     b22~20  b19~16   b15~14 b13~12 b11~10 b9~8  b7~6  b5 b4   b3   b2   b1   b0 
//<i>CCR1  -      TRGMODE STRMSEL BURSTLEN PL     SSIZE  DSIZE  SPTYP DPTYP -  TEIE BEIE HTIE TCIE EN 
// <q0.1> TCIE_ж
//    0: ֹTCж
//    1: TCж
// <q0.2> HTIE_봫ж 
//    0: ֹHTж
//    1: HTж
// <q0.3> BEIE_burstж
//    0: ֹBEж 
//    1: BEж
//    <i>burstΪ1ʱsingleģʽͬBEжϡ
// <q0.4> TEIE_ж
//    0: ֹTEж
//    1: TEж
// <o0.6..7> DPTYP_Ŀָ޸ķʽ
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.8..9> SPTYP_Դָ޸ķʽ
//λú
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.10..11> DSIZE_Ŀݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ 
//    <3=>
// <o0.12..13> SSIZE_Դݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ  
//    <3=>
// <o0.14..15> PL_ͨȼ
//Щλú
//    <0=>
//    <1=>
//    <2=> 
//    <3=>
// <o0.16..19> BURSTLEN_DMAͻλ
//λú
//    <0=>ÿburst1ݣsingle䣩
//    <1=>ÿburst2
//    <2=>ÿburst3
//    <3=>ÿburst4
//    <4=>ÿburst5
//    <5=>ÿburst6
//    <6=>ÿburst7
//    <7=>ÿburst8
//    <8=>ÿburst9
//    <9=>ÿburst10
//    <10=>ÿburst11
//    <11=>ÿburst12
//    <12=>ÿburst13
//    <13=>ÿburst14
//    <14=>ÿburst15
//    <15=>ÿburst16
//    <i>SIZEõĲͬ1ݴܰ1ֽ/2ֽ/4ֽڡ
// <o0.20..22> STRMSEL_DMAͨԴѡλ
//<i>Channel		CH0	CH1	CH2	CH3	CH4	CH5	CH6	CH7
//<i>stream0_UART	UART2_TX	UART2_RX	UART1_TX	UART1_RX	UART1_TX	UART1_RX	UART3_RX	UART3_TX
//<i>stream1_SPI/TWI	SPI1_TX	SPI1_RX	SPI2_RX	SPI2_TX	UART2_TX	UART2_RX	SPI1_TX	SPI1_RX
//<i>stream2_EXTI	EXTI0/1	EXTI2/3	EXTI4/5	EXTI6/7	EXTI8/9	EXTI10/11	EXTI12/13	EXTI14/15
//<i>stream3_ADC	ADC1	ADC2	ADC3	ADC1	ADC1	ADC2	ADC3	ADC2
//<i>stream4_MCM	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2
//<i>stream5_GPT	GPT0	GPT1	GPT2	GPT3	GPT0	GPT1	GPT2	GPT3
//<i>stream6_QEI	CMP1	QEI	GPT	CMP2	QEI	CMP	CMP3	GPT
//<i>stream7_TIM	TIM5	TIM6	TIM7	TIM8	TIM5	TIM6	TIM7	TIM8
//    <0=>ѡstream0
//    <1=>ѡstream1
//    <2=>ѡstream2
//    <3=>ѡstream3
//    <4=>ѡstream4
//    <5=>ѡstream5
//    <6=>ѡstream6
//    <7=>ѡstream7
// <o0.23> TRGMODE_DMAģʽѡλ
//λú
//    <0=>one-shotʽ
//    <1=>to-endʽ
//</h>
#define CFG_DMA_CCR1_INIT		0x000000
#if ((CFG_DMA_CCR1_INIT & 0xF) != 0)
	#define CFG_DMA_CH1_INT_EN 1
#else
	#define CFG_DMA_CH1_INT_EN 0
#endif

//<h>NPKT1_DMAͨ1Ĵ
//<i>0x034 b31~11 b10~0 
//<i>NPKT1 -      NPKT  
// <o0.0..10> NPKT_ͨ1ݴburst<0-511>
//    ݴΪNPKT÷Χ0511ʾburst1512Ĵֻͨ(DMA_CCRxEN=0)ʱд롣ͨüĴΪֻ

//</h>

#define CFG_DMA_NPKT1_INIT	0x000
//<h>SAR1_DMAͨ1ԴַĴ
//<i>0x03C b31~0 
//<i>SAR1  SAR   
// <o0.0..31> SAR_DMAԴַĴ
//     ԴݼĴĻַ
//     SSIZE=01(16λ)ʹSARλԶֵַ롣
//     SSIZE=10(32λ)ʹSARλԶֵַ롣
//     ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_SAR1_INIT	0x00000000

//<h>DAR1_DMAͨ1ĿַĴ
//<i>0x040 b31~0 
//<i>DAR1  DAR   
// <o0.0..31> DAR_DMAĿַĴ 
//    ĿݼĴĻַ
//    DSIZE=01(16λ)ʹDARλԶֵַ롣
//    DSIZE=10(32λ)ʹDARλԶֵַ롣
//    ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_DAR1_INIT	0x00000000


//</e>
//<e>DMA_CH2
#define CFG_DMA_CH2_EN 0
//<h>CCR2_DMAͨ2üĴ
//<i>0x050 b31~24 b23     b22~20  b19~16   b15~14 b13~12 b11~10 b9~8  b7~6  b5 b4   b3   b2   b1   b0 
//<i>CCR2  -      TRGMODE STRMSEL BURSTLEN PL     SSIZE  DSIZE  SPTYP DPTYP -  TEIE BEIE HTIE TCIE EN 
// <q0.1> TCIE_ж
//    0: ֹTCж
//    1: TCж
// <q0.2> HTIE_봫ж 
//    0: ֹHTж
//    1: HTж
// <q0.3> BEIE_burstж
//    0: ֹBEж 
//    1: BEж
//    <i>burstΪ1ʱsingleģʽͬBEжϡ
// <q0.4> TEIE_ж
//    0: ֹTEж
//    1: TEж
// <o0.6..7> DPTYP_Ŀָ޸ķʽ
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.8..9> SPTYP_Դָ޸ķʽ
//λú
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.10..11> DSIZE_Ŀݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ 
//    <3=>
// <o0.12..13> SSIZE_Դݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ  
//    <3=>
// <o0.14..15> PL_ͨȼ
//Щλú
//    <0=>
//    <1=>
//    <2=> 
//    <3=>
// <o0.16..19> BURSTLEN_DMAͻλ
//λú
//    <0=>ÿburst1ݣsingle䣩
//    <1=>ÿburst2
//    <2=>ÿburst3
//    <3=>ÿburst4
//    <4=>ÿburst5
//    <5=>ÿburst6
//    <6=>ÿburst7
//    <7=>ÿburst8
//    <8=>ÿburst9
//    <9=>ÿburst10
//    <10=>ÿburst11
//    <11=>ÿburst12
//    <12=>ÿburst13
//    <13=>ÿburst14
//    <14=>ÿburst15
//    <15=>ÿburst16
//    <i>SIZEõĲͬ1ݴܰ1ֽ/2ֽ/4ֽڡ
// <o0.20..22> STRMSEL_DMAͨԴѡλ
//<i>Channel		CH0	CH1	CH2	CH3	CH4	CH5	CH6	CH7
//<i>stream0_UART	UART2_TX	UART2_RX	UART1_TX	UART1_RX	UART1_TX	UART1_RX	UART3_RX	UART3_TX
//<i>stream1_SPI/TWI	SPI1_TX	SPI1_RX	SPI2_RX	SPI2_TX	UART2_TX	UART2_RX	SPI1_TX	SPI1_RX
//<i>stream2_EXTI	EXTI0/1	EXTI2/3	EXTI4/5	EXTI6/7	EXTI8/9	EXTI10/11	EXTI12/13	EXTI14/15
//<i>stream3_ADC	ADC1	ADC2	ADC3	ADC1	ADC1	ADC2	ADC3	ADC2
//<i>stream4_MCM	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2
//<i>stream5_GPT	GPT0	GPT1	GPT2	GPT3	GPT0	GPT1	GPT2	GPT3
//<i>stream6_QEI	CMP1	QEI	GPT	CMP2	QEI	CMP	CMP3	GPT
//<i>stream7_TIM	TIM5	TIM6	TIM7	TIM8	TIM5	TIM6	TIM7	TIM8
//    <0=>ѡstream0
//    <1=>ѡstream1
//    <2=>ѡstream2
//    <3=>ѡstream3
//    <4=>ѡstream4
//    <5=>ѡstream5
//    <6=>ѡstream6
//    <7=>ѡstream7
// <o0.23> TRGMODE_DMAģʽѡλ
//λú
//    <0=>one-shotʽ
//    <1=>to-endʽ
//</h>
#define CFG_DMA_CCR2_INIT		0x0


//<h>NPKT2_DMAͨ2Ĵ
//<i>0x054 b31~11 b10~0 
//<i>NPKT2 -      NPKT  
// <o0.0..10> NPKT_ͨ2ݴburst<0-511>
//    ݴΪNPKT÷Χ0511ʾburst1512Ĵֻͨ(DMA_CCRxEN=0)ʱд롣ͨüĴΪֻ
//</h>
#define CFG_DMA_NPKT2_INIT	0x0

//<h>SAR2_DMAͨ2ԴַĴ
//<i>0x05C b31~0 
//<i>SAR2  SAR   
// <o0.0..31> SAR_DMAԴַĴ
//     ԴݼĴĻַ
//     SSIZE=01(16λ)ʹSARλԶֵַ롣
//     SSIZE=10(32λ)ʹSARλԶֵַ롣
//     ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_SAR2_INIT	0x0

//<h>DAR2_DMAͨ2ĿַĴ
//<i>0x060 b31~0 
//<i>DAR2  DAR   
// <o0.0..31> DAR_DMAĿַĴ 
//    ĿݼĴĻַ
//    DSIZE=01(16λ)ʹDARλԶֵַ롣
//    DSIZE=10(32λ)ʹDARλԶֵַ롣
//    ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_DAR2_INIT	0x0

//</e>
//<e>DMA_CH3
#define CFG_DMA_CH3_EN 0

//<h>CCR3_DMAͨ3üĴ
//<i>0x070 b31~24 b23     b22~20  b19~16   b15~14 b13~12 b11~10 b9~8  b7~6  b5 b4   b3   b2   b1   b0 
//<i>CCR3  -      TRGMODE STRMSEL BURSTLEN PL     SSIZE  DSIZE  SPTYP DPTYP -  TEIE BEIE HTIE TCIE EN 
// <q0.1> TCIE_ж
//    0: ֹTCж
//    1: TCж
// <q0.2> HTIE_봫ж 
//    0: ֹHTж
//    1: HTж
// <q0.3> BEIE_burstж
//    0: ֹBEж 
//    1: BEж
//    <i>burstΪ1ʱsingleģʽͬBEжϡ
// <q0.4> TEIE_ж
//    0: ֹTEж
//    1: TEж
// <o0.6..7> DPTYP_Ŀָ޸ķʽ
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.8..9> SPTYP_Դָ޸ķʽ
//λú
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.10..11> DSIZE_Ŀݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ 
//    <3=>
// <o0.12..13> SSIZE_Դݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ  
//    <3=>
// <o0.14..15> PL_ͨȼ
//Щλú
//    <0=>
//    <1=>
//    <2=> 
//    <3=>
// <o0.16..19> BURSTLEN_DMAͻλ
//λú
//    <0=>ÿburst1ݣsingle䣩
//    <1=>ÿburst2
//    <2=>ÿburst3
//    <3=>ÿburst4
//    <4=>ÿburst5
//    <5=>ÿburst6
//    <6=>ÿburst7
//    <7=>ÿburst8
//    <8=>ÿburst9
//    <9=>ÿburst10
//    <10=>ÿburst11
//    <11=>ÿburst12
//    <12=>ÿburst13
//    <13=>ÿburst14
//    <14=>ÿburst15
//    <15=>ÿburst16
//    <i>SIZEõĲͬ1ݴܰ1ֽ/2ֽ/4ֽڡ
// <o0.20..22> STRMSEL_DMAͨԴѡλ
//<i>Channel		CH0	CH1	CH2	CH3	CH4	CH5	CH6	CH7
//<i>stream0_UART	UART2_TX	UART2_RX	UART1_TX	UART1_RX	UART1_TX	UART1_RX	UART3_RX	UART3_TX
//<i>stream1_SPI/TWI	SPI1_TX	SPI1_RX	SPI2_RX	SPI2_TX	UART2_TX	UART2_RX	SPI1_TX	SPI1_RX
//<i>stream2_EXTI	EXTI0/1	EXTI2/3	EXTI4/5	EXTI6/7	EXTI8/9	EXTI10/11	EXTI12/13	EXTI14/15
//<i>stream3_ADC	ADC1	ADC2	ADC3	ADC1	ADC1	ADC2	ADC3	ADC2
//<i>stream4_MCM	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2
//<i>stream5_GPT	GPT0	GPT1	GPT2	GPT3	GPT0	GPT1	GPT2	GPT3
//<i>stream6_QEI	CMP1	QEI	GPT	CMP2	QEI	CMP	CMP3	GPT
//<i>stream7_TIM	TIM5	TIM6	TIM7	TIM8	TIM5	TIM6	TIM7	TIM8
//    <0=>ѡstream0
//    <1=>ѡstream1
//    <2=>ѡstream2
//    <3=>ѡstream3
//    <4=>ѡstream4
//    <5=>ѡstream5
//    <6=>ѡstream6
//    <7=>ѡstream7
// <o0.23> TRGMODE_DMAģʽѡλ
//λú
//    <0=>one-shotʽ
//    <1=>to-endʽ
//</h>
#define CFG_DMA_CCR3_INIT		0x0


//<h>NPKT3_DMAͨ3Ĵ
//<i>0x074 b31~11 b10~0 
//<i>NPKT3 -      NPKT  
// <o0.0..10> NPKT_ͨ3ݴburst<0-511>
//    ݴΪNPKT÷Χ0511ʾburst1512Ĵֻͨ(DMA_CCRxEN=0)ʱд롣ͨüĴΪֻ
//</h>
#define CFG_DMA_NPKT3_INIT	0x0

//<h>SAR3_DMAͨ3ԴַĴ
//<i>0x07C b31~0 
//<i>SAR3  SAR   
// <o0.0..31> SAR_DMAԴַĴ
//     ԴݼĴĻַ
//     SSIZE=01(16λ)ʹSARλԶֵַ롣
//     SSIZE=10(32λ)ʹSARλԶֵַ롣
//     ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_SAR3_INIT	0x0

//<h>DAR3_DMAͨ3ĿַĴ
//<i>0x080 b31~0 
//<i>DAR3  DAR   
// <o0.0..31> DAR_DMAĿַĴ 
//    ĿݼĴĻַ
//    DSIZE=01(16λ)ʹDARλԶֵַ롣
//    DSIZE=10(32λ)ʹDARλԶֵַ롣
//    ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_DAR3_INIT	0x0
//</e>


//<e>DMA_CH4
#define CFG_DMA_CH4_EN 0

//<h>CCR4_DMAͨ4üĴ
//<i>0x090 b31~24 b23     b22~20  b19~16   b15~14 b13~12 b11~10 b9~8  b7~6  b5 b4   b3   b2   b1   b0 
//<i>CCR4  -      TRGMODE STRMSEL BURSTLEN PL     SSIZE  DSIZE  SPTYP DPTYP -  TEIE BEIE HTIE TCIE EN 
// <q0.1> TCIE_ж
//    0: ֹTCж
//    1: TCж
// <q0.2> HTIE_봫ж 
//    0: ֹHTж
//    1: HTж
// <q0.3> BEIE_burstж
//    0: ֹBEж 
//    1: BEж
//    <i>burstΪ1ʱsingleģʽͬBEжϡ
// <q0.4> TEIE_ж
//    0: ֹTEж
//    1: TEж
// <o0.6..7> DPTYP_Ŀָ޸ķʽ
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.8..9> SPTYP_Դָ޸ķʽ
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.10..11> DSIZE_Ŀݿ
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ 
//    <3=>
// <o0.12..13> SSIZE_Դݿ
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ  
//    <3=>
// <o0.14..15> PL_ͨȼ
//    <0=>
//    <1=>
//    <2=> 
//    <3=>
// <o0.16..19> BURSTLEN_DMAͻλ
//λú
//    <0=>ÿburst1ݣsingle䣩
//    <1=>ÿburst2
//    <2=>ÿburst3
//    <3=>ÿburst4
//    <4=>ÿburst5
//    <5=>ÿburst6
//    <6=>ÿburst7
//    <7=>ÿburst8
//    <8=>ÿburst9
//    <9=>ÿburst10
//    <10=>ÿburst11
//    <11=>ÿburst12
//    <12=>ÿburst13
//    <13=>ÿburst14
//    <14=>ÿburst15
//    <15=>ÿburst16
//    <i>SIZEõĲͬ1ݴܰ1ֽ/2ֽ/4ֽڡ
// <o0.20..22> STRMSEL_DMAͨԴѡλ
//    <0=>ѡstream0
//    <1=>ѡstream1
//    <2=>ѡstream2
//    <3=>ѡstream3
//    <4=>ѡstream4
//    <5=>ѡstream5
//    <6=>ѡstream6
//    <7=>ѡstream7
// <o0.23> TRGMODE_DMAģʽѡλ
//    <0=>one-shotʽ
//    <1=>to-endʽ
//</h>
#define CFG_DMA_CCR4_INIT		0x0


//<h>NPKT4_DMAͨ4Ĵ
//<i>0x094 b31~11 b10~0 
//<i>NPKT4 -      NPKT  
// <o0.0..10> NPKT_ͨ4ݴburst<0-511>
//<i>ݴΪNPKT÷Χ0511ʾburst1512Ĵֻͨ(DMA_CCRxEN=0)ʱд롣ͨüĴΪֻ 
//</h>
#define CFG_DMA_NPKT4_INIT	0x0

//<h>SAR4_DMAͨ4ԴַĴ
//<i>0x09C b31~0 
//<i>SAR4  SAR   
// <o0.0..31> SAR_DMAԴַĴ
// <i> ԴݼĴĻַ
// <i> SSIZE=01(16λ)ʹSARλԶֵַ롣
// <i> SSIZE=10(32λ)ʹSARλԶֵַ롣
// <i> ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_SAR4_INIT	0x0

//<h>DAR4_DMAͨ4ĿַĴ
//<i>0x0A0 b31~0 
//<i>DAR4  DAR   
// <o0.0..31> DAR_DMAĿַĴ 
// <i>   ĿݼĴĻַ
// <i>   DSIZE=01(16λ)ʹDARλԶֵַ롣
// <i>   DSIZE=10(32λ)ʹDARλԶֵַ롣
// <i>   ͨ(DMA_CCRxEN=1)ʱдüĴ 
//</h>
#define CFG_DMA_DAR4_INIT	0x0
//</e>


//<e>DMA_CH5
#define CFG_DMA_CH5_EN 0

//<h>CCR5_DMAͨ5üĴ
//<i>0x0B0 b31~24 b23     b22~20  b19~16   b15~14 b13~12 b11~10 b9~8  b7~6  b5 b4   b3   b2   b1   b0 
//<i>CCR5  -      TRGMODE STRMSEL BURSTLEN PL     SSIZE  DSIZE  SPTYP DPTYP -  TEIE BEIE HTIE TCIE EN 
// <q0.1> TCIE_ж
//    0: ֹTCж
//    1: TCж
// <q0.2> HTIE_봫ж 
//    0: ֹHTж
//    1: HTж
// <q0.3> BEIE_burstж
//    0: ֹBEж 
//    1: BEж
//    <i>burstΪ1ʱsingleģʽͬBEжϡ
// <q0.4> TEIE_ж
//    0: ֹTEж
//    1: TEж
// <o0.6..7> DPTYP_Ŀָ޸ķʽ
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.8..9> SPTYP_Դָ޸ķʽ
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.10..11> DSIZE_Ŀݿ
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ 
//    <3=>
// <o0.12..13> SSIZE_Դݿ
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ  
//    <3=>
// <o0.14..15> PL_ͨȼ
//    <0=>
//    <1=>
//    <2=> 
//    <3=>
// <o0.16..19> BURSTLEN_DMAͻλ
//λú
//    <0=>ÿburst1ݣsingle䣩
//    <1=>ÿburst2
//    <2=>ÿburst3
//    <3=>ÿburst4
//    <4=>ÿburst5
//    <5=>ÿburst6
//    <6=>ÿburst7
//    <7=>ÿburst8
//    <8=>ÿburst9
//    <9=>ÿburst10
//    <10=>ÿburst11
//    <11=>ÿburst12
//    <12=>ÿburst13
//    <13=>ÿburst14
//    <14=>ÿburst15
//    <15=>ÿburst16
//    <i>SIZEõĲͬ1ݴܰ1ֽ/2ֽ/4ֽڡ
// <o0.20..22> STRMSEL_DMAͨԴѡλ
//    <0=>ѡstream0
//    <1=>ѡstream1
//    <2=>ѡstream2
//    <3=>ѡstream3
//    <4=>ѡstream4
//    <5=>ѡstream5
//    <6=>ѡstream6
//    <7=>ѡstream7
// <o0.23> TRGMODE_DMAģʽѡλ
//    <0=>one-shotʽ
//    <1=>to-endʽ
//</h>
#define CFG_DMA_CCR5_INIT	0x0


//<h>NPKT5_DMAͨ5Ĵ
//<i>0x0B4 b31~11 b10~0 
//<i>NPKT5 -      NPKT  
// <o0.0..10> NPKT_ͨ5ݴburst<0-511>
//<i>ݴΪNPKT÷Χ0511ʾburst1512Ĵֻͨ(DMA_CCRxEN=0)ʱд롣ͨüĴΪֻ 
//</h>
#define CFG_DMA_NPKT5_INIT	0x0

//<h>SAR5_DMAͨ5ԴַĴ
//<i>0x0BC b31~0 
//<i>SAR5  SAR   
// <o0.0..31> SAR_DMAԴַĴ
// <i>ԴݼĴĻַ
// <i>SSIZE=01(16λ)ʹSARλԶֵַ롣
// <i>SSIZE=10(32λ)ʹSARλԶֵַ롣
// <i>ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_SAR5_INIT	0x0

//<h>DAR5_DMAͨ5ĿַĴ
//<i>0x0C0 b31~0 
//<i>DAR5  DAR   
// <o0.0..31> DAR_DMAĿַĴ
//  <i>ĿݼĴĻַ
//  <i>DSIZE=01(16λ)ʹDARλԶֵַ롣
//  <i>DSIZE=10(32λ)ʹDARλԶֵַ롣
//  <i>ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_DAR5_INIT	0x0
//</e>

//<e>DMA_CH6
#define CFG_DMA_CH6_EN 0
//<h>CCR6_DMAͨ6üĴ
//<i>0x0D0 b31~24 b23     b22~20  b19~16   b15~14 b13~12 b11~10 b9~8  b7~6  b5 b4   b3   b2   b1   b0 
//<i>CCR6  -      TRGMODE STRMSEL BURSTLEN PL     SSIZE  DSIZE  SPTYP DPTYP -  TEIE BEIE HTIE TCIE EN 
// <q0.1> TCIE_ж
//    0: ֹTCж
//    1: TCж
// <q0.2> HTIE_봫ж 
//    0: ֹHTж
//    1: HTж
// <q0.3> BEIE_burstж
//    0: ֹBEж 
//    1: BEж
//    <i>burstΪ1ʱsingleģʽͬBEжϡ
// <q0.4> TEIE_ж
//    0: ֹTEж
//    1: TEж
// <o0.6..7> DPTYP_Ŀָ޸ķʽ
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.8..9> SPTYP_Դָ޸ķʽ
//λú
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.10..11> DSIZE_Ŀݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ 
//    <3=>
// <o0.12..13> SSIZE_Դݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ  
//    <3=>
// <o0.14..15> PL_ͨȼ
//Щλú
//    <0=>
//    <1=>
//    <2=> 
//    <3=>
// <o0.16..19> BURSTLEN_DMAͻλ
//λú
//    <0=>ÿburst1ݣsingle䣩
//    <1=>ÿburst2
//    <2=>ÿburst3
//    <3=>ÿburst4
//    <4=>ÿburst5
//    <5=>ÿburst6
//    <6=>ÿburst7
//    <7=>ÿburst8
//    <8=>ÿburst9
//    <9=>ÿburst10
//    <10=>ÿburst11
//    <11=>ÿburst12
//    <12=>ÿburst13
//    <13=>ÿburst14
//    <14=>ÿburst15
//    <15=>ÿburst16
//    <i>SIZEõĲͬ1ݴܰ1ֽ/2ֽ/4ֽڡ
// <o0.20..22> STRMSEL_DMAͨԴѡλ
//<i>Channel		CH0	CH1	CH2	CH3	CH4	CH5	CH6	CH7
//<i>stream0_UART	UART2_TX	UART2_RX	UART1_TX	UART1_RX	UART1_TX	UART1_RX	UART3_RX	UART3_TX
//<i>stream1_SPI/TWI	SPI1_TX	SPI1_RX	SPI2_RX	SPI2_TX	UART2_TX	UART2_RX	SPI1_TX	SPI1_RX
//<i>stream2_EXTI	EXTI0/1	EXTI2/3	EXTI4/5	EXTI6/7	EXTI8/9	EXTI10/11	EXTI12/13	EXTI14/15
//<i>stream3_ADC	ADC1	ADC2	ADC3	ADC1	ADC1	ADC2	ADC3	ADC2
//<i>stream4_MCM	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2
//<i>stream5_GPT	GPT0	GPT1	GPT2	GPT3	GPT0	GPT1	GPT2	GPT3
//<i>stream6_QEI	CMP1	QEI	GPT	CMP2	QEI	CMP	CMP3	GPT
//<i>stream7_TIM	TIM5	TIM6	TIM7	TIM8	TIM5	TIM6	TIM7	TIM8
//    <0=>ѡstream0
//    <1=>ѡstream1
//    <2=>ѡstream2
//    <3=>ѡstream3
//    <4=>ѡstream4
//    <5=>ѡstream5
//    <6=>ѡstream6
//    <7=>ѡstream7
// <o0.23> TRGMODE_DMAģʽѡλ
//λú
//    <0=>one-shotʽ
//    <1=>to-endʽ
//</h>
#define CFG_DMA_CCR6_INIT		0x0


//<h>NPKT6_DMAͨ6Ĵ
//<i>0x0D4 b31~11 b10~0 
//<i>NPKT6 -      NPKT  
// <o0.0..10> NPKT_ͨ6ݴburst<0-511>
//    ݴΪNPKT÷Χ0511ʾburst1512Ĵֻͨ(DMA_CCRxEN=0)ʱд롣ͨüĴΪֻ
//</h>
#define CFG_DMA_NPKT6_INIT	0x0

//<h>SAR6_DMAͨ6ԴַĴ
//<i>0x0DC b31~0 
//<i>SAR6  SAR   
// <o0.0..31> SAR_DMAԴַĴ
//     ԴݼĴĻַ
//     SSIZE=01(16λ)ʹSARλԶֵַ롣
//     SSIZE=10(32λ)ʹSARλԶֵַ롣
//     ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_SAR6_INIT	0x0

//<h>DAR6_DMAͨ6ĿַĴ
//<i>0x0E0 b31~0 
//<i>DAR6  DAR   
// <o0.0..31> DAR_DMAĿַĴ 
//    ĿݼĴĻַ
//    DSIZE=01(16λ)ʹDARλԶֵַ롣
//    DSIZE=10(32λ)ʹDARλԶֵַ롣
//    ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_DAR6_INIT	0x0

//</e>
//<e>DMA_CH7
#define CFG_DMA_CH7_EN 0
//<h>CCR7_DMAͨ7üĴ
//<i>0x0F0 b31~24 b23     b22~20  b19~16   b15~14 b13~12 b11~10 b9~8  b7~6  b5 b4   b3   b2   b1   b0 
//<i>CCR7  -      TRGMODE STRMSEL BURSTLEN PL     SSIZE  DSIZE  SPTYP DPTYP -  TEIE BEIE HTIE TCIE EN 
// <q0.1> TCIE_ж
//    0: ֹTCж
//    1: TCж
// <q0.2> HTIE_봫ж 
//    0: ֹHTж
//    1: HTж
// <q0.3> BEIE_burstж
//    0: ֹBEж 
//    1: BEж
//    <i>burstΪ1ʱsingleģʽͬBEжϡ
// <q0.4> TEIE_ж
//    0: ֹTEж
//    1: TEж
// <o0.6..7> DPTYP_Ŀָ޸ķʽ
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.8..9> SPTYP_Դָ޸ķʽ
//λú
//    <0=>
//    <1=>ݼ
//    <2=>̶
//    <3=>ѭѭ
// <o0.10..11> DSIZE_Ŀݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ 
//    <3=>
// <o0.12..13> SSIZE_Դݿ
//Щλú
//    <0=>8λ
//    <1=>16λ 
//    <2=>32λ  
//    <3=>
// <o0.14..15> PL_ͨȼ
//Щλú
//    <0=>
//    <1=>
//    <2=> 
//    <3=>
// <o0.16..19> BURSTLEN_DMAͻλ
//λú
//    <0=>ÿburst1ݣsingle䣩
//    <1=>ÿburst2
//    <2=>ÿburst3
//    <3=>ÿburst4
//    <4=>ÿburst5
//    <5=>ÿburst6
//    <6=>ÿburst7
//    <7=>ÿburst8
//    <8=>ÿburst9
//    <9=>ÿburst10
//    <10=>ÿburst11
//    <11=>ÿburst12
//    <12=>ÿburst13
//    <13=>ÿburst14
//    <14=>ÿburst15
//    <15=>ÿburst16
//    <i>SIZEõĲͬ1ݴܰ1ֽ/2ֽ/4ֽڡ
// <o0.20..22> STRMSEL_DMAͨԴѡλ
//<i>Channel		CH0	CH1	CH2	CH3	CH4	CH5	CH6	CH7
//<i>stream0_UART	UART2_TX	UART2_RX	UART1_TX	UART1_RX	UART1_TX	UART1_RX	UART3_RX	UART3_TX
//<i>stream1_SPI/TWI	SPI1_TX	SPI1_RX	SPI2_RX	SPI2_TX	UART2_TX	UART2_RX	SPI1_TX	SPI1_RX
//<i>stream2_EXTI	EXTI0/1	EXTI2/3	EXTI4/5	EXTI6/7	EXTI8/9	EXTI10/11	EXTI12/13	EXTI14/15
//<i>stream3_ADC	ADC1	ADC2	ADC3	ADC1	ADC1	ADC2	ADC3	ADC2
//<i>stream4_MCM	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2	MCM1	MCM2
//<i>stream5_GPT	GPT0	GPT1	GPT2	GPT3	GPT0	GPT1	GPT2	GPT3
//<i>stream6_QEI	CMP1	QEI	GPT	CMP2	QEI	CMP	CMP3	GPT
//<i>stream7_TIM	TIM5	TIM6	TIM7	TIM8	TIM5	TIM6	TIM7	TIM8
//    <0=>ѡstream0
//    <1=>ѡstream1
//    <2=>ѡstream2
//    <3=>ѡstream3
//    <4=>ѡstream4
//    <5=>ѡstream5
//    <6=>ѡstream6
//    <7=>ѡstream7
// <o0.23> TRGMODE_DMAģʽѡλ
//λú
//    <0=>one-shotʽ
//    <1=>to-endʽ
//</h>
#define CFG_DMA_CCR7_INIT		0x0


//<h>NPKT7_DMAͨ7Ĵ
//<i>0x0F4 b31~11 b10~0 
//<i>NPKT7 -      NPKT  
// <o0.0..10> NPKT_ͨ7ݴburst<0-511>
//    ݴΪNPKT÷Χ0511ʾburst1512Ĵֻͨ(DMA_CCRxEN=0)ʱд롣ͨüĴΪֻ
//</h>
#define CFG_DMA_NPKT7_INIT	0x0

//<h>SAR7_DMAͨ7ԴַĴ
//<i>0x0FC b31~0 
//<i>SAR7  SAR   
// <o0.0..31> SAR_DMAԴַĴ
//     ԴݼĴĻַ
//     SSIZE=01(16λ)ʹSARλԶֵַ롣
//     SSIZE=10(32λ)ʹSARλԶֵַ롣
//     ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_SAR7_INIT	0x0

//<h>DAR7_DMAͨ7ĿַĴ
//<i>0x100 b31~0 
//<i>DAR7  DAR   
// <o0.0..31> DAR_DMAĿַĴ 
//    ĿݼĴĻַ
//    DSIZE=01(16λ)ʹDARλԶֵַ롣
//    DSIZE=10(32λ)ʹDARλԶֵַ롣
//    ͨ(DMA_CCRxEN=1)ʱдüĴ
//</h>
#define CFG_DMA_DAR7_INIT	0x0
//</e>
#define CFG_DMA_CH7_EN 0

#if (((CFG_DMA_CCR2_INIT & 0xF) != 0) || ((CFG_DMA_CCR3_INIT & 0xF) != 0) || ((CFG_DMA_CCR4_INIT & 0xF) != 0) || ((CFG_DMA_CCR5_INIT & 0xF) != 0) || ((CFG_DMA_CCR6_INIT & 0xF) != 0) || ((CFG_DMA_CCR7_INIT & 0xF) != 0)) 
	#define CFG_DMA_CH2_7_INT_EN 1
#else
	#define CFG_DMA_CH2_7_INT_EN 0
#endif


//***********************************************************/
//</e>


//<e>MCM
#define CFG_MCM_EN	0
//***********************************************************/
//<e>MCM1
#define CFG_MCM1_PWMOE	0
#define  CFG_MCM1_EN CFG_MCM1_PWMOE
// <o> PWMPSQ_PWMƵϵ<0-65535>
//<i>PWMʱΪ(PCLK2/(PSQ[15:0]+1)) 
#define CFG_MCM1_PWMPSQ_INIT	0x0

// <o> PWMP_PWMƵ (0-50000Hz) <0-50000> 
#define CFG_MCM1_PWMP_F	12000


//<o0>PWMD0:  PWM0ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o1>PWMD1:  PWM1ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o2>PWMD2:  PWM2ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o3>PWMD01: PWM01ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o4>PWMD11: PWM11ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o5>PWMD21: PWM21ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
#define CFG_MCM1_PWM0_DUTY	500
#define CFG_MCM1_PWM1_DUTY	500
#define CFG_MCM1_PWM2_DUTY	500
#define CFG_MCM1_PWM01_DUTY	500
#define CFG_MCM1_PWM11_DUTY	500
#define CFG_MCM1_PWM21_DUTY	500


// <o0.1..3> SECTOR_SVPWM趨λ
//<i>MAXMUMMIN
//    <0=>PWM2D > PWM1D > PWM0D
//    <1=>PWM2D > PWM0D > PWM1D
//    <2=>PWM0D > PWM2D > PWM1D
//    <3=>PWM0D > PWM1D > PWM2D
//    <4=>PWM1D > PWM0D > PWM2D
//    <5=>PWM1D > PWM2D > PWM0D
//    <i>趨110111ʱЧ
//    <i>SVPWM趨λͨλȷPWM0DPWM1DPWM2DĴС˳ֵʱĴС˳
#define CFG_MCM1_PSCON_L_INIT	0x0


// <q0.7> ʹֹͣPWM
//    0: ֹ
//    1: ʹ
#define CFG_MCM1_POSTDCR_INIT	0

//<h>PWM
// <o0.15> POUTMOD_PWM0/1/2ģʽ/λ
//    <0=>3ͨ
//    <1=>6·
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ

// <o0.12..14> POSTPS_Ƶϵ
//    <0=>޺Ƶ
//    <1=>жϡź¼źŽ2Ƶ
//    <2=>жϡź¼źŽ3Ƶ
//    <3=>жϡź¼źŽ4Ƶ
//    <4=>жϡź¼źŽ5Ƶ
//    <5=>жϡź¼źŽ6Ƶ
//    <6=>жϡź¼źŽ7Ƶ
//    <7=>жϡź¼źŽ8Ƶ
// <o0.10..11> PTMOD_PWM0/1/2ģʽ
//    <0=>ضģʽ   
//    <1=>Ķģʽ
//    <2=>μģʽ
//<i>ضģʽģʽ£ʱֻᷢƥ
//<i>Ķģʽģʽ£ʱᷢƥƥ
//<i>μģʽģʽ£ʱֻᷢƥ
// <o0.9> PWMSYM_PWMζԳԿ
//    <0=>ԳPWM
//    <1=>ǶԳPWM
//<i>ĶģʽĻʱЧ
// <o0.6> PDCON0_PWM0/PWM01ԭʼDUTYλ
//    <0=>ֵСռձȼĴʱΪDUTY
//    <1=>ֵڵռձȼĴʱΪDUTY
// <o0.7> PDCON1_PWM1/PWM11ԭʼDUTYλ
//    <0=>ֵСռձȼĴʱΪDUTY
//    <1=>ֵڵռձȼĴʱΪDUTY
// <o0.8> PDCON2_PWM2/PWM21ԭʼDUTYλ
//    <0=>ֵСռձȼĴʱΪDUTY
//    <1=>ֵڵռձȼĴʱΪDUTY
// <o0.0> PWM0S_PWM0Чƽѡλ
//    <0=>PWM0Dutyߵƽʱ͵ƽ
//    <1=>PWM0Duty͵ƽʱߵƽ
// <o0.1> PWM1S_PWM1Чƽѡλ
//    <0=>PWM1Dutyߵƽʱ͵ƽ
//    <1=>PWM1Duty͵ƽʱߵƽ
// <o0.2> PWM2S_PWM2Чƽѡλ
//    <0=>PWM2Dutyߵƽʱ͵ƽ
//    <1=>PWM2Duty͵ƽʱߵƽ
// <o0.3> PWM01S_PWM01Чƽѡλ
//    <0=>PWM01Duty͵ƽʱߵƽ
//    <1=>PWM01Dutyߵƽʱ͵ƽ
// <o0.4> PWM11S_PWM11Чƽѡλ
//    <0=>PWM11Duty͵ƽʱߵƽ
//    <1=>PWM11Dutyߵƽʱ͵ƽ
// <o0.5> PWM21S_PWM21Чƽѡλ
//    <0=>PWM21Duty͵ƽʱߵƽ
//    <1=>PWM21Dutyߵƽʱ͵ƽ

#define CFG_MCM1_PWMCON1_INIT	0x0
//</h>

//<h>PWM
// <o> PWMDT00_PWMͨ0(0.1us) <0-100>
#define CFG_MCM1_PWMDT00_DT	20

// <o> PWMDT01_PWMͨ0½(0.1us) <0-100>
#define CFG_MCM1_PWMDT01_DT	20

// <o> PWMDT10_PWMͨ1(0.1us) <0-100>
#define CFG_MCM1_PWMDT10_DT	20


// <o> PWMDT11_PWMͨ1½(0.1us) <0-100>
#define CFG_MCM1_PWMDT11_DT	20


// <o> PWMDT20_PWMͨ2(0.1us) <0-100>
#define CFG_MCM1_PWMDT20_DT	20


// <o> PWMDT21_PWMͨ2½(0.1us) <0-100>
#define CFG_MCM1_PWMDT21_DT	20
//</h>


//<h>ȽϼĴAD
// <o0.0..1> CMP1_ȽϼĴ1ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ1ʱᴥAD
//    <2=>ֻPWMȽϼĴ1ʱᴥAD
//PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ1ʱᴥAD
//PTMOD = 01ĶģʽЧ    
//<i>ADCADONPWMTRGENλ1
// <o1> PWMCMP1_¼Ƚֵ1ٷֱ(0.1%) <0-1000>
// <o0.2..3> CMP2_ȽϼĴ2ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ2ʱᴥAD
//    <2=>ֻPWMȽϼĴ2ʱᴥAD
// PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ2ʱᴥAD
//PTMOD = 01    ADCADONPWMTRGENλ1£
//<i>ADCADONPWMTRGENλ1
// <o2> PWMCMP2_¼Ƚֵ2ٷֱ(0.1%) <0-1000>
// <o0.4..5> CMP3_ȽϼĴ3ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ3ʱᴥAD
//    <2=>ֻPWMȽϼĴ3ʱᴥAD
//PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ3ʱᴥAD
//PTMOD = 01ĶģʽЧ    ADCADONPWMTRGENλ1£
//<i>ADCADONPWMTRGENλ1
// <o3> PWMCMP3_¼Ƚֵ3ٷֱ(0.1%) <0-1000>
// <o0.6..7> CMP4_ȽϼĴ4ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ4ʱᴥAD
//    <2=>ֻPWMȽϼĴ4ʱᴥAD
// PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ4ʱᴥAD
//PTMOD = 01    ADCADONPWMTRGENλ1£
//<i>ADCADONPWMTRGENλ1
// <o4> PWMCMP4_¼Ƚֵ4ٷֱ(0.1%) <0-1000>
//</h>
//<h>ͬ
// <o0.8> OSYNC_ֶ޸PWMx/PWMx1ͬλ
//    <0=>ֶ޸ĺЧ
//    <1=>ֶ޸PWMͬЧ
//<i>ֶ޸ͨPMANUALCON1/2Ĵʵ,һĴ޸,ʱЧɴ˼Ĵ
// <o0.9> DILDEN_PWMռձȼĴЧʹλ
//    <0=>PWMͬЧ
//    <1=>Ч
// <o0.10> CILDEN_PWM¼ȽϼĴЧʹλ
//    <0=>PWMͬЧ
//    <1=>Ч
// <q0.11> ZDLDEN_PWMƥʱռձȼĴĴ
//    <i> ֵܴǷ趨0ƥʱԶڼĴƵԤƵĴκμĴ
// <q0.12> PDLDEN_PWMƥʱռձȼĴĴ
//    <i>ۼĴãƥʱPWMڼĴƵԤƵĴ,ֻĶģʽЧ
// <q0.13> ZCMLDEN_PWMƥʱ¼Ĵ
//<i>PWMCMPxx=1,2,3,4,ƥʱ¼ȽϼĴADʽĴ(CMP1~4[1-0])ʹλ      
// <q0.14> PCMLDEN_PWMƥʱ¼Ĵ
//<i>ƥʱ¼ȽϼĴADʽĴ(CMP1~4[1-0])ʹλֻĶģʽЧ
// <q0.15> MCMSYNEN_MCM1MCM2ͬʹλ
//    0: رMCM1MCM2ͬ
//    1: MCM1MCM2ͬ
//    <i>Ϊ˷ֹֻMCM1.PWMOE[MCMSYNEN]MCM2.PWMOE[MCMSYNEN]ͬʱ1ܿͬ,ֻĶģʽЧ
//</h>

#define CFG_MCM1_PWMCON2_INIT	0x0
#define CFG_MCM1_PWMCMP1_VALUE	0
#define CFG_MCM1_PWMCMP2_VALUE	0
#define CFG_MCM1_PWMCMP3_VALUE	0
#define CFG_MCM1_PWMCMP4_VALUE	0


//<h>PWM0/1/2ֶ
//<i>PMANUALCON1_PWM0/1/2ֶüĴ1
//<i>0x058       b31~6 b5        b4        b3        b2       b1       b0       
//<i>PMANUALCON1 -     PMANUAL21 PMANUAL11 PMANUAL01 PMANUAL2 PMANUAL1 PMANUAL0 
//<i>PMANUALCON2_PWM0/1/2ֶüĴ2
//<i>0x05C       b31~6 b5     b4     b3     b2    b1    b0    
//<i>PMANUALCON2 -     POUT21 POUT11 POUT01 POUT2 POUT1 POUT0 
// <o0.0> PMANUAL0_PWM0λ
//    <0=>PWM0PWM
//    <1=>PWM0PMANUALCON2ĴеPOUT0λ

// <o0.1> PMANUAL1_PWM1λ
//    <0=>PWM1PWM
//    <1=>PWM1PMANUALCON2ĴеPOUT1λ
// <o0.2> PMANUAL2_PWM2λ
//    <0=>PWM2PWM
//    <1=>PWM2PMANUALCON2ĴеPOUT2λ
// <o0.3> PMANUAL01_PWM01λ
//    <0=>PWM01PWM
//    <1=>PWM01PMANUALCON2ĴеPOUT01λ
// <o0.4> PMANUAL11_PWM11λ
//    <0=>PWM11PWM
//    <1=>PWM11PMANUALCON2ĴеPOUT11λ
// <o0.5> PMANUAL21_PWM21λ
//    <0=>PWM21PWM
//    <1=>PWM21PMANUALCON2ĴеPOUT21λ
#define CFG_MCM1_PMANUALCON1_INIT	0x0

//<h>PMANUALCON2_PWM0/1/2ֶüĴ2
//<i>0x05C       b31~6 b5     b4     b3     b2    b1    b0    
//<i>PMANUALCON2 -     POUT21 POUT11 POUT01 POUT2 POUT1 POUT0 
// <o0.0> POUT0_PMANUAL0 = 1ʱPWM0ڵƽ
//    <0=>0
//    <1=>1
// <o0.1> POUT1_PMANUAL1 = 1ʱPWM1ڵƽ
//    <0=>0
//    <1=>1
// <o0.2> POUT2_PMANUAL2 = 1ʱPWM2ڵƽ
//    <0=>0
//    <1=>1
// <o0.3> POUT01_PMANUAL01 = 1ʱPWM01ڵƽ
//    <0=>0
//    <1=>1
// <o0.4> POUT11_PMANUAL11 = 1ʱPWM11ڵƽ
//    <0=>0
//    <1=>1
// <o0.5> POUT21_PMANUAL21 = 1ʱPWM21ڵƽ
//    <0=>0
//    <1=>1
#define CFG_MCM1_PMANUALCON2_INIT	0x0
//</h>
//</h>

//<h>ϼ
//<i>0x060  b31~16 b15~14 b13~12 b11 b10    b9~8    b7~4    b3     b2    b1   b0      
//<i>FLTCON -      FOUT1  FOUT0  -   FLT1EN FLT1SEL FLT2DEB FLT2EN FLT2S FLTM FLTSTAT 
// <o0.1> FLTM_⹦ģʽѡ
//    <0=>ģʽ
//    <1=>ģʽ
//<i>ģʽ£⵽ЧFLTSTAT Ӳ1PWMֹͣΪЧʱ״ֲ̬䣬ֻеFLTSTATPWMβŻPWMʱ0ʱ̻ڼĴPWMPֵƥʱָһֱЧʱFLTSTAT޷
//<i>ģʽ£PWMֱɹϼƣЧFLTSTATӲ1رPWMΪЧFLTSTATԶ0PWM0/1/2νPWMʱ0ʱԶָ
// <q0.10> FLT1EN_ϼ1ʹ
//    <i>ϼ1ܴ򿪣ԴѡȽ1Ƚ2
// <o0.8..9> FLT1SEL_ϼ1Դѡλ
//    <0=>Ƚ1˲ΪPWMϼ1ԴߵƽЧ
//    <1=>Ƚ2˲ΪPWMϼ1ԴߵƽЧ
//    <2=>Ƚ3˲ΪPWMϼ1ԴߵƽЧ
//    <3=>

// <q0.3> FLT2EN_ϼ2ʹ
//    <i>ܴ򿪣ԴΪFLT
// <o0.2> FLT2S_ϼ2Чƽѡλ
//    <0=>FLTߵƽЧ
//    <1=>FLT͵ƽЧ
// <o0.4..7> FLT2DEB_ϼ2˲ѡ
//    <0=>˲
//    <1=>0.5us
//    <2=>1us
//    <3=>1.5us
//    <4=>2us
//    <5=>3us
//    <6=>4us
//    <7=>6us
//    <8=>8us
//    <9=>10us
//    <10=>12us
//    <11=>14us
//    <12=>16us
//    <13=>20us
//    <14=>24us
//    <15=>32us
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲Ϊ͵ƽ1С˲,˲0ͬʱΪ0

// <o0.12..13> FOUT0_ϷPWMx״̬ѡλ
//    <0=>̬
//    <2=>͵ƽ
//    <3=>ߵƽ
// <o0.14..15> FOUT1_ϷPWMx1״̬ѡλ
//    <0=>̬
//    <2=>͵ƽ
//    <3=>ߵƽ
//</h>
#define CFG_MCM1_FLTCON_INIT	0x00

//<e0.7>PWMʹ
//<i>0x064 b31~8 b7    b6 b5     b4     b3     b2    b1    b0    
//<i>POSCR -     OLSEN -  OLSG21 OLSG11 OLSG01 OLSG2 OLSG1 OLSG0 
// <o0.0> OLSG0_·PWM0Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.1> OLSG1_·PWM1Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.2> OLSG2_·PWM2Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.3> OLSG01_·PWM01Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.4> OLSG11_·PWM11Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.5> OLSG21_·PWM21Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
//</e>
#define CFG_MCM1_POSCR_INIT	0x0

//<h>PWMDMA
//<i>0x06C    b31~8 b7     b6     b5      b4      b3      b2      b1      b0      
//<i>PWMDMAEN -     PWMPDE PWMZDE PTDD2DE PTUD2DE PTDD1DE PTUD1DE PTDD0DE PTUD0DE 
// <q0.0> PTUD0DE_PWMʱPWM0DƥʱDMA

// <q0.1> PTDD0DE_PWMʱPWM0D/PWM01DƥʱDMA
//<i>ֻĶģʽЧ,ĶԳģʽ£ΪPWM0DĶǶԳģʽ£ΪPWM01D

// <q0.2> PTUD1DE_PWMʱPWM1DƥʱDMA

// <q0.3> PTDD1DE_PWMʱPWM1D/PWM11DƥʱDMA 
//<i>ֻĶģʽЧ,ĶԳģʽ£ΪPWM1DĶǶԳģʽ£ΪPWM11D

// <q0.4> PTUD2DE_PWMʱPWM2DƥʱDMA

// <q0.5> PTDD2DE_PWMʱPWM2D/PWM21DƥʱDMA
//<i>ֻĶģʽЧ;ĶԳģʽ£ΪPWM2DĶǶԳģʽ£ΪPWM21D

// <q0.6> PWMZDE_PWMʱ㴥DMA

// <q0.7> PWMPDE_PWMʱƥ䴥DMA
//<i>ֻĶģʽЧ
//</h>

#define CFG_MCM1_PWMDMAEN_INIT	0x0


//<h>PWMж
//<i>0x070    b31~11 b10    b9  b8    b7     b6     b5      b4      b3      b2      b1      b0      
//<i>PWMINTEN -      OSTDIE OIE FLTIE PWMPIE PWMZIE PTDD2IE PTUD2IE PTDD1IE PTUD1IE PTDD0IE PTUD0IE 
// <q0.0> PTUD0IE_PWMʱPWM0Dƥʱж
//    0: ֹPWMʱPWM0Dƥʱж
//    1: PWMʱPWM0Dƥʱж
// <q0.1> PTDD0IE_PWMʱPWM0Dƥʱж
//<i>ֻĶģʽЧ

// <q0.2> PTUD1IE_PWMʱPWM1Dƥʱж

// <q0.3> PTDD1IE_PWMʱPWM1Dƥʱж
//<i>ֻĶģʽЧ

// <q0.4> PTUD2IE_PWMʱPWM2Dƥʱж

// <q0.5> PTDD2IE_PWMʱPWM2Dƥʱж
//<i>ֻĶģʽЧ

// <q0.6> PWMZIE_PWMʱ㴥ж

// <q0.7> PWMPIE_PWMʱƥ䴥ж
//<i>ֻĶģʽЧ

// <q0.8> FLTIE_жλ
//    0: ֹϼж
//    1: ϼж
// <q0.9> OIE_·жλ
//    0: ֹж
//    1: ж
// <q0.10> OSTDIE_ֹͣPWMжʹλ
//    0: ֹж
//    1: ж

//</h>
#define CFG_MCM1_PWMINTEN_INIT	0x0

#if ((CFG_MCM1_PWMINTEN_INIT & 0xFF) != 0)
	#define CFG_MCM1_PWM_INT_EN 1
#else
	#define CFG_MCM1_PWM_INT_EN 0
#endif

#if ((CFG_MCM1_PWMINTEN_INIT & 0x700) != 0)
	#define CFG_MCM1_FLT_INT_EN 1
#else
	#define CFG_MCM1_FLT_INT_EN 0
#endif

//PWMRLDEN
//0x078    b31~8 b7~0     
//PWMRLDEN -     PWMRLDEN 
//PWMRLDEN_Ĵ޸ĺؿƼĴ
//    0x55:ģĴ޸
//    0xAA:ģļĴ
//    PWMģļĴжϱ־ĴPWMINTFֶƼĴPMANUALCON2FLTCONPOSCRPOSTDCR⣬Ĵ޸ֻеPWMRLDEN = 0x55ʱ޸ģ޸Ч
//    PWMģһЩĴлĴռձȼĴPWMxD&PWMx1DڼĴPWMPPWMʱԤƵĴPWMPSQƵĴPOSTPS[2:0]@ PWMCON1DutyѡĴPDCONx@PWMCON1ԳԿƼĴPWMSYM@PWMCON1ĴPWMDTxxȽϼĴADλCMPx@PWMCON2PWM¼ĴPWMCMPx

#define CFG_MCM1_PWMRLDEN_INIT	0x0

//<h>PWM
//<i>PSCON
//<i>0x07C b31~9 b8      b7~6      b5~4      b3~1   b0       
//<i>PSCON -     STATRUN MINSELECT MAXSELECT SECTOR SHIFTRUN 

// <o0.4..5> MAXSELECT_ʱޱȽֵȽϺPWMռձֵѡλ
//    <0=>κʱPWMxռձȣPWMxDֵ
//    <1=>PWMxDڵPWMDMAxʱPWMxD޸ΪPWMDMAx򲻱
//    <2=>PWMxDڵPWMDMAxʱPWMxD޸ΪֵPWMP򲻱
// <o0.6..7> MINSELECT_ʱޱȽֵȽϺPWMռձֵѡλ
//    <0=>κʱPWMxռձȣPWMxDֵ
//    <1=>PWMxDСڵPWMDMINʱPWMxD޸ΪPWMDMIN򲻱
//    <2=>PWMxDСڵPWMDMINʱPWMxD޸Ϊ0򲻱
#define CFG_MCM1_PSCON_H_INIT	0x00
#define CFG_MCM1_PSCON_INIT	(CFG_MCM1_PSCON_L_INIT|CFG_MCM1_PSCON_H_INIT)

// PWMDMAX_PWMռձޱȽϼĴ
// <o> PWMDMAX_PWMռձޱȽֵ(0.1%) <0-1000> 
//PWMDMAX
//0x080   b31~16 b15~0   
//PWMDMAX -      PWMDMAX 
#define CFG_MCM1_PWMDMAX_VALUE	0
// PWMDMIN_PWMռձޱȽϼĴ
// <o> PWMDMIN_PWMռձޱȽֵ(0.1%) <0-1000> 
//PWMDMIN
//0x084   b31~16 b15~0   
//PWMDMIN -      PWMDMIN 
#define CFG_MCM1_PWMDMIN_VALUE	0


// <o> PWMDCMP1_PWMռձСĴ1 <0-65535>
//<i>PWMDCMP1
//<i>0x088    b31~16 b15~0    
//<i>PWMDCMP1 -      PWMDCMP1 
#define CFG_MCM1_PWMDCMP1_INIT	0x0

// <o0> PWMDCMP2_PWMռձСĴ2 <0-65535>
//<i>PWMDCMP2
//<i>0x08C    b31~16 b15~0    
//<i>PWMDCMP2 -      PWMDCMP2 
#define CFG_MCM1_PWMDCMP2_INIT	0x0
//</h>

//<h>
//<e0.12>Ƚź1ʹ
//<i>0x090  b31~13 b12  b11 b10      b9       b8       b7~4  b3~0   
//<i>SC1CON -      SCEN SCS SCPWM2EN SCPWM1EN SCPWM0EN SCDEB SCTIME 
//SCEN_SC1ʹ
// <o0.11> SCS_SC1Чƽѡλ
//    <0=>SC1ߵƽЧ
//    <1=>SC1͵ƽЧ
// <q0.8> SCPWM0EN_SC1PWM0ʹ
// <q0.9> SCPWM1EN_SC1PWM1ʹ
// <q0.10> SCPWM2EN_SC1PWM2ʹ
// <o0.0..3> SCTIME_ʱѡλ
//    <0=>600*Pclk2
//    <1=>900*Pclk2
//    <2=>1200*Pclk2
//    <3=>1500*Pclk2
//    <4=>1800*Pclk2
//    <5=>2100*Pclk2
//    <6=>2400*Pclk2
//    <7=>3000*Pclk2
//    <8=>3600*Pclk2
//    <9=>4800*Pclk2
//    <10=>6000*Pclk2
//    <11=>12000*Pclk2
//    <12=>24000*Pclk2
//    <13=>36000*Pclk2
//    <14=>48000*Pclk2
//    <15=>60000*Pclk2
// <o0.4..7> SCDEB_SC1˲ѡ
//    <0=>0
//    <1=>30*Pclk2
//    <2=>60*Pclk2
//    <3=>90*Pclk2
//    <4=>120*Pclk2
//    <5=>180*Pclk2
//    <6=>240*Pclk2
//    <7=>360*Pclk2
//    <8=>480*Pclk2
//    <9=>600*Pclk2
//    <10=>720*Pclk2
//    <11=>840*Pclk2
//    <12=>960*Pclk2
//    <13=>1200*Pclk2
//    <14=>1440*Pclk2
//    <15=>1920*Pclk2
//   <i>˲ʱ䲻Ǿȷֵ
//   <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0

//</e>
#define CFG_MCM1_SC1CON_INIT	0x0000
//<e0.12>Ƚź2ʹ
//<i>0x094  b31~13 b12  b11 b10      b9       b8       b7~4  b3~0   
//<i>SC2CON -      SCEN SCS SCPWM2EN SCPWM1EN SCPWM0EN SCDEB SCTIME 
// <o0.11> SCS_SC2Чƽѡλ
//    <0=>SC2ߵƽЧ
//    <1=>SC2͵ƽЧ
// <q0.8> SCPWM0EN_SC2PWM0ʹ
// <q0.9> SCPWM1EN_SC2PWM1ʹ
// <q0.10> SCPWM2EN_SC2PWM2ʹ
// <o0.0..3> SCTIME_ʱѡλ
//    <0=>600*Pclk2
//    <1=>900*Pclk2
//    <2=>1200*Pclk2
//    <3=>1500*Pclk2
//    <4=>1800*Pclk2
//    <5=>2100*Pclk2
//    <6=>2400*Pclk2
//    <7=>3000*Pclk2
//    <8=>3600*Pclk2
//    <9=>4800*Pclk2
//    <10=>6000*Pclk2
//    <11=>12000*Pclk2
//    <12=>24000*Pclk2
//    <13=>36000*Pclk2
//    <14=>48000*Pclk2
//    <15=>60000*Pclk2
// <o0.4..7> SCDEB_SC2˲ѡ
//    <0=>0
//    <1=>30*Pclk2
//    <2=>60*Pclk2
//    <3=>90*Pclk2
//    <4=>120*Pclk2
//    <5=>180*Pclk2
//    <6=>240*Pclk2
//    <7=>360*Pclk2
//    <8=>480*Pclk2
//    <9=>600*Pclk2
//    <10=>720*Pclk2
//    <11=>840*Pclk2
//    <12=>960*Pclk2
//    <13=>1200*Pclk2
//    <14=>1440*Pclk2
//    <15=>1920*Pclk2
//   <i>˲ʱ䲻Ǿȷֵ
//   <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0

//</e>
#define CFG_MCM1_SC2CON_INIT	0x0000

//<e0.12>Ƚź3ʹ
//<i>0x098  b31~13 b12  b11 b10      b9       b8       b7~4  b3~0   
//<i>SC3CON -      SCEN SCS SCPWM2EN SCPWM1EN SCPWM0EN SCDEB SCTIME
// <o0.11> SCS_SC3Чƽѡλ
//    <0=>SC3ߵƽЧ
//    <1=>SC3͵ƽЧ
// <q0.8> SCPWM0EN_SC3PWM0ʹ
// <q0.9> SCPWM1EN_SC3PWM1ʹ
// <q0.10> SCPWM2EN_SC3PWM2ʹ
// <o0.0..3> SCTIME_ʱѡλ
//    <0=>600*Pclk2
//    <1=>900*Pclk2
//    <2=>1200*Pclk2
//    <3=>1500*Pclk2
//    <4=>1800*Pclk2
//    <5=>2100*Pclk2
//    <6=>2400*Pclk2
//    <7=>3000*Pclk2
//    <8=>3600*Pclk2
//    <9=>4800*Pclk2
//    <10=>6000*Pclk2
//    <11=>12000*Pclk2
//    <12=>24000*Pclk2
//    <13=>36000*Pclk2
//    <14=>48000*Pclk2
//    <15=>60000*Pclk2
// <o0.4..7> SCDEB_SC3˲ѡ
//    <0=>0
//    <1=>30*Pclk2
//    <2=>60*Pclk2
//    <3=>90*Pclk2
//    <4=>120*Pclk2
//    <5=>180*Pclk2
//    <6=>240*Pclk2
//    <7=>360*Pclk2
//    <8=>480*Pclk2
//    <9=>600*Pclk2
//    <10=>720*Pclk2
//    <11=>840*Pclk2
//    <12=>960*Pclk2
//    <13=>1200*Pclk2
//    <14=>1440*Pclk2
//    <15=>1920*Pclk2
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0
//</e>
#define CFG_MCM1_SC3CON_INIT	0x0000

//</h>

//</e>



#define CFG_MCM1_CLK		(unsigned long)(SYS_CLK/APB2_F/(CFG_MCM1_PWMPSQ_INIT + 1))


#if (CFG_MCM1_PWMCON1_INIT & (1<<10)) 
	#define CFG_MCM1_PWMP_MODE 2
#else
	#define CFG_MCM1_PWMP_MODE 1
#endif

#define CFG_MCM1_PWMP_INIT (unsigned long)(CFG_MCM1_CLK/CFG_MCM1_PWMP_F/CFG_MCM1_PWMP_MODE)


#define CFG_MCM1_PWM0D_INIT (uint16_t)(CFG_MCM1_PWMP_INIT*CFG_MCM1_PWM0_DUTY/1000)
#define CFG_MCM1_PWM1D_INIT (uint16_t)(CFG_MCM1_PWMP_INIT*CFG_MCM1_PWM1_DUTY/1000)
#define CFG_MCM1_PWM2D_INIT (uint16_t)(CFG_MCM1_PWMP_INIT*CFG_MCM1_PWM2_DUTY/1000)
#define CFG_MCM1_PWM01D_INIT (uint16_t)(CFG_MCM1_PWMP_INIT*CFG_MCM1_PWM01_DUTY/1000)
#define CFG_MCM1_PWM11D_INIT (uint16_t)(CFG_MCM1_PWMP_INIT*CFG_MCM1_PWM11_DUTY/1000)
#define CFG_MCM1_PWM21D_INIT (uint16_t)(CFG_MCM1_PWMP_INIT*CFG_MCM1_PWM21_DUTY/1000)

#define CFG_MCM1_PWMDT21_INIT ((uint16_t)(CFG_MCM1_PWMDT21_DT*CFG_MCM1_CLK/10000000))
#define CFG_MCM1_PWMDT20_INIT ((uint16_t)(CFG_MCM1_PWMDT20_DT*CFG_MCM1_CLK/10000000))
#define CFG_MCM1_PWMDT11_INIT ((uint16_t)(CFG_MCM1_PWMDT11_DT*CFG_MCM1_CLK/10000000))
#define CFG_MCM1_PWMDT10_INIT ((uint16_t)(CFG_MCM1_PWMDT10_DT*CFG_MCM1_CLK/10000000))
#define CFG_MCM1_PWMDT01_INIT ((uint16_t)(CFG_MCM1_PWMDT01_DT*CFG_MCM1_CLK/10000000))
#define CFG_MCM1_PWMDT00_INIT ((uint16_t)(CFG_MCM1_PWMDT00_DT*CFG_MCM1_CLK/10000000))

#define CFG_MCM1_PWMDMIN_INIT	(uint16_t)(CFG_MCM1_PWMDMIN_VALUE*CFG_MCM1_PWMP_INIT/1000)
#define CFG_MCM1_PWMDMAX_INIT	(uint16_t)(CFG_MCM1_PWMDMAX_VALUE*CFG_MCM1_PWMP_INIT/1000)

#define CFG_MCM1_PWMCMP1_INIT	(uint16_t)(CFG_MCM1_PWMCMP1_VALUE*CFG_MCM1_PWMP_INIT/1000)
#define CFG_MCM1_PWMCMP2_INIT	(uint16_t)(CFG_MCM1_PWMCMP2_VALUE*CFG_MCM1_PWMP_INIT/1000)
#define CFG_MCM1_PWMCMP3_INIT	(uint16_t)(CFG_MCM1_PWMCMP3_VALUE*CFG_MCM1_PWMP_INIT/1000)
#define CFG_MCM1_PWMCMP4_INIT	(uint16_t)(CFG_MCM1_PWMCMP4_VALUE*CFG_MCM1_PWMP_INIT/1000)


#if ((CFG_MCM_EN) && (CFG_MCM1_PWMOE) && ((CFG_PB13_AFR != 1)&&(CFG_PB12_AFR != 1)&&(CFG_PB11_AFR != 1)&&(CFG_PB10_AFR != 1)&&(CFG_PB9_AFR != 1)&&(CFG_PB8_AFR != 1)))
#error "MCM1 PWM PIN(PB13/PB12/PB11/PB10/PB9/PB8) AF1 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM1_PWMOE) && (CFG_MCM1_SC1CON_INIT &(1<<12)) && ((CFG_PB4_AFR != 1)&&(CFG_PC5_AFR != 1)))
#error "MCM1_SC1 PIN(PB4/PC5) AF1 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM1_PWMOE) && (CFG_MCM1_SC2CON_INIT &(1<<12)) && ((CFG_PB5_AFR != 1)&&(CFG_PC6_AFR != 1)))
#error "MCM1_SC2 PIN(PB5/PC6) AF1 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM1_PWMOE) && (CFG_MCM1_SC3CON_INIT &(1<<12)) && ((CFG_PB6_AFR != 1)&&(CFG_PC7_AFR != 1)))
#error "MCM1_SC3 PIN(PB6/PC7) AF1 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM1_PWMOE) && (CFG_MCM1_FLTCON_INIT &(1<<3)) && (CFG_PB7_AFR != 1))
#error "MCM1_FLT PIN(PB7) AF1 function mapping is not enable."
#endif
//***********************************************************/

//***********************************************************/
//<e>MCM2
#define CFG_MCM2_PWMOE	0
#define  CFG_MCM2_EN CFG_MCM2_PWMOE
// <o> PWMPSQ_PWMƵϵ<0-65535>
//<i>PWMʱΪ(PCLK2/(PSQ[15:0]+1)) 
#define CFG_MCM2_PWMPSQ_INIT	0x0

// <o> PWMP_PWMƵ (0-50000Hz) <0-50000> 
#define CFG_MCM2_PWMP_F	5000


//<o0>PWMD0:  PWM0ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o1>PWMD1:  PWM1ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o2>PWMD2:  PWM2ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o3>PWMD01: PWM01ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o4>PWMD11: PWM11ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o5>PWMD21: PWM21ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
#define CFG_MCM2_PWM0_DUTY	500
#define CFG_MCM2_PWM1_DUTY	500
#define CFG_MCM2_PWM2_DUTY	500
#define CFG_MCM2_PWM01_DUTY	500
#define CFG_MCM2_PWM11_DUTY	500
#define CFG_MCM2_PWM21_DUTY	500


// <o0.1..3> SECTOR_SVPWM趨λ
//<i>MAXMUMMIN
//    <0=>PWM2D > PWM1D > PWM0D
//    <1=>PWM2D > PWM0D > PWM1D
//    <2=>PWM0D > PWM2D > PWM1D
//    <3=>PWM0D > PWM1D > PWM2D
//    <4=>PWM1D > PWM0D > PWM2D
//    <5=>PWM1D > PWM2D > PWM0D
//    <i>趨110111ʱЧ
//    <i>SVPWM趨λͨλȷPWM0DPWM1DPWM2DĴС˳ֵʱĴС˳
#define CFG_MCM2_PSCON_L_INIT	0x0


// <q0.7> ʹֹͣPWM
//    0: ֹ
//    1: ʹ
#define CFG_MCM2_POSTDCR_INIT	0

//<h>PWM
// <o0.15> POUTMOD_PWM0/1/2ģʽ/λ
//    <0=>3ͨ
//    <1=>6·
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ)ǶԳƲΣĶģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ

// <o0.12..14> POSTPS_Ƶϵ
//    <0=>޺Ƶ
//    <1=>жϡź¼źŽ2Ƶ
//    <2=>жϡź¼źŽ3Ƶ
//    <3=>жϡź¼źŽ4Ƶ
//    <4=>жϡź¼źŽ5Ƶ
//    <5=>жϡź¼źŽ6Ƶ
//    <6=>жϡź¼źŽ7Ƶ
//    <7=>жϡź¼źŽ8Ƶ
// <o0.10..11> PTMOD_PWM0/1/2ģʽ
//    <0=>ضģʽ   
//    <1=>Ķģʽ
//    <2=>μģʽ
//<i>ضģʽģʽ£ʱֻᷢƥ
//<i>Ķģʽģʽ£ʱᷢƥƥ
//<i>μģʽģʽ£ʱֻᷢƥ
// <o0.9> PWMSYM_PWMζԳԿ
//    <0=>ԳPWM
//    <1=>ǶԳPWM
//<i>ĶģʽĻʱЧ
// <o0.6> PDCON0_PWM0/PWM01ԭʼDUTYλ
//    <0=>ֵСռձȼĴʱΪDUTY
//    <1=>ֵڵռձȼĴʱΪDUTY
// <o0.7> PDCON1_PWM1/PWM11ԭʼDUTYλ
//    <0=>ֵСռձȼĴʱΪDUTY
//    <1=>ֵڵռձȼĴʱΪDUTY
// <o0.8> PDCON2_PWM2/PWM21ԭʼDUTYλ
//    <0=>ֵСռձȼĴʱΪDUTY
//    <1=>ֵڵռձȼĴʱΪDUTY
// <o0.0> PWM0S_PWM0Чƽѡλ
//    <0=>PWM0Dutyߵƽʱ͵ƽ
//    <1=>PWM0Duty͵ƽʱߵƽ
// <o0.1> PWM1S_PWM1Чƽѡλ
//    <0=>PWM1Dutyߵƽʱ͵ƽ
//    <1=>PWM1Duty͵ƽʱߵƽ
// <o0.2> PWM2S_PWM2Чƽѡλ
//    <0=>PWM2Dutyߵƽʱ͵ƽ
//    <1=>PWM2Duty͵ƽʱߵƽ
// <o0.3> PWM01S_PWM01Чƽѡλ
//    <0=>PWM01Duty͵ƽʱߵƽ
//    <1=>PWM01Dutyߵƽʱ͵ƽ
// <o0.4> PWM11S_PWM11Чƽѡλ
//    <0=>PWM11Duty͵ƽʱߵƽ
//    <1=>PWM11Dutyߵƽʱ͵ƽ
// <o0.5> PWM21S_PWM21Чƽѡλ
//    <0=>PWM21Duty͵ƽʱߵƽ
//    <1=>PWM21Dutyߵƽʱ͵ƽ

#define CFG_MCM2_PWMCON1_INIT	0x0000
//</h>

//<h>PWM
// <o> PWMDT00_PWMͨ0(0.1us) <0-100>
#define CFG_MCM2_PWMDT00_DT	0

// <o> PWMDT01_PWMͨ0½(0.1us) <0-100>
#define CFG_MCM2_PWMDT01_DT	0

// <o> PWMDT10_PWMͨ1(0.1us) <0-100>
#define CFG_MCM2_PWMDT10_DT	0


// <o> PWMDT11_PWMͨ1½(0.1us) <0-100>
#define CFG_MCM2_PWMDT11_DT	0


// <o> PWMDT20_PWMͨ2(0.1us) <0-100>
#define CFG_MCM2_PWMDT20_DT	0


// <o> PWMDT21_PWMͨ2½(0.1us) <0-100>
#define CFG_MCM2_PWMDT21_DT	0
//</h>


//<h>ȽϼĴAD
// <o0.0..1> CMP1_ȽϼĴ1ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ1ʱᴥAD
//    <2=>ֻPWMȽϼĴ1ʱᴥAD
//PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ1ʱᴥAD
//PTMOD = 01ĶģʽЧ    
//<i>ADCADONPWMTRGENλ1
// <o1> PWMCMP1_¼Ƚֵ1ٷֱ(0.1%) <0-1000>
// <o0.2..3> CMP2_ȽϼĴ2ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ2ʱᴥAD
//    <2=>ֻPWMȽϼĴ2ʱᴥAD
// PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ2ʱᴥAD
//PTMOD = 01    ADCADONPWMTRGENλ1£
//<i>ADCADONPWMTRGENλ1
// <o2> PWMCMP2_¼Ƚֵ2ٷֱ(0.1%) <0-1000>
// <o0.4..5> CMP3_ȽϼĴ3ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ3ʱᴥAD
//    <2=>ֻPWMȽϼĴ3ʱᴥAD
//PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ3ʱᴥAD
//PTMOD = 01ĶģʽЧ    ADCADONPWMTRGENλ1£
//<i>ADCADONPWMTRGENλ1
// <o3> PWMCMP3_¼Ƚֵ3ٷֱ(0.1%) <0-1000>
// <o0.6..7> CMP4_ȽϼĴ4ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ4ʱᴥAD
//    <2=>ֻPWMȽϼĴ4ʱᴥAD
// PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ4ʱᴥAD
//PTMOD = 01    ADCADONPWMTRGENλ1£
//<i>ADCADONPWMTRGENλ1
// <o4> PWMCMP4_¼Ƚֵ4ٷֱ(0.1%) <0-1000>
//</h>
//<h>ͬ
// <o0.8> OSYNC_ֶ޸PWMx/PWMx1ͬλ
//    <0=>ֶ޸ĺЧ
//    <1=>ֶ޸PWMͬЧ
//<i>ֶ޸ͨPMANUALCON1/2Ĵʵ,һĴ޸,ʱЧɴ˼Ĵ
// <o0.9> DILDEN_PWMռձȼĴЧʹλ
//    <0=>PWMͬЧ
//    <1=>Ч
// <o0.10> CILDEN_PWM¼ȽϼĴЧʹλ
//    <0=>PWMͬЧ
//    <1=>Ч
// <q0.11> ZDLDEN_PWMƥʱռձȼĴĴ
//    <i> ֵܴǷ趨0ƥʱԶڼĴƵԤƵĴκμĴ
// <q0.12> PDLDEN_PWMƥʱռձȼĴĴ
//    <i>ۼĴãƥʱPWMڼĴƵԤƵĴ,ֻĶģʽЧ
// <q0.13> ZCMLDEN_PWMƥʱ¼Ĵ
//<i>PWMCMPxx=1,2,3,4,ƥʱ¼ȽϼĴADʽĴ(CMP1~4[1-0])ʹλ      
// <q0.14> PCMLDEN_PWMƥʱ¼Ĵ
//<i>ƥʱ¼ȽϼĴADʽĴ(CMP1~4[1-0])ʹλֻĶģʽЧ
// <q0.15> MCMSYNEN_MCM2MCM2ͬʹλ
//    0: رMCM1MCM2ͬ
//    1: MCM1MCM2ͬ
//    <i>Ϊ˷ֹֻMCM2.PWMOE[MCMSYNEN]MCM2.PWMOE[MCMSYNEN]ͬʱ1ܿͬ,ֻĶģʽЧ
//</h>

#define CFG_MCM2_PWMCON2_INIT	0x0000
#define CFG_MCM2_PWMCMP1_VALUE	0
#define CFG_MCM2_PWMCMP2_VALUE	0
#define CFG_MCM2_PWMCMP3_VALUE	0
#define CFG_MCM2_PWMCMP4_VALUE	0
	
//<h>PWM0/1/2ֶ
//<i>PMANUALCON1_PWM0/1/2ֶüĴ1
//<i>0x058       b31~6 b5        b4        b3        b2       b1       b0       
//<i>PMANUALCON1 -     PMANUAL21 PMANUAL11 PMANUAL01 PMANUAL2 PMANUAL1 PMANUAL0 
//<i>PMANUALCON2_PWM0/1/2ֶüĴ2
//<i>0x05C       b31~6 b5     b4     b3     b2    b1    b0    
//<i>PMANUALCON2 -     POUT21 POUT11 POUT01 POUT2 POUT1 POUT0 
// <o0.0> PMANUAL0_PWM0λ
//    <0=>PWM0PWM
//    <1=>PWM0PMANUALCON2ĴеPOUT0λ

// <o0.1> PMANUAL1_PWM1λ
//    <0=>PWM1PWM
//    <1=>PWM1PMANUALCON2ĴеPOUT1λ
// <o0.2> PMANUAL2_PWM2λ
//    <0=>PWM2PWM
//    <1=>PWM2PMANUALCON2ĴеPOUT2λ
// <o0.3> PMANUAL01_PWM01λ
//    <0=>PWM01PWM
//    <1=>PWM01PMANUALCON2ĴеPOUT01λ
// <o0.4> PMANUAL11_PWM11λ
//    <0=>PWM11PWM
//    <1=>PWM11PMANUALCON2ĴеPOUT11λ
// <o0.5> PMANUAL21_PWM21λ
//    <0=>PWM21PWM
//    <1=>PWM21PMANUALCON2ĴеPOUT21λ
#define CFG_MCM2_PMANUALCON1_INIT	0x00

//<h>PMANUALCON2_PWM0/1/2ֶüĴ2
//<i>0x05C       b31~6 b5     b4     b3     b2    b1    b0    
//<i>PMANUALCON2 -     POUT21 POUT11 POUT01 POUT2 POUT1 POUT0 
// <o0.0> POUT0_PMANUAL0 = 1ʱPWM0ڵƽ
//    <0=>0
//    <1=>1
// <o0.1> POUT1_PMANUAL1 = 1ʱPWM1ڵƽ
//    <0=>0
//    <1=>1
// <o0.2> POUT2_PMANUAL2 = 1ʱPWM2ڵƽ
//    <0=>0
//    <1=>1
// <o0.3> POUT01_PMANUAL01 = 1ʱPWM01ڵƽ
//    <0=>0
//    <1=>1
// <o0.4> POUT11_PMANUAL11 = 1ʱPWM11ڵƽ
//    <0=>0
//    <1=>1
// <o0.5> POUT21_PMANUAL21 = 1ʱPWM21ڵƽ
//    <0=>0
//    <1=>1
#define CFG_MCM2_PMANUALCON2_INIT	0x00
//</h>
//</h>

//<h>ϼ
//<i>0x060  b31~16 b15~14 b13~12 b11 b10    b9~8    b7~4    b3     b2    b1   b0      
//<i>FLTCON -      FOUT1  FOUT0  -   FLT1EN FLT1SEL FLT2DEB FLT2EN FLT2S FLTM FLTSTAT 
// <o0.1> FLTM_⹦ģʽѡ
//    <0=>ģʽ
//    <1=>ģʽ
//<i>ģʽ£⵽ЧFLTSTAT Ӳ1PWMֹͣΪЧʱ״ֲ̬䣬ֻеFLTSTATPWMβŻPWMʱ0ʱ̻ڼĴPWMPֵƥʱָһֱЧʱFLTSTAT޷
//<i>ģʽ£PWMֱɹϼƣЧFLTSTATӲ1رPWMΪЧFLTSTATԶ0PWM0/1/2νPWMʱ0ʱԶָ
// <q0.10> FLT1EN_ϼ1ʹ
//    <i>ϼ1ܴ򿪣ԴѡȽ1Ƚ2
// <o0.8..9> FLT1SEL_ϼ1Դѡλ
//    <0=>Ƚ1˲ΪPWMϼ1ԴߵƽЧ
//    <1=>Ƚ2˲ΪPWMϼ1ԴߵƽЧ
//    <2=>Ƚ3˲ΪPWMϼ1ԴߵƽЧ
//    <3=>

// <q0.3> FLT2EN_ϼ2ʹ
//    <i>ܴ򿪣ԴΪFLT
// <o0.2> FLT2S_ϼ2Чƽѡλ
//    <0=>FLTߵƽЧ
//    <1=>FLT͵ƽЧ
// <o0.4..7> FLT2DEB_ϼ2˲ѡ
//    <0=>˲
//    <1=>0.5us
//    <2=>1us
//    <3=>1.5us
//    <4=>2us
//    <5=>3us
//    <6=>4us
//    <7=>6us
//    <8=>8us
//    <9=>10us
//    <10=>12us
//    <11=>14us
//    <12=>16us
//    <13=>20us
//    <14=>24us
//    <15=>32us
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲Ϊ͵ƽ1С˲,˲0ͬʱΪ0

// <o0.12..13> FOUT0_ϷPWMx״̬ѡλ
//    <0=>̬
//    <2=>͵ƽ
//    <3=>ߵƽ
// <o0.14..15> FOUT1_ϷPWMx1״̬ѡλ
//    <0=>̬
//    <2=>͵ƽ
//    <3=>ߵƽ
//</h>
#define CFG_MCM2_FLTCON_INIT	0x000

//<e0.7>PWMʹ
//<i>0x064 b31~8 b7    b6 b5     b4     b3     b2    b1    b0    
//<i>POSCR -     OLSEN -  OLSG21 OLSG11 OLSG01 OLSG2 OLSG1 OLSG0 
// <o0.0> OLSG0_·PWM0Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.1> OLSG1_·PWM1Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.2> OLSG2_·PWM2Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.3> OLSG01_·PWM01Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.4> OLSG11_·PWM11Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.5> OLSG21_·PWM21Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
//</e>
#define CFG_MCM2_POSCR_INIT	0x00

//<h>PWMDMA
//<i>0x06C    b31~8 b7     b6     b5      b4      b3      b2      b1      b0      
//<i>PWMDMAEN -     PWMPDE PWMZDE PTDD2DE PTUD2DE PTDD1DE PTUD1DE PTDD0DE PTUD0DE 
// <q0.0> PTUD0DE_PWMʱPWM0DƥʱDMA

// <q0.1> PTDD0DE_PWMʱPWM0D/PWM01DƥʱDMA
//<i>ֻĶģʽЧ,ĶԳģʽ£ΪPWM0DĶǶԳģʽ£ΪPWM01D

// <q0.2> PTUD1DE_PWMʱPWM1DƥʱDMA

// <q0.3> PTDD1DE_PWMʱPWM1D/PWM11DƥʱDMA 
//<i>ֻĶģʽЧ,ĶԳģʽ£ΪPWM1DĶǶԳģʽ£ΪPWM11D

// <q0.4> PTUD2DE_PWMʱPWM2DƥʱDMA

// <q0.5> PTDD2DE_PWMʱPWM2D/PWM21DƥʱDMA
//<i>ֻĶģʽЧ;ĶԳģʽ£ΪPWM2DĶǶԳģʽ£ΪPWM21D

// <q0.6> PWMZDE_PWMʱ㴥DMA

// <q0.7> PWMPDE_PWMʱƥ䴥DMA
//<i>ֻĶģʽЧ
//</h>

#define CFG_MCM2_PWMDMAEN_INIT	0x0


//<h>PWMж
//<i>0x070    b31~11 b10    b9  b8    b7     b6     b5      b4      b3      b2      b1      b0      
//<i>PWMINTEN -      OSTDIE OIE FLTIE PWMPIE PWMZIE PTDD2IE PTUD2IE PTDD1IE PTUD1IE PTDD0IE PTUD0IE 
// <q0.0> PTUD0IE_PWMʱPWM0Dƥʱж
//    0: ֹPWMʱPWM0Dƥʱж
//    1: PWMʱPWM0Dƥʱж
// <q0.1> PTDD0IE_PWMʱPWM0Dƥʱж
//<i>ֻĶģʽЧ

// <q0.2> PTUD1IE_PWMʱPWM1Dƥʱж

// <q0.3> PTDD1IE_PWMʱPWM1Dƥʱж
//<i>ֻĶģʽЧ

// <q0.4> PTUD2IE_PWMʱPWM2Dƥʱж

// <q0.5> PTDD2IE_PWMʱPWM2Dƥʱж
//<i>ֻĶģʽЧ

// <q0.6> PWMZIE_PWMʱ㴥ж

// <q0.7> PWMPIE_PWMʱƥ䴥ж
//<i>ֻĶģʽЧ

// <q0.8> FLTIE_жλ
//    0: ֹϼж
//    1: ϼж
// <q0.9> OIE_·жλ
//    0: ֹж
//    1: ж
// <q0.10> OSTDIE_ֹͣPWMжʹλ
//    0: ֹж
//    1: ж

//</h>
#define CFG_MCM2_PWMINTEN_INIT	0x000

#if ((CFG_MCM2_PWMINTEN_INIT & 0xFF) != 0)
	#define CFG_MCM2_PWM_INT_EN 1
#else
	#define CFG_MCM2_PWM_INT_EN 0
#endif

#if ((CFG_MCM2_PWMINTEN_INIT & 0x700) != 0)
	#define CFG_MCM2_FLT_INT_EN 1
#else
	#define CFG_MCM2_FLT_INT_EN 0
#endif

//PWMRLDEN
//0x078    b31~8 b7~0     
//PWMRLDEN -     PWMRLDEN 
//PWMRLDEN_Ĵ޸ĺؿƼĴ
//    0x55:ģĴ޸
//    0xAA:ģļĴ
//    PWMģļĴжϱ־ĴPWMINTFֶƼĴPMANUALCON2FLTCONPOSCRPOSTDCR⣬Ĵ޸ֻеPWMRLDEN = 0x55ʱ޸ģ޸Ч
//    PWMģһЩĴлĴռձȼĴPWMxD&PWMx1DڼĴPWMPPWMʱԤƵĴPWMPSQƵĴPOSTPS[2:0]@ PWMCON1DutyѡĴPDCONx@PWMCON1ԳԿƼĴPWMSYM@PWMCON1ĴPWMDTxxȽϼĴADλCMPx@PWMCON2PWM¼ĴPWMCMPx

#define CFG_MCM2_PWMRLDEN_INIT	0x0

//<h>PWM
//<i>PSCON
//<i>0x07C b31~9 b8      b7~6      b5~4      b3~1   b0       
//<i>PSCON -     STATRUN MINSELECT MAXSELECT SECTOR SHIFTRUN 

// <o0.4..5> MAXSELECT_ʱޱȽֵȽϺPWMռձֵѡλ
//    <0=>κʱPWMxռձȣPWMxDֵ
//    <1=>PWMxDڵPWMDMAxʱPWMxD޸ΪPWMDMAx򲻱
//    <2=>PWMxDڵPWMDMAxʱPWMxD޸ΪֵPWMP򲻱
// <o0.6..7> MINSELECT_ʱޱȽֵȽϺPWMռձֵѡλ
//    <0=>κʱPWMxռձȣPWMxDֵ
//    <1=>PWMxDСڵPWMDMINʱPWMxD޸ΪPWMDMIN򲻱
//    <2=>PWMxDСڵPWMDMINʱPWMxD޸Ϊ0򲻱
#define CFG_MCM2_PSCON_H_INIT	0x00
#define CFG_MCM2_PSCON_INIT	(CFG_MCM2_PSCON_L_INIT|CFG_MCM2_PSCON_H_INIT)
// PWMDMAX_PWMռձޱȽϼĴ
// <o> PWMDMAX_PWMռձޱȽֵ(0.1%) <0-1000> 
//PWMDMAX
//0x080   b31~16 b15~0   
//PWMDMAX -      PWMDMAX 
#define CFG_MCM2_PWMDMAX_VALUE	0
// PWMDMIN_PWMռձޱȽϼĴ
// <o> PWMDMIN_PWMռձޱȽֵ(0.1%) <0-1000> 
//PWMDMIN
//0x084   b31~16 b15~0   
//PWMDMIN -      PWMDMIN 
#define CFG_MCM2_PWMDMIN_VALUE	0



// <o> PWMDCMP1_PWMռձСĴ1 <0-65535>
//<i>PWMDCMP1
//<i>0x088    b31~16 b15~0    
//<i>PWMDCMP1 -      PWMDCMP1 
#define CFG_MCM2_PWMDCMP1_INIT	0x0000

// <o0> PWMDCMP2_PWMռձСĴ2 <0-65535>
//<i>PWMDCMP2
//<i>0x08C    b31~16 b15~0    
//<i>PWMDCMP2 -      PWMDCMP2 
#define CFG_MCM2_PWMDCMP2_INIT	0x0000
//</h>

//<h>
//<e0.12>Ƚź1ʹ
//<i>0x090  b31~13 b12  b11 b10      b9       b8       b7~4  b3~0   
//<i>SC1CON -      SCEN SCS SCPWM2EN SCPWM1EN SCPWM0EN SCDEB SCTIME 
//SCEN_SC1ʹ
// <o0.11> SCS_SC1Чƽѡλ
//    <0=>SC1ߵƽЧ
//    <1=>SC1͵ƽЧ
// <q0.8> SCPWM0EN_SC1PWM0ʹ
// <q0.9> SCPWM1EN_SC1PWM1ʹ
// <q0.10> SCPWM2EN_SC1PWM2ʹ
// <o0.0..3> SCTIME_ʱѡλ
//    <0=>600*Pclk2
//    <1=>900*Pclk2
//    <2=>1200*Pclk2
//    <3=>1500*Pclk2
//    <4=>1800*Pclk2
//    <5=>2100*Pclk2
//    <6=>2400*Pclk2
//    <7=>3000*Pclk2
//    <8=>3600*Pclk2
//    <9=>4800*Pclk2
//    <10=>6000*Pclk2
//    <11=>12000*Pclk2
//    <12=>24000*Pclk2
//    <13=>36000*Pclk2
//    <14=>48000*Pclk2
//    <15=>60000*Pclk2
// <o0.4..7> SCDEB_SC1˲ѡ
//    <0=>0
//    <1=>30*Pclk2
//    <2=>60*Pclk2
//    <3=>90*Pclk2
//    <4=>120*Pclk2
//    <5=>180*Pclk2
//    <6=>240*Pclk2
//    <7=>360*Pclk2
//    <8=>480*Pclk2
//    <9=>600*Pclk2
//    <10=>720*Pclk2
//    <11=>840*Pclk2
//    <12=>960*Pclk2
//    <13=>1200*Pclk2
//    <14=>1440*Pclk2
//    <15=>1920*Pclk2
//   <i>˲ʱ䲻Ǿȷֵ
//   <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0

//</e>
#define CFG_MCM2_SC1CON_INIT	0x0000
//<e0.12>Ƚź2ʹ
//<i>0x094  b31~13 b12  b11 b10      b9       b8       b7~4  b3~0   
//<i>SC2CON -      SCEN SCS SCPWM2EN SCPWM1EN SCPWM0EN SCDEB SCTIME 
// <o0.11> SCS_SC2Чƽѡλ
//    <0=>SC2ߵƽЧ
//    <1=>SC2͵ƽЧ
// <q0.8> SCPWM0EN_SC2PWM0ʹ
// <q0.9> SCPWM1EN_SC2PWM1ʹ
// <q0.10> SCPWM2EN_SC2PWM2ʹ
// <o0.0..3> SCTIME_ʱѡλ
//    <0=>600*Pclk2
//    <1=>900*Pclk2
//    <2=>1200*Pclk2
//    <3=>1500*Pclk2
//    <4=>1800*Pclk2
//    <5=>2100*Pclk2
//    <6=>2400*Pclk2
//    <7=>3000*Pclk2
//    <8=>3600*Pclk2
//    <9=>4800*Pclk2
//    <10=>6000*Pclk2
//    <11=>12000*Pclk2
//    <12=>24000*Pclk2
//    <13=>36000*Pclk2
//    <14=>48000*Pclk2
//    <15=>60000*Pclk2
// <o0.4..7> SCDEB_SC2˲ѡ
//    <0=>0
//    <1=>30*Pclk2
//    <2=>60*Pclk2
//    <3=>90*Pclk2
//    <4=>120*Pclk2
//    <5=>180*Pclk2
//    <6=>240*Pclk2
//    <7=>360*Pclk2
//    <8=>480*Pclk2
//    <9=>600*Pclk2
//    <10=>720*Pclk2
//    <11=>840*Pclk2
//    <12=>960*Pclk2
//    <13=>1200*Pclk2
//    <14=>1440*Pclk2
//    <15=>1920*Pclk2
//   <i>˲ʱ䲻Ǿȷֵ
//   <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0

//</e>
#define CFG_MCM2_SC2CON_INIT	0x0000

//<e0.12>Ƚź3ʹ
//<i>0x098  b31~13 b12  b11 b10      b9       b8       b7~4  b3~0   
//<i>SC3CON -      SCEN SCS SCPWM2EN SCPWM1EN SCPWM0EN SCDEB SCTIME
// <o0.11> SCS_SC3Чƽѡλ
//    <0=>SC3ߵƽЧ
//    <1=>SC3͵ƽЧ
// <q0.8> SCPWM0EN_SC3PWM0ʹ
// <q0.9> SCPWM1EN_SC3PWM1ʹ
// <q0.10> SCPWM2EN_SC3PWM2ʹ
// <o0.0..3> SCTIME_ʱѡλ
//    <0=>600*Pclk2
//    <1=>900*Pclk2
//    <2=>1200*Pclk2
//    <3=>1500*Pclk2
//    <4=>1800*Pclk2
//    <5=>2100*Pclk2
//    <6=>2400*Pclk2
//    <7=>3000*Pclk2
//    <8=>3600*Pclk2
//    <9=>4800*Pclk2
//    <10=>6000*Pclk2
//    <11=>12000*Pclk2
//    <12=>24000*Pclk2
//    <13=>36000*Pclk2
//    <14=>48000*Pclk2
//    <15=>60000*Pclk2
// <o0.4..7> SCDEB_SC3˲ѡ
//    <0=>0
//    <1=>30*Pclk2
//    <2=>60*Pclk2
//    <3=>90*Pclk2
//    <4=>120*Pclk2
//    <5=>180*Pclk2
//    <6=>240*Pclk2
//    <7=>360*Pclk2
//    <8=>480*Pclk2
//    <9=>600*Pclk2
//    <10=>720*Pclk2
//    <11=>840*Pclk2
//    <12=>960*Pclk2
//    <13=>1200*Pclk2
//    <14=>1440*Pclk2
//    <15=>1920*Pclk2
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0
//</e>
#define CFG_MCM2_SC3CON_INIT	0x0000
//</h>

//</e>


#define CFG_MCM2_CLK		(unsigned long)(SYS_CLK/APB2_F/(CFG_MCM2_PWMPSQ_INIT + 1))


#if (CFG_MCM2_PWMCON1_INIT & (1<<10)) 
	#define CFG_MCM2_PWMP_MODE 2
#else
	#define CFG_MCM2_PWMP_MODE 1
#endif

#define CFG_MCM2_PWMP_INIT (unsigned long)(CFG_MCM2_CLK/CFG_MCM2_PWMP_F/CFG_MCM2_PWMP_MODE)


#define CFG_MCM2_PWM0D_INIT (uint16_t)(CFG_MCM2_PWMP_INIT*CFG_MCM2_PWM0_DUTY/1000)
#define CFG_MCM2_PWM1D_INIT (uint16_t)(CFG_MCM2_PWMP_INIT*CFG_MCM2_PWM1_DUTY/1000)
#define CFG_MCM2_PWM2D_INIT (uint16_t)(CFG_MCM2_PWMP_INIT*CFG_MCM2_PWM2_DUTY/1000)
#define CFG_MCM2_PWM01D_INIT (uint16_t)(CFG_MCM2_PWMP_INIT*CFG_MCM2_PWM01_DUTY/1000)
#define CFG_MCM2_PWM11D_INIT (uint16_t)(CFG_MCM2_PWMP_INIT*CFG_MCM2_PWM11_DUTY/1000)
#define CFG_MCM2_PWM21D_INIT (uint16_t)(CFG_MCM2_PWMP_INIT*CFG_MCM2_PWM21_DUTY/1000)

#define CFG_MCM2_PWMDT21_INIT ((uint16_t)(CFG_MCM2_PWMDT21_DT*CFG_MCM2_CLK/10000000))
#define CFG_MCM2_PWMDT20_INIT ((uint16_t)(CFG_MCM2_PWMDT20_DT*CFG_MCM2_CLK/10000000))
#define CFG_MCM2_PWMDT11_INIT ((uint16_t)(CFG_MCM2_PWMDT11_DT*CFG_MCM2_CLK/10000000))
#define CFG_MCM2_PWMDT10_INIT ((uint16_t)(CFG_MCM2_PWMDT10_DT*CFG_MCM2_CLK/10000000))
#define CFG_MCM2_PWMDT01_INIT ((uint16_t)(CFG_MCM2_PWMDT01_DT*CFG_MCM2_CLK/10000000))
#define CFG_MCM2_PWMDT00_INIT ((uint16_t)(CFG_MCM2_PWMDT00_DT*CFG_MCM2_CLK/10000000))

#define CFG_MCM2_PWMDMIN_INIT	(uint16_t)(CFG_MCM2_PWMDMIN_VALUE*CFG_MCM2_PWMP_INIT/1000)
#define CFG_MCM2_PWMDMAX_INIT	(uint16_t)(CFG_MCM2_PWMDMAX_VALUE*CFG_MCM2_PWMP_INIT/1000)

#define CFG_MCM2_PWMCMP1_INIT	(uint16_t)(CFG_MCM2_PWMCMP1_VALUE*CFG_MCM2_PWMP_INIT/1000)
#define CFG_MCM2_PWMCMP2_INIT	(uint16_t)(CFG_MCM2_PWMCMP2_VALUE*CFG_MCM2_PWMP_INIT/1000)
#define CFG_MCM2_PWMCMP3_INIT	(uint16_t)(CFG_MCM2_PWMCMP3_VALUE*CFG_MCM2_PWMP_INIT/1000)
#define CFG_MCM2_PWMCMP4_INIT	(uint16_t)(CFG_MCM2_PWMCMP4_VALUE*CFG_MCM2_PWMP_INIT/1000)

#if ((CFG_MCM_EN) && (CFG_MCM2_PWMOE) && ((CFG_PA15_AFR != 2)&&(CFG_PB14_AFR != 2)))
#error "MCM2 PWM21 PIN(PB14/PA15) AF2 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM2_PWMOE) && ((CFG_PA14_AFR != 2)&&(CFG_PB15_AFR != 2)))
#error "MCM2 PWM11 PIN(PB15/PA14) AF2 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM2_PWMOE) && ((CFG_PA13_AFR != 2)&&(CFG_PC0_AFR != 2)))
#error "MCM2 PWM01 PIN(PC0/PA13) AF2 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM2_PWMOE) && ((CFG_PA12_AFR != 2)&&(CFG_PC1_AFR != 2)))
#error "MCM2 PWM2 PIN(PC1/PA12) AF2 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM2_PWMOE) && ((CFG_PA11_AFR != 2)&&(CFG_PC2_AFR != 2)))
#error "MCM2 PWM1 PIN(PC2/PA11) AF2 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM2_PWMOE) && ((CFG_PA10_AFR != 2)&&(CFG_PC3_AFR != 2)))
#error "MCM2 PWM0 PIN(PC3/PA10) AF2 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM2_PWMOE) && (CFG_MCM2_SC1CON_INIT &(1<<12)) && ((CFG_PB3_AFR != 2)&&(CFG_PC5_AFR != 2)))
#error "MCM2_SC1 PIN(PB3/PC5) AF2 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM2_PWMOE) && (CFG_MCM2_SC2CON_INIT &(1<<12)) && ((CFG_PB4_AFR != 2)&&(CFG_PC6_AFR != 2)))
#error "MCM2_SC2 PIN(PB4/PC6) AF2 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM2_PWMOE) && (CFG_MCM2_SC3CON_INIT &(1<<12)) && ((CFG_PB5_AFR != 2)&&(CFG_PC7_AFR != 2)))
#error "MCM2_SC3 PIN(PB5/PC7) AF2 function mapping is not enable."
#endif

#if ((CFG_MCM_EN) && (CFG_MCM2_PWMOE) && (CFG_MCM2_FLTCON_INIT &(1<<3)) && ((CFG_PB2_AFR != 2)&&(CFG_PC4_AFR != 2)))
#error "MCM2_FLT PIN(PB2/PC4) AF2 function mapping is not enable."
#endif
//***********************************************************/
//***********************************************************/
//</e>


//<e>GPT
#define CFG_GPT_EN	0
//<h>GTPOE
//<i>GTPOECR
//<i>0x008   b31~8 b7    b6 b5~4 b3        b2        b1        b0        
//<i>GTPOECR -     POEIE -  POEM GPT3ABZE0 GPT2ABZE0 GPT1ABZE0 GPT0ABZE0 
// <q0.0> GPT0ABZE0_POEGTIOC0A/Bʹλ
//    0: رձ
//    1: 
// <q0.1> GPT1ABZE0_POEGTIOC1A/Bʹλ
//    0: رձ
//    1: 
// <q0.2> GPT2ABZE0_POEGTIOC2A/Bʹλ
//    0: رձ
//    1: 
// <q0.3> GPT3ABZE0_POEGTIOC3A/Bʹλ
//    0: رձ
//    1: 
// <o0.4..5> POEM_GTPOE˲ѡλ
//    <0=>GTPOELowƽ
//    <1=>ÿHCLK/8 ʱӶGTPOELowƽ16βȫΪLowƽʱ
//    <2=>ÿHCLK/16ʱӶGTPOELowƽ16βȫΪLowƽʱ
//    <3=>ÿHCLK/128 ʱӶGTPOELowƽ16βȫΪLowƽʱ
// <q0.7> POEIE_GTPOEжλ
//    0: ֹж
//    1: ж

//</h>
#define CFG_GPT_GTPOECR_INIT	0x0

#if ((CFG_GPT_GTPOECR_INIT & (1<<7)) != 0)
	#define CFG_GPT_POE_INT_EN 1
#else
	#define CFG_GPT_POE_INT_EN 0
#endif

//<h>GTETRGⲿ
//<i>GTETINT
//<i>0x004   b31~8 b7~6 b5~4 b3     b2     b1     b0     
//<i>GTETINT -     PS   SN   ETNDMA ETPDMA ETINEN ETIPEN 
// <q0.0> ETIPEN_ⲿصжλ
//    0: ֹж
//    1: ж
// <q0.1> ETINEN_ⲿ½صжλ
//    0: ֹж
//    1: ж
// <q0.2> ETPDMA_ⲿصDMAλ
//    0: ֹDMA
//    1: DMA
// <q0.3> ETNDMA_ⲿ½صDMAλ
//    0: ֹDMA
//    1: DMA
// <o0.4..5> SN_ⲿGTETRGѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
// <o0.6..7> PS_ⲿGTETRGʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128

//</h>
#define CFG_GPT_GTETINT_INIT	0x0
//***********************************************************/


#define CFG_TIMER1_EN	0
//***********************************************************/
//<e>GPT0_ͨPWMʱ
#define CFG_GPT0_EN	0
//<e>ʱԴѡ(ѡһ)
// <q0.8>GPT0ѡHCLKΪʱԴѡ
//<i>TPSC_ʱʱԴѡλ:
//    <i>0=HCLK
//    <i>1=ΪGPT1GPT3/м
//<i>GPT0GPT2λЧGPT1GPT3λ
#define CFG_GPT0_CLK_HCLK	0x00


// <e0.8>GPT0ѡGPT1/ΪʱԴ
//<i>TPSC_ʱʱԴѡλ:
//    <i>0=HCLK
//    <i>1=ΪGPT1GPT3/м
//<i>GPT0GPT2λЧGPT1GPT3λ
#define CFG_GPT0_CLK_GPT1	0x00
// <o> GPT1Ƶ (0-200000Hz) <0-200000> 
#define CFG_GPT1_CLK_F	50000
//</e>
//</e>
#if ((CFG_GPT0_CLK_HCLK & CFG_GPT0_CLK_GPT1) == (1<<8))
#error "GPT0ʱԴѡֻHCLKGPT1/жѡһ."
#endif



//<i>GPTʱԤƵĴ
//<i>GTPSQ_GPTʱԤƵĴ
//<i>0x020 b31~16 b15~0 
//<i>GTPSQ -      GTPSQ 
// <o0.0..15> GPTʱԤƵĴ<0-65535>
//<i>GPTʱΪ(GPTCLK/(PSQ[15:0]+1))
//<i>ڶʱʱ޸ 
#define CFG_GPT0_GTPSQ_INIT	0x0

// <o> GPT0_PWMƵ (0-200000Hz) <0-200000> 
#define CFG_GPT0_PWMP_F	50000

#define CFG_GPT0_CLK		((unsigned long)(SYS_CLK/(CFG_GPT0_GTPSQ_INIT + 1)))
#define CFG_GPT0_GTPR_INIT (CFG_GPT0_CLK/CFG_GPT0_PWMP_F)
	

//<o>GTIOCnAռձ (0.1%) <0-1000>
#define CFG_GPT0_GTIOC0A_DUTY	500

//<o>GTIOCnBռձ (0.1%) <0-1000>
#define CFG_GPT0_GTIOC0B_DUTY	500


//GTCCRA_ͨPWMʱıȽϲ׽ĴA 
//0x038  b31~16  b15~0   
//GTCCRA GTCCRAH GTCCRAL 
//GTCCRAL_Ƚϲ׽ĴGTCCRA16λ
#define CFG_GPT0_GTCCRA_INIT (CFG_GPT0_GTPR_INIT*CFG_GPT0_GTIOC0A_DUTY/1000)

//GTCCRB_ͨPWMʱıȽϲ׽ĴB
//0x03C  b31~16  b15~0   
//GTCCRB GTCCRBH GTCCRBL 
//GTCCRBL_Ƚϲ׽ĴGTCCRB16λ
#define CFG_GPT0_GTCCRB_INIT (CFG_GPT0_GTPR_INIT*CFG_GPT0_GTIOC0B_DUTY/1000)


// <o0.0..2> PWMģʽѡ
//    <0=>ݲPWM ģʽܵ/ ˫壩
//    <1=>ݲģʽ̶ΪУ
//    <4=>ǲPWM ģʽ1ڲ16 λͣܵ/ ˫壩
//    <5=>ǲPWM ģʽ2ڲ/ 16 λͣܵ/ ˫壩
//    <6=>ǲPWM ģʽ3ڲ32 λ̶ͣΪУ
//    <7=>ǲPWM ģʽ4ڲ16λͣܵ/˫壩
//<h>GPTƼĴ
//<i>GTCR_ͨPWMʱĿƼĴ
//<i>0x01C b31~14 b13~12 b11~10 b9  b8   b7~3 b2~0 
//<i>GTCR  -      CCLR   -      HIZ TPSC -    MD   
//<i>GPT0GPT2λЧGPT1GPT3λ
// <q0.9> HIZ_ȽCMP1GPTxʹλ
//    0: ֹCMP1GPTx
//    1: ʹCMP1GPTx
//<i>λ󣬵CMP1C1IF@AMOC->CMPINTFΪ1ʱGPTx̬
// <o0.12..13> CCLR_Դѡλ
//    <0=>趨Դ
//    <1=>ͨGTCCRA Ĵ벶׽
//    <2=>ͨGTCCRB Ĵ벶׽
//    <3=>ͨڽͬ/ ͬеԴ
//    <i>ھݲѡͬʱͬͨ/ еͬ/ Уǣ־/ ־λǲѡͬʱֻͬмֵΪ0ǣΪ ȡ 
//    <i>ͨԴѡ01b10b ߡ11b ʱGTCNT ڼGTSTR.CTSn=1ֹͣGTSTR.CSTn=0n=0  3ͨԴ
//</h>
#define CFG_GPT0_GTCR_VALUE	0x0
#define CFG_GPT0_GTCR_INIT	( CFG_GPT0_GTCR_VALUE | CFG_GPT0_CLK_GPT1 )


// <e0.1>GTPRڻ
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
#define CFG_GPT0_BDPR_EN	0x0

// <o0.4..5> PR_GTPR λ
//    <0=>
//    <1=>еУGTPBR=>GTPR
//    <2=>˫ GTPDBR=>GTPBR=>GTPR
#define CFG_GPT0_GTBER_PR_INIT	0x0

// <o0.0..15> GTPBR_ͨPWMʱ趨Ĵ<0-65535>
//<i>GTPBR_ͨPWMʱ趨Ĵ
//<i>0x054 b31~16 b15~0 
//<i>GTPBR -      GTPBR 
//<i>GTPBRĴ16λɶдĴGTPRĴĻĴͨ14GTPBRĴ
#define CFG_GPT0_GTPBR_INIT	0xffff

//<i>GTPDBR_ͨPWMʱ趨˫Ĵ
//<i>0x058  b31~16 b15~0  
//<i>GTPDBR -      GTPDBR 
// <o0.0..15> GTPDBR_ͨPWMʱ趨˫Ĵ<0-65535>
//<i>GTPDBRĴ16λɶдĴGTPBRĴĻĴ GTPRĴ˫Ĵͨ14GTPDBRĴ
#define CFG_GPT0_GTPDBR_INIT	0xffff
//</e>






//<h>
//<i>GTUDC_ͨPWMʱļĴ
//<i>0x028 b31~2 b1  b0 
//<i>GTUDC -     UDF UD 
// <o0.0> UD_趨λ
//    <0=>GTCNT
//    <1=>GTCNTݼ
// <q0.1> UDF_ǿ趨λ
//    <i>0:ǿ趨
//    <i>1:ǿ趨
//    <i>λGTCNTʼʱļǿ趨ΪUDλֵʱֻܸλд0
//</h>
#define CFG_GPT0_GTUDC_INIT	0x0


//<h>ʱƼĴ
// <o0.0> TDE_ನ趨λ
//    <0=>ʹGTDVU ĴGTDVD Ĵ趨GTCCRB Ĵ
//    <1=>ʹGTDVU ĴGTDVD ĴʱķನεıȽƥֵԶ趨GTCCRBĴ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>    λ趨ǷʹGTDVUĴGTDVDĴʹGTDVUĴGTDVDĴʱನεıȽƥֵ GTCRRAĴʱֵ GTDVUĴGTDVDĴĴʱķನεıȽƥֵԶ趨GTCCRBĴ
//<i>    ھݲPWMģʽкTDEλ趨ҲԶ趨λ
//<i>    Զ趨GTCCRBĴֵ/ֵʾGTCCRBĴֵֵ/ֵķΧʱ͸GTCCRBĴ趨ֵ/ֵGTST.DTEF־Ϊ1
//<i>    ǲ    ֵ:GTPR1    ֵ:ʱΪ1ݼʱΪ0
//<i>    ݲģʽ    ֵ:GTPR    ֵ:0
// <o0.8> TDFER_GTDVD 趨λ
//    <0=>趨GTDVU ĴGTDVD Ĵ
//    <1=>GTDVU ĴдֵԶ趨GTDVDĴ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 

//<o1> GTDVU_ڵʱ(0.1us) <0-100>
//<i>GTDVU_ͨPWM ʱʱֵĴU
//<i>0x078 b31~16 b15~0 
//<i>GTDVU -      GTDVU 
//<i>GTDVUĴ16λɶдĴ趨ɴʱPWMεʱ䡣
//<i>ֱͨ2ڵGTDVUĴڵݼGTDVDĴ8GTDVĴ
//<i>ֹ趨ڵʱֵ,ͨGTCCRBĴ趨ֵʹGTDVĴʱֹдGTCCRBĴ
//<i>ʱֵ趨Ϊ0ʱĲΡ
//<i>ֹ8λΪλȡGTDVĴ16λΪλдȡ 

//<o2>GTDVD_ڵݼʱ(0.1us) <0-100>
//<i>GTDVD_ͨPWM ʱʱֵĴD
//<i>0x07C b31~16 b15~0 
//<i>GTDVD -      GTDVD 
//<i>GTDVDĴ16λɶдĴ趨ɴʱPWMεʱ䡣
//<i>ֱͨ2ڵGTDVUĴڵݼGTDVDĴ8GTDVĴ
//<i>ֹ趨ڵʱֵ,ͨGTCCRBĴ趨ֵʹGTDVĴʱֹдGTCCRBĴ
//<i>ʱֵ趨Ϊ0ʱĲΡ
//<i>ֹ8λΪλȡGTDVĴ16λΪλдȡ

// <e3.3>GTDVʱ仺
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 

// <q0.4> TDBUE_GTDVU λ
//    0: ֹGTDVU ĴĻ
//    1: GTDVU ĴĻ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>崫ʱǲʱΪȣھݲʱΪ硣

// <q0.5> TDBDE_GTDVD λ
//    0: ֹGTDVD ĴĻ
//    1: GTDVD ĴĻ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>    λGTDVDĴGTDBDĴϵĻС崫ʱǲʱΪȣھݲʱΪ硣ͬʱTDFERλá1ʱTDFERλ趨

//<o4> GTDBU_GTDVUĴĻʱ(0.1us) <0-100>
//<i>GTDBU_ͨPWM ʱʱ仺ĴU
//<i>0x080 b31~16 b15~0 
//<i>GTDBU -      GTDBU 
//<i>GTDBUĴ16λɶдĴGTDVUĴĻĴ

// <o5> GTDBD_GTDVDĴĻʱ(0.1us) <0-100>
//<i>GTDBD_ͨPWM ʱʱ仺ĴD
//<i>0x084 b31~16 b15~0 
//<i>GTDBD -      GTDBD 
//<i>GTDBDĴ16λɶдĴGTDVDĴĻĴ 

//</e>


#define CFG_GPT0_GTDTCR_INIT	0x0
#define CFG_GPT0_GTDVU_DT	0
#define CFG_GPT0_GTDVD_DT	0
#define CFG_GPT0_BDDV_EN	0x0
#define CFG_GPT0_GTDBU_DT	0
#define CFG_GPT0_GTDBD_DT	0
#define CFG_GPT0_GTDVU_INIT ((uint16_t)(CFG_GPT0_GTDVU_DT*CFG_GPT0_CLK/10000000))
#define CFG_GPT0_GTDVD_INIT ((uint16_t)(CFG_GPT0_GTDVD_DT*CFG_GPT0_CLK/10000000))
#define CFG_GPT0_GTDBU_INIT ((uint16_t)(CFG_GPT0_GTDBU_DT*CFG_GPT0_CLK/10000000))
#define CFG_GPT0_GTDBD_INIT ((uint16_t)(CFG_GPT0_GTDBD_DT*CFG_GPT0_CLK/10000000))

//</h>

//<h>GTIOCxA/BüĴ
//<i>GTIOR_ͨPWM ʱI/OƼĴ
//<i>0x010 b31~16 b15   b14    b13~8 b7    b6     b5~0  
//<i>GTIOR -      OBHLD OBDFLT GTIOB OAHLD OADFLT GTIOA 
// <o0.6> OADFLT_GTIOCxA żֹͣʱֵλ
//    <0=>ֹͣʱGTIOCxALow ƽ
//    <1=>ֹͣʱGTIOCxAHigh ƽ
// <o0.7> OAHLD_GTIOCxAżʼ/ֹͣʱֿ
//    <0=>ʼ/ֹͣʱGTIOCxA ŵƽȡڼĴ趨ֵ
//    <1=>ּʼ/ֹͣʱGTIOCxAŵƽ
//<i>ܼĴģʽڼʼʱGTIORĴbit4ֵָ
//<i>ܼĴģʽڼֹͣʱOADFLTλֵָ
//<i>ܼĴģʽڼֹͣʱOADFLTλֵ£ӳ
// <o0.14> OBDFLT_GTIOCxB żֹͣʱֵλ
//    <0=>ֹͣʱGTIOCxB Low ƽ
//    <1=>ֹͣʱGTIOCxB High ƽ
// <o0.15> OBHLD_GTIOCxB żʼ/ ֹͣʱλ
//    <0=>ʼ/ ֹͣʱGTIOCxB ŵƽȡȡڼĴ趨ֵ
//    <1=>ּʼ/ ֹͣʱGTIOCxB ŵƽ
//<i>    ڼʼʱGTIORĴbit4ֵָ
//<i>    ڼֹͣʱOBDFLTλֵָ
//<i>    ڼֹͣʱOBDFLTλֵ£ӳ
#define CFG_GPT0_GTIOR	0x0

//<e>GTIOA_GTIOCxAȽƥ
#define CFG_GPT0_GTIOR_GTIOA_O_EN	0

// <o0.4> GTIOA_GTIOCxAųʼƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o0.2..3> GTIOA_GTIOCxAڽʱ״̬
//    <0=>ڽʱ
//    <1=>ڽʱLOWƽ
//    <2=>ڽʱHIGHƽ
//    <3=>ڽʱ
// <o0.0..1> GTIOA_GTIOCxAŵıȽƥ״̬
//    <0=>ͨGPTn.GTCCRAıȽƥ䱣
//    <1=>ͨGPTn.GTCCRAıȽƥLowƽ
//    <2=>ͨGPTn.GTCCRAıȽƥHighƽ
//    <3=>ͨGPTn.GTCCRAıȽƥн
#define CFG_GPT0_GTIOR_GTIOA_O	0

//</e>
//<e>GTIOA_GTIOCxA벶׽
#define CFG_GPT0_GTIOR_GTIOA_I_EN	0

// <o0.2..3> GTIOA_GTIOCxAŲ׽ѡ
//    <0=>GTIOCxAΪ׽
//    <1=>RXD1Ϊǲ׽
//    <2=>RXD2Ϊǲ׽
//    <3=>RXD3Ϊǲ׽
// <o0.0..1> GTIOA_GTIOCxAŵ벶׽ʽѡ
//    <0=>벶׽
//    <1=>½벶׽
//    <2=>˫벶׽
#define CFG_GPT0_GTIOR_GTIOA_I	0

//</e>
//<e>GTIOB_GTIOCxBȽƥ
#define CFG_GPT0_GTIOR_GTIOB_O_EN 0 

// <o0.12> GTIOB_GTIOCxBųʼƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o0.10..11> GTIOB_GTIOCxBڽʱ״̬
//    <0=>ڽʱ
//    <1=>ڽʱLOWƽ
//    <2=>ڽʱHIGHƽ
//    <3=>ڽʱ
// <o0.8..9> GTIOB_GTIOCxBŵıȽƥ״̬
//    <0=>ͨGPTn.GTCCRA/BıȽƥ䱣
//    <1=>ͨGPTn.GTCCRA/BıȽƥLowƽ
//    <2=>ͨGPTn.GTCCRA/BıȽƥHighƽ
//    <3=>ͨGPTn.GTCCRA/BıȽƥн
#define CFG_GPT0_GTIOR_GTIOB_O	0x00

//</e>
//<e>GTIOB_GTIOCxB벶׽
#define CFG_GPT0_GTIOR_GTIOB_I_EN	0

// <o0.8..9> GTIOB_GTIOCxBŵ벶׽ʽѡ
//    <0=>벶׽
//    <1=>½벶׽
//    <2=>˫벶׽
#define CFG_GPT0_GTIOR_GTIOB_I	0
//</e>
//</h>



#if	CFG_GPT0_GTIOR_GTIOA_O_EN
#define CFG_GPT0_GTIOR_VALUE	(CFG_GPT0_GTIOR | CFG_GPT0_GTIOR_GTIOA_O)
#elif	CFG_GPT0_GTIOR_GTIOA_I_EN
#define CFG_GPT0_GTIOR_VALUE	(CFG_GPT0_GTIOR | (1<<5) |CFG_GPT0_GTIOR_GTIOA_I)
#else
#define CFG_GPT0_GTIOR_VALUE	(CFG_GPT0_GTIOR)
#endif

#if	CFG_GPT0_GTIOR_GTIOB_O_EN
#define CFG_GPT0_GTIOR_INIT	(CFG_GPT0_GTIOR_VALUE | CFG_GPT0_GTIOR_GTIOB_O)
#elif	CFG_GPT0_GTIOR_GTIOB_I_EN
#define CFG_GPT0_GTIOR_INIT	(CFG_GPT0_GTIOR_VALUE | (1<<13) |CFG_GPT0_GTIOR_GTIOB_I)
#else
#define CFG_GPT0_GTIOR_INIT	(CFG_GPT0_GTIOR_VALUE)
#endif

#if ((CFG_GPT0_GTIOR_GTIOA_O_EN & CFG_GPT0_GTIOR_GTIOA_I_EN) == 1)
#error "GTIOA_GTIOC0AֻѡȽƥ벶׽еһģʽ."
#endif

#if ((CFG_GPT0_GTIOR_GTIOB_O_EN & CFG_GPT0_GTIOR_GTIOB_I_EN) == 1)
#error "GTIOB_GTIOC0BֻѡȽƥ벶׽еһģʽ."
#endif




//<h>Ƚƥ䴥A/Dת
// <q0.8> ADTRAUEN_GTADTRAȽƥ()A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.9> ADTRADEN_GTADTRAȽƥ(ݼ)A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.10> ADTRBUEN_GTADTRBȽƥ()A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.11> ADTRBDEN_GTADTRBȽƥ(ݼ)A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
#define CFG_GPT0_GTINTAD_H	0x00


//<i>GTADTRA_A/DתʼʱĴA
//<i>0x05C   b31~16 b15~0   
//<i>GTADTRA -      GTADTRA 
// <o0.0..15> GTADTRA_A/D תʼʱĴA<0-65535>
//<i>趨A/Dתʼʱ򡣵GTADTRAĴֵGTCNTֵͬʱA/Dתʼ
//<i>ͨ28GTADTRĴֹ8λΪλȡGTADTRĴ16λΪλдȡ 
#define CFG_GPT0_GTADTRA_INIT	0x000

// <o0.0..15> GTADTRB_A/D תʼʱĴB<0-65535>
//<i>GTADTRB_A/DתʼʱĴB
//<i>0x060   b31~16 b15~0   
//<i>GTADTRB -      GTADTRB 
//<i>趨A/Dתʼʱ򡣵GTADTRBĴֵGTCNTֵͬʱA/Dתʼ
//<i>ͨ28GTADTRĴֹ8λΪλȡGTADTRĴ16λΪλдȡ 
#define CFG_GPT0_GTADTRB_INIT	0x000


// <e1.2>GTADTR A/Dʱ򻺳
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
// <o0.10> ADTDA_GTADTRAλ
//    <0=>е(GTADTBRA=>GTADTRA)
//    <1=>˫(GTADTDBRA=>GTADTBRA=>GTADTRA)
// <o0.8..9> ADTTA_GTADTRA 崫ʱѡλ
//    <0=>ǲ/ݲ:;ݲ
//    <1=>ǲ:ڲд;ݲ()(ݼ)ʱд
//    <2=>ǲ:ڲȽд
//    <3=>ǲ:ڲ/ Ƚд
// <o0.14> ADTDB_GTADTRBλ
//    <0=>е(GTADTBRB=>GTADTRB)
//    <1=>˫(GTADTDBRB=>GTADTBRB=>GTADTRB)
// <o0.12..13> ADTTB_GTADTRB 崫ʱѡλ
//    <0=>ǲ/ݲ:;ݲ
//    <1=>ǲ:ڲд;ݲ:()(ݼ)ʱд
//    <2=>ǲ:ڲȽд
//    <3=>ǲ:ڲ/ Ƚд

// <o2.0..15> GTADTBRA_A/Dתʼʱ򻺳ĴA<0-65535>
//<i>GTADTBRA_A/Dתʼʱ򻺳ĴA
//<i>0x064    b31~16 b15~0    
//<i>GTADTBRA -      GTADTBRA 
//<i>GTADTBRAĴ16λɶдĴGTADTRAĴĻĴ
//<i>ͨ28GTADTBRĴֹ8λΪλȡGTADTBRĴ16λΪλдȡ

// <o3.0..15> GTADTBRB_A/D תʼʱ򻺳ĴB<0-65535>
//<i>GTADTBRB_A/Dתʼʱ򻺳ĴB
//<i>0x068    b31~16 b15~0    
//<i>GTADTBRB -      GTADTBRB 
//<i>GTADTBRBĴ16λɶдĴGTADTRBĴĻĴͨ28GTADTBRĴ
//<i>ֹ8λΪλȡGTADTBRĴ16λΪλдȡ 


// <o4.0..15> GTADTDBRA_A/Dתʼʱ˫ĴA<0-65535>
//<i>GTADTDBRA_A/Dתʼʱ˫ĴA
//<i>0x06C     b31~16 b15~0     
//<i>GTADTDBRA -      GTADTDBRA 
//<i>GTADTDBRAĴ16λɶдĴGTADTBRAĴĻĴ GTADTR˫Ĵ
//<i>ͨ28GTADTDBRĴ8λΪλȡGTADTDBRĴ16λΪλдڡ 


// <o5.0..15> GTADTDBRB_A/D תʼʱ˫ĴB<0-65535>
//<i>GTADTDBRB_A/Dתʼʱ˫ĴB
//<i>0x070     b31~16 b15~0     
//<i>GTADTDBRB -      GTADTDBRB 
//<i>GTADTDBRBĴ16λɶдĴGTADTBRBĴĻĴ GTADTR˫Ĵ
//<i>ͨ28GTADTDBRĴ8λΪλȡGTADTDBRĴ16λΪλдڡ 

#define CFG_GPT0_GTBER_H_INIT	0x0000
#define CFG_GPT0_BDADTR_EN	0x0
#define CFG_GPT0_GTADTBRA_INIT	0xffff
#define CFG_GPT0_GTADTBRB_INIT	0xffff
#define CFG_GPT0_GTADTDBRA_INIT	0xffff
#define CFG_GPT0_GTADTDBRB_INIT	0xffff
//</e>
//</h>



// <e0.0>GTCCRȽϲ׽
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
#define CFG_GPT0_BDCCR_EN	0x0

 
// <o0.0..1> CCRA_GTCCRA λ
//    <0=>л
//    <1=>еУGTCCRA=GTCCRC
//    <2=>˫ GTCCRA=GTCCRC=GTCCRD
//<i>GTBER_PWMʱĻĴ
//<i>0x024 b31~15 b14   b13~12 b11 b10   b9~8  b7 b6     b5~4 b3~2 b1~0 
//<i>GTBER -      ADTDB ADTTB  -   ADTDA ADTTA -  CCRSWT PR   CCRB CCRA
// <o0.2..3> CCRB_GTCCRB λ
//    <0=>л
//    <1=>еУGTCCRB=GTCCRE
//    <2=>˫ GTCCRB=GTCCRE=GTCCRF
//<i>GTBER_PWMʱĻĴ
//<i>0x024 b31~15 b14   b13~12 b11 b10   b9~8  b7 b6     b5~4 b3~2 b1~0 
//<i>GTBER -      ADTDB ADTTB  -   ADTDA ADTTA -  CCRSWT PR   CCRB CCRA
#define CFG_GPT0_GTBER_L_INIT	0x0
#define CFG_GPT0_GTBER_INIT	(CFG_GPT0_GTBER_L_INIT	| CFG_GPT0_GTBER_PR_INIT | CFG_GPT0_GTBER_H_INIT)


//<i>GTCCRC_ͨPWMʱıȽϲ׽ĴC
//<i>0x040  b31~16  b15~0   
//<i>GTCCRC GTCCRCH GTCCRCL 
// <o0.0..15> GTCCRCL_Ƚϲ׽ĴGTCCRC16λ<0-65535>
#define CFG_GPT0_GTCCRC_INIT	0xffff

//<i>GTCCRD_ͨPWMʱıȽϲ׽ĴD
//<i>0x044  b31~16  b15~0   
//<i>GTCCRD GTCCRDH GTCCRDL 
// <o0.0..15> GTCCRDL_Ƚϲ׽ĴGTCCRD16λ<0-65535> 
#define CFG_GPT0_GTCCRD_INIT	0xffff

//<i>GTCCRE_ͨPWMʱıȽϲ׽ĴE
//<i>0x048  b31~16  b15~0   
//<i>GTCCRE GTCCREH GTCCREL 
// <o0.0..15> GTCCREL_Ƚϲ׽ĴGTCCRE16λ<0-65535>
#define CFG_GPT0_GTCCRE_INIT	0xffff

//<i>GTCCRF_ͨPWMʱıȽϲ׽ĴF
//<i>0x04C  b31~16  b15~0   
//<i>GTCCRF GTCCRFH GTCCRFL 
// <o0.0..15> GTCCRFL_Ƚϲ׽ĴGTCCRF16λ<0-65535>   
#define CFG_GPT0_GTCCRF_INIT	0xffff
//</e>


//<h>Ӳֹͣ
//<i>GTHCR_ͨPWM ʱӲֹͣƼĴ
//<i>0x000 b31~9 b8   b7~6 b5~4 b3~2 b1~0 
//<i>GTHCR -     CCSW SYNC CCHW CPHW CSHW 
// <o0.0..1> CSHW_GPTx.GTCNT ӲԴGTETRGʼλ
//    <0=>ͨӲԴʼ
//    <1=>ӲԴؿʼ
//    <2=>ӲԴ½ؿʼ
//    <3=>ӲԴ˫ؿʼ
//    <i>ͨӲԴGTSTRĴĶӦλԶΪ1
// <o0.2..3> CPHW_GPTx.GTCNT ӲԴGTETRGֹͣλ
//    <0=>ͨӲԴֹͣ
//    <1=>ӲԴֹͣ
//    <2=>ӲԴ½ֹͣ
//    <3=>ӲԴ˫ֹͣ
//    <i>ͨӲԴֹͣGTSTRĴĶӦλԶΪ0
// <o0.4..5> CCHW_GPTx.GTCNT ӲԴGTETRG
//    <0=>ͨӲԴ
//    <1=>ӲԴ
//    <2=>ӲԴ½
//    <3=>ӲԴ˫
//    <i>趨ΪͨӲԴGPTx.GTCNTʱGPTx.GTCNTڼGTSTR.CTS=1ֹͣ GTSTR.CTS=0ͨӲԴм
// <o0.6..7> SYNC_GPTx.GTCNT ͬԴѡλ
//    <0=>ͨGPT0ԴGPTx.GTCNT
//    <1=>ͨGPT1ԴͬGPTx.GTCNT
//    <2=>ͨGPT2ԴͬGPTx.GTCNT
//    <3=>ͨGPT3ԴͬGPTx.GTCNT
//    <i>GPTx.GTCNT0=03ֹͣ״̬½д
//    <i>趨GPTx.SYNC[1:0]λȽGPTx.GTCR.CCLR[1:0]λá11bͨڽͬ/ͬеԴ
//</h>
#define CFG_GPT0_GTHCR_INIT	0x0

//<h>˲
//<i>GTDEB_ͨPWMʱ˲Ĵ
//<i>0x004 b31~10 b9   b8   b7~4 b3~0 
//<i>GTDEB -      INBE INAE -    DEB  
// <o0.0..3> DEB_GPTxź˲ѡλ
//    <0=>˲
//    <1=>˲ʱ䳣Ϊ30*HCLK(0.5us)
//    <2=>˲ʱ䳣Ϊ60*HCLK(1us)
//    <3=>˲ʱ䳣Ϊ120*HCLK(2us)
//    <4=>˲ʱ䳣Ϊ180*HCLK(3us)
//    <5=>˲ʱ䳣Ϊ240*HCLK(4us)
//    <6=>˲ʱ䳣Ϊ300*HCLK(5us)
//    <7=>˲ʱ䳣Ϊ360*HCLK(6us)
//    <8=>˲ʱ䳣Ϊ480*HCLK(8us)
//    <9=>˲ʱ䳣Ϊ600*HCLK(10us)
//    <10=>˲ʱ䳣Ϊ720*HCLK(12us)
//    <11=>˲ʱ䳣Ϊ960*HCLK(16us)
//    <12=>˲ʱ䳣Ϊ1200*HCLK(20us)
//    <13=>˲ʱ䳣Ϊ1440*HCLK(24us)
//    <14=>˲ʱ䳣Ϊ1680*HCLK(28us)
//    <15=>˲ʱ䳣Ϊ1920*HCLK(32us)
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.8> INAE_ͨA벶׽λ
//    <0=>GPTx.GTCCRA׷ӵ32λһʱ벶׽
//    <1=>GPTx.GTCCRA׷ӵ32λһʱ벶׽
//    <i>ʱGPTx.GTCCRA32λʱ
//    <i>ʱGPTx.GTCCRAΪһʱԱʱ趨ΪȽһΪ벶׽Ķʱһ
// <o0.9> INBE_ͨB벶׽λ
//    <0=>GPTx.GTCCRB׷ӵ32λһʱ벶׽
//    <1=>GPTx.GTCCRB׷ӵ32λһʱ벶׽
//    <i>ʱGPTx.GTCCRB32λʱ
//    <i>ʱGPTx.GTCCRBΪһʱԱʱ趨ΪȽһΪ벶׽Ķʱһ
//    <i>GPT0GPT1һԣGPT2GPT3һ

//</h>
#define CFG_GPT0_GTDEB_INIT	0x0

//<h>DMA趨Ĵ
//<i>GTDMA_ͨPWMʱDMA趨Ĵ
//<i>0x018 b31~4 b3~2 b1 b0 
//<i>GTDMA -     PR   TB TA 
// <q0.0> TA_GTCCRA Ƚƥ/벶׽DMAλ
//    0: ֹDMA
//    1: DMA
// <q0.1> TB_GTCCRB Ƚƥ/벶׽DMAλ
//    0: ֹDMA
//    1: DMA
// <o0.2..3> PR_GTPR ȽƥDMAλ
//    <0=>ֹDMA
//    <1=>ݲʱ硢ǲʱڲDMA
//    <2=>ݲʱ硢ǲʱڲDMA
//    <3=>ݲʱ硢ǲʱڲͲȶDMA
//</h>
#define CFG_GPT0_GTDMA_INIT	0x0


//<h>ж趨Ĵ
//<i>GTINTAD_ͨPWMʱж趨Ĵ
//<i>0x014   b31~12 b11      b10      b9       b8       b7~6 b5   b4   b3~2    b1     b0     
//<i>GTINTAD -      ADTRBDEN ADTRBUEN ADTRADEN ADTRAUEN -    OINT EINT GTINTPR GTINTB GTINTA 
// <q0.0> GTINTA_GTCCRA Ƚƥ/벶׽жλ
//    0: ֹж
//    1: ж
// <q0.1> GTINTB_GTCCRB Ƚƥ/벶׽жλ
//    0: ֹж
//    1: ж
// <o0.2..3> GTINTPR_GTPRжλ
//    <0=>ֹж
//    <1=>ݲʱ硢ǲʱڲж
//    <2=>ݲʱ硢ǲʱڲж
//    <3=>ݲʱ硢ǲʱڲͲȶж
// <q0.4> EINT_ʱжλ
//    0: ֹж
//    1: ж
// <q0.5> OINT_·жλ
//    0: ֹж
//    1: ж
//</h>
#define CFG_GPT0_GTINTAD_L	0x0

#if ((CFG_GPT0_GTINTAD_L & (3<<2)) != 0)
	#define CFG_GPT0_GTCIV_INT_EN 1
#else
	#define CFG_GPT0_GTCIV_INT_EN 0
#endif

#if ((CFG_GPT0_GTINTAD_L & 0x33) != 0)
	#define CFG_GPT0_GTCIN_INT_EN 1
#else
	#define CFG_GPT0_GTCIN_INT_EN 0
#endif

#define CFG_GPT0_GTINTAD_INIT	(CFG_GPT0_GTINTAD_L | CFG_GPT0_GTINTAD_H)

//<h>ж
//<i>GTITC_ͨPWMʱжϡA/Dתʼ趨Ĵ
//<i>0x02C b31~15 b14   b13 b12   b11 b10~8 b7~6 b5~4 b3~2 b1   b0   
//<i>GTITC -      ADTBL -   ADTAL -   IVTT  -    IVTC -    ITLB ITLA 
// <o0.0> ITLA_GTCCRA Ƚƥ/ 벶׽жλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.1> ITLB_GTCCRB Ƚƥ/ 벶׽жλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.4..5> IVTC_GTCIV жϼٹѡλ
//    <0=>
//    <1=>Ծݲʱ硢ǲʱĲм
//    <2=>Ծݲʱ硢ǲʱĲȽм
//    <3=>Ծݲʱ/ 硢ǲ/ ȶм
// <o0.8..10> IVTT_GTCIV жϼٴѡλ
//    <0=>
//    <1=>ٴΪ1 
//    <2=>ٴΪ2 
//    <3=>ٴΪ3 
//    <4=>ٴΪ4 
//    <5=>ٴΪ5 
//    <6=>ٴΪ6 
//    <7=>ٴΪ7 
//<i>ڽIVTC[<1=>0]λá00bܸIVTT[2:0]λ
// <o0.12> ADTAL_GTADTRA A/D תʼλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.14> ADTBL_GTADTRB A/D תʼλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ

//</h>
#define CFG_GPT0_GTITC_INIT	0x0


//<h>ƽ
//<i>GTOSCR_ͨPWMʱĵƽƼĴ
//<i>0x088  b31~8 b7    b6~2 b1    b0    
//<i>GTOSCR -     OLSEN -    OLSGB OLSGA 
// <q0.7> OLSEN_ƽʹλ
//    0: ֹ
//    1: ʹ
// <o0.0> OLSGA_·GTIOCxAЧƽ趨λ
//    <0=>Low ƽЧ
//    <1=>High ƽЧ
// <o0.1> OLSGB_·GTIOCxBЧƽ趨λ
//    <0=>Low ƽЧ
//    <1=>High ƽЧ

//</h>
#define CFG_GPT0_GTOSCR_INIT	0x0

#define CFG_GPT0_GTBDR_INIT	(CFG_GPT0_BDDV_EN | CFG_GPT0_BDADTR_EN | CFG_GPT0_BDPR_EN | CFG_GPT0_BDCCR_EN)
//</e>

//***********************************************************/
//<e>GPT1_ͨPWMʱ
#define CFG_GPT1_EN	0

//<i>GPTʱԤƵĴ
//<i>GTPSQ_GPTʱԤƵĴ
//<i>0x020 b31~16 b15~0 
//<i>GTPSQ -      GTPSQ 
// <o0.0..15> GPTʱԤƵĴ<0-65535>
//<i>GPTʱΪ(GPTCLK/(PSQ[15:0]+1))
//<i>ڶʱʱ޸ 
#define CFG_GPT1_GTPSQ_INIT	0x0

// <o> GPT1_PWMƵ (0-200000Hz) <0-200000> 
#define CFG_GPT1_PWMP_F	50000

#define CFG_GPT1_CLK		((unsigned long)(SYS_CLK/(CFG_GPT1_GTPSQ_INIT + 1)))
#define CFG_GPT1_GTPR_INIT (CFG_GPT1_CLK/CFG_GPT1_PWMP_F)
	

//<o>GTIOCnAռձ (0.1%) <0-1000>
#define CFG_GPT1_GTIOC0A_DUTY	500

//<o>GTIOCnBռձ (0.1%) <0-1000>
#define CFG_GPT1_GTIOC0B_DUTY	500


//GTCCRA_ͨPWMʱıȽϲ׽ĴA 
//0x038  b31~16  b15~0   
//GTCCRA GTCCRAH GTCCRAL 
//GTCCRAL_Ƚϲ׽ĴGTCCRA16λ
#define CFG_GPT1_GTCCRA_INIT (CFG_GPT1_GTPR_INIT*CFG_GPT1_GTIOC0A_DUTY/1000)

//GTCCRB_ͨPWMʱıȽϲ׽ĴB
//0x03C  b31~16  b15~0   
//GTCCRB GTCCRBH GTCCRBL 
//GTCCRBL_Ƚϲ׽ĴGTCCRB16λ
#define CFG_GPT1_GTCCRB_INIT (CFG_GPT1_GTPR_INIT*CFG_GPT1_GTIOC0B_DUTY/1000)


// <o0.0..2> PWMģʽѡ
//    <0=>ݲPWM ģʽܵ/ ˫壩
//    <1=>ݲģʽ̶ΪУ
//    <4=>ǲPWM ģʽ1ڲ16 λͣܵ/ ˫壩
//    <5=>ǲPWM ģʽ2ڲ/ 16 λͣܵ/ ˫壩
//    <6=>ǲPWM ģʽ3ڲ32 λ̶ͣΪУ
//    <7=>ǲPWM ģʽ4ڲ16λͣܵ/˫壩
//<h>GPTƼĴ
//<i>GTCR_ͨPWMʱĿƼĴ
//<i>0x01C b31~14 b13~12 b11~10 b9  b8   b7~3 b2~0 
//<i>GTCR  -      CCLR   -      HIZ TPSC -    MD   
//<i>GPT1GPT2λЧGPT1GPT3λ
// <q0.9> HIZ_ȽCMP1GPTxʹλ
//    0: ֹCMP1GPTx
//    1: ʹCMP1GPTx
//<i>λ󣬵CMP1C1IF@AMOC->CMPINTFΪ1ʱGPTx̬
// <o0.12..13> CCLR_Դѡλ
//    <0=>趨Դ
//    <1=>ͨGTCCRA Ĵ벶׽
//    <2=>ͨGTCCRB Ĵ벶׽
//    <3=>ͨڽͬ/ ͬеԴ
//    <i>ھݲѡͬʱͬͨ/ еͬ/ Уǣ־/ ־λǲѡͬʱֻͬмֵΪ0ǣΪ ȡ 
//    <i>ͨԴѡ01b10b ߡ11b ʱGTCNT ڼGTSTR.CTSn=1ֹͣGTSTR.CSTn=0n=0  3ͨԴ
//</h>
#define CFG_GPT1_GTCR_VALUE	0x0
#define CFG_GPT1_GTCR_INIT	CFG_GPT1_GTCR_VALUE


// <e0.1>GTPRڻ
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
#define CFG_GPT1_BDPR_EN	0x0

// <o0.4..5> PR_GTPR λ
//    <0=>
//    <1=>еУGTPBR=>GTPR
//    <2=>˫ GTPDBR=>GTPBR=>GTPR
#define CFG_GPT1_GTBER_PR_INIT	0x0

// <o0.0..15> GTPBR_ͨPWMʱ趨Ĵ<0-65535>
//<i>GTPBR_ͨPWMʱ趨Ĵ
//<i>0x054 b31~16 b15~0 
//<i>GTPBR -      GTPBR 
//<i>GTPBRĴ16λɶдĴGTPRĴĻĴͨ14GTPBRĴ
#define CFG_GPT1_GTPBR_INIT	0xffff

//<i>GTPDBR_ͨPWMʱ趨˫Ĵ
//<i>0x058  b31~16 b15~0  
//<i>GTPDBR -      GTPDBR 
// <o0.0..15> GTPDBR_ͨPWMʱ趨˫Ĵ<0-65535>
//<i>GTPDBRĴ16λɶдĴGTPBRĴĻĴ GTPRĴ˫Ĵͨ14GTPDBRĴ
#define CFG_GPT1_GTPDBR_INIT	0xffff
//</e>


//<h>
//<i>GTUDC_ͨPWMʱļĴ
//<i>0x028 b31~2 b1  b0 
//<i>GTUDC -     UDF UD 
// <o0.0> UD_趨λ
//    <0=>GTCNT
//    <1=>GTCNTݼ
// <q0.1> UDF_ǿ趨λ
//    <i>0:ǿ趨
//    <i>1:ǿ趨
//    <i>λGTCNTʼʱļǿ趨ΪUDλֵʱֻܸλд0
//</h>
#define CFG_GPT1_GTUDC_INIT	0x0


//<h>ʱƼĴ
// <o0.0> TDE_ನ趨λ
//    <0=>ʹGTDVU ĴGTDVD Ĵ趨GTCCRB Ĵ
//    <1=>ʹGTDVU ĴGTDVD ĴʱķನεıȽƥֵԶ趨GTCCRBĴ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>    λ趨ǷʹGTDVUĴGTDVDĴʹGTDVUĴGTDVDĴʱನεıȽƥֵ GTCRRAĴʱֵ GTDVUĴGTDVDĴĴʱķನεıȽƥֵԶ趨GTCCRBĴ
//<i>    ھݲPWMģʽкTDEλ趨ҲԶ趨λ
//<i>    Զ趨GTCCRBĴֵ/ֵʾGTCCRBĴֵֵ/ֵķΧʱ͸GTCCRBĴ趨ֵ/ֵGTST.DTEF־Ϊ1
//<i>    ǲ    ֵ:GTPR1    ֵ:ʱΪ1ݼʱΪ0
//<i>    ݲģʽ    ֵ:GTPR    ֵ:0
// <o0.8> TDFER_GTDVD 趨λ
//    <0=>趨GTDVU ĴGTDVD Ĵ
//    <1=>GTDVU ĴдֵԶ趨GTDVDĴ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 

//<o1> GTDVU_ڵʱ(0.1us) <0-100>
//<i>GTDVU_ͨPWM ʱʱֵĴU
//<i>0x078 b31~16 b15~0 
//<i>GTDVU -      GTDVU 
//<i>GTDVUĴ16λɶдĴ趨ɴʱPWMεʱ䡣
//<i>ֱͨ2ڵGTDVUĴڵݼGTDVDĴ8GTDVĴ
//<i>ֹ趨ڵʱֵ,ͨGTCCRBĴ趨ֵʹGTDVĴʱֹдGTCCRBĴ
//<i>ʱֵ趨Ϊ0ʱĲΡ
//<i>ֹ8λΪλȡGTDVĴ16λΪλдȡ 

//<o2>GTDVD_ڵݼʱ(0.1us) <0-100>
//<i>GTDVD_ͨPWM ʱʱֵĴD
//<i>0x07C b31~16 b15~0 
//<i>GTDVD -      GTDVD 
//<i>GTDVDĴ16λɶдĴ趨ɴʱPWMεʱ䡣
//<i>ֱͨ2ڵGTDVUĴڵݼGTDVDĴ8GTDVĴ
//<i>ֹ趨ڵʱֵ,ͨGTCCRBĴ趨ֵʹGTDVĴʱֹдGTCCRBĴ
//<i>ʱֵ趨Ϊ0ʱĲΡ
//<i>ֹ8λΪλȡGTDVĴ16λΪλдȡ

// <e3.3>GTDVʱ仺
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 

// <q0.4> TDBUE_GTDVU λ
//    0: ֹGTDVU ĴĻ
//    1: GTDVU ĴĻ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>崫ʱǲʱΪȣھݲʱΪ硣

// <q0.5> TDBDE_GTDVD λ
//    0: ֹGTDVD ĴĻ
//    1: GTDVD ĴĻ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>    λGTDVDĴGTDBDĴϵĻС崫ʱǲʱΪȣھݲʱΪ硣ͬʱTDFERλá1ʱTDFERλ趨

//<o4> GTDBU_GTDVUĴĻʱ(0.1us) <0-100>
//<i>GTDBU_ͨPWM ʱʱ仺ĴU
//<i>0x080 b31~16 b15~0 
//<i>GTDBU -      GTDBU 
//<i>GTDBUĴ16λɶдĴGTDVUĴĻĴ

// <o5> GTDBD_GTDVDĴĻʱ(0.1us) <0-100>
//<i>GTDBD_ͨPWM ʱʱ仺ĴD
//<i>0x084 b31~16 b15~0 
//<i>GTDBD -      GTDBD 
//<i>GTDBDĴ16λɶдĴGTDVDĴĻĴ 

//</e>


#define CFG_GPT1_GTDTCR_INIT	0x0
#define CFG_GPT1_GTDVU_DT	0
#define CFG_GPT1_GTDVD_DT	0
#define CFG_GPT1_BDDV_EN	0x0
#define CFG_GPT1_GTDBU_DT	0
#define CFG_GPT1_GTDBD_DT	0
#define CFG_GPT1_GTDVU_INIT ((uint16_t)(CFG_GPT1_GTDVU_DT*CFG_GPT1_CLK/10000000))
#define CFG_GPT1_GTDVD_INIT ((uint16_t)(CFG_GPT1_GTDVD_DT*CFG_GPT1_CLK/10000000))
#define CFG_GPT1_GTDBU_INIT ((uint16_t)(CFG_GPT1_GTDBU_DT*CFG_GPT1_CLK/10000000))
#define CFG_GPT1_GTDBD_INIT ((uint16_t)(CFG_GPT1_GTDBD_DT*CFG_GPT1_CLK/10000000))

//</h>

//<h>GTIOCxA/BüĴ
//<i>GTIOR_ͨPWM ʱI/OƼĴ
//<i>0x010 b31~16 b15   b14    b13~8 b7    b6     b5~0  
//<i>GTIOR -      OBHLD OBDFLT GTIOB OAHLD OADFLT GTIOA 
// <o0.6> OADFLT_GTIOCxA żֹͣʱֵλ
//    <0=>ֹͣʱGTIOCxALow ƽ
//    <1=>ֹͣʱGTIOCxAHigh ƽ
// <o0.7> OAHLD_GTIOCxAżʼ/ֹͣʱֿ
//    <0=>ʼ/ֹͣʱGTIOCxA ŵƽȡڼĴ趨ֵ
//    <1=>ּʼ/ֹͣʱGTIOCxAŵƽ
//<i>ܼĴģʽڼʼʱGTIORĴbit4ֵָ
//<i>ܼĴģʽڼֹͣʱOADFLTλֵָ
//<i>ܼĴģʽڼֹͣʱOADFLTλֵ£ӳ
// <o0.14> OBDFLT_GTIOCxB żֹͣʱֵλ
//    <0=>ֹͣʱGTIOCxB Low ƽ
//    <1=>ֹͣʱGTIOCxB High ƽ
// <o0.15> OBHLD_GTIOCxB żʼ/ ֹͣʱλ
//    <0=>ʼ/ ֹͣʱGTIOCxB ŵƽȡȡڼĴ趨ֵ
//    <1=>ּʼ/ ֹͣʱGTIOCxB ŵƽ
//<i>    ڼʼʱGTIORĴbit4ֵָ
//<i>    ڼֹͣʱOBDFLTλֵָ
//<i>    ڼֹͣʱOBDFLTλֵ£ӳ
#define CFG_GPT1_GTIOR	0x0

//<e>GTIOA_GTIOCxAȽƥ
#define CFG_GPT1_GTIOR_GTIOA_O_EN	0

// <o0.4> GTIOA_GTIOCxAųʼƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o0.2..3> GTIOA_GTIOCxAڽʱ״̬
//    <0=>ڽʱ
//    <1=>ڽʱLOWƽ
//    <2=>ڽʱHIGHƽ
//    <3=>ڽʱ
// <o0.0..1> GTIOA_GTIOCxAŵıȽƥ״̬
//    <0=>ͨGPTn.GTCCRAıȽƥ䱣
//    <1=>ͨGPTn.GTCCRAıȽƥLowƽ
//    <2=>ͨGPTn.GTCCRAıȽƥHighƽ
//    <3=>ͨGPTn.GTCCRAıȽƥн
#define CFG_GPT1_GTIOR_GTIOA_O	0

//</e>
//<e>GTIOA_GTIOCxA벶׽
#define CFG_GPT1_GTIOR_GTIOA_I_EN	0

// <o0.2..3> GTIOA_GTIOCxAŲ׽ѡ
//    <0=>GTIOCxAΪ׽
//    <1=>RXD1Ϊǲ׽
//    <2=>RXD2Ϊǲ׽
//    <3=>RXD3Ϊǲ׽
// <o0.0..1> GTIOA_GTIOCxAŵ벶׽ʽѡ
//    <0=>벶׽
//    <1=>½벶׽
//    <2=>˫벶׽
#define CFG_GPT1_GTIOR_GTIOA_I	0

//</e>
//<e>GTIOB_GTIOCxBȽƥ
#define CFG_GPT1_GTIOR_GTIOB_O_EN 0 

// <o0.12> GTIOB_GTIOCxBųʼƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o0.10..11> GTIOB_GTIOCxBڽʱ״̬
//    <0=>ڽʱ
//    <1=>ڽʱLOWƽ
//    <2=>ڽʱHIGHƽ
//    <3=>ڽʱ
// <o0.8..9> GTIOB_GTIOCxBŵıȽƥ״̬
//    <0=>ͨGPTn.GTCCRA/BıȽƥ䱣
//    <1=>ͨGPTn.GTCCRA/BıȽƥLowƽ
//    <2=>ͨGPTn.GTCCRA/BıȽƥHighƽ
//    <3=>ͨGPTn.GTCCRA/BıȽƥн
#define CFG_GPT1_GTIOR_GTIOB_O	0x00

//</e>
//<e>GTIOB_GTIOCxB벶׽
#define CFG_GPT1_GTIOR_GTIOB_I_EN	0

// <o0.8..9> GTIOB_GTIOCxBŵ벶׽ʽѡ
//    <0=>벶׽
//    <1=>½벶׽
//    <2=>˫벶׽
#define CFG_GPT1_GTIOR_GTIOB_I	0
//</e>
//</h>



#if	CFG_GPT1_GTIOR_GTIOA_O_EN
#define CFG_GPT1_GTIOR_VALUE	(CFG_GPT1_GTIOR | CFG_GPT1_GTIOR_GTIOA_O)
#elif	CFG_GPT1_GTIOR_GTIOA_I_EN
#define CFG_GPT1_GTIOR_VALUE	(CFG_GPT1_GTIOR | (1<<5) |CFG_GPT1_GTIOR_GTIOA_I)
#else
#define CFG_GPT1_GTIOR_VALUE	(CFG_GPT1_GTIOR)
#endif

#if	CFG_GPT1_GTIOR_GTIOB_O_EN
#define CFG_GPT1_GTIOR_INIT	(CFG_GPT1_GTIOR_VALUE | CFG_GPT1_GTIOR_GTIOB_O)
#elif	CFG_GPT1_GTIOR_GTIOB_I_EN
#define CFG_GPT1_GTIOR_INIT	(CFG_GPT1_GTIOR_VALUE | (1<<13) |CFG_GPT1_GTIOR_GTIOB_I)
#else
#define CFG_GPT1_GTIOR_INIT	(CFG_GPT1_GTIOR_VALUE)
#endif

#if ((CFG_GPT1_GTIOR_GTIOA_O_EN & CFG_GPT1_GTIOR_GTIOA_I_EN) == 1)
#error "GTIOA_GTIOC0AֻѡȽƥ벶׽еһģʽ."
#endif

#if ((CFG_GPT1_GTIOR_GTIOB_O_EN & CFG_GPT1_GTIOR_GTIOB_I_EN) == 1)
#error "GTIOB_GTIOC0BֻѡȽƥ벶׽еһģʽ."
#endif




//<h>Ƚƥ䴥A/Dת
// <q0.8> ADTRAUEN_GTADTRAȽƥ()A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.9> ADTRADEN_GTADTRAȽƥ(ݼ)A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.10> ADTRBUEN_GTADTRBȽƥ()A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.11> ADTRBDEN_GTADTRBȽƥ(ݼ)A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
#define CFG_GPT1_GTINTAD_H	0x00


//<i>GTADTRA_A/DתʼʱĴA
//<i>0x05C   b31~16 b15~0   
//<i>GTADTRA -      GTADTRA 
// <o0.0..15> GTADTRA_A/D תʼʱĴA<0-65535>
//<i>趨A/Dתʼʱ򡣵GTADTRAĴֵGTCNTֵͬʱA/Dתʼ
//<i>ͨ28GTADTRĴֹ8λΪλȡGTADTRĴ16λΪλдȡ 
#define CFG_GPT1_GTADTRA_INIT	0x000

// <o0.0..15> GTADTRB_A/D תʼʱĴB<0-65535>
//<i>GTADTRB_A/DתʼʱĴB
//<i>0x060   b31~16 b15~0   
//<i>GTADTRB -      GTADTRB 
//<i>趨A/Dתʼʱ򡣵GTADTRBĴֵGTCNTֵͬʱA/Dתʼ
//<i>ͨ28GTADTRĴֹ8λΪλȡGTADTRĴ16λΪλдȡ 
#define CFG_GPT1_GTADTRB_INIT	0x000


// <e1.2>GTADTR A/Dʱ򻺳
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
// <o0.10> ADTDA_GTADTRAλ
//    <0=>е(GTADTBRA=>GTADTRA)
//    <1=>˫(GTADTDBRA=>GTADTBRA=>GTADTRA)
// <o0.8..9> ADTTA_GTADTRA 崫ʱѡλ
//    <0=>ǲ/ݲ:;ݲ
//    <1=>ǲ:ڲд;ݲ()(ݼ)ʱд
//    <2=>ǲ:ڲȽд
//    <3=>ǲ:ڲ/ Ƚд
// <o0.14> ADTDB_GTADTRBλ
//    <0=>е(GTADTBRB=>GTADTRB)
//    <1=>˫(GTADTDBRB=>GTADTBRB=>GTADTRB)
// <o0.12..13> ADTTB_GTADTRB 崫ʱѡλ
//    <0=>ǲ/ݲ:;ݲ
//    <1=>ǲ:ڲд;ݲ:()(ݼ)ʱд
//    <2=>ǲ:ڲȽд
//    <3=>ǲ:ڲ/ Ƚд

// <o2.0..15> GTADTBRA_A/Dתʼʱ򻺳ĴA<0-65535>
//<i>GTADTBRA_A/Dתʼʱ򻺳ĴA
//<i>0x064    b31~16 b15~0    
//<i>GTADTBRA -      GTADTBRA 
//<i>GTADTBRAĴ16λɶдĴGTADTRAĴĻĴ
//<i>ͨ28GTADTBRĴֹ8λΪλȡGTADTBRĴ16λΪλдȡ

// <o3.0..15> GTADTBRB_A/D תʼʱ򻺳ĴB<0-65535>
//<i>GTADTBRB_A/Dתʼʱ򻺳ĴB
//<i>0x068    b31~16 b15~0    
//<i>GTADTBRB -      GTADTBRB 
//<i>GTADTBRBĴ16λɶдĴGTADTRBĴĻĴͨ28GTADTBRĴ
//<i>ֹ8λΪλȡGTADTBRĴ16λΪλдȡ 


// <o4.0..15> GTADTDBRA_A/Dתʼʱ˫ĴA<0-65535>
//<i>GTADTDBRA_A/Dתʼʱ˫ĴA
//<i>0x06C     b31~16 b15~0     
//<i>GTADTDBRA -      GTADTDBRA 
//<i>GTADTDBRAĴ16λɶдĴGTADTBRAĴĻĴ GTADTR˫Ĵ
//<i>ͨ28GTADTDBRĴ8λΪλȡGTADTDBRĴ16λΪλдڡ 


// <o5.0..15> GTADTDBRB_A/D תʼʱ˫ĴB<0-65535>
//<i>GTADTDBRB_A/Dתʼʱ˫ĴB
//<i>0x070     b31~16 b15~0     
//<i>GTADTDBRB -      GTADTDBRB 
//<i>GTADTDBRBĴ16λɶдĴGTADTBRBĴĻĴ GTADTR˫Ĵ
//<i>ͨ28GTADTDBRĴ8λΪλȡGTADTDBRĴ16λΪλдڡ 

#define CFG_GPT1_GTBER_H_INIT	0x000
#define CFG_GPT1_BDADTR_EN	0x0
#define CFG_GPT1_GTADTBRA_INIT	0xffff
#define CFG_GPT1_GTADTBRB_INIT	0xffff
#define CFG_GPT1_GTADTDBRA_INIT	0xffff
#define CFG_GPT1_GTADTDBRB_INIT	0xffff
//</e>
//</h>



// <e0.0>GTCCRȽϲ׽
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
#define CFG_GPT1_BDCCR_EN	0x0

 
// <o0.0..1> CCRA_GTCCRA λ
//    <0=>л
//    <1=>еУGTCCRA=GTCCRC
//    <2=>˫ GTCCRA=GTCCRC=GTCCRD
//<i>GTBER_PWMʱĻĴ
//<i>0x024 b31~15 b14   b13~12 b11 b10   b9~8  b7 b6     b5~4 b3~2 b1~0 
//<i>GTBER -      ADTDB ADTTB  -   ADTDA ADTTA -  CCRSWT PR   CCRB CCRA
// <o0.2..3> CCRB_GTCCRB λ
//    <0=>л
//    <1=>еУGTCCRB=GTCCRE
//    <2=>˫ GTCCRB=GTCCRE=GTCCRF
//<i>GTBER_PWMʱĻĴ
//<i>0x024 b31~15 b14   b13~12 b11 b10   b9~8  b7 b6     b5~4 b3~2 b1~0 
//<i>GTBER -      ADTDB ADTTB  -   ADTDA ADTTA -  CCRSWT PR   CCRB CCRA
#define CFG_GPT1_GTBER_L_INIT	0x0
#define CFG_GPT1_GTBER_INIT	(CFG_GPT1_GTBER_L_INIT	| CFG_GPT1_GTBER_PR_INIT | CFG_GPT1_GTBER_H_INIT)


//<i>GTCCRC_ͨPWMʱıȽϲ׽ĴC
//<i>0x040  b31~16  b15~0   
//<i>GTCCRC GTCCRCH GTCCRCL 
// <o0.0..15> GTCCRCL_Ƚϲ׽ĴGTCCRC16λ<0-65535>
#define CFG_GPT1_GTCCRC_INIT	0xffff

//<i>GTCCRD_ͨPWMʱıȽϲ׽ĴD
//<i>0x044  b31~16  b15~0   
//<i>GTCCRD GTCCRDH GTCCRDL 
// <o0.0..15> GTCCRDL_Ƚϲ׽ĴGTCCRD16λ<0-65535> 
#define CFG_GPT1_GTCCRD_INIT	0xffff

//<i>GTCCRE_ͨPWMʱıȽϲ׽ĴE
//<i>0x048  b31~16  b15~0   
//<i>GTCCRE GTCCREH GTCCREL 
// <o0.0..15> GTCCREL_Ƚϲ׽ĴGTCCRE16λ<0-65535>
#define CFG_GPT1_GTCCRE_INIT	0xffff

//<i>GTCCRF_ͨPWMʱıȽϲ׽ĴF
//<i>0x04C  b31~16  b15~0   
//<i>GTCCRF GTCCRFH GTCCRFL 
// <o0.0..15> GTCCRFL_Ƚϲ׽ĴGTCCRF16λ<0-65535>   
#define CFG_GPT1_GTCCRF_INIT	0xffff
//</e>


//<h>Ӳֹͣ
//<i>GTHCR_ͨPWM ʱӲֹͣƼĴ
//<i>0x000 b31~9 b8   b7~6 b5~4 b3~2 b1~0 
//<i>GTHCR -     CCSW SYNC CCHW CPHW CSHW 
// <o0.0..1> CSHW_GPTx.GTCNT ӲԴGTETRGʼλ
//    <0=>ͨӲԴʼ
//    <1=>ӲԴؿʼ
//    <2=>ӲԴ½ؿʼ
//    <3=>ӲԴ˫ؿʼ
//    <i>ͨӲԴGTSTRĴĶӦλԶΪ1
// <o0.2..3> CPHW_GPTx.GTCNT ӲԴGTETRGֹͣλ
//    <0=>ͨӲԴֹͣ
//    <1=>ӲԴֹͣ
//    <2=>ӲԴ½ֹͣ
//    <3=>ӲԴ˫ֹͣ
//    <i>ͨӲԴֹͣGTSTRĴĶӦλԶΪ0
// <o0.4..5> CCHW_GPTx.GTCNT ӲԴGTETRG
//    <0=>ͨӲԴ
//    <1=>ӲԴ
//    <2=>ӲԴ½
//    <3=>ӲԴ˫
//    <i>趨ΪͨӲԴGPTx.GTCNTʱGPTx.GTCNTڼGTSTR.CTS=1ֹͣ GTSTR.CTS=0ͨӲԴм
// <o0.6..7> SYNC_GPTx.GTCNT ͬԴѡλ
//    <0=>ͨGPT0ԴGPTx.GTCNT
//    <1=>ͨGPT1ԴͬGPTx.GTCNT
//    <2=>ͨGPT2ԴͬGPTx.GTCNT
//    <3=>ͨGPT3ԴͬGPTx.GTCNT
//    <i>GPTx.GTCNT0=03ֹͣ״̬½д
//    <i>趨GPTx.SYNC[1:0]λȽGPTx.GTCR.CCLR[1:0]λá11bͨڽͬ/ͬеԴ
//</h>
#define CFG_GPT1_GTHCR_INIT	0x0

//<h>˲
//<i>GTDEB_ͨPWMʱ˲Ĵ
//<i>0x004 b31~10 b9   b8   b7~4 b3~0 
//<i>GTDEB -      INBE INAE -    DEB  
// <o0.0..3> DEB_GPTxź˲ѡλ
//    <0=>˲
//    <1=>˲ʱ䳣Ϊ30*HCLK(0.5us)
//    <2=>˲ʱ䳣Ϊ60*HCLK(1us)
//    <3=>˲ʱ䳣Ϊ120*HCLK(2us)
//    <4=>˲ʱ䳣Ϊ180*HCLK(3us)
//    <5=>˲ʱ䳣Ϊ240*HCLK(4us)
//    <6=>˲ʱ䳣Ϊ300*HCLK(5us)
//    <7=>˲ʱ䳣Ϊ360*HCLK(6us)
//    <8=>˲ʱ䳣Ϊ480*HCLK(8us)
//    <9=>˲ʱ䳣Ϊ600*HCLK(10us)
//    <10=>˲ʱ䳣Ϊ720*HCLK(12us)
//    <11=>˲ʱ䳣Ϊ960*HCLK(16us)
//    <12=>˲ʱ䳣Ϊ1200*HCLK(20us)
//    <13=>˲ʱ䳣Ϊ1440*HCLK(24us)
//    <14=>˲ʱ䳣Ϊ1680*HCLK(28us)
//    <15=>˲ʱ䳣Ϊ1920*HCLK(32us)
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.8> INAE_ͨA벶׽λ
//    <0=>GPTx.GTCCRA׷ӵ32λһʱ벶׽
//    <1=>GPTx.GTCCRA׷ӵ32λһʱ벶׽
//    <i>ʱGPTx.GTCCRA32λʱ
//    <i>ʱGPTx.GTCCRAΪһʱԱʱ趨ΪȽһΪ벶׽Ķʱһ
// <o0.9> INBE_ͨB벶׽λ
//    <0=>GPTx.GTCCRB׷ӵ32λһʱ벶׽
//    <1=>GPTx.GTCCRB׷ӵ32λһʱ벶׽
//    <i>ʱGPTx.GTCCRB32λʱ
//    <i>ʱGPTx.GTCCRBΪһʱԱʱ趨ΪȽһΪ벶׽Ķʱһ
//    <i>GPT1GPT1һԣGPT2GPT3һ

//</h>
#define CFG_GPT1_GTDEB_INIT	0x0

//<h>DMA趨Ĵ
//<i>GTDMA_ͨPWMʱDMA趨Ĵ
//<i>0x018 b31~4 b3~2 b1 b0 
//<i>GTDMA -     PR   TB TA 
// <q0.0> TA_GTCCRA Ƚƥ/벶׽DMAλ
//    0: ֹDMA
//    1: DMA
// <q0.1> TB_GTCCRB Ƚƥ/벶׽DMAλ
//    0: ֹDMA
//    1: DMA
// <o0.2..3> PR_GTPR ȽƥDMAλ
//    <0=>ֹDMA
//    <1=>ݲʱ硢ǲʱڲDMA
//    <2=>ݲʱ硢ǲʱڲDMA
//    <3=>ݲʱ硢ǲʱڲͲȶDMA
//</h>
#define CFG_GPT1_GTDMA_INIT	0x0


//<h>ж趨Ĵ
//<i>GTINTAD_ͨPWMʱж趨Ĵ
//<i>0x014   b31~12 b11      b10      b9       b8       b7~6 b5   b4   b3~2    b1     b0     
//<i>GTINTAD -      ADTRBDEN ADTRBUEN ADTRADEN ADTRAUEN -    OINT EINT GTINTPR GTINTB GTINTA 
// <q0.0> GTINTA_GTCCRA Ƚƥ/벶׽жλ
//    0: ֹж
//    1: ж
// <q0.1> GTINTB_GTCCRB Ƚƥ/벶׽жλ
//    0: ֹж
//    1: ж
// <o0.2..3> GTINTPR_GTPRжλ
//    <0=>ֹж
//    <1=>ݲʱ硢ǲʱڲж
//    <2=>ݲʱ硢ǲʱڲж
//    <3=>ݲʱ硢ǲʱڲͲȶж
// <q0.4> EINT_ʱжλ
//    0: ֹж
//    1: ж
// <q0.5> OINT_·жλ
//    0: ֹж
//    1: ж
//</h>
#define CFG_GPT1_GTINTAD_L	0x0

#if ((CFG_GPT1_GTINTAD_L & (3<<2)) != 0)
	#define CFG_GPT1_GTCIV_INT_EN 1
#else
	#define CFG_GPT1_GTCIV_INT_EN 0
#endif

#if ((CFG_GPT1_GTINTAD_L & 0x33) != 0)
	#define CFG_GPT1_GTCIN_INT_EN 1
#else
	#define CFG_GPT1_GTCIN_INT_EN 0
#endif

#define CFG_GPT1_GTINTAD_INIT	(CFG_GPT1_GTINTAD_L | CFG_GPT1_GTINTAD_H)


//<h>ж
//<i>GTITC_ͨPWMʱжϡA/Dתʼ趨Ĵ
//<i>0x02C b31~15 b14   b13 b12   b11 b10~8 b7~6 b5~4 b3~2 b1   b0   
//<i>GTITC -      ADTBL -   ADTAL -   IVTT  -    IVTC -    ITLB ITLA 
// <o0.0> ITLA_GTCCRA Ƚƥ/ 벶׽жλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.1> ITLB_GTCCRB Ƚƥ/ 벶׽жλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.4..5> IVTC_GTCIV жϼٹѡλ
//    <0=>
//    <1=>Ծݲʱ硢ǲʱĲм
//    <2=>Ծݲʱ硢ǲʱĲȽм
//    <3=>Ծݲʱ/ 硢ǲ/ ȶм
// <o0.8..10> IVTT_GTCIV жϼٴѡλ
//    <0=>
//    <1=>ٴΪ1 
//    <2=>ٴΪ2 
//    <3=>ٴΪ3 
//    <4=>ٴΪ4 
//    <5=>ٴΪ5 
//    <6=>ٴΪ6 
//    <7=>ٴΪ7 
//<i>ڽIVTC[<1=>0]λá00bܸIVTT[2:0]λ
// <o0.12> ADTAL_GTADTRA A/D תʼλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.14> ADTBL_GTADTRB A/D תʼλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ

//</h>
#define CFG_GPT1_GTITC_INIT	0x0


//<h>ƽ
//<i>GTOSCR_ͨPWMʱĵƽƼĴ
//<i>0x088  b31~8 b7    b6~2 b1    b0    
//<i>GTOSCR -     OLSEN -    OLSGB OLSGA 
// <q0.7> OLSEN_ƽʹλ
//    0: ֹ
//    1: ʹ
// <o0.0> OLSGA_·GTIOCxAЧƽ趨λ
//    <0=>Low ƽЧ
//    <1=>High ƽЧ
// <o0.1> OLSGB_·GTIOCxBЧƽ趨λ
//    <0=>Low ƽЧ
//    <1=>High ƽЧ

//</h>
#define CFG_GPT1_GTOSCR_INIT	0x0

#define CFG_GPT1_GTBDR_INIT	(CFG_GPT1_BDDV_EN | CFG_GPT1_BDADTR_EN | CFG_GPT1_BDPR_EN | CFG_GPT1_BDCCR_EN)
//</e>

//***********************************************************/
//<e>GPT2_ͨPWMʱ
#define CFG_GPT2_EN	0

//<e>ʱԴѡ(ѡһ)
// <q0.8>GPT2ѡHCLKΪʱԴѡ
//<i>TPSC_ʱʱԴѡλ:
//    <i>0=HCLK
//    <i>1=ΪGPT3/м
//<i>GPT0GPT2λЧGPT1GPT3λ
#define CFG_GPT2_CLK_HCLK	0x0


// <e0.8>GPT2ѡGPT3/ΪʱԴ
//<i>TPSC_ʱʱԴѡλ:
//    <i>0=HCLK
//    <i>1=ΪGPT3/м
//<i>GPT0GPT2λЧGPT1GPT3λ
#define CFG_GPT2_CLK_GPT3	0x0
// <o> GPT3Ƶ (0-200000Hz) <0-200000> 
#define CFG_GPT3_CLK_F	50000
//</e>
//</e>
#if ((CFG_GPT2_CLK_HCLK & CFG_GPT2_CLK_GPT3) == (1<<8))
#error "GPT0ʱԴѡֻHCLKGPT1/жѡһ."
#endif

//<i>GPTʱԤƵĴ
//<i>GTPSQ_GPTʱԤƵĴ
//<i>0x020 b31~16 b15~0 
//<i>GTPSQ -      GTPSQ 
// <o0.0..15> GPTʱԤƵĴ<0-65535>
//<i>GPTʱΪ(GPTCLK/(PSQ[15:0]+1))
//<i>ڶʱʱ޸ 
#define CFG_GPT2_GTPSQ_INIT	0x0

// <o> GPT2_PWMƵ (0-200000Hz) <0-200000> 
#define CFG_GPT2_PWMP_F	50000

#define CFG_GPT2_CLK		((unsigned long)(SYS_CLK/(CFG_GPT2_GTPSQ_INIT + 1)))
#define CFG_GPT2_GTPR_INIT (CFG_GPT2_CLK/CFG_GPT2_PWMP_F)
	

//<o>GTIOCnAռձ (0.1%) <0-1000>
#define CFG_GPT2_GTIOC0A_DUTY	500

//<o>GTIOCnBռձ (0.1%) <0-1000>
#define CFG_GPT2_GTIOC0B_DUTY	500


//GTCCRA_ͨPWMʱıȽϲ׽ĴA 
//0x038  b31~16  b15~0   
//GTCCRA GTCCRAH GTCCRAL 
//GTCCRAL_Ƚϲ׽ĴGTCCRA16λ
#define CFG_GPT2_GTCCRA_INIT (CFG_GPT2_GTPR_INIT*CFG_GPT2_GTIOC0A_DUTY/1000)

//GTCCRB_ͨPWMʱıȽϲ׽ĴB
//0x03C  b31~16  b15~0   
//GTCCRB GTCCRBH GTCCRBL 
//GTCCRBL_Ƚϲ׽ĴGTCCRB16λ
#define CFG_GPT2_GTCCRB_INIT (CFG_GPT2_GTPR_INIT*CFG_GPT2_GTIOC0B_DUTY/1000)


// <o0.0..2> PWMģʽѡ
//    <0=>ݲPWM ģʽܵ/ ˫壩
//    <1=>ݲģʽ̶ΪУ
//    <4=>ǲPWM ģʽ1ڲ16 λͣܵ/ ˫壩
//    <5=>ǲPWM ģʽ2ڲ/ 16 λͣܵ/ ˫壩
//    <6=>ǲPWM ģʽ3ڲ32 λ̶ͣΪУ
//    <7=>ǲPWM ģʽ4ڲ16λͣܵ/˫壩
//<h>GPTƼĴ
//<i>GTCR_ͨPWMʱĿƼĴ
//<i>0x01C b31~14 b13~12 b11~10 b9  b8   b7~3 b2~0 
//<i>GTCR  -      CCLR   -      HIZ TPSC -    MD   
//<i>GPT2GPT2λЧGPT1GPT3λ
// <q0.9> HIZ_ȽCMP1GPTxʹλ
//    0: ֹCMP1GPTx
//    1: ʹCMP1GPTx
//<i>λ󣬵CMP1C1IF@AMOC->CMPINTFΪ1ʱGPTx̬
// <o0.12..13> CCLR_Դѡλ
//    <0=>趨Դ
//    <1=>ͨGTCCRA Ĵ벶׽
//    <2=>ͨGTCCRB Ĵ벶׽
//    <3=>ͨڽͬ/ ͬеԴ
//    <i>ھݲѡͬʱͬͨ/ еͬ/ Уǣ־/ ־λǲѡͬʱֻͬмֵΪ0ǣΪ ȡ 
//    <i>ͨԴѡ01b10b ߡ11b ʱGTCNT ڼGTSTR.CTSn=1ֹͣGTSTR.CSTn=0n=0  3ͨԴ
//</h>
#define CFG_GPT2_GTCR_VALUE	0x0
#define CFG_GPT2_GTCR_INIT	( CFG_GPT2_GTCR_VALUE | CFG_GPT2_CLK_GPT3 )


// <e0.1>GTPRڻ
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
#define CFG_GPT2_BDPR_EN	0x0

// <o0.4..5> PR_GTPR λ
//    <0=>
//    <1=>еУGTPBR=>GTPR
//    <2=>˫ GTPDBR=>GTPBR=>GTPR
#define CFG_GPT2_GTBER_PR_INIT	0x0

// <o0.0..15> GTPBR_ͨPWMʱ趨Ĵ<0-65535>
//<i>GTPBR_ͨPWMʱ趨Ĵ
//<i>0x054 b31~16 b15~0 
//<i>GTPBR -      GTPBR 
//<i>GTPBRĴ16λɶдĴGTPRĴĻĴͨ14GTPBRĴ
#define CFG_GPT2_GTPBR_INIT	0xffff

//<i>GTPDBR_ͨPWMʱ趨˫Ĵ
//<i>0x058  b31~16 b15~0  
//<i>GTPDBR -      GTPDBR 
// <o0.0..15> GTPDBR_ͨPWMʱ趨˫Ĵ<0-65535>
//<i>GTPDBRĴ16λɶдĴGTPBRĴĻĴ GTPRĴ˫Ĵͨ14GTPDBRĴ
#define CFG_GPT2_GTPDBR_INIT	0xffff
//</e>






//<h>
//<i>GTUDC_ͨPWMʱļĴ
//<i>0x028 b31~2 b1  b0 
//<i>GTUDC -     UDF UD 
// <o0.0> UD_趨λ
//    <0=>GTCNT
//    <1=>GTCNTݼ
// <q0.1> UDF_ǿ趨λ
//    <i>0:ǿ趨
//    <i>1:ǿ趨
//    <i>λGTCNTʼʱļǿ趨ΪUDλֵʱֻܸλд0
//</h>
#define CFG_GPT2_GTUDC_INIT	0x0


//<h>ʱƼĴ
// <o0.0> TDE_ನ趨λ
//    <0=>ʹGTDVU ĴGTDVD Ĵ趨GTCCRB Ĵ
//    <1=>ʹGTDVU ĴGTDVD ĴʱķನεıȽƥֵԶ趨GTCCRBĴ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>    λ趨ǷʹGTDVUĴGTDVDĴʹGTDVUĴGTDVDĴʱನεıȽƥֵ GTCRRAĴʱֵ GTDVUĴGTDVDĴĴʱķನεıȽƥֵԶ趨GTCCRBĴ
//<i>    ھݲPWMģʽкTDEλ趨ҲԶ趨λ
//<i>    Զ趨GTCCRBĴֵ/ֵʾGTCCRBĴֵֵ/ֵķΧʱ͸GTCCRBĴ趨ֵ/ֵGTST.DTEF־Ϊ1
//<i>    ǲ    ֵ:GTPR1    ֵ:ʱΪ1ݼʱΪ0
//<i>    ݲģʽ    ֵ:GTPR    ֵ:0
// <o0.8> TDFER_GTDVD 趨λ
//    <0=>趨GTDVU ĴGTDVD Ĵ
//    <1=>GTDVU ĴдֵԶ趨GTDVDĴ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 

//<o1> GTDVU_ڵʱ(0.1us) <0-100>
//<i>GTDVU_ͨPWM ʱʱֵĴU
//<i>0x078 b31~16 b15~0 
//<i>GTDVU -      GTDVU 
//<i>GTDVUĴ16λɶдĴ趨ɴʱPWMεʱ䡣
//<i>ֱͨ2ڵGTDVUĴڵݼGTDVDĴ8GTDVĴ
//<i>ֹ趨ڵʱֵ,ͨGTCCRBĴ趨ֵʹGTDVĴʱֹдGTCCRBĴ
//<i>ʱֵ趨Ϊ0ʱĲΡ
//<i>ֹ8λΪλȡGTDVĴ16λΪλдȡ 

//<o2>GTDVD_ڵݼʱ(0.1us) <0-100>
//<i>GTDVD_ͨPWM ʱʱֵĴD
//<i>0x07C b31~16 b15~0 
//<i>GTDVD -      GTDVD 
//<i>GTDVDĴ16λɶдĴ趨ɴʱPWMεʱ䡣
//<i>ֱͨ2ڵGTDVUĴڵݼGTDVDĴ8GTDVĴ
//<i>ֹ趨ڵʱֵ,ͨGTCCRBĴ趨ֵʹGTDVĴʱֹдGTCCRBĴ
//<i>ʱֵ趨Ϊ0ʱĲΡ
//<i>ֹ8λΪλȡGTDVĴ16λΪλдȡ

// <e3.3>GTDVʱ仺
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 

// <q0.4> TDBUE_GTDVU λ
//    0: ֹGTDVU ĴĻ
//    1: GTDVU ĴĻ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>崫ʱǲʱΪȣھݲʱΪ硣

// <q0.5> TDBDE_GTDVD λ
//    0: ֹGTDVD ĴĻ
//    1: GTDVD ĴĻ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>    λGTDVDĴGTDBDĴϵĻС崫ʱǲʱΪȣھݲʱΪ硣ͬʱTDFERλá1ʱTDFERλ趨

//<o4> GTDBU_GTDVUĴĻʱ(0.1us) <0-100>
//<i>GTDBU_ͨPWM ʱʱ仺ĴU
//<i>0x080 b31~16 b15~0 
//<i>GTDBU -      GTDBU 
//<i>GTDBUĴ16λɶдĴGTDVUĴĻĴ

// <o5> GTDBD_GTDVDĴĻʱ(0.1us) <0-100>
//<i>GTDBD_ͨPWM ʱʱ仺ĴD
//<i>0x084 b31~16 b15~0 
//<i>GTDBD -      GTDBD 
//<i>GTDBDĴ16λɶдĴGTDVDĴĻĴ 

//</e>


#define CFG_GPT2_GTDTCR_INIT	0x0
#define CFG_GPT2_GTDVU_DT	0
#define CFG_GPT2_GTDVD_DT	0
#define CFG_GPT2_BDDV_EN	0x0
#define CFG_GPT2_GTDBU_DT	0
#define CFG_GPT2_GTDBD_DT	0
#define CFG_GPT2_GTDVU_INIT ((uint16_t)(CFG_GPT2_GTDVU_DT*CFG_GPT2_CLK/10000000))
#define CFG_GPT2_GTDVD_INIT ((uint16_t)(CFG_GPT2_GTDVD_DT*CFG_GPT2_CLK/10000000))
#define CFG_GPT2_GTDBU_INIT ((uint16_t)(CFG_GPT2_GTDBU_DT*CFG_GPT2_CLK/10000000))
#define CFG_GPT2_GTDBD_INIT ((uint16_t)(CFG_GPT2_GTDBD_DT*CFG_GPT2_CLK/10000000))

//</h>

//<h>GTIOCxA/BüĴ
//<i>GTIOR_ͨPWM ʱI/OƼĴ
//<i>0x010 b31~16 b15   b14    b13~8 b7    b6     b5~0  
//<i>GTIOR -      OBHLD OBDFLT GTIOB OAHLD OADFLT GTIOA 
// <o0.6> OADFLT_GTIOCxA żֹͣʱֵλ
//    <0=>ֹͣʱGTIOCxALow ƽ
//    <1=>ֹͣʱGTIOCxAHigh ƽ
// <o0.7> OAHLD_GTIOCxAżʼ/ֹͣʱֿ
//    <0=>ʼ/ֹͣʱGTIOCxA ŵƽȡڼĴ趨ֵ
//    <1=>ּʼ/ֹͣʱGTIOCxAŵƽ
//<i>ܼĴģʽڼʼʱGTIORĴbit4ֵָ
//<i>ܼĴģʽڼֹͣʱOADFLTλֵָ
//<i>ܼĴģʽڼֹͣʱOADFLTλֵ£ӳ
// <o0.14> OBDFLT_GTIOCxB żֹͣʱֵλ
//    <0=>ֹͣʱGTIOCxB Low ƽ
//    <1=>ֹͣʱGTIOCxB High ƽ
// <o0.15> OBHLD_GTIOCxB żʼ/ ֹͣʱλ
//    <0=>ʼ/ ֹͣʱGTIOCxB ŵƽȡȡڼĴ趨ֵ
//    <1=>ּʼ/ ֹͣʱGTIOCxB ŵƽ
//<i>    ڼʼʱGTIORĴbit4ֵָ
//<i>    ڼֹͣʱOBDFLTλֵָ
//<i>    ڼֹͣʱOBDFLTλֵ£ӳ
#define CFG_GPT2_GTIOR	0x0

//<e>GTIOA_GTIOCxAȽƥ
#define CFG_GPT2_GTIOR_GTIOA_O_EN	0

// <o0.4> GTIOA_GTIOCxAųʼƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o0.2..3> GTIOA_GTIOCxAڽʱ״̬
//    <0=>ڽʱ
//    <1=>ڽʱLOWƽ
//    <2=>ڽʱHIGHƽ
//    <3=>ڽʱ
// <o0.0..1> GTIOA_GTIOCxAŵıȽƥ״̬
//    <0=>ͨGPTn.GTCCRAıȽƥ䱣
//    <1=>ͨGPTn.GTCCRAıȽƥLowƽ
//    <2=>ͨGPTn.GTCCRAıȽƥHighƽ
//    <3=>ͨGPTn.GTCCRAıȽƥн
#define CFG_GPT2_GTIOR_GTIOA_O	0

//</e>
//<e>GTIOA_GTIOCxA벶׽
#define CFG_GPT2_GTIOR_GTIOA_I_EN	0

// <o0.2..3> GTIOA_GTIOCxAŲ׽ѡ
//    <0=>GTIOCxAΪ׽
//    <1=>RXD1Ϊǲ׽
//    <2=>RXD2Ϊǲ׽
//    <3=>RXD3Ϊǲ׽
// <o0.0..1> GTIOA_GTIOCxAŵ벶׽ʽѡ
//    <0=>벶׽
//    <1=>½벶׽
//    <2=>˫벶׽
#define CFG_GPT2_GTIOR_GTIOA_I	0

//</e>
//<e>GTIOB_GTIOCxBȽƥ
#define CFG_GPT2_GTIOR_GTIOB_O_EN 0

// <o0.12> GTIOB_GTIOCxBųʼƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o0.10..11> GTIOB_GTIOCxBڽʱ״̬
//    <0=>ڽʱ
//    <1=>ڽʱLOWƽ
//    <2=>ڽʱHIGHƽ
//    <3=>ڽʱ
// <o0.8..9> GTIOB_GTIOCxBŵıȽƥ״̬
//    <0=>ͨGPTn.GTCCRA/BıȽƥ䱣
//    <1=>ͨGPTn.GTCCRA/BıȽƥLowƽ
//    <2=>ͨGPTn.GTCCRA/BıȽƥHighƽ
//    <3=>ͨGPTn.GTCCRA/BıȽƥн
#define CFG_GPT2_GTIOR_GTIOB_O	0x00

//</e>
//<e>GTIOB_GTIOCxB벶׽
#define CFG_GPT2_GTIOR_GTIOB_I_EN	0

// <o0.8..9> GTIOB_GTIOCxBŵ벶׽ʽѡ
//    <0=>벶׽
//    <1=>½벶׽
//    <2=>˫벶׽
#define CFG_GPT2_GTIOR_GTIOB_I	0
//</e>
//</h>



#if	CFG_GPT2_GTIOR_GTIOA_O_EN
#define CFG_GPT2_GTIOR_VALUE	(CFG_GPT2_GTIOR | CFG_GPT2_GTIOR_GTIOA_O)
#elif	CFG_GPT2_GTIOR_GTIOA_I_EN
#define CFG_GPT2_GTIOR_VALUE	(CFG_GPT2_GTIOR | (1<<5) |CFG_GPT2_GTIOR_GTIOA_I)
#else
#define CFG_GPT2_GTIOR_VALUE	(CFG_GPT2_GTIOR)
#endif

#if	CFG_GPT2_GTIOR_GTIOB_O_EN
#define CFG_GPT2_GTIOR_INIT	(CFG_GPT2_GTIOR_VALUE | CFG_GPT2_GTIOR_GTIOB_O)
#elif	CFG_GPT2_GTIOR_GTIOB_I_EN
#define CFG_GPT2_GTIOR_INIT	(CFG_GPT2_GTIOR_VALUE | (1<<13) |CFG_GPT2_GTIOR_GTIOB_I)
#else
#define CFG_GPT2_GTIOR_INIT	(CFG_GPT2_GTIOR_VALUE)
#endif

#if ((CFG_GPT2_GTIOR_GTIOA_O_EN & CFG_GPT2_GTIOR_GTIOA_I_EN) == 1)
#error "GTIOA_GTIOC0AֻѡȽƥ벶׽еһģʽ."
#endif

#if ((CFG_GPT2_GTIOR_GTIOB_O_EN & CFG_GPT2_GTIOR_GTIOB_I_EN) == 1)
#error "GTIOB_GTIOC0BֻѡȽƥ벶׽еһģʽ."
#endif




//<h>Ƚƥ䴥A/Dת
// <q0.8> ADTRAUEN_GTADTRAȽƥ()A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.9> ADTRADEN_GTADTRAȽƥ(ݼ)A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.10> ADTRBUEN_GTADTRBȽƥ()A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.11> ADTRBDEN_GTADTRBȽƥ(ݼ)A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
#define CFG_GPT2_GTINTAD_H	0x00


//<i>GTADTRA_A/DתʼʱĴA
//<i>0x05C   b31~16 b15~0   
//<i>GTADTRA -      GTADTRA 
// <o0.0..15> GTADTRA_A/D תʼʱĴA<0-65535>
//<i>趨A/Dתʼʱ򡣵GTADTRAĴֵGTCNTֵͬʱA/Dתʼ
//<i>ͨ28GTADTRĴֹ8λΪλȡGTADTRĴ16λΪλдȡ 
#define CFG_GPT2_GTADTRA_INIT	0x000

// <o0.0..15> GTADTRB_A/D תʼʱĴB<0-65535>
//<i>GTADTRB_A/DתʼʱĴB
//<i>0x060   b31~16 b15~0   
//<i>GTADTRB -      GTADTRB 
//<i>趨A/Dתʼʱ򡣵GTADTRBĴֵGTCNTֵͬʱA/Dתʼ
//<i>ͨ28GTADTRĴֹ8λΪλȡGTADTRĴ16λΪλдȡ 
#define CFG_GPT2_GTADTRB_INIT	0x000


// <e1.2>GTADTR A/Dʱ򻺳
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
// <o0.10> ADTDA_GTADTRAλ
//    <0=>е(GTADTBRA=>GTADTRA)
//    <1=>˫(GTADTDBRA=>GTADTBRA=>GTADTRA)
// <o0.8..9> ADTTA_GTADTRA 崫ʱѡλ
//    <0=>ǲ/ݲ:;ݲ
//    <1=>ǲ:ڲд;ݲ()(ݼ)ʱд
//    <2=>ǲ:ڲȽд
//    <3=>ǲ:ڲ/ Ƚд
// <o0.14> ADTDB_GTADTRBλ
//    <0=>е(GTADTBRB=>GTADTRB)
//    <1=>˫(GTADTDBRB=>GTADTBRB=>GTADTRB)
// <o0.12..13> ADTTB_GTADTRB 崫ʱѡλ
//    <0=>ǲ/ݲ:;ݲ
//    <1=>ǲ:ڲд;ݲ:()(ݼ)ʱд
//    <2=>ǲ:ڲȽд
//    <3=>ǲ:ڲ/ Ƚд

// <o2.0..15> GTADTBRA_A/Dתʼʱ򻺳ĴA<0-65535>
//<i>GTADTBRA_A/Dתʼʱ򻺳ĴA
//<i>0x064    b31~16 b15~0    
//<i>GTADTBRA -      GTADTBRA 
//<i>GTADTBRAĴ16λɶдĴGTADTRAĴĻĴ
//<i>ͨ28GTADTBRĴֹ8λΪλȡGTADTBRĴ16λΪλдȡ

// <o3.0..15> GTADTBRB_A/D תʼʱ򻺳ĴB<0-65535>
//<i>GTADTBRB_A/Dתʼʱ򻺳ĴB
//<i>0x068    b31~16 b15~0    
//<i>GTADTBRB -      GTADTBRB 
//<i>GTADTBRBĴ16λɶдĴGTADTRBĴĻĴͨ28GTADTBRĴ
//<i>ֹ8λΪλȡGTADTBRĴ16λΪλдȡ 


// <o4.0..15> GTADTDBRA_A/Dתʼʱ˫ĴA<0-65535>
//<i>GTADTDBRA_A/Dתʼʱ˫ĴA
//<i>0x06C     b31~16 b15~0     
//<i>GTADTDBRA -      GTADTDBRA 
//<i>GTADTDBRAĴ16λɶдĴGTADTBRAĴĻĴ GTADTR˫Ĵ
//<i>ͨ28GTADTDBRĴ8λΪλȡGTADTDBRĴ16λΪλдڡ 


// <o5.0..15> GTADTDBRB_A/D תʼʱ˫ĴB<0-65535>
//<i>GTADTDBRB_A/Dתʼʱ˫ĴB
//<i>0x070     b31~16 b15~0     
//<i>GTADTDBRB -      GTADTDBRB 
//<i>GTADTDBRBĴ16λɶдĴGTADTBRBĴĻĴ GTADTR˫Ĵ
//<i>ͨ28GTADTDBRĴ8λΪλȡGTADTDBRĴ16λΪλдڡ 

#define CFG_GPT2_GTBER_H_INIT	0x0000
#define CFG_GPT2_BDADTR_EN	0x0
#define CFG_GPT2_GTADTBRA_INIT	0xffff
#define CFG_GPT2_GTADTBRB_INIT	0xffff
#define CFG_GPT2_GTADTDBRA_INIT	0xffff
#define CFG_GPT2_GTADTDBRB_INIT	0xffff
//</e>
//</h>


// <e0.0>GTCCRȽϲ׽
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
#define CFG_GPT2_BDCCR_EN	0x0

 
// <o0.0..1> CCRA_GTCCRA λ
//    <0=>л
//    <1=>еУGTCCRA=GTCCRC
//    <2=>˫ GTCCRA=GTCCRC=GTCCRD
//<i>GTBER_PWMʱĻĴ
//<i>0x024 b31~15 b14   b13~12 b11 b10   b9~8  b7 b6     b5~4 b3~2 b1~0 
//<i>GTBER -      ADTDB ADTTB  -   ADTDA ADTTA -  CCRSWT PR   CCRB CCRA
// <o0.2..3> CCRB_GTCCRB λ
//    <0=>л
//    <1=>еУGTCCRB=GTCCRE
//    <2=>˫ GTCCRB=GTCCRE=GTCCRF
//<i>GTBER_PWMʱĻĴ
//<i>0x024 b31~15 b14   b13~12 b11 b10   b9~8  b7 b6     b5~4 b3~2 b1~0 
//<i>GTBER -      ADTDB ADTTB  -   ADTDA ADTTA -  CCRSWT PR   CCRB CCRA
#define CFG_GPT2_GTBER_L_INIT	0x0
#define CFG_GPT2_GTBER_INIT	(CFG_GPT2_GTBER_L_INIT	| CFG_GPT2_GTBER_PR_INIT | CFG_GPT2_GTBER_H_INIT)


//<i>GTCCRC_ͨPWMʱıȽϲ׽ĴC
//<i>0x040  b31~16  b15~0   
//<i>GTCCRC GTCCRCH GTCCRCL 
// <o0.0..15> GTCCRCL_Ƚϲ׽ĴGTCCRC16λ<0-65535>
#define CFG_GPT2_GTCCRC_INIT	0xffff

//<i>GTCCRD_ͨPWMʱıȽϲ׽ĴD
//<i>0x044  b31~16  b15~0   
//<i>GTCCRD GTCCRDH GTCCRDL 
// <o0.0..15> GTCCRDL_Ƚϲ׽ĴGTCCRD16λ<0-65535> 
#define CFG_GPT2_GTCCRD_INIT	0xffff

//<i>GTCCRE_ͨPWMʱıȽϲ׽ĴE
//<i>0x048  b31~16  b15~0   
//<i>GTCCRE GTCCREH GTCCREL 
// <o0.0..15> GTCCREL_Ƚϲ׽ĴGTCCRE16λ<0-65535>
#define CFG_GPT2_GTCCRE_INIT	0xffff

//<i>GTCCRF_ͨPWMʱıȽϲ׽ĴF
//<i>0x04C  b31~16  b15~0   
//<i>GTCCRF GTCCRFH GTCCRFL 
// <o0.0..15> GTCCRFL_Ƚϲ׽ĴGTCCRF16λ<0-65535>   
#define CFG_GPT2_GTCCRF_INIT	0xffff
//</e>


//<h>Ӳֹͣ
//<i>GTHCR_ͨPWM ʱӲֹͣƼĴ
//<i>0x000 b31~9 b8   b7~6 b5~4 b3~2 b1~0 
//<i>GTHCR -     CCSW SYNC CCHW CPHW CSHW 
// <o0.0..1> CSHW_GPTx.GTCNT ӲԴGTETRGʼλ
//    <0=>ͨӲԴʼ
//    <1=>ӲԴؿʼ
//    <2=>ӲԴ½ؿʼ
//    <3=>ӲԴ˫ؿʼ
//    <i>ͨӲԴGTSTRĴĶӦλԶΪ1
// <o0.2..3> CPHW_GPTx.GTCNT ӲԴGTETRGֹͣλ
//    <0=>ͨӲԴֹͣ
//    <1=>ӲԴֹͣ
//    <2=>ӲԴ½ֹͣ
//    <3=>ӲԴ˫ֹͣ
//    <i>ͨӲԴֹͣGTSTRĴĶӦλԶΪ0
// <o0.4..5> CCHW_GPTx.GTCNT ӲԴGTETRG
//    <0=>ͨӲԴ
//    <1=>ӲԴ
//    <2=>ӲԴ½
//    <3=>ӲԴ˫
//    <i>趨ΪͨӲԴGPTx.GTCNTʱGPTx.GTCNTڼGTSTR.CTS=1ֹͣ GTSTR.CTS=0ͨӲԴм
// <o0.6..7> SYNC_GPTx.GTCNT ͬԴѡλ
//    <0=>ͨGPT0ԴGPTx.GTCNT
//    <1=>ͨGPT1ԴͬGPTx.GTCNT
//    <2=>ͨGPT2ԴͬGPTx.GTCNT
//    <3=>ͨGPT3ԴͬGPTx.GTCNT
//    <i>GPTx.GTCNT0=03ֹͣ״̬½д
//    <i>趨GPTx.SYNC[1:0]λȽGPTx.GTCR.CCLR[1:0]λá11bͨڽͬ/ͬеԴ
//</h>
#define CFG_GPT2_GTHCR_INIT	0x0

//<h>˲
//<i>GTDEB_ͨPWMʱ˲Ĵ
//<i>0x004 b31~10 b9   b8   b7~4 b3~0 
//<i>GTDEB -      INBE INAE -    DEB  
// <o0.0..3> DEB_GPTxź˲ѡλ
//    <0=>˲
//    <1=>˲ʱ䳣Ϊ30*HCLK(0.5us)
//    <2=>˲ʱ䳣Ϊ60*HCLK(1us)
//    <3=>˲ʱ䳣Ϊ120*HCLK(2us)
//    <4=>˲ʱ䳣Ϊ180*HCLK(3us)
//    <5=>˲ʱ䳣Ϊ240*HCLK(4us)
//    <6=>˲ʱ䳣Ϊ300*HCLK(5us)
//    <7=>˲ʱ䳣Ϊ360*HCLK(6us)
//    <8=>˲ʱ䳣Ϊ480*HCLK(8us)
//    <9=>˲ʱ䳣Ϊ600*HCLK(10us)
//    <10=>˲ʱ䳣Ϊ720*HCLK(12us)
//    <11=>˲ʱ䳣Ϊ960*HCLK(16us)
//    <12=>˲ʱ䳣Ϊ1200*HCLK(20us)
//    <13=>˲ʱ䳣Ϊ1440*HCLK(24us)
//    <14=>˲ʱ䳣Ϊ1680*HCLK(28us)
//    <15=>˲ʱ䳣Ϊ1920*HCLK(32us)
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.8> INAE_ͨA벶׽λ
//    <0=>GPTx.GTCCRA׷ӵ32λһʱ벶׽
//    <1=>GPTx.GTCCRA׷ӵ32λһʱ벶׽
//    <i>ʱGPTx.GTCCRA32λʱ
//    <i>ʱGPTx.GTCCRAΪһʱԱʱ趨ΪȽһΪ벶׽Ķʱһ
// <o0.9> INBE_ͨB벶׽λ
//    <0=>GPTx.GTCCRB׷ӵ32λһʱ벶׽
//    <1=>GPTx.GTCCRB׷ӵ32λһʱ벶׽
//    <i>ʱGPTx.GTCCRB32λʱ
//    <i>ʱGPTx.GTCCRBΪһʱԱʱ趨ΪȽһΪ벶׽Ķʱһ
//    <i>GPT2GPT1һԣGPT2GPT3һ

//</h>
#define CFG_GPT2_GTDEB_INIT	0x0

//<h>DMA趨Ĵ
//<i>GTDMA_ͨPWMʱDMA趨Ĵ
//<i>0x018 b31~4 b3~2 b1 b0 
//<i>GTDMA -     PR   TB TA 
// <q0.0> TA_GTCCRA Ƚƥ/벶׽DMAλ
//    0: ֹDMA
//    1: DMA
// <q0.1> TB_GTCCRB Ƚƥ/벶׽DMAλ
//    0: ֹDMA
//    1: DMA
// <o0.2..3> PR_GTPR ȽƥDMAλ
//    <0=>ֹDMA
//    <1=>ݲʱ硢ǲʱڲDMA
//    <2=>ݲʱ硢ǲʱڲDMA
//    <3=>ݲʱ硢ǲʱڲͲȶDMA
//</h>
#define CFG_GPT2_GTDMA_INIT	0x0


//<h>ж趨Ĵ
//<i>GTINTAD_ͨPWMʱж趨Ĵ
//<i>0x014   b31~12 b11      b10      b9       b8       b7~6 b5   b4   b3~2    b1     b0     
//<i>GTINTAD -      ADTRBDEN ADTRBUEN ADTRADEN ADTRAUEN -    OINT EINT GTINTPR GTINTB GTINTA 
// <q0.0> GTINTA_GTCCRA Ƚƥ/벶׽жλ
//    0: ֹж
//    1: ж
// <q0.1> GTINTB_GTCCRB Ƚƥ/벶׽жλ
//    0: ֹж
//    1: ж
// <o0.2..3> GTINTPR_GTPRжλ
//    <0=>ֹж
//    <1=>ݲʱ硢ǲʱڲж
//    <2=>ݲʱ硢ǲʱڲж
//    <3=>ݲʱ硢ǲʱڲͲȶж
// <q0.4> EINT_ʱжλ
//    0: ֹж
//    1: ж
// <q0.5> OINT_·жλ
//    0: ֹж
//    1: ж
//</h>
#define CFG_GPT2_GTINTAD_L	0x0

#if ((CFG_GPT2_GTINTAD_L & (3<<2)) != 0)
	#define CFG_GPT2_GTCIV_INT_EN 1
#else
	#define CFG_GPT2_GTCIV_INT_EN 0
#endif

#if ((CFG_GPT2_GTINTAD_L & 0x33) != 0)
	#define CFG_GPT2_GTCIN_INT_EN 1
#else
	#define CFG_GPT2_GTCIN_INT_EN 0
#endif

#define CFG_GPT2_GTINTAD_INIT	(CFG_GPT2_GTINTAD_L | CFG_GPT2_GTINTAD_H)

//<h>ж
//<i>GTITC_ͨPWMʱжϡA/Dתʼ趨Ĵ
//<i>0x02C b31~15 b14   b13 b12   b11 b10~8 b7~6 b5~4 b3~2 b1   b0   
//<i>GTITC -      ADTBL -   ADTAL -   IVTT  -    IVTC -    ITLB ITLA 
// <o0.0> ITLA_GTCCRA Ƚƥ/ 벶׽жλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.1> ITLB_GTCCRB Ƚƥ/ 벶׽жλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.4..5> IVTC_GTCIV жϼٹѡλ
//    <0=>
//    <1=>Ծݲʱ硢ǲʱĲм
//    <2=>Ծݲʱ硢ǲʱĲȽм
//    <3=>Ծݲʱ/ 硢ǲ/ ȶм
// <o0.8..10> IVTT_GTCIV жϼٴѡλ
//    <0=>
//    <1=>ٴΪ1 
//    <2=>ٴΪ2 
//    <3=>ٴΪ3 
//    <4=>ٴΪ4 
//    <5=>ٴΪ5 
//    <6=>ٴΪ6 
//    <7=>ٴΪ7 
//<i>ڽIVTC[<1=>0]λá00bܸIVTT[2:0]λ
// <o0.12> ADTAL_GTADTRA A/D תʼλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.14> ADTBL_GTADTRB A/D תʼλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ

//</h>
#define CFG_GPT2_GTITC_INIT	0x0


//<h>ƽ
//<i>GTOSCR_ͨPWMʱĵƽƼĴ
//<i>0x088  b31~8 b7    b6~2 b1    b0    
//<i>GTOSCR -     OLSEN -    OLSGB OLSGA 
// <q0.7> OLSEN_ƽʹλ
//    0: ֹ
//    1: ʹ
// <o0.0> OLSGA_·GTIOCxAЧƽ趨λ
//    <0=>Low ƽЧ
//    <1=>High ƽЧ
// <o0.1> OLSGB_·GTIOCxBЧƽ趨λ
//    <0=>Low ƽЧ
//    <1=>High ƽЧ

//</h>
#define CFG_GPT2_GTOSCR_INIT	0x0

#define CFG_GPT2_GTBDR_INIT	(CFG_GPT2_BDDV_EN | CFG_GPT2_BDADTR_EN | CFG_GPT2_BDPR_EN | CFG_GPT2_BDCCR_EN)
//</e>
//***********************************************************/
//<e>GPT3_ͨPWMʱ
#define CFG_GPT3_EN	0

//<i>GPTʱԤƵĴ
//<i>GTPSQ_GPTʱԤƵĴ
//<i>0x020 b31~16 b15~0 
//<i>GTPSQ -      GTPSQ 
// <o0.0..15> GPTʱԤƵĴ<0-65535>
//<i>GPTʱΪ(GPTCLK/(PSQ[15:0]+1))
//<i>ڶʱʱ޸ 
#define CFG_GPT3_GTPSQ_INIT	0x0

// <o> GPT3_PWMƵ (0-200000Hz) <0-200000> 
#define CFG_GPT3_PWMP_F	50000

#define CFG_GPT3_CLK		((unsigned long)(SYS_CLK/(CFG_GPT3_GTPSQ_INIT + 1)))
#define CFG_GPT3_GTPR_INIT (CFG_GPT3_CLK/CFG_GPT3_PWMP_F)
	

//<o>GTIOCnAռձ (0.1%) <0-1000>
#define CFG_GPT3_GTIOC0A_DUTY	500

//<o>GTIOCnBռձ (0.1%) <0-1000>
#define CFG_GPT3_GTIOC0B_DUTY	500


//GTCCRA_ͨPWMʱıȽϲ׽ĴA 
//0x038  b31~16  b15~0   
//GTCCRA GTCCRAH GTCCRAL 
//GTCCRAL_Ƚϲ׽ĴGTCCRA16λ
#define CFG_GPT3_GTCCRA_INIT (CFG_GPT3_GTPR_INIT*CFG_GPT3_GTIOC0A_DUTY/1000)

//GTCCRB_ͨPWMʱıȽϲ׽ĴB
//0x03C  b31~16  b15~0   
//GTCCRB GTCCRBH GTCCRBL 
//GTCCRBL_Ƚϲ׽ĴGTCCRB16λ
#define CFG_GPT3_GTCCRB_INIT (CFG_GPT3_GTPR_INIT*CFG_GPT3_GTIOC0B_DUTY/1000)


// <o0.0..2> PWMģʽѡ
//    <0=>ݲPWM ģʽܵ/ ˫壩
//    <1=>ݲģʽ̶ΪУ
//    <4=>ǲPWM ģʽ1ڲ16 λͣܵ/ ˫壩
//    <5=>ǲPWM ģʽ2ڲ/ 16 λͣܵ/ ˫壩
//    <6=>ǲPWM ģʽ3ڲ32 λ̶ͣΪУ
//    <7=>ǲPWM ģʽ4ڲ16λͣܵ/˫壩
//<h>GPTƼĴ
//<i>GTCR_ͨPWMʱĿƼĴ
//<i>0x01C b31~14 b13~12 b11~10 b9  b8   b7~3 b2~0 
//<i>GTCR  -      CCLR   -      HIZ TPSC -    MD   
//<i>GPT3GPT2λЧGPT3GPT3λ
// <q0.9> HIZ_ȽCMP1GPTxʹλ
//    0: ֹCMP1GPTx
//    1: ʹCMP1GPTx
//<i>λ󣬵CMP1C1IF@AMOC->CMPINTFΪ1ʱGPTx̬
// <o0.12..13> CCLR_Դѡλ
//    <0=>趨Դ
//    <1=>ͨGTCCRA Ĵ벶׽
//    <2=>ͨGTCCRB Ĵ벶׽
//    <3=>ͨڽͬ/ ͬеԴ
//    <i>ھݲѡͬʱͬͨ/ еͬ/ Уǣ־/ ־λǲѡͬʱֻͬмֵΪ0ǣΪ ȡ 
//    <i>ͨԴѡ01b10b ߡ11b ʱGTCNT ڼGTSTR.CTSn=1ֹͣGTSTR.CSTn=0n=0  3ͨԴ
//</h>
#define CFG_GPT3_GTCR_VALUE	0x0
#define CFG_GPT3_GTCR_INIT	CFG_GPT3_GTCR_VALUE


// <e0.1>GTPRڻ
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
#define CFG_GPT3_BDPR_EN	0x0

// <o0.4..5> PR_GTPR λ
//    <0=>
//    <1=>еУGTPBR=>GTPR
//    <2=>˫ GTPDBR=>GTPBR=>GTPR
#define CFG_GPT3_GTBER_PR_INIT	0x0

// <o0.0..15> GTPBR_ͨPWMʱ趨Ĵ<0-65535>
//<i>GTPBR_ͨPWMʱ趨Ĵ
//<i>0x054 b31~16 b15~0 
//<i>GTPBR -      GTPBR 
//<i>GTPBRĴ16λɶдĴGTPRĴĻĴͨ14GTPBRĴ
#define CFG_GPT3_GTPBR_INIT	0xffff

//<i>GTPDBR_ͨPWMʱ趨˫Ĵ
//<i>0x058  b31~16 b15~0  
//<i>GTPDBR -      GTPDBR 
// <o0.0..15> GTPDBR_ͨPWMʱ趨˫Ĵ<0-65535>
//<i>GTPDBRĴ16λɶдĴGTPBRĴĻĴ GTPRĴ˫Ĵͨ14GTPDBRĴ
#define CFG_GPT3_GTPDBR_INIT	0xffff
//</e>






//<h>
//<i>GTUDC_ͨPWMʱļĴ
//<i>0x028 b31~2 b1  b0 
//<i>GTUDC -     UDF UD 
// <o0.0> UD_趨λ
//    <0=>GTCNT
//    <1=>GTCNTݼ
// <q0.1> UDF_ǿ趨λ
//    <i>0:ǿ趨
//    <i>1:ǿ趨
//    <i>λGTCNTʼʱļǿ趨ΪUDλֵʱֻܸλд0
//</h>
#define CFG_GPT3_GTUDC_INIT	0x0


//<h>ʱƼĴ
// <o0.0> TDE_ನ趨λ
//    <0=>ʹGTDVU ĴGTDVD Ĵ趨GTCCRB Ĵ
//    <1=>ʹGTDVU ĴGTDVD ĴʱķನεıȽƥֵԶ趨GTCCRBĴ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>    λ趨ǷʹGTDVUĴGTDVDĴʹGTDVUĴGTDVDĴʱನεıȽƥֵ GTCRRAĴʱֵ GTDVUĴGTDVDĴĴʱķನεıȽƥֵԶ趨GTCCRBĴ
//<i>    ھݲPWMģʽкTDEλ趨ҲԶ趨λ
//<i>    Զ趨GTCCRBĴֵ/ֵʾGTCCRBĴֵֵ/ֵķΧʱ͸GTCCRBĴ趨ֵ/ֵGTST.DTEF־Ϊ1
//<i>    ǲ    ֵ:GTPR1    ֵ:ʱΪ1ݼʱΪ0
//<i>    ݲģʽ    ֵ:GTPR    ֵ:0
// <o0.8> TDFER_GTDVD 趨λ
//    <0=>趨GTDVU ĴGTDVD Ĵ
//    <1=>GTDVU ĴдֵԶ趨GTDVDĴ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 

//<o1> GTDVU_ڵʱ(0.1us) <0-100>
//<i>GTDVU_ͨPWM ʱʱֵĴU
//<i>0x078 b31~16 b15~0 
//<i>GTDVU -      GTDVU 
//<i>GTDVUĴ16λɶдĴ趨ɴʱPWMεʱ䡣
//<i>ֱͨ2ڵGTDVUĴڵݼGTDVDĴ8GTDVĴ
//<i>ֹ趨ڵʱֵ,ͨGTCCRBĴ趨ֵʹGTDVĴʱֹдGTCCRBĴ
//<i>ʱֵ趨Ϊ0ʱĲΡ
//<i>ֹ8λΪλȡGTDVĴ16λΪλдȡ 

//<o2>GTDVD_ڵݼʱ(0.1us) <0-100>
//<i>GTDVD_ͨPWM ʱʱֵĴD
//<i>0x07C b31~16 b15~0 
//<i>GTDVD -      GTDVD 
//<i>GTDVDĴ16λɶдĴ趨ɴʱPWMεʱ䡣
//<i>ֱͨ2ڵGTDVUĴڵݼGTDVDĴ8GTDVĴ
//<i>ֹ趨ڵʱֵ,ͨGTCCRBĴ趨ֵʹGTDVĴʱֹдGTCCRBĴ
//<i>ʱֵ趨Ϊ0ʱĲΡ
//<i>ֹ8λΪλȡGTDVĴ16λΪλдȡ

// <e3.3>GTDVʱ仺
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 

// <q0.4> TDBUE_GTDVU λ
//    0: ֹGTDVU ĴĻ
//    1: GTDVU ĴĻ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>崫ʱǲʱΪȣھݲʱΪ硣

// <q0.5> TDBDE_GTDVD λ
//    0: ֹGTDVD ĴĻ
//    1: GTDVD ĴĻ
//<i>GTDTCR_ͨPWM ʱʱƼĴ
//<i>0x074  b31~9 b8    b7~6 b5    b4    b3~1 b0  
//<i>GTDTCR -     TDFER -    TDBDE TDBUE -    TDE 
//<i>    λGTDVDĴGTDBDĴϵĻС崫ʱǲʱΪȣھݲʱΪ硣ͬʱTDFERλá1ʱTDFERλ趨

//<o4> GTDBU_GTDVUĴĻʱ(0.1us) <0-100>
//<i>GTDBU_ͨPWM ʱʱ仺ĴU
//<i>0x080 b31~16 b15~0 
//<i>GTDBU -      GTDBU 
//<i>GTDBUĴ16λɶдĴGTDVUĴĻĴ

// <o5> GTDBD_GTDVDĴĻʱ(0.1us) <0-100>
//<i>GTDBD_ͨPWM ʱʱ仺ĴD
//<i>0x084 b31~16 b15~0 
//<i>GTDBD -      GTDBD 
//<i>GTDBDĴ16λɶдĴGTDVDĴĻĴ 

//</e>


#define CFG_GPT3_GTDTCR_INIT	0x0
#define CFG_GPT3_GTDVU_DT	0
#define CFG_GPT3_GTDVD_DT	0
#define CFG_GPT3_BDDV_EN	0x0
#define CFG_GPT3_GTDBU_DT	0
#define CFG_GPT3_GTDBD_DT	0
#define CFG_GPT3_GTDVU_INIT ((uint16_t)(CFG_GPT3_GTDVU_DT*CFG_GPT3_CLK/10000000))
#define CFG_GPT3_GTDVD_INIT ((uint16_t)(CFG_GPT3_GTDVD_DT*CFG_GPT3_CLK/10000000))
#define CFG_GPT3_GTDBU_INIT ((uint16_t)(CFG_GPT3_GTDBU_DT*CFG_GPT3_CLK/10000000))
#define CFG_GPT3_GTDBD_INIT ((uint16_t)(CFG_GPT3_GTDBD_DT*CFG_GPT3_CLK/10000000))

//</h>

//<h>GTIOCxA/BüĴ
//<i>GTIOR_ͨPWM ʱI/OƼĴ
//<i>0x010 b31~16 b15   b14    b13~8 b7    b6     b5~0  
//<i>GTIOR -      OBHLD OBDFLT GTIOB OAHLD OADFLT GTIOA 
// <o0.6> OADFLT_GTIOCxA żֹͣʱֵλ
//    <0=>ֹͣʱGTIOCxALow ƽ
//    <1=>ֹͣʱGTIOCxAHigh ƽ
// <o0.7> OAHLD_GTIOCxAżʼ/ֹͣʱֿ
//    <0=>ʼ/ֹͣʱGTIOCxA ŵƽȡڼĴ趨ֵ
//    <1=>ּʼ/ֹͣʱGTIOCxAŵƽ
//<i>ܼĴģʽڼʼʱGTIORĴbit4ֵָ
//<i>ܼĴģʽڼֹͣʱOADFLTλֵָ
//<i>ܼĴģʽڼֹͣʱOADFLTλֵ£ӳ
// <o0.14> OBDFLT_GTIOCxB żֹͣʱֵλ
//    <0=>ֹͣʱGTIOCxB Low ƽ
//    <1=>ֹͣʱGTIOCxB High ƽ
// <o0.15> OBHLD_GTIOCxB żʼ/ ֹͣʱλ
//    <0=>ʼ/ ֹͣʱGTIOCxB ŵƽȡȡڼĴ趨ֵ
//    <1=>ּʼ/ ֹͣʱGTIOCxB ŵƽ
//<i>    ڼʼʱGTIORĴbit4ֵָ
//<i>    ڼֹͣʱOBDFLTλֵָ
//<i>    ڼֹͣʱOBDFLTλֵ£ӳ
#define CFG_GPT3_GTIOR	0x0

//<e>GTIOA_GTIOCxAȽƥ
#define CFG_GPT3_GTIOR_GTIOA_O_EN	0

// <o0.4> GTIOA_GTIOCxAųʼƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o0.2..3> GTIOA_GTIOCxAڽʱ״̬
//    <0=>ڽʱ
//    <1=>ڽʱLOWƽ
//    <2=>ڽʱHIGHƽ
//    <3=>ڽʱ
// <o0.0..1> GTIOA_GTIOCxAŵıȽƥ״̬
//    <0=>ͨGPTn.GTCCRAıȽƥ䱣
//    <1=>ͨGPTn.GTCCRAıȽƥLowƽ
//    <2=>ͨGPTn.GTCCRAıȽƥHighƽ
//    <3=>ͨGPTn.GTCCRAıȽƥн
#define CFG_GPT3_GTIOR_GTIOA_O	0

//</e>
//<e>GTIOA_GTIOCxA벶׽
#define CFG_GPT3_GTIOR_GTIOA_I_EN	0

// <o0.2..4> GTIOA_GTIOCxAŲ׽ѡ
//    <0=>
//    <1=>GTIOC3AΪ׽
//    <2=>GTIOC3A1Ϊ׽
//    <4=>GTIOC3A2Ϊ׽
// <o0.0..1> GTIOA_GTIOCxAŵ벶׽ʽѡ
//    <0=>벶׽
//    <1=>½벶׽
//    <2=>˫벶׽
#define CFG_GPT3_GTIOR_GTIOA_I	0

//</e>
//<e>GTIOB_GTIOCxBȽƥ
#define CFG_GPT3_GTIOR_GTIOB_O_EN 0

// <o0.12> GTIOB_GTIOCxBųʼƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
// <o0.10..11> GTIOB_GTIOCxBڽʱ״̬
//    <0=>ڽʱ
//    <1=>ڽʱLOWƽ
//    <2=>ڽʱHIGHƽ
//    <3=>ڽʱ
// <o0.8..9> GTIOB_GTIOCxBŵıȽƥ״̬
//    <0=>ͨGPTn.GTCCRA/BıȽƥ䱣
//    <1=>ͨGPTn.GTCCRA/BıȽƥLowƽ
//    <2=>ͨGPTn.GTCCRA/BıȽƥHighƽ
//    <3=>ͨGPTn.GTCCRA/BıȽƥн
#define CFG_GPT3_GTIOR_GTIOB_O	0x00

//</e>
//<e>GTIOB_GTIOCxB벶׽
#define CFG_GPT3_GTIOR_GTIOB_I_EN	0
// <o0.10..12> GTIOB_GTIOCxBŲ׽ѡ
//    <0=>
//    <1=>GTIOC3BΪ׽
//    <2=>GTIOC3B1Ϊ׽
//    <4=>GTIOC3B2Ϊ׽
// <o0.8..9> GTIOB_GTIOCxBŵ벶׽ʽѡ
//    <0=>벶׽
//    <1=>½벶׽
//    <2=>˫벶׽
#define CFG_GPT3_GTIOR_GTIOB_I	0
//</e>
//</h>



#if	CFG_GPT3_GTIOR_GTIOA_O_EN
#define CFG_GPT3_GTIOR_VALUE	(CFG_GPT3_GTIOR | CFG_GPT3_GTIOR_GTIOA_O)
#elif	CFG_GPT3_GTIOR_GTIOA_I_EN
#define CFG_GPT3_GTIOR_VALUE	(CFG_GPT3_GTIOR | (1<<5) |CFG_GPT3_GTIOR_GTIOA_I)
#else
#define CFG_GPT3_GTIOR_VALUE	(CFG_GPT3_GTIOR)
#endif

#if	CFG_GPT3_GTIOR_GTIOB_O_EN
#define CFG_GPT3_GTIOR_INIT	(CFG_GPT3_GTIOR_VALUE | CFG_GPT3_GTIOR_GTIOB_O)
#elif	CFG_GPT3_GTIOR_GTIOB_I_EN
#define CFG_GPT3_GTIOR_INIT	(CFG_GPT3_GTIOR_VALUE | (1<<13) |CFG_GPT3_GTIOR_GTIOB_I)
#else
#define CFG_GPT3_GTIOR_INIT	(CFG_GPT3_GTIOR_VALUE)
#endif

#if ((CFG_GPT3_GTIOR_GTIOA_O_EN & CFG_GPT3_GTIOR_GTIOA_I_EN) == 1)
#error "GTIOA_GTIOC0AֻѡȽƥ벶׽еһģʽ."
#endif

#if ((CFG_GPT3_GTIOR_GTIOB_O_EN & CFG_GPT3_GTIOR_GTIOB_I_EN) == 1)
#error "GTIOB_GTIOC0BֻѡȽƥ벶׽еһģʽ."
#endif




//<h>Ƚƥ䴥A/Dת
// <q0.8> ADTRAUEN_GTADTRAȽƥ()A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.9> ADTRADEN_GTADTRAȽƥ(ݼ)A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.10> ADTRBUEN_GTADTRBȽƥ()A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
// <q0.11> ADTRBDEN_GTADTRBȽƥ(ݼ)A/Dתʼ
//    0: ֹA/Dתʼ
//    1: A/Dתʼ
#define CFG_GPT3_GTINTAD_H	0x00


//<i>GTADTRA_A/DתʼʱĴA
//<i>0x05C   b31~16 b15~0   
//<i>GTADTRA -      GTADTRA 
// <o0.0..15> GTADTRA_A/D תʼʱĴA<0-65535>
//<i>趨A/Dתʼʱ򡣵GTADTRAĴֵGTCNTֵͬʱA/Dתʼ
//<i>ͨ28GTADTRĴֹ8λΪλȡGTADTRĴ16λΪλдȡ 
#define CFG_GPT3_GTADTRA_INIT	0x000

// <o0.0..15> GTADTRB_A/D תʼʱĴB<0-65535>
//<i>GTADTRB_A/DתʼʱĴB
//<i>0x060   b31~16 b15~0   
//<i>GTADTRB -      GTADTRB 
//<i>趨A/Dתʼʱ򡣵GTADTRBĴֵGTCNTֵͬʱA/Dתʼ
//<i>ͨ28GTADTRĴֹ8λΪλȡGTADTRĴ16λΪλдȡ 
#define CFG_GPT3_GTADTRB_INIT	0x000


// <e1.2>GTADTR A/Dʱ򻺳
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
// <o0.10> ADTDA_GTADTRAλ
//    <0=>е(GTADTBRA=>GTADTRA)
//    <1=>˫(GTADTDBRA=>GTADTBRA=>GTADTRA)
// <o0.8..9> ADTTA_GTADTRA 崫ʱѡλ
//    <0=>ǲ/ݲ:;ݲ
//    <1=>ǲ:ڲд;ݲ()(ݼ)ʱд
//    <2=>ǲ:ڲȽд
//    <3=>ǲ:ڲ/ Ƚд
// <o0.14> ADTDB_GTADTRBλ
//    <0=>е(GTADTBRB=>GTADTRB)
//    <1=>˫(GTADTDBRB=>GTADTBRB=>GTADTRB)
// <o0.12..13> ADTTB_GTADTRB 崫ʱѡλ
//    <0=>ǲ/ݲ:;ݲ
//    <1=>ǲ:ڲд;ݲ:()(ݼ)ʱд
//    <2=>ǲ:ڲȽд
//    <3=>ǲ:ڲ/ Ƚд

// <o2.0..15> GTADTBRA_A/Dתʼʱ򻺳ĴA<0-65535>
//<i>GTADTBRA_A/Dתʼʱ򻺳ĴA
//<i>0x064    b31~16 b15~0    
//<i>GTADTBRA -      GTADTBRA 
//<i>GTADTBRAĴ16λɶдĴGTADTRAĴĻĴ
//<i>ͨ28GTADTBRĴֹ8λΪλȡGTADTBRĴ16λΪλдȡ

// <o3.0..15> GTADTBRB_A/D תʼʱ򻺳ĴB<0-65535>
//<i>GTADTBRB_A/Dתʼʱ򻺳ĴB
//<i>0x068    b31~16 b15~0    
//<i>GTADTBRB -      GTADTBRB 
//<i>GTADTBRBĴ16λɶдĴGTADTRBĴĻĴͨ28GTADTBRĴ
//<i>ֹ8λΪλȡGTADTBRĴ16λΪλдȡ 


// <o4.0..15> GTADTDBRA_A/Dתʼʱ˫ĴA<0-65535>
//<i>GTADTDBRA_A/Dתʼʱ˫ĴA
//<i>0x06C     b31~16 b15~0     
//<i>GTADTDBRA -      GTADTDBRA 
//<i>GTADTDBRAĴ16λɶдĴGTADTBRAĴĻĴ GTADTR˫Ĵ
//<i>ͨ28GTADTDBRĴ8λΪλȡGTADTDBRĴ16λΪλдڡ 


// <o5.0..15> GTADTDBRB_A/D תʼʱ˫ĴB<0-65535>
//<i>GTADTDBRB_A/Dתʼʱ˫ĴB
//<i>0x070     b31~16 b15~0     
//<i>GTADTDBRB -      GTADTDBRB 
//<i>GTADTDBRBĴ16λɶдĴGTADTBRBĴĻĴ GTADTR˫Ĵ
//<i>ͨ28GTADTDBRĴ8λΪλȡGTADTDBRĴ16λΪλдڡ 

#define CFG_GPT3_GTBER_H_INIT	0x000
#define CFG_GPT3_BDADTR_EN	0x0
#define CFG_GPT3_GTADTBRA_INIT	0xffff
#define CFG_GPT3_GTADTBRB_INIT	0xffff
#define CFG_GPT3_GTADTDBRA_INIT	0xffff
#define CFG_GPT3_GTADTDBRB_INIT	0xffff
//</e>
//</h>



// <e0.0>GTCCRȽϲ׽
//    0: 
//    1: ֹ
//<i>нֹĴ
//<i>GTBDR_ͨPWM ʱĻнֹĴ
//<i>0x00C b31~4 b3   b2     b1   b0    
//<i>GTBDR -     BDDV BDADTR BDPR BDCCR 
#define CFG_GPT3_BDCCR_EN	0x0

 
// <o0.0..1> CCRA_GTCCRA λ
//    <0=>л
//    <1=>еУGTCCRA=GTCCRC
//    <2=>˫ GTCCRA=GTCCRC=GTCCRD
//<i>GTBER_PWMʱĻĴ
//<i>0x024 b31~15 b14   b13~12 b11 b10   b9~8  b7 b6     b5~4 b3~2 b1~0 
//<i>GTBER -      ADTDB ADTTB  -   ADTDA ADTTA -  CCRSWT PR   CCRB CCRA
// <o0.2..3> CCRB_GTCCRB λ
//    <0=>л
//    <1=>еУGTCCRB=GTCCRE
//    <2=>˫ GTCCRB=GTCCRE=GTCCRF
//<i>GTBER_PWMʱĻĴ
//<i>0x024 b31~15 b14   b13~12 b11 b10   b9~8  b7 b6     b5~4 b3~2 b1~0 
//<i>GTBER -      ADTDB ADTTB  -   ADTDA ADTTA -  CCRSWT PR   CCRB CCRA
#define CFG_GPT3_GTBER_L_INIT	0x0
#define CFG_GPT3_GTBER_INIT	(CFG_GPT3_GTBER_L_INIT	| CFG_GPT3_GTBER_PR_INIT | CFG_GPT3_GTBER_H_INIT)


//<i>GTCCRC_ͨPWMʱıȽϲ׽ĴC
//<i>0x040  b31~16  b15~0   
//<i>GTCCRC GTCCRCH GTCCRCL 
// <o0.0..15> GTCCRCL_Ƚϲ׽ĴGTCCRC16λ<0-65535>
#define CFG_GPT3_GTCCRC_INIT	0xffff

//<i>GTCCRD_ͨPWMʱıȽϲ׽ĴD
//<i>0x044  b31~16  b15~0   
//<i>GTCCRD GTCCRDH GTCCRDL 
// <o0.0..15> GTCCRDL_Ƚϲ׽ĴGTCCRD16λ<0-65535> 
#define CFG_GPT3_GTCCRD_INIT	0xffff

//<i>GTCCRE_ͨPWMʱıȽϲ׽ĴE
//<i>0x048  b31~16  b15~0   
//<i>GTCCRE GTCCREH GTCCREL 
// <o0.0..15> GTCCREL_Ƚϲ׽ĴGTCCRE16λ<0-65535>
#define CFG_GPT3_GTCCRE_INIT	0xffff

//<i>GTCCRF_ͨPWMʱıȽϲ׽ĴF
//<i>0x04C  b31~16  b15~0   
//<i>GTCCRF GTCCRFH GTCCRFL 
// <o0.0..15> GTCCRFL_Ƚϲ׽ĴGTCCRF16λ<0-65535>   
#define CFG_GPT3_GTCCRF_INIT	0xffff
//</e>


//<h>Ӳֹͣ
//<i>GTHCR_ͨPWM ʱӲֹͣƼĴ
//<i>0x000 b31~9 b8   b7~6 b5~4 b3~2 b1~0 
//<i>GTHCR -     CCSW SYNC CCHW CPHW CSHW 
// <o0.0..1> CSHW_GPTx.GTCNT ӲԴGTETRGʼλ
//    <0=>ͨӲԴʼ
//    <1=>ӲԴؿʼ
//    <2=>ӲԴ½ؿʼ
//    <3=>ӲԴ˫ؿʼ
//    <i>ͨӲԴGTSTRĴĶӦλԶΪ1
// <o0.2..3> CPHW_GPTx.GTCNT ӲԴGTETRGֹͣλ
//    <0=>ͨӲԴֹͣ
//    <1=>ӲԴֹͣ
//    <2=>ӲԴ½ֹͣ
//    <3=>ӲԴ˫ֹͣ
//    <i>ͨӲԴֹͣGTSTRĴĶӦλԶΪ0
// <o0.4..5> CCHW_GPTx.GTCNT ӲԴGTETRG
//    <0=>ͨӲԴ
//    <1=>ӲԴ
//    <2=>ӲԴ½
//    <3=>ӲԴ˫
//    <i>趨ΪͨӲԴGPTx.GTCNTʱGPTx.GTCNTڼGTSTR.CTS=1ֹͣ GTSTR.CTS=0ͨӲԴм
// <o0.6..7> SYNC_GPTx.GTCNT ͬԴѡλ
//    <0=>ͨGPT0ԴGPTx.GTCNT
//    <1=>ͨGPT1ԴͬGPTx.GTCNT
//    <2=>ͨGPT2ԴͬGPTx.GTCNT
//    <3=>ͨGPT3ԴͬGPTx.GTCNT
//    <i>GPTx.GTCNT0=03ֹͣ״̬½д
//    <i>趨GPTx.SYNC[1:0]λȽGPTx.GTCR.CCLR[1:0]λá11bͨڽͬ/ͬеԴ
//</h>
#define CFG_GPT3_GTHCR_INIT	0x0

//<h>˲
//<i>GTDEB_ͨPWMʱ˲Ĵ
//<i>0x004 b31~10 b9   b8   b7~4 b3~0 
//<i>GTDEB -      INBE INAE -    DEB  
// <o0.0..3> DEB_GPTxź˲ѡλ
//    <0=>˲
//    <1=>˲ʱ䳣Ϊ30*HCLK(0.5us)
//    <2=>˲ʱ䳣Ϊ60*HCLK(1us)
//    <3=>˲ʱ䳣Ϊ120*HCLK(2us)
//    <4=>˲ʱ䳣Ϊ180*HCLK(3us)
//    <5=>˲ʱ䳣Ϊ240*HCLK(4us)
//    <6=>˲ʱ䳣Ϊ300*HCLK(5us)
//    <7=>˲ʱ䳣Ϊ360*HCLK(6us)
//    <8=>˲ʱ䳣Ϊ480*HCLK(8us)
//    <9=>˲ʱ䳣Ϊ600*HCLK(10us)
//    <10=>˲ʱ䳣Ϊ720*HCLK(12us)
//    <11=>˲ʱ䳣Ϊ960*HCLK(16us)
//    <12=>˲ʱ䳣Ϊ1200*HCLK(20us)
//    <13=>˲ʱ䳣Ϊ1440*HCLK(24us)
//    <14=>˲ʱ䳣Ϊ1680*HCLK(28us)
//    <15=>˲ʱ䳣Ϊ1920*HCLK(32us)
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.8> INAE_ͨA벶׽λ
//    <0=>GPTx.GTCCRA׷ӵ32λһʱ벶׽
//    <1=>GPTx.GTCCRA׷ӵ32λһʱ벶׽
//    <i>ʱGPTx.GTCCRA32λʱ
//    <i>ʱGPTx.GTCCRAΪһʱԱʱ趨ΪȽһΪ벶׽Ķʱһ
// <o0.9> INBE_ͨB벶׽λ
//    <0=>GPTx.GTCCRB׷ӵ32λһʱ벶׽
//    <1=>GPTx.GTCCRB׷ӵ32λһʱ벶׽
//    <i>ʱGPTx.GTCCRB32λʱ
//    <i>ʱGPTx.GTCCRBΪһʱԱʱ趨ΪȽһΪ벶׽Ķʱһ
//    <i>GPT3GPT3һԣGPT2GPT3һ

//</h>
#define CFG_GPT3_GTDEB_INIT	0x0

//<h>DMA趨Ĵ
//<i>GTDMA_ͨPWMʱDMA趨Ĵ
//<i>0x018 b31~4 b3~2 b1 b0 
//<i>GTDMA -     PR   TB TA 
// <q0.0> TA_GTCCRA Ƚƥ/벶׽DMAλ
//    0: ֹDMA
//    1: DMA
// <q0.1> TB_GTCCRB Ƚƥ/벶׽DMAλ
//    0: ֹDMA
//    1: DMA
// <o0.2..3> PR_GTPR ȽƥDMAλ
//    <0=>ֹDMA
//    <1=>ݲʱ硢ǲʱڲDMA
//    <2=>ݲʱ硢ǲʱڲDMA
//    <3=>ݲʱ硢ǲʱڲͲȶDMA
//</h>
#define CFG_GPT3_GTDMA_INIT	0x0


//<h>ж趨Ĵ
//<i>GTINTAD_ͨPWMʱж趨Ĵ
//<i>0x014   b31~12 b11      b10      b9       b8       b7~6 b5   b4   b3~2    b1     b0     
//<i>GTINTAD -      ADTRBDEN ADTRBUEN ADTRADEN ADTRAUEN -    OINT EINT GTINTPR GTINTB GTINTA 
// <q0.0> GTINTA_GTCCRA Ƚƥ/벶׽жλ
//    0: ֹж
//    1: ж
// <q0.1> GTINTB_GTCCRB Ƚƥ/벶׽жλ
//    0: ֹж
//    1: ж
// <o0.2..3> GTINTPR_GTPRжλ
//    <0=>ֹж
//    <1=>ݲʱ硢ǲʱڲж
//    <2=>ݲʱ硢ǲʱڲж
//    <3=>ݲʱ硢ǲʱڲͲȶж
// <q0.4> EINT_ʱжλ
//    0: ֹж
//    1: ж
// <q0.5> OINT_·жλ
//    0: ֹж
//    1: ж
//</h>
#define CFG_GPT3_GTINTAD_L	0x0

#if ((CFG_GPT3_GTINTAD_L & (3<<2)) != 0)
	#define CFG_GPT3_GTCIV_INT_EN 1
#else
	#define CFG_GPT3_GTCIV_INT_EN 0
#endif

#if ((CFG_GPT3_GTINTAD_L & 0x33) != 0)
	#define CFG_GPT3_GTCIN_INT_EN 1
#else
	#define CFG_GPT3_GTCIN_INT_EN 0
#endif

#define CFG_GPT3_GTINTAD_INIT	(CFG_GPT3_GTINTAD_L | CFG_GPT3_GTINTAD_H)

//<h>ж
//<i>GTITC_ͨPWMʱжϡA/Dתʼ趨Ĵ
//<i>0x02C b31~15 b14   b13 b12   b11 b10~8 b7~6 b5~4 b3~2 b1   b0   
//<i>GTITC -      ADTBL -   ADTAL -   IVTT  -    IVTC -    ITLB ITLA 
// <o0.0> ITLA_GTCCRA Ƚƥ/ 벶׽жλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.1> ITLB_GTCCRB Ƚƥ/ 벶׽жλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.4..5> IVTC_GTCIV жϼٹѡλ
//    <0=>
//    <1=>Ծݲʱ硢ǲʱĲм
//    <2=>Ծݲʱ硢ǲʱĲȽм
//    <3=>Ծݲʱ/ 硢ǲ/ ȶм
// <o0.8..10> IVTT_GTCIV жϼٴѡλ
//    <0=>
//    <1=>ٴΪ1 
//    <2=>ٴΪ2 
//    <3=>ٴΪ3 
//    <4=>ٴΪ4 
//    <5=>ٴΪ5 
//    <6=>ٴΪ6 
//    <7=>ٴΪ7 
//<i>ڽIVTC[<1=>0]λá00bܸIVTT[2:0]λ
// <o0.12> ADTAL_GTADTRA A/D תʼλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ
// <o0.14> ADTBL_GTADTRB A/D תʼλ
//    <0=>GTCIV жϼٹ
//    <1=>GTCIV жϼٹ

//</h>
#define CFG_GPT3_GTITC_INIT	0x0


//<h>ƽ
//<i>GTOSCR_ͨPWMʱĵƽƼĴ
//<i>0x088  b31~8 b7    b6~2 b1    b0    
//<i>GTOSCR -     OLSEN -    OLSGB OLSGA 
// <q0.7> OLSEN_ƽʹλ
//    0: ֹ
//    1: ʹ
// <o0.0> OLSGA_·GTIOCxAЧƽ趨λ
//    <0=>Low ƽЧ
//    <1=>High ƽЧ
// <o0.1> OLSGB_·GTIOCxBЧƽ趨λ
//    <0=>Low ƽЧ
//    <1=>High ƽЧ

//</h>
#define CFG_GPT3_GTOSCR_INIT	0x0

#define CFG_GPT3_GTBDR_INIT	(CFG_GPT3_BDDV_EN | CFG_GPT3_BDADTR_EN | CFG_GPT3_BDPR_EN | CFG_GPT3_BDCCR_EN)
//</e>
//</e>


//<e>TIMER
#define CFG_TIM_EN	0
//***********************************************************/
//<e>TIM5
#define CFG_TIM5_EN	0
//<i>CR_TIMƼĴ
//<i>0x000 b31~16 b15    b14~11 b10 b9   b8     b7 b6 b5~4 b3  b2~1 b0  
//<i>CR    -      CASCEN -      TC  ETEN TRIGEN -  IE CLKS OPM -    STR 
// <o0.4..5> CLKS_TIMxʱԴICLKѡλ
//    <0=>ڲAPB1ʱӣPCLK1
//    <1=>Tn(n=5,6,7,8)룬Զ

//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <o1>TIM5ʼֵ <0-0xFFFF>

// <o2>TIM5ֵ(us) <0-100000000>

//<i>PSQ_TIMԤƵĴ
//<i>0x00C b31~16 b15~0 
//<i>PSQ   PSQH   PSQL  
// <o3> PSQL_ʱƵֵ<0-65535>
//<i>ȫTIMЧ
//<i>ʱʱΪ(ICLK/(PSQ[15:0]+1))  

// <o0.3> OPM_ģʽ
//    <0=>ʱxʱʱֹͣ
//    <1=>ʱxʱʱֹͣ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <q0.6> IE_TIMxжʹλ
//    0: ֹʱTIMxж
//    1: ʱTIMxж
// <q0.8> TRIGEN_TIMxⲿģʹλ
//    0: ʱxֹģ
//    1: ʱxģ
//    <i>ģDMAADC
//    <i>ģ鶼ܴDMAֻTIM8ܹADC
// <q0.9> ETEN_TIMx¼ʹλ
//    0: ֹʱCM3ں
//    1: ʱCM3ں
//   <i>֮Ϊ32λʱ
// <q0.10> TC_Ƚλ
//    0: ֹʱxȽ
//    1: ʱxȽ
//<i>ʱȽʱ(TC=1)ʱԴѡTn(n=5,6,7,8)ڡ
    

//<q4>ʱ5ϵʼʱ

#define CFG_TIM5_CR_INIT 0x0	
#define CFG_TIM5_TCNT_INIT 0
#define CFG_TIM5_RL_VALUE 0
#define CFG_TIM5_PSQ_INIT	0x0
#define CFG_TIM5_CR_START	0x0

#if ((CFG_TIM5_CR_INIT & (1<<6)) != 0)
	#define CFG_TIM5_INT_EN 1
#else
	#define CFG_TIM5_INT_EN 0
#endif

#if (CFG_TIM5_CR_INIT & 0x30) == 0x0
#define CFG_TIM5_CLK		((unsigned long)(SYS_CLK/APB1_F/(CFG_TIM5_PSQ_INIT + 1)))
#elif (CFG_TIM5_CR_INIT & 0x30) == 0x10
#define CFG_TIM5_CLK		128000 	
#elif (CFG_TIM5_CR_INIT & 0x30) == 0x20
#define CFG_TIM5_CLK		128000 	
#endif

#define CFG_TIM5_TPR_INIT (unsigned long)(CFG_TIM5_RL_VALUE*(CFG_TIM5_CLK/1000000.0))

//</e>
#if ((CFG_TIM_EN) && (CFG_TIM5_EN) && ((CFG_TIM5_CR_INIT & (1<<10)) || (CFG_TIM5_CR_INIT & (1<<4))) && ((CFG_PB0_AFR != 5)&&(CFG_PE3_AFR != 5)))
#error "TIM5 T5(PB0/PE3) AF5 function mapping is not enable."
#endif


//***********************************************************/
//<e>TIM6
#define CFG_TIM6_EN	0
//<i>CR_TIMƼĴ
//<i>0x000 b31~16 b15    b14~11 b10 b9   b8     b7 b6 b5~4 b3  b2~1 b0  
//<i>CR    -      CASCEN -      TC  ETEN TRIGEN -  IE CLKS OPM -    STR 
// <o0.4..5> CLKS_TIMxʱԴICLKѡλ
//    <0=>ڲAPB1ʱӣPCLK1
//    <1=>Tn(n=5,6,7,8)룬Զ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <o1>TIM6ʼֵ <0-0xFFFF>
// <o2>TIM6ֵ(us) <0-100000000>

//<i>PSQ_TIMԤƵĴ
//<i>0x00C b31~16 b15~0 
//<i>PSQ   PSQH   PSQL  
// <o3> PSQL_ʱƵֵ<0-65535>
//<i>ȫTIMЧ
//<i>ʱʱΪ(ICLK/(PSQ[15:0]+1))  

// <o0.3> OPM_ģʽ
//    <0=>ʱxʱʱֹͣ
//    <1=>ʱxʱʱֹͣ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <q0.6> IE_TIMxжʹλ
//    0: ֹʱTIMxж
//    1: ʱTIMxж
// <q0.8> TRIGEN_TIMxⲿģʹλ
//    0: ʱxֹģ
//    1: ʱxģ
//    <i>ģDMAADC
//    <i>ģ鶼ܴDMAֻTIM8ܹADC
// <q0.9> ETEN_TIMx¼ʹλ
//    0: ֹʱCM3ں
//    1: ʱCM3ں
//   <i>֮Ϊ32λʱ
// <q0.10> TC_Ƚλ
//    0: ֹʱxȽ
//    1: ʱxȽ
//<i>ʱȽʱ(TC=1)ʱԴѡTn(n=5,6,7,8)ڡ

//<q4>TIM6ϵʼʱ

#define CFG_TIM6_CR_INIT 0x0
#define CFG_TIM6_TCNT_INIT 0
#define CFG_TIM6_RL_VALUE 0
#define CFG_TIM6_PSQ_INIT	0x0
#define CFG_TIM6_CR_START	0x0

#if ((CFG_TIM6_CR_INIT & (1<<6)) != 0)
	#define CFG_TIM6_INT_EN 1
#else
	#define CFG_TIM6_INT_EN 0
#endif



#if (CFG_TIM6_CR_INIT & 0x30) == 0x0
#define CFG_TIM6_CLK		(unsigned long)(SYS_CLK/APB1_F/(CFG_TIM6_PSQ_INIT + 1)) 
#elif (CFG_TIM6_CR_INIT & 0x30) == 0x10
#define CFG_TIM6_CLK		128000 	
#elif (CFG_TIM6_CR_INIT & 0x30) == 0x20
#define CFG_TIM6_CLK		128000 	
#endif

#define CFG_TIM6_TPR_INIT ((unsigned long)(CFG_TIM6_RL_VALUE*(CFG_TIM6_CLK/1000000.0)))



//</e>
#if ((CFG_TIM_EN) && (CFG_TIM6_EN) && ((CFG_TIM6_CR_INIT & (1<<10)) || (CFG_TIM6_CR_INIT & (1<<4))) && ((CFG_PB1_AFR != 5)&&(CFG_PE4_AFR != 5)))
#error "TIM6 T6(PB1/PE4) AF5 function mapping is not enable."
#endif

//***********************************************************/
//<e>TIM5&TIM6
#define CFG_TIM56_EN 0

//<i>CR_TIMƼĴ
//<i>0x000 b31~16 b15    b14~11 b10 b9   b8     b7 b6 b5~4 b3  b2~1 b0  
//<i>CR    -      CASCEN -      TC  ETEN TRIGEN -  IE CLKS OPM -    STR 
// <o0.4..5> CLKS_TIMxʱԴICLKѡλ
//    <0=>ڲAPB1ʱӣPCLK1
//    <1=>T6룬Զ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <o1>ʼֵ <0-0xFFFFFFFF>
// <o2>ֵ(us) <0-100000000>
//<i>PSQ_TIMԤƵĴ
//<i>0x00C b31~16 b15~0 
//<i>PSQ   PSQH   PSQL  
// <o3> PSQL_ʱƵֵ<0-65535>
//<i>ȫTIMЧ
//<i>ʱʱΪ(ICLK/(PSQ[15:0]+1))  
// <o0.3> OPM_ģʽ
//    <0=>ʱxʱʱֹͣ
//    <1=>ʱxʱʱֹͣ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <q0.6> IE_TIMxжʹλ
//    0: ֹʱTIMxж
//    1: ʱTIMxж
// <q0.8> TRIGEN_TIMxⲿģʹλ
//    0: ʱxֹģ
//    1: ʱxģ
//    <i>ģDMAADC
//    <i>ģ鶼ܴDMAֻTIM8ܹADC
// <q0.9> ETEN_TIMx¼ʹλ
//    0: ֹʱCM3ں
//    1: ʱCM3ں
//   <i>֮Ϊ32λʱ
// <q0.10> TC_Ƚλ
//    0: ֹʱxȽ
//    1: ʱxȽ
//<i>ʱȽʱ(TC=1)ʱԴѡTn(n=5,6,7,8)ڡ

//<q4>ϵʼʱ

#define CFG_TIM56_CR_VALUE 0x0
#define CFG_TIM56_TCNT_INIT 0x0
#define CFG_TIM56_RL_VALUE 1000000
#define CFG_TIM56_PSQ_INIT	0x0
#define CFG_TIM56_CR_START	0x0

#define CFG_TIM56_CR_INIT (CFG_TIM56_CR_VALUE|(CFG_TIM56_EN<<15))

#if ((CFG_TIM56_CR_INIT & (1<<6)) != 0)
	#define CFG_TIM56_INT_EN 1
#else
	#define CFG_TIM56_INT_EN 0
#endif

#if (CFG_TIM56_CR_INIT & 0x30) == 0x0
#define CFG_TIM56_CLK		(SYS_CLK/APB1_F/(CFG_TIM56_PSQ_INIT + 1)) 
#elif (CFG_TIM56_CR_INIT & 0x30) == 0x10
#define CFG_TIM56_CLK		128000 	
#elif (CFG_TIM56_CR_INIT & 0x30) == 0x20
#define CFG_TIM56_CLK		128000 	
#endif

#define CFG_TIM56_TPR_INIT ((unsigned long)(CFG_TIM56_RL_VALUE*(CFG_TIM56_CLK/1000000.0)))


//</e>
#if ((CFG_TIM_EN) && (CFG_TIM56_EN) && ((CFG_TIM56_CR_INIT & (1<<10)) || (CFG_TIM56_CR_INIT & (1<<4))) && ((CFG_PB1_AFR != 5)&&(CFG_PE4_AFR != 5) && (CFG_PB0_AFR != 5)&&(CFG_PE3_AFR != 5)))
#error "TIM5/6 T5/T6(PB0/PE3/PB1/PE4) AF5 function mapping is not enable."
#endif


//***********************************************************/
//<e>TIM7
#define CFG_TIM7_EN	0
//<i>CR_TIMƼĴ
//<i>0x000 b31~16 b15    b14~11 b10 b9   b8     b7 b6 b5~4 b3  b2~1 b0  
//<i>CR    -      CASCEN -      TC  ETEN TRIGEN -  IE CLKS OPM -    STR 
// <o0.4..5> CLKS_TIMxʱԴICLKѡλ
//    <0=>ڲAPB1ʱӣPCLK1
//    <1=>Tn(n=5,6,7,8)룬Զ
//    <2=>128kLSICLK
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <o1>TIM7ʼֵ <0-0xFFFF>

// <o2>TIM7ֵ(us) <0-100000000>

//<i>PSQ_TIMԤƵĴ
//<i>0x00C b31~16 b15~0 
//<i>PSQ   PSQH   PSQL  
// <o3> PSQL_ʱƵֵ<0-65535>
//<i>ȫTIMЧ
//<i>ʱʱΪ(ICLK/(PSQ[15:0]+1))  

// <o0.3> OPM_ģʽ
//    <0=>ʱxʱʱֹͣ
//    <1=>ʱxʱʱֹͣ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <q0.6> IE_TIMxжʹλ
//    0: ֹʱTIMxж
//    1: ʱTIMxж
// <q0.8> TRIGEN_TIMxⲿģʹλ
//    0: ʱxֹģ
//    1: ʱxģ
//    <i>ģDMAADC
//    <i>ģ鶼ܴDMAֻTIM8ܹADC
// <q0.9> ETEN_TIMx¼ʹλ
//    0: ֹʱCM3ں
//    1: ʱCM3ں
//   <i>֮Ϊ32λʱ
// <q0.10> TC_Ƚλ
//    0: ֹʱxȽ
//    1: ʱxȽ
//<i>ʱȽʱ(TC=1)ʱԴѡTn(n=5,6,7,8)ڡ

//<q4>ʱ5ϵʼʱ

#define CFG_TIM7_CR_INIT 0x00
#define CFG_TIM7_TCNT_INIT 0
#define CFG_TIM7_RL_VALUE 0
#define CFG_TIM7_PSQ_INIT	0x0
#define CFG_TIM7_CR_START	0x0

#if ((CFG_TIM7_CR_INIT & (1<<6)) != 0)
	#define CFG_TIM7_INT_EN 1
#else
	#define CFG_TIM7_INT_EN 0
#endif

#if (CFG_TIM7_CR_INIT & 0x30) == 0x0
#define CFG_TIM7_CLK		(unsigned long)(SYS_CLK/APB1_F/(CFG_TIM7_PSQ_INIT + 1)) 
#elif (CFG_TIM7_CR_INIT & 0x30) == 0x10
#define CFG_TIM7_CLK		128000 	
#elif (CFG_TIM7_CR_INIT & 0x30) == 0x20
#define CFG_TIM7_CLK		128000 	
#endif


#define CFG_TIM7_TPR_INIT ((unsigned long)(CFG_TIM7_RL_VALUE*(CFG_TIM7_CLK/1000000.0)))

//</e>
#if ((CFG_TIM_EN) && (CFG_TIM7_EN) && ((CFG_TIM7_CR_INIT & (1<<10)) || (CFG_TIM7_CR_INIT & (1<<4))) && ((CFG_PA0_AFR != 5)&&(CFG_PE5_AFR != 5)))
#error "TIM7 T7(PA0/PE5) AF5 function mapping is not enable."
#endif


//***********************************************************/
//<e>TIM8
#define CFG_TIM8_EN	0
//<i>CR_TIMƼĴ
//<i>0x000 b31~16 b15    b14~11 b10 b9   b8     b7 b6 b5~4 b3  b2~1 b0  
//<i>CR    -      CASCEN -      TC  ETEN TRIGEN -  IE CLKS OPM -    STR 
// <o0.4..5> CLKS_TIMxʱԴICLKѡλ
//    <0=>ڲAPB1ʱӣPCLK1
//    <1=>Tn(n=5,6,7,8)룬Զ
//    <2=>128kLSICLK
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <o1>TIM8ʼֵ <0-0xFFFF>

// <o2>TIM8ֵ(us) <0-100000000>

//<i>PSQ_TIMԤƵĴ
//<i>0x00C b31~16 b15~0 
//<i>PSQ   PSQH   PSQL  
// <o3> PSQL_ʱƵֵ<0-65535>
//<i>ȫTIMЧ
//<i>ʱʱΪ(ICLK/(PSQ[15:0]+1))  

// <o0.3> OPM_ģʽ
//    <0=>ʱxʱʱֹͣ
//    <1=>ʱxʱʱֹͣ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <q0.6> IE_TIMxжʹλ
//    0: ֹʱTIMxж
//    1: ʱTIMxж
// <q0.8> TRIGEN_TIMxⲿģʹλ
//    0: ʱxֹģ
//    1: ʱxģ
//    <i>ģDMAADC
//    <i>ģ鶼ܴDMAֻTIM8ܹADC
// <q0.9> ETEN_TIMx¼ʹλ
//    0: ֹʱCM3ں
//    1: ʱCM3ں
//   <i>֮Ϊ32λʱ
// <q0.10> TC_Ƚλ
//    0: ֹʱxȽ
//    1: ʱxȽ
//<i>ʱȽʱ(TC=1)ʱԴѡTn(n=5,6,7,8)ڡ

//<q4>TIM8ϵʼʱ

#define CFG_TIM8_CR_INIT 0x0	
#define CFG_TIM8_TCNT_INIT 0
#define CFG_TIM8_RL_VALUE 0
#define CFG_TIM8_PSQ_INIT	0x0
#define CFG_TIM8_CR_START	0x0

#if ((CFG_TIM8_CR_INIT & (1<<6)) != 0)
	#define CFG_TIM8_INT_EN 1
#else
	#define CFG_TIM8_INT_EN 0
#endif



#if (CFG_TIM8_CR_INIT & 0x30) == 0x0
#define CFG_TIM8_CLK		(unsigned long)(SYS_CLK/APB1_F/(CFG_TIM8_PSQ_INIT + 1)) 
#elif (CFG_TIM8_CR_INIT & 0x30) == 0x10
#define CFG_TIM8_CLK		128000 	
#elif (CFG_TIM8_CR_INIT & 0x30) == 0x20
#define CFG_TIM8_CLK		128000 	
#endif

#define CFG_TIM8_TPR_INIT ((unsigned long)(CFG_TIM8_RL_VALUE*(CFG_TIM8_CLK/1000000.0)))

//</e>
#if ((CFG_TIM_EN) && (CFG_TIM8_EN) && ((CFG_TIM8_CR_INIT & (1<<10)) || (CFG_TIM8_CR_INIT & (1<<4))) && ((CFG_PA1_AFR != 5)&&(CFG_PE6_AFR != 5) && (CFG_PA0_AFR != 5)&&(CFG_PE5_AFR != 5)))
#error "TIM8 T8(PA1/PE6) AF5 function mapping is not enable."
#endif


//***********************************************************/
//<e>TIM7&TIM8
#define CFG_TIM78_EN 0

//<i>CR_TIMƼĴ
//<i>0x000 b31~16 b15    b14~11 b10 b9   b8     b7 b6 b5~4 b3  b2~1 b0  
//<i>CR    -      CASCEN -      TC  ETEN TRIGEN -  IE CLKS OPM -    STR 
// <o0.4..5> CLKS_TIMxʱԴICLKѡλ
//    <0=>ڲAPB1ʱӣPCLK1
//    <1=>T6룬Զ
//    <2=>128kLSICLK
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <o1>ʼֵ <0-0xFFFFFFFF>

// <o2>ֵ(us) <0-100000000>

//<i>PSQ_TIMԤƵĴ
//<i>0x00C b31~16 b15~0 
//<i>PSQ   PSQH   PSQL  
// <o3> PSQL_ʱƵֵ<0-65535>
//<i>ȫTIMЧ
//<i>ʱʱΪ(ICLK/(PSQ[15:0]+1))  

// <o0.3> OPM_ģʽ
//    <0=>ʱxʱʱֹͣ
//    <1=>ʱxʱʱֹͣ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <q0.6> IE_TIMxжʹλ
//    0: ֹʱTIMxж
//    1: ʱTIMxж
// <q0.8> TRIGEN_TIMxⲿģʹλ
//    0: ʱxֹģ
//    1: ʱxģ
//    <i>ģDMAADC
//    <i>ģ鶼ܴDMAֻTIM8ܹADC
// <q0.9> ETEN_TIMx¼ʹλ
//    0: ֹʱCM3ں
//    1: ʱCM3ں
//   <i>֮Ϊ32λʱ
// <q0.10> TC_Ƚλ
//    0: ֹʱxȽ
//    1: ʱxȽ
//<i>ʱȽʱ(TC=1)ʱԴѡTn(n=5,6,7,8)ڡ

//<q4>ϵʼʱ

#define CFG_TIM78_CR_VALUE 0x00
#define CFG_TIM78_TCNT_INIT 0x0
#define CFG_TIM78_RL_VALUE 1000000
#define CFG_TIM78_PSQ_INIT	0x0
#define CFG_TIM78_CR_START	0x0

#define CFG_TIM78_CR_INIT (CFG_TIM78_CR_VALUE|(CFG_TIM78_EN<<15))

#if ((CFG_TIM78_CR_INIT & (1<<6)) != 0)
	#define CFG_TIM78_INT_EN 1
#else
	#define CFG_TIM78_INT_EN 0
#endif

#if (CFG_TIM78_CR_INIT & 0x30) == 0x0
#define CFG_TIM78_CLK		(SYS_CLK/APB1_F/(CFG_TIM78_PSQ_INIT + 1)) 
#elif (CFG_TIM78_CR_INIT & 0x30) == 0x10
#define CFG_TIM78_CLK		128000 	
#elif (CFG_TIM78_CR_INIT & 0x30) == 0x20
#define CFG_TIM78_CLK		128000 	
#endif

#define CFG_TIM78_TPR_INIT ((unsigned long)(CFG_TIM78_RL_VALUE*(CFG_TIM78_CLK/1000000.0)))

//</e>
#if ((CFG_TIM_EN) && (CFG_TIM78_EN) && ((CFG_TIM78_CR_INIT & (1<<10)) || (CFG_TIM78_CR_INIT & (1<<4))) && ((CFG_PA1_AFR != 5)&&(CFG_PE5_AFR != 5)&&(CFG_PA0_AFR != 5)&&(CFG_PE6_AFR != 5)))
#error "TIM7/8 T7/8(PA0/PE5/PA1/PE6) AF5 function mapping is not enable."
#endif

//</e>




//<e>MACP
#define CFG_MACP_EN	0
//<h>CORDCSR0_CORDIC״̬Ĵ0
//<i>0x000    b31~8 b7   b6~5   b4 b3    b2   b1  b0  
//<i>CORDCSR0 -     MODE FORMAT -  XYMRS KADJ OVF RUN 
// <o0.0> RUN_CORDIC־λֻ1Ӳ0
//    <0=>ѽδ
//    <1=>Cordic㣬б־Ϊ1,ɺ־Ӳ0
//<i>RUNǿн㡣 RUNʱCORDICڲflag㡣
// <o0.2> KADJ_CORDICKӵѡλ
//    <0=>1/K
//    <1=>1/KK
//    <i>K=1.64676
// <o0.3> XYMRS_CORDICxYȵѡλ
//    <0=>һεxYΪս
//    <1=>һεxY2Ϊս
//    <i>ȷxYMRSλɱ
// <o0.5..6> FORMAT_CORDICݸʽ
//    <0=>IQ26ʽĬϣ
//    <1=>IQ24ʽ
//    <2=>IQ15ʽ
//<i>IQ26/IQ24ʹ27λCORDIC㣬IQ15ʹ16λCORDIC㡣
//ݸʽ֣ûʹʽ룬Ҫе
// <o0.7> MODE_CORDICģʽѡλ
//    <0=>תģʽ
//    <1=>ģʽ
//</h>
#define CFG_MACP_CORDCSR0_INIT	0x0

//<h>CORDCSR1_CORDIC״̬Ĵ1
//<i>0x010    b31~8 b7   b6~5   b4 b3    b2   b1  b0  
//<i>CORDCSR1 -     MODE FORMAT -  XYMRS KADJ OVF RUN 
// <o0.0> RUN_CORDIC־λֻ1Ӳ0
//    <0=>ѽδ
//    <1=>Cordic㣬б־Ϊ1,ɺ־Ӳ0
//<i>RUNǿн㡣 RUNʱCORDICڲflag㡣
// <o0.2> KADJ_CORDICKӵѡλ
//    <0=>1/K
//    <1=>1/KK
//    <i>K=1.64676
// <o0.3> XYMRS_CORDICxYȵѡλ
//    <0=>һεxYΪս
//    <1=>һεxY2Ϊս
//    <i>ȷxYMRSλɱ
// <o0.5..6> FORMAT_CORDICݸʽ
//    <0=>IQ26ʽĬϣ
//    <1=>IQ24ʽ
//    <2=>IQ15ʽ
//<i>IQ26/IQ24ʹ27λCORDIC㣬IQ15ʹ16λCORDIC㡣
//ݸʽ֣ûʹʽ룬Ҫе
// <o0.7> MODE_CORDICģʽѡλ
//    <0=>תģʽ
//    <1=>ģʽ
//</h>
#define CFG_MACP_CORDCSR1_INIT	0x0

//<h>IQDIVCSR0_IQʽ״̬Ĵ0 
//<i>0x100     b31~9 b8   b7~3 b2  b1   b0  
//<i>IQDIVCSR0 -     CMOD Q    SAT SIGN RUN 
// <o0.1> SIGN_ѡзų
//    <0=>޷ų(Ϊԭ)
//    <1=>зų(Ϊ)
// <o0.2> SAT_ͱ־
//Ϊֵôλ
//0λ32λ󣬽ĴΪֵҴλΪ1Ϊ0
//    ޷ʱֵΪ0xFFFFFFFF 
//    зʱķλֻһǸʱΪǸֵΪ0x80000000,򱥺ֵΪ0x7FFFFFFF
// <o0.3..7> Q_QʽΪ31 <0-31>
// <o0.8> CMOD_ʽѡλ
//  <0=>С봦
//  <1=>Сֱ
//</h>
#define CFG_MACP_IQDIVCSR0_INIT	0x0
//<h>IQDIVCSR1_IQʽ״̬Ĵ1
//<i>0x110     b31~9 b8   b7~3 b2  b1   b0  
//<i>IQDIVCSR1 -     CMOD Q    SAT SIGN RUN 
// <o0.1> SIGN_ѡзų
//    <0=>޷ų(Ϊԭ)
//    <1=>зų(Ϊ)
// <o0.2> SAT_ͱ־
//<i>Ϊֵôλ
//<i>0λ32λ󣬽ĴΪֵҴλΪ1Ϊ0
//<i>޷ʱֵΪ0xFFFFFFFF 
//<i>зʱķλֻһǸʱΪǸֵΪ0x80000000,򱥺ֵΪ0x7FFFFFFF
// <o0.3..7> Q_QʽΪ31 <0-31>
// <o0.8> CMOD_ʽѡλ
//  <0=>С봦
//  <1=>Сֱ
//</h>
#define CFG_MACP_IQDIVCSR1_INIT	0x0

//<h>SVUALPHA_SVPWMUalphaֵĴ
//<i>0x204    b31~0    
//<i>SVUALPHA SVUALPHA 
// <o0.0..31> SVUALPHA_SVPWMUalphaֵ <0-4294967295>
//</h>
#define CFG_MACP_SVUALPHA_INIT	0x0

//<h>SVUBETA_SVPWMUbetaֵĴ
//<i>0x208   b31~0   
//<i>SVUBETA SVUBETA 
// <o0.0..31> SVUBETA_SVPWMUbetaֵ <0-4294967295>
//</h>
#define CFG_MACP_SVUBETA_INIT	0x0

//<h>SVIQN_SVPWMݸʽüĴ
//<i>0x20C b31~9 b8    b7~0  
//<i>SVIQN -     SVTYP SVIQN 
// <o0.0..7> SVIQN_SVPWMݸʽ<0-31>
// <o0.8> SVTYP_ʽ߶ʽѡλ
//    <0=>߶ʽ
//    <1=>ʽ
//</h>
#define CFG_MACP_SVIQN_INIT	0x0

//***********************************************************/
//</e>



//<e>ADC
#define CFG_ADC_EN 0
//***********************************************************/
//<e>ADC1
#define CFG_ADC1_EN 0

//<h>ADCON1_ADCƼĴ1
//<i>0x000  b31~16 b15  b14~8  b7   b6   b5~4 b3  b2~1  b0    
//<i>ADCON1 -      ADON ADSTRS ADIE ADDE REFC MOD ADCTU ADSOC 
// <o0.1..2> ADCTU_ADCͨеתʽλ:
//    <0=>תʽ
//    <1=>תʽ
//    <2=>תʽ
//    <3=>
//    <i>޸ĸÿλһADתʱŲЧ
// <o0.3> MOD_ADCģʽѡλ
//    <0=>12bit
//    <1=>10bit
// <o0.4..5> REFC_׼ѹѡλ
//    <0=>ѡAVDDΪ׼ѹ
//    <1=>ѡⲿVREF˿Ϊ׼ѹ
//    <2=>ѡڽVREFΪ׼ѹ
//    <3=>
//<i>ΪڽVREFⲿVREFţ3ADCܼѡڽVREFѡVREF
// <q0.6> ADDE_ͨתDMAʹλ
//    0: ֹADCתDMA
//    1: ʹADCתDMA
// <q0.7> ADIE_ͨתжʹλ
//    0: ֹADCתж
//    1: ʹADCתж

// <q0.15> ADON_ADCλ
//    0: ֹADCxģ
//    1: ADCxģ

#define CFG_ADC1_ADCON1_VALUE 0x0000

// <e> ADSTRS_ADCӲԴѡ(ֻ8ѡ1)
#define CFG_ADC1_ADCON1_ADSTRS 0x0
//<i>ADSTRS[6:0]
//<i>000 0000	ADSOC
//<i>------------------------------------------------	
//<i>000 0001	ⲿADTRG1
//<i>000 0010	ⲿADTRG2
//<i>000 0100	ⲿADTRG3
//<i>-------------------------------------------------	
//<i>001 0000	ʱ8BTIMTRG_ʱ8
//<i>-------------------------------------------------	
//<i>010 0001	MCM1	MCM1TRG1	MCM1. PWMCMP1Ƚƥ
//<i>010 0010		MCM1TRG2	MCM1. PWMCMP2Ƚƥ
//<i>010 0100		MCM1TRG3	MCM1. PWMCMP3Ƚƥ
//<i>010 1000		MCM1TRG4	MCM1. PWMCMP4Ƚƥ
//<i>-------------------------------------------------	
//<i>011 0001	MCM2	MCM1TRG1	MCM2. PWMCMP1Ƚƥ
//<i>011 0010		MCM1TRG2	MCM2. PWMCMP2Ƚƥ
//<i>011 0100		MCM1TRG3	MCM2. PWMCMP3Ƚƥ
//<i>011 1000		MCM1TRG4	MCM2. PWMCMP4Ƚƥ
//<i>-------------------------------------------------
//<i>100 0001	GPT0	GTADTRA0N	GPT0.GTADTRAȽƥ
//<i>100 0010		GTADTRB0N	GPT0.GTADTRBȽƥ
//<i>-------------------------------------------------
//<i>101 0001	GPT1	GTADTRA1N	GPT1.GTADTRAȽƥ
//<i>101 0010		GTADTRB1N	GPT1.GTADTRBȽƥ
//<i>-------------------------------------------------
//<i>110 0001	GPT2	GTADTRA2N	GPT2.GTADTRAȽƥ
//<i>110 0010		GTADTRB2N	GPT2.GTADTRBȽƥ
//<i>-------------------------------------------------
//<i>111 0001	GPT3	GTADTRA3N	GPT3.GTADTRAȽƥ
//<i>111 0010		GTADTRB3N	GPT3.GTADTRBȽƥ
//<e0>ⲿ
//    <q1.0>ADTRG1 1
//    <q1.1>ADTRG2 2
//    <q1.2>ADTRG3 3
//</e>
#define CFG_ADC1_ADTRG_EX_EN 0x0
#define CFG_ADC1_ADTRG_EX_VALUE 0x0


//<q>ʱ8BTIMTRG_ʱ8
#define CFG_ADC1_ADTRG_T8_EN 0x0

//<e0>MCM1
//    <q1.0>MCM1TRG1_MCM1.PWMCMP1Ƚƥ
//    <q1.1>MCM1TRG2_MCM1.PWMCMP2Ƚƥ
//    <q1.2>MCM1TRG3_MCM1.PWMCMP3Ƚƥ
//    <q1.3>MCM1TRG4_MCM1.PWMCMP4Ƚƥ
//</e>
#define CFG_ADC1_ADTRG_MCM1_EN 0x0
#define CFG_ADC1_ADTRG_MCM1_VALUE 0x0

//<e0>MCM2
//    <q1.0>MCM2TRG1_MCM2.PWMCMP1Ƚƥ
//    <q1.1>MCM2TRG2_MCM2.PWMCMP2Ƚƥ
//    <q1.2>MCM2TRG3_MCM2.PWMCMP3Ƚƥ
//    <q1.3>MCM2TRG4_MCM2.PWMCMP4Ƚƥ
//</e>
#define CFG_ADC1_ADTRG_MCM2_EN 0x0
#define CFG_ADC1_ADTRG_MCM2_VALUE 0x0

//<e0>GPT0
//    <q1.0>GTADTRA0N_GPT0.GTADTRA ıȽƥ
//    <q1.1>GTADTRB0N_GPT0.GTADTRB ıȽƥ
//</e>
#define CFG_ADC1_ADTRG_GPT0_EN 0x0
#define CFG_ADC1_ADTRG_GPT0_VALUE 0x0

//<e0>GPT1
//    <q1.0>GTADTRA1N_GPT1.GTADTRA ıȽƥ
//    <q1.1>GTADTRB1N_GPT1.GTADTRB ıȽƥ
//</e>
#define CFG_ADC1_ADTRG_GPT1_EN 0x0
#define CFG_ADC1_ADTRG_GPT1_VALUE 0x0

//<e0>GPT2
//    <q1.0>GTADTRA2N_GPT2.GTADTRA ıȽƥ
//    <q1.1>GTADTRB2N_GPT2.GTADTRB ıȽƥ
//</e>
#define CFG_ADC1_ADTRG_GPT2_EN 0x0
#define CFG_ADC1_ADTRG_GPT2_VALUE 0x0

//<e0>GPT3
//    <q1.0>GTADTRA3N_GPT3.GTADTRA ıȽƥ
//    <q1.1>GTADTRB3N_GPT3.GTADTRB ıȽƥ
//</e>
#define CFG_ADC1_ADTRG_GPT3_EN 0x0
#define CFG_ADC1_ADTRG_GPT3_VALUE 0x0
//</e>

#if ((CFG_ADC1_ADCON1_ADSTRS) && (CFG_ADC1_EN) \
									&&((CFG_ADC1_ADTRG_EX_EN && (CFG_ADC1_ADTRG_T8_EN || CFG_ADC1_ADTRG_MCM1_EN || CFG_ADC1_ADTRG_MCM2_EN || CFG_ADC1_ADTRG_GPT0_EN || CFG_ADC1_ADTRG_GPT1_EN || CFG_ADC1_ADTRG_GPT2_EN || CFG_ADC1_ADTRG_GPT3_EN ))\
									||(CFG_ADC1_ADTRG_T8_EN &&  (CFG_ADC1_ADTRG_EX_EN || CFG_ADC1_ADTRG_MCM1_EN || CFG_ADC1_ADTRG_MCM2_EN || CFG_ADC1_ADTRG_GPT0_EN || CFG_ADC1_ADTRG_GPT1_EN || CFG_ADC1_ADTRG_GPT2_EN || CFG_ADC1_ADTRG_GPT3_EN))\
									||(CFG_ADC1_ADTRG_MCM1_EN && (CFG_ADC1_ADTRG_EX_EN || CFG_ADC1_ADTRG_T8_EN || CFG_ADC1_ADTRG_MCM2_EN || CFG_ADC1_ADTRG_GPT0_EN || CFG_ADC1_ADTRG_GPT1_EN || CFG_ADC1_ADTRG_GPT2_EN || CFG_ADC1_ADTRG_GPT3_EN))\
									||(CFG_ADC1_ADTRG_MCM2_EN && (CFG_ADC1_ADTRG_EX_EN || CFG_ADC1_ADTRG_T8_EN || CFG_ADC1_ADTRG_MCM1_EN || CFG_ADC1_ADTRG_GPT0_EN || CFG_ADC1_ADTRG_GPT1_EN || CFG_ADC1_ADTRG_GPT2_EN || CFG_ADC1_ADTRG_GPT3_EN))\
									||(CFG_ADC1_ADTRG_GPT0_EN && (CFG_ADC1_ADTRG_EX_EN || CFG_ADC1_ADTRG_T8_EN || CFG_ADC1_ADTRG_MCM1_EN || CFG_ADC1_ADTRG_MCM2_EN || CFG_ADC1_ADTRG_GPT1_EN || CFG_ADC1_ADTRG_GPT2_EN || CFG_ADC1_ADTRG_GPT3_EN))\
									||(CFG_ADC1_ADTRG_GPT1_EN && (CFG_ADC1_ADTRG_EX_EN || CFG_ADC1_ADTRG_T8_EN || CFG_ADC1_ADTRG_MCM1_EN || CFG_ADC1_ADTRG_MCM2_EN || CFG_ADC1_ADTRG_GPT0_EN || CFG_ADC1_ADTRG_GPT2_EN || CFG_ADC1_ADTRG_GPT3_EN))\
									||(CFG_ADC1_ADTRG_GPT2_EN && (CFG_ADC1_ADTRG_EX_EN || CFG_ADC1_ADTRG_T8_EN || CFG_ADC1_ADTRG_MCM1_EN || CFG_ADC1_ADTRG_MCM2_EN || CFG_ADC1_ADTRG_GPT0_EN || CFG_ADC1_ADTRG_GPT1_EN || CFG_ADC1_ADTRG_GPT3_EN))\
									||(CFG_ADC1_ADTRG_GPT3_EN && (CFG_ADC1_ADTRG_EX_EN || CFG_ADC1_ADTRG_T8_EN || CFG_ADC1_ADTRG_MCM1_EN || CFG_ADC1_ADTRG_MCM2_EN || CFG_ADC1_ADTRG_GPT0_EN || CFG_ADC1_ADTRG_GPT1_EN || CFG_ADC1_ADTRG_GPT2_EN)))\
									)
#error "ADC1ӲԴѡֻѡӲԴеһ֣"
#endif

#if (CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_EX_EN && (CFG_ADC1_ADTRG_EX_VALUE==0))
#error "ADC1ΪӲԴתδⲿţ"
#endif

#if (CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_MCM1_EN && (CFG_ADC1_ADTRG_MCM1_VALUE==0))
#error "ADC1ΪMCM1ӲԴתδþ崥"
#endif

#if (CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_MCM2_EN && (CFG_ADC1_ADTRG_MCM2_VALUE==0))
#error "ADC1ΪMCM2ӲԴתδþ崥"
#endif

#if (CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_GPT0_EN && (CFG_ADC1_ADTRG_GPT0_VALUE==0))
#error "ADC1ΪGPT0ӲԴתδþ崥"
#endif

#if (CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_GPT1_EN && (CFG_ADC1_ADTRG_GPT1_VALUE==0))
#error "ADC1ΪGPT1ӲԴתδþ崥"
#endif

#if (CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_GPT2_EN && (CFG_ADC1_ADTRG_GPT2_VALUE==0))
#error "ADC1ΪGPT2ӲԴתδþ崥"
#endif

#if (CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_GPT3_EN && (CFG_ADC1_ADTRG_GPT3_VALUE==0))
#error "ADC1ΪGPT3ӲԴתδþ崥"
#endif

#if(CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_EX_EN)
#define CFG_ADC1_ADCON1_INIT ((CFG_ADC1_ADCON1_VALUE & 0x80FF) | (CFG_ADC1_ADTRG_EX_VALUE<<8))
#elif(CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_T8_EN)
#define CFG_ADC1_ADCON1_INIT ((CFG_ADC1_ADCON1_VALUE & 0x80FF) | (1<<12))
#elif(CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_MCM1_EN)
#define CFG_ADC1_ADCON1_INIT ((CFG_ADC1_ADCON1_VALUE & 0x80FF) |(2<<12)|(CFG_ADC1_ADTRG_MCM1_VALUE<<8))
#elif(CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_MCM2_EN)
#define CFG_ADC1_ADCON1_INIT ((CFG_ADC1_ADCON1_VALUE & 0x80FF) |(3<<12)|(CFG_ADC1_ADTRG_MCM2_VALUE<<8))
#elif(CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_GPT0_EN)
#define CFG_ADC1_ADCON1_INIT ((CFG_ADC1_ADCON1_VALUE & 0x80FF) |(4<<12)|(CFG_ADC1_ADTRG_GPT0_VALUE<<8))
#elif(CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_GPT1_EN)
#define CFG_ADC1_ADCON1_INIT ((CFG_ADC1_ADCON1_VALUE & 0x80FF) |(5<<12)|(CFG_ADC1_ADTRG_GPT1_VALUE<<8))
#elif(CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_GPT2_EN)
#define CFG_ADC1_ADCON1_INIT ((CFG_ADC1_ADCON1_VALUE & 0x80FF) |(6<<12)|(CFG_ADC1_ADTRG_GPT2_VALUE<<8))
#elif(CFG_ADC1_ADCON1_ADSTRS && CFG_ADC1_EN && CFG_ADC1_ADTRG_GPT3_EN)
#define CFG_ADC1_ADCON1_INIT ((CFG_ADC1_ADCON1_VALUE & 0x80FF) |(7<<12)|(CFG_ADC1_ADTRG_GPT3_VALUE<<8))
#else
#define CFG_ADC1_ADCON1_INIT (CFG_ADC1_ADCON1_VALUE & 0x80FF)
#endif
//</h>


#if ((CFG_ADC1_ADCON1_INIT & (1<<7)) != 0)
	#define CFG_ADC1_INT_EN 1
#else
	#define CFG_ADC1_INT_EN 0
#endif

//<h>ADCON2_ADCƼĴ2
//<i>0x004  b31~19 b18~16 b15~12 b11~8 b7 b6~4    b3~0 
//<i>ADCON2 -      TGAP   -      TS    -  ADMAXCH TADC 
// <o0.0..3> TADC_ADCʱѡ
//    <0=>ADCʱtAD = 1 tHCLK
//    <1=>ADCʱtAD = 2 tHCLK
//    <2=>ADCʱtAD = 3 tHCLK
//    <3=>ADCʱtAD = 4 tHCLK
//    <4=>ADCʱtAD = 5 tHCLK
//    <5=>ADCʱtAD = 6 tHCLK
//    <6=>ADCʱtAD = 8 tHCLK
//    <7=>ADCʱtAD = 12 tHCLK
//    <8=>ADCʱtAD = 16 tHCLK
//    <9=>ADCʱtAD = 24 tHCLK
//    <10=>ADCʱtAD = 32 tHCLK
//    <11=>ADCʱtAD = 48 tHCLK
//    <12=>ADCʱtAD = 64 tHCLK
//    <13=>ADCʱtAD = 128 tHCLK
//    <14=>ADCʱtAD = 256 tHCLK
//    <15=>ADCʱtAD = 320 tHCLK
//    <i>tHCLKΪHCLKʱ
// <o0.4..6> ADMAXCH_һADת̵ģͨ
//<0=>1
//<1=>2
//<2=>3
//<3=>4
//<4=>5
//<5=>6
//<6=>7
//<7=>8
//    <i>һADת̵ģͨΪADMAxCH1+1
// <o0.8..11> TS _ʱ
//<0=>1ADCʱ
//<1=>2ADCʱ
//<2=>3ADCʱ
//<3=>4ADCʱ
//<4=>5ADCʱ
//<5=>6ADCʱ
//<6=>7ADCʱ
//<7=>8ADCʱ
//<8=>9ADCʱ
//<9=>10ADCʱ
//<10=>11ADCʱ
//<11=>12ADCʱ
//<12=>13ADCʱ
//<13=>14ADCʱ
//<14=>15ADCʱ
//<15=>16ADCʱ
//<i>1 tAD   (TS [3-0]+1) * tAD  16 tAD
//<i>һͨܲʱ:TS + TGAP ˴TS֣
//<i>ܲʱ䷶Χ:1 tAD  ((TS[3~0])+1+TGAP[2~0]*GAPEN)* tAD  144 tAD TGAPGAPENǷʹܣ
//<i>TS[3:0]ǰӵADCŵĴ裬ԻѲȣѡ1 * tADΪʱʱȷӵADCŵĴ迹21.3.10
//<i>TADC豣֤ADCʱ Tadc  25ns
//<i>12bitģʽһܹͨתʱ = 15tAD + ʱ䣻10bitģʽһܹͨתʱ = 13tAD + ʱ
// <o0.16..18> TGAP _ʱ֮ͨʱλ
//<i>һתУһͨתϵһͨʼ֮ʱ
//<0=>޵ȴʱ
//<1=>2ADCʱ
//<2=>4ADCʱ
//<3=>8ADCʱ
//<4=>16ADCʱ
//<5=>32ADCʱ
//<6=>64ADCʱ
//<7=>128ADCʱ
//</h>
#define CFG_ADC1_ADCON2_INIT	0x0

//<h>ADCMPCON_ADCȽϿƼĴ
//<i>0x02C    b31~8 b7    b6    b5    b4    b3 b2~0 
//<i>ADCMPCON -     ADGIE ADGDE ADLIE ADLDE -  CSEL 
// <o0.0..2> CSEL_ڱȽϵĽĴѡλ
//    <0=>ѡADDR0еֵADDGTADDLTȽ
//    <1=>ѡADDR1еֵADDGTADDLTȽ
//    <2=>ѡADDR2еֵADDGTADDLTȽ
//    <3=>ѡADDR3еֵADDGTADDLTȽ
//    <4=>ѡADDR4еֵADDGTADDLTȽ
//    <5=>ѡADDR5еֵADDGTADDLTȽ
//    <6=>ѡADDR6еֵADDGTADDLTȽ
//    <7=>ѡADDR7еֵADDGTADDLTȽ
// <q0.4> ADLDE_ޱȽDMAʹλ
//    0: ֹޱȽDMA
//    1: ʹޱȽDMA
// <q0.5> ADLIE_ޱȽжʹλ
//    0: ֹޱȽж
//    1: ʹޱȽж
// <q0.6> ADGDE_ޱȽDMAʹλ
//    0: ֹޱȽϴDMA
//    1: ʹޱȽϴDMA
// <q0.7> ADGIE_ޱȽжʹλ
//    0: ֹޱȽж
//    1: ʹޱȽж

//</h>
#define CFG_ADC1_ADCMPCON_INIT	0x0

//<h>ADDGT_ADCޱȽϼĴ
//<i>0x030 b31~16 b15~0 
//<i>ADDGT -      GT    
// <o0.0..15> GT_ADCޱȽϼĴ<0-65535>
//һתʱADCMPCONĴCSELλָĴֵADDGTеֵȽϣڵADDGTеֵADCMPCONеADGIFλ1ADGIFλΪ1ֱ 
//</h>
#define CFG_ADC1_ADDGT_INIT	0x0

//<h>ADDLT_ADCޱȽϼĴ
//<i>0x034 b31~16 b15~0 
//<i>ADDLT -      LT    
// <o0.0..15> LT_ADCޱȽϼĴ<0-65535>
//һתʱADCMPCONĴCSELλָĴֵADDLTеֵȽϣСڵADDLTеֵADCMPCONеADLIFλ1ADLIFλΪ1ֱ 
//</h>
#define CFG_ADC1_ADDLT_INIT	0x0

//<h>SEQCHSEL_ADCͨѡĴ
//<i>0x038    b31~28 b27~24 b23~20 b19~16 b15~12 b11~8  b7~4   b3~0   
//<i>SEQCHSEL SEQCH7 SEQCH6 SEQCH5 SEQCH4 SEQCH3 SEQCH2 SEQCH1 SEQCH0 
// <o> SEQCH0_ģͨ0ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC1_SEQCH0 0

// <o> SEQCH1_ģͨ1ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC1_SEQCH1 0
// <o> SEQCH2_ģͨ2ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC1_SEQCH2 0
// <o0> SEQCH3_ģͨ3ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC1_SEQCH3 0
// <o> SEQCH4_ģͨ4ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC1_SEQCH4 0
// <o> SEQCH5_ģͨ5ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC1_SEQCH5 0
// <o> SEQCH6_ģͨ6ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC1_SEQCH6 0
// <o> SEQCH7_ģͨ7ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC1_SEQCH7 0
//</h>

#define CFG_ADC1_SEQCHSEL_INIT	((CFG_ADC1_SEQCH7<<28)\
																|(CFG_ADC1_SEQCH6<<24)\
																|(CFG_ADC1_SEQCH5<<20)\
																|(CFG_ADC1_SEQCH4<<16)\
																|(CFG_ADC1_SEQCH3<<12)\
																|(CFG_ADC1_SEQCH2<<8)\
																|(CFG_ADC1_SEQCH1<<4)\
																|CFG_ADC1_SEQCH0)
//<h>ADGAPON_ADCͨGAPλ
//<i>0x03C   b31~8 b7     b6     b5     b4     b3     b2     b1     b0     
//<i>ADGAPON -     GAPEN7 GAPEN6 GAPEN5 GAPEN4 GAPEN3 GAPEN2 GAPEN1 GAPEN0 
// <q0.0> GAPEN0_ADCͨ0GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.1> GAPEN1_ADCͨ1GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.2> GAPEN2_ADCͨ2GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.3> GAPEN3_ADCͨ3GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.4> GAPEN4_ADCͨ4GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.5> GAPEN5_ADCͨ5GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.6> GAPEN6_ADCͨ6GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.7> GAPEN7_ADCͨ7GAPʱʹλ
//0: ֹ
//1: ʹ
//</h>
#define CFG_ADC1_ADGAPON_INIT	0x0

//</e>
#if ((CFG_ADC_EN) && (CFG_ADC1_EN) \
									&& ((CFG_ADC1_SEQCH1 == 0x1)||(CFG_ADC1_SEQCH2 == 0x1)||(CFG_ADC1_SEQCH3 == 0x1)||(CFG_ADC1_SEQCH4 == 0x1)\
											||(CFG_ADC1_SEQCH5 == 0x1)||(CFG_ADC1_SEQCH6 == 0x1)||(CFG_ADC1_SEQCH7 == 0x1))\
									&& (CFG_PD8_AFR != 14))
#error "ADC1 AN1(PD8) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC1_EN) \
									&& ((CFG_ADC1_SEQCH1 == 0x2)||(CFG_ADC1_SEQCH2 == 0x2)||(CFG_ADC1_SEQCH3 == 0x2)||(CFG_ADC1_SEQCH4 == 0x2)\
											||(CFG_ADC1_SEQCH5 == 0x2)||(CFG_ADC1_SEQCH6 == 0x2)||(CFG_ADC1_SEQCH7 == 0x2))\
									&& (CFG_PD9_AFR != 14))
#error "ADC1 AN2(PD9) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC1_EN) \
									&& ((CFG_ADC1_SEQCH1 == 0x3)||(CFG_ADC1_SEQCH2 == 0x3)||(CFG_ADC1_SEQCH3 == 0x3)||(CFG_ADC1_SEQCH4 == 0x3)\
											||(CFG_ADC1_SEQCH5 == 0x3)||(CFG_ADC1_SEQCH6 == 0x3)||(CFG_ADC1_SEQCH7 == 0x3))\
									&& (CFG_PD10_AFR != 14))
#error "ADC1 AN3(PD10) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC1_EN) \
									&& ((CFG_ADC1_SEQCH1 == 0x4)||(CFG_ADC1_SEQCH2 == 0x4)||(CFG_ADC1_SEQCH3 == 0x4)||(CFG_ADC1_SEQCH4 == 0x4)\
											||(CFG_ADC1_SEQCH5 == 0x4)||(CFG_ADC1_SEQCH6 == 0x4)||(CFG_ADC1_SEQCH7 == 0x4))\
									&& (CFG_PD11_AFR != 14))
#error "ADC1 AN4(PD11) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC1_EN) \
									&& ((CFG_ADC1_SEQCH1 == 0x5)||(CFG_ADC1_SEQCH2 == 0x5)||(CFG_ADC1_SEQCH3 == 0x5)||(CFG_ADC1_SEQCH4 == 0x5)\
											||(CFG_ADC1_SEQCH5 == 0x5)||(CFG_ADC1_SEQCH6 == 0x5)||(CFG_ADC1_SEQCH7 == 0x5))\
									&& (CFG_PD12_AFR != 14))
#error "ADC1 AN5(PD12) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC1_EN) \
									&& ((CFG_ADC1_SEQCH1 == 0x6)||(CFG_ADC1_SEQCH2 == 0x6)||(CFG_ADC1_SEQCH3 == 0x6)||(CFG_ADC1_SEQCH4 == 0x6)\
											||(CFG_ADC1_SEQCH5 == 0x6)||(CFG_ADC1_SEQCH6 == 0x6)||(CFG_ADC1_SEQCH7 == 0x6))\
									&& (CFG_PD13_AFR != 14))
#error "ADC1 AN6(PD13) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC1_EN) \
									&& ((CFG_ADC1_SEQCH1 == 0x7)||(CFG_ADC1_SEQCH2 == 0x7)||(CFG_ADC1_SEQCH3 == 0x7)||(CFG_ADC1_SEQCH4 == 0x7)\
											||(CFG_ADC1_SEQCH5 == 0x7)||(CFG_ADC1_SEQCH6 == 0x7)||(CFG_ADC1_SEQCH7 == 0x7))\
									&& (CFG_PD14_AFR != 14))
#error "ADC1 AN7(PD14) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC1_EN) \
									&& ((CFG_ADC1_SEQCH1 == 0xB )||(CFG_ADC1_SEQCH2 == 0xB)||(CFG_ADC1_SEQCH3 == 0xB)||(CFG_ADC1_SEQCH4 == 0xB)\
											||(CFG_ADC1_SEQCH5 == 0xB)||(CFG_ADC1_SEQCH6 == 0xB)||(CFG_ADC1_SEQCH7 == 0xB))\
									&& (CFG_PD4_AFR != 14))
#error "ADC1 OP1OUT(PD4) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC1_EN) \
									&& ((CFG_ADC1_SEQCH1 == 0xC)||(CFG_ADC1_SEQCH2 == 0xC)||(CFG_ADC1_SEQCH3 == 0xC)||(CFG_ADC1_SEQCH4 == 0xC)\
											||(CFG_ADC1_SEQCH5 == 0xC)||(CFG_ADC1_SEQCH6 == 0xC)||(CFG_ADC1_SEQCH7 == 0xC))\
									&& (CFG_PD1_AFR != 14))
#error "ADC1 OP2OUT(PD1) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC1_EN) \
									&& ((CFG_ADC1_SEQCH1 == 0xD)||(CFG_ADC1_SEQCH2 == 0xD)||(CFG_ADC1_SEQCH3 == 0xD)||(CFG_ADC1_SEQCH4 == 0xD)\
											||(CFG_ADC1_SEQCH5 == 0xD)||(CFG_ADC1_SEQCH6 == 0xD)||(CFG_ADC1_SEQCH7 == 0xD))\
									&& (CFG_PC15_AFR != 14))
#error "ADC1 OP3OUT(PC15) AF14 function mapping is not enable."
#endif

#if ((CFG_ADC_EN) && (CFG_ADC1_EN) && (CFG_ADC1_ADCON1_INIT & (1<<8) == (1<<8)) && ((CFG_PB3_AFR != 10)&&(CFG_PC5_AFR != 10)&&(CFG_PD7_AFR != 10)))
#error "ADTRG1(PB3/PC5/PD7) AF10 function mapping is not enable."
#endif

#if ((CFG_ADC_EN) && (CFG_ADC1_EN) && (CFG_ADC1_ADCON1_INIT & (2<<8) == (2<<8)) && ((CFG_PB4_AFR != 10)&&(CFG_PC6_AFR != 10)&&(CFG_PD6_AFR != 10)))
#error "ADTRG2(PB4/PC6/PD6) AF10 function mapping is not enable."
#endif

#if ((CFG_ADC_EN) && (CFG_ADC1_EN) && (CFG_ADC1_ADCON1_INIT & (4<<8) == (4<<8)) && ((CFG_PB5_AFR != 10)&&(CFG_PC7_AFR != 10)&&(CFG_PD5_AFR != 10)))
#error "ADTRG3(PB5/PC7/PD5) AF10 function mapping is not enable."
#endif

//***********************************************************/
//<e>ADC2
#define CFG_ADC2_EN 0

//<h>ADCON1_ADCƼĴ1
//<i>0x000  b31~16 b15  b14~8  b7   b6   b5~4 b3  b2~1  b0    
//<i>ADCON1 -      ADON ADSTRS ADIE ADDE REFC MOD ADCTU ADSOC 
// <o0.1..2> ADCTU_ADCͨеתʽλ
//    <0=>תʽ
//    <1=>תʽ
//    <2=>תʽ
//    <3=>
//    <i>޸ĸÿλһADתʱŲЧ
// <o0.3> MOD_ADCģʽѡλ
//    <0=>12bit
//    <1=>10bit
// <o0.4..5> REFC_׼ѹѡλ
//    <0=>ѡAVDDΪ׼ѹ
//    <1=>ѡⲿVREF˿Ϊ׼ѹ
//    <2=>ѡڽVREFΪ׼ѹ
//    <3=>
//<i>ΪڽVREFⲿVREFţ3ADCܼѡڽVREFѡVREF
// <q0.6> ADDE_ͨתDMAʹλ
//    0: ֹADCתDMA
//    1: ʹADCתDMA
// <q0.7> ADIE_ͨתжʹλ
//    0: ֹADCתж
//    1: ʹADCתж

// <q0.15> ADON_ADCλ
//    0: ֹADCxģ
//    1: ADCxģ

#define CFG_ADC2_ADCON1_VALUE 0x00

// <e> ADSTRS_ADCӲԴѡ(ֻ8ѡ1)
#define CFG_ADC2_ADCON1_ADSTRS 0x0
//<i>ADSTRS[6:0]
//<i>000 0000	ADSOC
//<i>------------------------------------------------	
//<i>000 0001	ⲿADTRG1
//<i>000 0010	ⲿADTRG2
//<i>000 0100	ⲿADTRG3
//<i>-------------------------------------------------	
//<i>001 0000	ʱ8BTIMTRG_ʱ8
//<i>-------------------------------------------------	
//<i>010 0001	MCM1	MCM1TRG1	MCM1. PWMCMP1Ƚƥ
//<i>010 0010		MCM1TRG2	MCM1. PWMCMP2Ƚƥ
//<i>010 0100		MCM1TRG3	MCM1. PWMCMP3Ƚƥ
//<i>010 1000		MCM1TRG4	MCM1. PWMCMP4Ƚƥ
//<i>-------------------------------------------------	
//<i>011 0001	MCM2	MCM1TRG1	MCM2. PWMCMP1Ƚƥ
//<i>011 0010		MCM1TRG2	MCM2. PWMCMP2Ƚƥ
//<i>011 0100		MCM1TRG3	MCM2. PWMCMP3Ƚƥ
//<i>011 1000		MCM1TRG4	MCM2. PWMCMP4Ƚƥ
//<i>-------------------------------------------------
//<i>100 0001	GPT0	GTADTRA0N	GPT0.GTADTRAȽƥ
//<i>100 0010		GTADTRB0N	GPT0.GTADTRBȽƥ
//<i>-------------------------------------------------
//<i>101 0001	GPT1	GTADTRA1N	GPT1.GTADTRAȽƥ
//<i>101 0010		GTADTRB1N	GPT1.GTADTRBȽƥ
//<i>-------------------------------------------------
//<i>110 0001	GPT2	GTADTRA2N	GPT2.GTADTRAȽƥ
//<i>110 0010		GTADTRB2N	GPT2.GTADTRBȽƥ
//<i>-------------------------------------------------
//<i>111 0001	GPT3	GTADTRA3N	GPT3.GTADTRAȽƥ
//<i>111 0010		GTADTRB3N	GPT3.GTADTRBȽƥ
//<e0>ⲿ
//    <q1.0>ADTRG1 1
//    <q1.1>ADTRG2 2
//    <q1.2>ADTRG3 3
//</e>
#define CFG_ADC2_ADTRG_EX_EN 0x0
#define CFG_ADC2_ADTRG_EX_VALUE 0x0


//<q>ʱ8BTIMTRG_ʱ8
#define CFG_ADC2_ADTRG_T8_EN 0x0

//<e0>MCM1
//    <q1.0>MCM1TRG1_MCM1.PWMCMP1Ƚƥ
//    <q1.1>MCM1TRG2_MCM1.PWMCMP2Ƚƥ
//    <q1.2>MCM1TRG3_MCM1.PWMCMP3Ƚƥ
//    <q1.3>MCM1TRG4_MCM1.PWMCMP4Ƚƥ
//</e>
#define CFG_ADC2_ADTRG_MCM1_EN 0x0
#define CFG_ADC2_ADTRG_MCM1_VALUE 0x0

//<e0>MCM2
//    <q1.0>MCM2TRG1_MCM2.PWMCMP1Ƚƥ
//    <q1.1>MCM2TRG2_MCM2.PWMCMP2Ƚƥ
//    <q1.2>MCM2TRG3_MCM2.PWMCMP3Ƚƥ
//    <q1.3>MCM2TRG4_MCM2.PWMCMP4Ƚƥ
//</e>
#define CFG_ADC2_ADTRG_MCM2_EN 0x0
#define CFG_ADC2_ADTRG_MCM2_VALUE 0x0

//<e0>GPT0
//    <q1.0>GTADTRA0N_GPT0.GTADTRA ıȽƥ
//    <q1.1>GTADTRB0N_GPT0.GTADTRB ıȽƥ
//</e>
#define CFG_ADC2_ADTRG_GPT0_EN 0x0
#define CFG_ADC2_ADTRG_GPT0_VALUE 0x0

//<e0>GPT1
//    <q1.0>GTADTRA1N_GPT1.GTADTRA ıȽƥ
//    <q1.1>GTADTRB1N_GPT1.GTADTRB ıȽƥ
//</e>
#define CFG_ADC2_ADTRG_GPT1_EN 0x0
#define CFG_ADC2_ADTRG_GPT1_VALUE 0x0

//<e0>GPT2
//    <q1.0>GTADTRA2N_GPT2.GTADTRA ıȽƥ
//    <q1.1>GTADTRB2N_GPT2.GTADTRB ıȽƥ
//</e>
#define CFG_ADC2_ADTRG_GPT2_EN 0x0
#define CFG_ADC2_ADTRG_GPT2_VALUE 0x0

//<e0>GPT3
//    <q1.0>GTADTRA3N_GPT3.GTADTRA ıȽƥ
//    <q1.1>GTADTRB3N_GPT3.GTADTRB ıȽƥ
//</e>
#define CFG_ADC2_ADTRG_GPT3_EN 0x0
#define CFG_ADC2_ADTRG_GPT3_VALUE 0x0
//</e>

#if ((CFG_ADC2_ADCON1_ADSTRS) && (CFG_ADC2_EN) \
									&&((CFG_ADC2_ADTRG_EX_EN && (CFG_ADC2_ADTRG_T8_EN || CFG_ADC2_ADTRG_MCM1_EN || CFG_ADC2_ADTRG_MCM2_EN || CFG_ADC2_ADTRG_GPT0_EN || CFG_ADC2_ADTRG_GPT1_EN || CFG_ADC2_ADTRG_GPT2_EN || CFG_ADC2_ADTRG_GPT3_EN ))\
									||(CFG_ADC2_ADTRG_T8_EN &&  (CFG_ADC2_ADTRG_EX_EN || CFG_ADC2_ADTRG_MCM1_EN || CFG_ADC2_ADTRG_MCM2_EN || CFG_ADC2_ADTRG_GPT0_EN || CFG_ADC2_ADTRG_GPT1_EN || CFG_ADC2_ADTRG_GPT2_EN || CFG_ADC2_ADTRG_GPT3_EN))\
									||(CFG_ADC2_ADTRG_MCM1_EN && (CFG_ADC2_ADTRG_EX_EN || CFG_ADC2_ADTRG_T8_EN || CFG_ADC2_ADTRG_MCM2_EN || CFG_ADC2_ADTRG_GPT0_EN || CFG_ADC2_ADTRG_GPT1_EN || CFG_ADC2_ADTRG_GPT2_EN || CFG_ADC2_ADTRG_GPT3_EN))\
									||(CFG_ADC2_ADTRG_MCM2_EN && (CFG_ADC2_ADTRG_EX_EN || CFG_ADC2_ADTRG_T8_EN || CFG_ADC2_ADTRG_MCM1_EN || CFG_ADC2_ADTRG_GPT0_EN || CFG_ADC2_ADTRG_GPT1_EN || CFG_ADC2_ADTRG_GPT2_EN || CFG_ADC2_ADTRG_GPT3_EN))\
									||(CFG_ADC2_ADTRG_GPT0_EN && (CFG_ADC2_ADTRG_EX_EN || CFG_ADC2_ADTRG_T8_EN || CFG_ADC2_ADTRG_MCM1_EN || CFG_ADC2_ADTRG_MCM2_EN || CFG_ADC2_ADTRG_GPT1_EN || CFG_ADC2_ADTRG_GPT2_EN || CFG_ADC2_ADTRG_GPT3_EN))\
									||(CFG_ADC2_ADTRG_GPT1_EN && (CFG_ADC2_ADTRG_EX_EN || CFG_ADC2_ADTRG_T8_EN || CFG_ADC2_ADTRG_MCM1_EN || CFG_ADC2_ADTRG_MCM2_EN || CFG_ADC2_ADTRG_GPT0_EN || CFG_ADC2_ADTRG_GPT2_EN || CFG_ADC2_ADTRG_GPT3_EN))\
									||(CFG_ADC2_ADTRG_GPT2_EN && (CFG_ADC2_ADTRG_EX_EN || CFG_ADC2_ADTRG_T8_EN || CFG_ADC2_ADTRG_MCM1_EN || CFG_ADC2_ADTRG_MCM2_EN || CFG_ADC2_ADTRG_GPT0_EN || CFG_ADC2_ADTRG_GPT1_EN || CFG_ADC2_ADTRG_GPT3_EN))\
									||(CFG_ADC2_ADTRG_GPT3_EN && (CFG_ADC2_ADTRG_EX_EN || CFG_ADC2_ADTRG_T8_EN || CFG_ADC2_ADTRG_MCM1_EN || CFG_ADC2_ADTRG_MCM2_EN || CFG_ADC2_ADTRG_GPT0_EN || CFG_ADC2_ADTRG_GPT1_EN || CFG_ADC2_ADTRG_GPT2_EN)))\
									)
#error "ADC2ӲԴѡֻѡӲԴеһ֣"
#endif

#if (CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_EX_EN && (CFG_ADC2_ADTRG_EX_VALUE==0))
#error "ADC2ΪӲԴתδⲿţ"
#endif

#if (CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_MCM1_EN && (CFG_ADC2_ADTRG_MCM1_VALUE==0))
#error "ADC2ΪMCM1ӲԴתδþ崥"
#endif

#if (CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_MCM2_EN && (CFG_ADC2_ADTRG_MCM2_VALUE==0))
#error "ADC2ΪMCM2ӲԴתδþ崥"
#endif

#if (CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_GPT0_EN && (CFG_ADC2_ADTRG_GPT0_VALUE==0))
#error "ADC2ΪGPT0ӲԴתδþ崥"
#endif

#if (CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_GPT1_EN && (CFG_ADC2_ADTRG_GPT1_VALUE==0))
#error "ADC2ΪGPT1ӲԴתδþ崥"
#endif

#if (CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_GPT2_EN && (CFG_ADC2_ADTRG_GPT2_VALUE==0))
#error "ADC2ΪGPT2ӲԴתδþ崥"
#endif

#if (CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_GPT3_EN && (CFG_ADC2_ADTRG_GPT3_VALUE==0))
#error "ADC2ΪGPT3ӲԴתδþ崥"
#endif

#if(CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_EX_EN)
#define CFG_ADC2_ADCON1_INIT ((CFG_ADC2_ADCON1_VALUE & 0x80FF) | (CFG_ADC2_ADTRG_EX_VALUE<<8))
#elif(CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_T8_EN)
#define CFG_ADC2_ADCON1_INIT ((CFG_ADC2_ADCON1_VALUE & 0x80FF) | (1<<12))
#elif(CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_MCM1_EN)
#define CFG_ADC2_ADCON1_INIT ((CFG_ADC2_ADCON1_VALUE & 0x80FF) |(2<<12)|(CFG_ADC2_ADTRG_MCM1_VALUE<<8))
#elif(CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_MCM2_EN)
#define CFG_ADC2_ADCON1_INIT ((CFG_ADC2_ADCON1_VALUE & 0x80FF) |(3<<12)|(CFG_ADC2_ADTRG_MCM2_VALUE<<8))
#elif(CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_GPT0_EN)
#define CFG_ADC2_ADCON1_INIT ((CFG_ADC2_ADCON1_VALUE & 0x80FF) |(4<<12)|(CFG_ADC2_ADTRG_GPT0_VALUE<<8))
#elif(CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_GPT1_EN)
#define CFG_ADC2_ADCON1_INIT ((CFG_ADC2_ADCON1_VALUE & 0x80FF) |(5<<12)|(CFG_ADC2_ADTRG_GPT1_VALUE<<8))
#elif(CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_GPT2_EN)
#define CFG_ADC2_ADCON1_INIT ((CFG_ADC2_ADCON1_VALUE & 0x80FF) |(6<<12)|(CFG_ADC2_ADTRG_GPT2_VALUE<<8))
#elif(CFG_ADC2_ADCON1_ADSTRS && CFG_ADC2_EN && CFG_ADC2_ADTRG_GPT3_EN)
#define CFG_ADC2_ADCON1_INIT ((CFG_ADC2_ADCON1_VALUE & 0x80FF) |(7<<12)|(CFG_ADC2_ADTRG_GPT3_VALUE<<8))
#else
#define CFG_ADC2_ADCON1_INIT (CFG_ADC2_ADCON1_VALUE & 0x80FF)
#endif
//</h>


#if ((CFG_ADC2_ADCON1_INIT & (1<<7)) != 0)
	#define CFG_ADC2_INT_EN 1
#else
	#define CFG_ADC2_INT_EN 0
#endif

//<h>ADCON2_ADCƼĴ2
//<i>0x004  b31~19 b18~16 b15~12 b11~8 b7 b6~4    b3~0 
//<i>ADCON2 -      TGAP   -      TS    -  ADMAXCH TADC 
// <o0.0..3> TADC_ADCʱѡ
//    <0=>ADCʱtAD = 1 tHCLK
//    <1=>ADCʱtAD = 2 tHCLK
//    <2=>ADCʱtAD = 3 tHCLK
//    <3=>ADCʱtAD = 4 tHCLK
//    <4=>ADCʱtAD = 5 tHCLK
//    <5=>ADCʱtAD = 6 tHCLK
//    <6=>ADCʱtAD = 8 tHCLK
//    <7=>ADCʱtAD = 12 tHCLK
//    <8=>ADCʱtAD = 16 tHCLK
//    <9=>ADCʱtAD = 24 tHCLK
//    <10=>ADCʱtAD = 32 tHCLK
//    <11=>ADCʱtAD = 48 tHCLK
//    <12=>ADCʱtAD = 64 tHCLK
//    <13=>ADCʱtAD = 128 tHCLK
//    <14=>ADCʱtAD = 256 tHCLK
//    <15=>ADCʱtAD = 320 tHCLK
//    <i>tHCLKΪHCLKʱ
// <o0.4..6> ADMAXCH_һADת̵ģͨ
//<0=>1
//<1=>2
//<2=>3
//<3=>4
//<4=>5
//<5=>6
//<6=>7
//<7=>8
//    <i>һADת̵ģͨΪADMAxCH1+1
// <o0.8..11> TS _ʱ
//<0=>1ADCʱ
//<1=>2ADCʱ
//<2=>3ADCʱ
//<3=>4ADCʱ
//<4=>5ADCʱ
//<5=>6ADCʱ
//<6=>7ADCʱ
//<7=>8ADCʱ
//<8=>9ADCʱ
//<9=>10ADCʱ
//<10=>11ADCʱ
//<11=>12ADCʱ
//<12=>13ADCʱ
//<13=>14ADCʱ
//<14=>15ADCʱ
//<15=>16ADCʱ
//<i>1 tAD   (TS [3-0]+1) * tAD  16 tAD
//<i>һͨܲʱ:TS + TGAP ˴TS֣
//<i>ܲʱ䷶Χ:1 tAD  ((TS[3~0])+1+TGAP[2~0]*GAPEN)* tAD  144 tAD TGAPGAPENǷʹܣ
//<i>TS[3:0]ǰӵADCŵĴ裬ԻѲȣѡ1 * tADΪʱʱȷӵADCŵĴ迹21.3.10
//<i>TADC豣֤ADCʱ Tadc  25ns
//<i>12bitģʽһܹͨתʱ = 15tAD + ʱ䣻10bitģʽһܹͨתʱ = 13tAD + ʱ
// <o0.16..18> TGAP _ʱ֮ͨʱλ
//<i>һתУһͨתϵһͨʼ֮ʱ
//<0=>޵ȴʱ
//<1=>2ADCʱ
//<2=>4ADCʱ
//<3=>8ADCʱ
//<4=>16ADCʱ
//<5=>32ADCʱ
//<6=>64ADCʱ
//<7=>128ADCʱ
//</h>
#define CFG_ADC2_ADCON2_INIT	0x0

//<h>ADCMPCON_ADCȽϿƼĴ
//<i>0x02C    b31~8 b7    b6    b5    b4    b3 b2~0 
//<i>ADCMPCON -     ADGIE ADGDE ADLIE ADLDE -  CSEL 
// <o0.0..2> CSEL_ڱȽϵĽĴѡλ
//    <0=>ѡADDR0еֵADDGTADDLTȽ
//    <1=>ѡADDR1еֵADDGTADDLTȽ
//    <2=>ѡADDR2еֵADDGTADDLTȽ
//    <3=>ѡADDR3еֵADDGTADDLTȽ
//    <4=>ѡADDR4еֵADDGTADDLTȽ
//    <5=>ѡADDR5еֵADDGTADDLTȽ
//    <6=>ѡADDR6еֵADDGTADDLTȽ
//    <7=>ѡADDR7еֵADDGTADDLTȽ
// <q0.4> ADLDE_ޱȽDMAʹλ
//    0: ֹޱȽDMA
//    1: ʹޱȽDMA
// <q0.5> ADLIE_ޱȽжʹλ
//    0: ֹޱȽж
//    1: ʹޱȽж
// <q0.6> ADGDE_ޱȽDMAʹλ
//    0: ֹޱȽϴDMA
//    1: ʹޱȽϴDMA
// <q0.7> ADGIE_ޱȽжʹλ
//    0: ֹޱȽж
//    1: ʹޱȽж

//</h>

#define CFG_ADC2_ADCMPCON_INIT	0x0
//<h>ADDGT_ADCޱȽϼĴ
//<i>0x030 b31~16 b15~0 
//<i>ADDGT -      GT    
// <o0.0..15> GT_ADCޱȽϼĴ<0-65535>
//һתʱADCMPCONĴCSELλָĴֵADDGTеֵȽϣڵADDGTеֵADCMPCONеADGIFλ1ADGIFλΪ1ֱ
//</h>
#define CFG_ADC2_ADDGT_INIT	0x0

//<h>ADDLT_ADCޱȽϼĴ
//<i>0x034 b31~16 b15~0 
//<i>ADDLT -      LT    
// <o0.0..15> LT_ADCޱȽϼĴ<0-65535>
//һתʱADCMPCONĴCSELλָĴֵADDLTеֵȽϣСڵADDLTеֵADCMPCONеADLIFλ1ADLIFλΪ1ֱ 
//</h>
#define CFG_ADC2_ADDLT_INIT	0x0

//<h>SEQCHSEL_ADCͨѡĴ
//<i>0x038    b31~28 b27~24 b23~20 b19~16 b15~12 b11~8  b7~4   b3~0   
//<i>SEQCHSEL SEQCH7 SEQCH6 SEQCH5 SEQCH4 SEQCH3 SEQCH2 SEQCH1 SEQCH0 
// <o> SEQCH0_ģͨ0ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC2_SEQCH0 7

// <o> SEQCH1_ģͨ1ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC2_SEQCH1 7
// <o> SEQCH2_ģͨ2ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC2_SEQCH2 0
// <o0> SEQCH3_ģͨ3ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC2_SEQCH3 0
// <o> SEQCH4_ģͨ4ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC2_SEQCH4 0
// <o> SEQCH5_ģͨ5ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC2_SEQCH5 0
// <o> SEQCH6_ģͨ6ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC2_SEQCH6 0
// <o> SEQCH7_ģͨ7ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <12=>OP2OUT(ADC3ûдͨ)
//    <13=>OP3OUT(ADC2ûдͨ)
//    <15=>
#define CFG_ADC2_SEQCH7 0
//</h>

#define CFG_ADC2_SEQCHSEL_INIT	((uint32_t)(((uint32_t)CFG_ADC2_SEQCH7<<28)\
																|(CFG_ADC2_SEQCH6<<24)\
																|(CFG_ADC2_SEQCH5<<20)\
																|(CFG_ADC2_SEQCH4<<16)\
																|(CFG_ADC2_SEQCH3<<12)\
																|(CFG_ADC2_SEQCH2<<8)\
																|(CFG_ADC2_SEQCH1<<4)\
																|CFG_ADC2_SEQCH0))


//<h>ADGAPON_ADCͨGAPλ
//<i>0x03C   b31~8 b7     b6     b5     b4     b3     b2     b1     b0     
//<i>ADGAPON -     GAPEN7 GAPEN6 GAPEN5 GAPEN4 GAPEN3 GAPEN2 GAPEN1 GAPEN0 
// <q0.0> GAPEN0_ADCͨ0GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.1> GAPEN1_ADCͨ1GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.2> GAPEN2_ADCͨ2GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.3> GAPEN3_ADCͨ3GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.4> GAPEN4_ADCͨ4GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.5> GAPEN5_ADCͨ5GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.6> GAPEN6_ADCͨ6GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.7> GAPEN7_ADCͨ7GAPʱʹλ
//0: ֹ
//1: ʹ
//</h>
#define CFG_ADC2_ADGAPON_INIT	0x0
//</e>
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0x1)||(CFG_ADC2_SEQCH2 == 0x1)||(CFG_ADC2_SEQCH3 == 0x1)||(CFG_ADC2_SEQCH4 == 0x1)\
											||(CFG_ADC2_SEQCH5 == 0x1)||(CFG_ADC2_SEQCH6 == 0x1)||(CFG_ADC2_SEQCH7 == 0x1))\
									&& (CFG_PD8_AFR != 14))
#error "ADC2 AN1(PD8) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0x2)||(CFG_ADC2_SEQCH2 == 0x2)||(CFG_ADC2_SEQCH3 == 0x2)||(CFG_ADC2_SEQCH4 == 0x2)\
											||(CFG_ADC2_SEQCH5 == 0x2)||(CFG_ADC2_SEQCH6 == 0x2)||(CFG_ADC2_SEQCH7 == 0x2))\
									&& (CFG_PD0_AFR != 14))
#error "ADC2 AN2(PD0) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0x3)||(CFG_ADC2_SEQCH2 == 0x3)||(CFG_ADC2_SEQCH3 == 0x3)||(CFG_ADC2_SEQCH4 == 0x3)\
											||(CFG_ADC2_SEQCH5 == 0x3)||(CFG_ADC2_SEQCH6 == 0x3)||(CFG_ADC2_SEQCH7 == 0x3))\
									&& (CFG_PC15_AFR != 14))
#error "ADC2 AN3(PC15) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0x4)||(CFG_ADC2_SEQCH2 == 0x4)||(CFG_ADC2_SEQCH3 == 0x4)||(CFG_ADC2_SEQCH4 == 0x4)\
											||(CFG_ADC2_SEQCH5 == 0x4)||(CFG_ADC2_SEQCH6 == 0x4)||(CFG_ADC2_SEQCH7 == 0x4))\
									&& (CFG_PC14_AFR != 14))
#error "ADC2 AN4(PC14) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0x5)||(CFG_ADC2_SEQCH2 == 0x5)||(CFG_ADC2_SEQCH3 == 0x5)||(CFG_ADC2_SEQCH4 == 0x5)\
											||(CFG_ADC2_SEQCH5 == 0x5)||(CFG_ADC2_SEQCH6 == 0x5)||(CFG_ADC2_SEQCH7 == 0x5))\
									&& (CFG_PC13_AFR != 14))
#error "ADC2 AN5(PC13) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0x6)||(CFG_ADC2_SEQCH2 == 0x6)||(CFG_ADC2_SEQCH3 == 0x6)||(CFG_ADC2_SEQCH4 == 0x6)\
											||(CFG_ADC2_SEQCH5 == 0x6)||(CFG_ADC2_SEQCH6 == 0x6)||(CFG_ADC2_SEQCH7 == 0x6))\
									&& (CFG_PC12_AFR != 14))
#error "ADC2 AN6(PC12) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0x7)||(CFG_ADC2_SEQCH2 == 0x7)||(CFG_ADC2_SEQCH3 == 0x7)||(CFG_ADC2_SEQCH4 == 0x7)\
											||(CFG_ADC2_SEQCH5 == 0x7)||(CFG_ADC2_SEQCH6 == 0x7)||(CFG_ADC2_SEQCH7 == 0x7))\
									&& (CFG_PC11_AFR != 14))
#error "ADC2 AN7(PC11) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0x8)||(CFG_ADC2_SEQCH2 == 0x8)||(CFG_ADC2_SEQCH3 == 0x8)||(CFG_ADC2_SEQCH4 == 0x8)\
											||(CFG_ADC2_SEQCH5 == 0x8)||(CFG_ADC2_SEQCH6 == 0x8)||(CFG_ADC2_SEQCH7 == 0x8))\
									&& (CFG_PC10_AFR != 14))
#error "ADC2 AN8(PC10) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0x9)||(CFG_ADC2_SEQCH2 == 0x9)||(CFG_ADC2_SEQCH3 == 0x9)||(CFG_ADC2_SEQCH4 == 0x9)\
											||(CFG_ADC2_SEQCH5 == 0x9)||(CFG_ADC2_SEQCH6 == 0x9)||(CFG_ADC2_SEQCH7 == 0x9))\
									&& (CFG_PC9_AFR != 14))
#error "ADC2 AN9(PC9) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0xB )||(CFG_ADC2_SEQCH2 == 0xB)||(CFG_ADC2_SEQCH3 == 0xB)||(CFG_ADC2_SEQCH4 == 0xB)\
											||(CFG_ADC2_SEQCH5 == 0xB)||(CFG_ADC2_SEQCH6 == 0xB)||(CFG_ADC2_SEQCH7 == 0xB))\
									&& (CFG_PD4_AFR != 14))
#error "ADC2 OP1OUT(PD4) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0xC)||(CFG_ADC2_SEQCH2 == 0xC)||(CFG_ADC2_SEQCH3 == 0xC)||(CFG_ADC2_SEQCH4 == 0xC)\
											||(CFG_ADC2_SEQCH5 == 0xC)||(CFG_ADC2_SEQCH6 == 0xC)||(CFG_ADC2_SEQCH7 == 0xC))\
									&& (CFG_PD1_AFR != 14))
#error "ADC2OP2OUT(PD1) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC2_EN) \
									&& ((CFG_ADC2_SEQCH1 == 0xD)||(CFG_ADC2_SEQCH2 == 0xD)||(CFG_ADC2_SEQCH3 == 0xD)||(CFG_ADC2_SEQCH4 == 0xD)\
											||(CFG_ADC2_SEQCH5 == 0xD)||(CFG_ADC2_SEQCH6 == 0xD)||(CFG_ADC2_SEQCH7 == 0xD))\
									&& (CFG_PC15_AFR != 14))
#error "ADC2 OP3OUT(PC15) AF14 function mapping is not enable."
#endif

#if ((CFG_ADC_EN) && (CFG_ADC2_EN) && (CFG_ADC2_ADCON1_INIT & (1<<8) == (1<<8)) && ((CFG_PB3_AFR != 10)&&(CFG_PC5_AFR != 10)&&(CFG_PD7_AFR != 10)))
#error "ADTRG1(PB3/PC5/PD7) AF10 function mapping is not enable."
#endif

#if ((CFG_ADC_EN) && (CFG_ADC2_EN) && (CFG_ADC2_ADCON1_INIT & (2<<8) == (2<<8)) && ((CFG_PB4_AFR != 10)&&(CFG_PC6_AFR != 10)&&(CFG_PD6_AFR != 10)))
#error "ADTRG2(PB4/PC6/PD6) AF10 function mapping is not enable."
#endif

#if ((CFG_ADC_EN) && (CFG_ADC2_EN) && (CFG_ADC2_ADCON1_INIT & (4<<8) == (4<<8)) && ((CFG_PB5_AFR != 10)&&(CFG_PC7_AFR != 10)&&(CFG_PD5_AFR != 10)))
#error "ADTRG3(PB5/PC7/PD5) AF10 function mapping is not enable."
#endif

//***********************************************************/
//<e>ADC3
#define CFG_ADC3_EN 0
//<h>ADCON1_ADCƼĴ1
//<i>0x000  b31~16 b15  b14~8  b7   b6   b5~4 b3  b2~1  b0    
//<i>ADCON1 -      ADON ADSTRS ADIE ADDE REFC MOD ADCTU ADSOC 
// <o0.1..2> ADCTU_ADCͨеתʽλ
//    <0=>תʽ
//    <1=>תʽ
//    <2=>תʽ
//    <3=>
//    <i>޸ĸÿλһADתʱŲЧ
// <o0.3> MOD_ADCģʽѡλ
//    <0=>12bit
//    <1=>10bit
// <o0.4..5> REFC_׼ѹѡλ
//    <0=>ѡAVDDΪ׼ѹ
//    <1=>ѡⲿVREF˿Ϊ׼ѹ
//    <2=>ѡڽVREFΪ׼ѹ
//    <3=>
//<i>ΪڽVREFⲿVREFţ3ADCܼѡڽVREFѡVREF
// <q0.6> ADDE_ͨתDMAʹλ
//    0: ֹADCתDMA
//    1: ʹADCתDMA
// <q0.7> ADIE_ͨתжʹλ
//    0: ֹADCתж
//    1: ʹADCתж

// <q0.15> ADON_ADCλ
//    0: ֹADCxģ
//    1: ADCxģ

#define CFG_ADC3_ADCON1_VALUE 0x00

// <e> ADSTRS_ADCӲԴѡ(ֻ8ѡ1)
#define CFG_ADC3_ADCON1_ADSTRS 0x0
//<i>ADSTRS[6:0]
//<i>000 0000	ADSOC
//<i>------------------------------------------------	
//<i>000 0001	ⲿADTRG1
//<i>000 0010	ⲿADTRG2
//<i>000 0100	ⲿADTRG3
//<i>-------------------------------------------------	
//<i>001 0000	ʱ8BTIMTRG_ʱ8
//<i>-------------------------------------------------	
//<i>010 0001	MCM1	MCM1TRG1	MCM1. PWMCMP1Ƚƥ
//<i>010 0010		MCM1TRG2	MCM1. PWMCMP2Ƚƥ
//<i>010 0100		MCM1TRG3	MCM1. PWMCMP3Ƚƥ
//<i>010 1000		MCM1TRG4	MCM1. PWMCMP4Ƚƥ
//<i>-------------------------------------------------	
//<i>011 0001	MCM2	MCM1TRG1	MCM2. PWMCMP1Ƚƥ
//<i>011 0010		MCM1TRG2	MCM2. PWMCMP2Ƚƥ
//<i>011 0100		MCM1TRG3	MCM2. PWMCMP3Ƚƥ
//<i>011 1000		MCM1TRG4	MCM2. PWMCMP4Ƚƥ
//<i>-------------------------------------------------
//<i>100 0001	GPT0	GTADTRA0N	GPT0.GTADTRAȽƥ
//<i>100 0010		GTADTRB0N	GPT0.GTADTRBȽƥ
//<i>-------------------------------------------------
//<i>101 0001	GPT1	GTADTRA1N	GPT1.GTADTRAȽƥ
//<i>101 0010		GTADTRB1N	GPT1.GTADTRBȽƥ
//<i>-------------------------------------------------
//<i>110 0001	GPT2	GTADTRA2N	GPT2.GTADTRAȽƥ
//<i>110 0010		GTADTRB2N	GPT2.GTADTRBȽƥ
//<i>-------------------------------------------------
//<i>111 0001	GPT3	GTADTRA3N	GPT3.GTADTRAȽƥ
//<i>111 0010		GTADTRB3N	GPT3.GTADTRBȽƥ
//<e0>ⲿ
//    <q1.0>ADTRG1 1
//    <q1.1>ADTRG2 2
//    <q1.2>ADTRG3 3
//</e>
#define CFG_ADC3_ADTRG_EX_EN 0x0
#define CFG_ADC3_ADTRG_EX_VALUE 0x0


//<q>ʱ8BTIMTRG_ʱ8
#define CFG_ADC3_ADTRG_T8_EN 0x0

//<e0>MCM1
//    <q1.0>MCM1TRG1_MCM1.PWMCMP1Ƚƥ
//    <q1.1>MCM1TRG2_MCM1.PWMCMP2Ƚƥ
//    <q1.2>MCM1TRG3_MCM1.PWMCMP3Ƚƥ
//    <q1.3>MCM1TRG4_MCM1.PWMCMP4Ƚƥ
//</e>
#define CFG_ADC3_ADTRG_MCM1_EN 0x0
#define CFG_ADC3_ADTRG_MCM1_VALUE 0x0

//<e0>MCM2
//    <q1.0>MCM2TRG1_MCM2.PWMCMP1Ƚƥ
//    <q1.1>MCM2TRG2_MCM2.PWMCMP2Ƚƥ
//    <q1.2>MCM2TRG3_MCM2.PWMCMP3Ƚƥ
//    <q1.3>MCM2TRG4_MCM2.PWMCMP4Ƚƥ
//</e>
#define CFG_ADC3_ADTRG_MCM2_EN 0x0
#define CFG_ADC3_ADTRG_MCM2_VALUE 0x0

//<e0>GPT0
//    <q1.0>GTADTRA0N_GPT0.GTADTRA ıȽƥ
//    <q1.1>GTADTRB0N_GPT0.GTADTRB ıȽƥ
//</e>
#define CFG_ADC3_ADTRG_GPT0_EN 0x0
#define CFG_ADC3_ADTRG_GPT0_VALUE 0x0

//<e0>GPT1
//    <q1.0>GTADTRA1N_GPT1.GTADTRA ıȽƥ
//    <q1.1>GTADTRB1N_GPT1.GTADTRB ıȽƥ
//</e>
#define CFG_ADC3_ADTRG_GPT1_EN 0x0
#define CFG_ADC3_ADTRG_GPT1_VALUE 0x0

//<e0>GPT2
//    <q1.0>GTADTRA2N_GPT2.GTADTRA ıȽƥ
//    <q1.1>GTADTRB2N_GPT2.GTADTRB ıȽƥ
//</e>
#define CFG_ADC3_ADTRG_GPT2_EN 0x0
#define CFG_ADC3_ADTRG_GPT2_VALUE 0x0

//<e0>GPT3
//    <q1.0>GTADTRA3N_GPT3.GTADTRA ıȽƥ
//    <q1.1>GTADTRB3N_GPT3.GTADTRB ıȽƥ
//</e>
#define CFG_ADC3_ADTRG_GPT3_EN 0x0
#define CFG_ADC3_ADTRG_GPT3_VALUE 0x0
//</e>

#if ((CFG_ADC3_ADCON1_ADSTRS) && (CFG_ADC3_EN) \
									&&((CFG_ADC3_ADTRG_EX_EN && (CFG_ADC3_ADTRG_T8_EN || CFG_ADC3_ADTRG_MCM1_EN || CFG_ADC3_ADTRG_MCM2_EN || CFG_ADC3_ADTRG_GPT0_EN || CFG_ADC3_ADTRG_GPT1_EN || CFG_ADC3_ADTRG_GPT2_EN || CFG_ADC3_ADTRG_GPT3_EN ))\
									||(CFG_ADC3_ADTRG_T8_EN &&  (CFG_ADC3_ADTRG_EX_EN || CFG_ADC3_ADTRG_MCM1_EN || CFG_ADC3_ADTRG_MCM2_EN || CFG_ADC3_ADTRG_GPT0_EN || CFG_ADC3_ADTRG_GPT1_EN || CFG_ADC3_ADTRG_GPT2_EN || CFG_ADC3_ADTRG_GPT3_EN))\
									||(CFG_ADC3_ADTRG_MCM1_EN && (CFG_ADC3_ADTRG_EX_EN || CFG_ADC3_ADTRG_T8_EN || CFG_ADC3_ADTRG_MCM2_EN || CFG_ADC3_ADTRG_GPT0_EN || CFG_ADC3_ADTRG_GPT1_EN || CFG_ADC3_ADTRG_GPT2_EN || CFG_ADC3_ADTRG_GPT3_EN))\
									||(CFG_ADC3_ADTRG_MCM2_EN && (CFG_ADC3_ADTRG_EX_EN || CFG_ADC3_ADTRG_T8_EN || CFG_ADC3_ADTRG_MCM1_EN || CFG_ADC3_ADTRG_GPT0_EN || CFG_ADC3_ADTRG_GPT1_EN || CFG_ADC3_ADTRG_GPT2_EN || CFG_ADC3_ADTRG_GPT3_EN))\
									||(CFG_ADC3_ADTRG_GPT0_EN && (CFG_ADC3_ADTRG_EX_EN || CFG_ADC3_ADTRG_T8_EN || CFG_ADC3_ADTRG_MCM1_EN || CFG_ADC3_ADTRG_MCM2_EN || CFG_ADC3_ADTRG_GPT1_EN || CFG_ADC3_ADTRG_GPT2_EN || CFG_ADC3_ADTRG_GPT3_EN))\
									||(CFG_ADC3_ADTRG_GPT1_EN && (CFG_ADC3_ADTRG_EX_EN || CFG_ADC3_ADTRG_T8_EN || CFG_ADC3_ADTRG_MCM1_EN || CFG_ADC3_ADTRG_MCM2_EN || CFG_ADC3_ADTRG_GPT0_EN || CFG_ADC3_ADTRG_GPT2_EN || CFG_ADC3_ADTRG_GPT3_EN))\
									||(CFG_ADC3_ADTRG_GPT2_EN && (CFG_ADC3_ADTRG_EX_EN || CFG_ADC3_ADTRG_T8_EN || CFG_ADC3_ADTRG_MCM1_EN || CFG_ADC3_ADTRG_MCM2_EN || CFG_ADC3_ADTRG_GPT0_EN || CFG_ADC3_ADTRG_GPT1_EN || CFG_ADC3_ADTRG_GPT3_EN))\
									||(CFG_ADC3_ADTRG_GPT3_EN && (CFG_ADC3_ADTRG_EX_EN || CFG_ADC3_ADTRG_T8_EN || CFG_ADC3_ADTRG_MCM1_EN || CFG_ADC3_ADTRG_MCM2_EN || CFG_ADC3_ADTRG_GPT0_EN || CFG_ADC3_ADTRG_GPT1_EN || CFG_ADC3_ADTRG_GPT2_EN)))\
									)
#error "ADC3ӲԴѡֻѡӲԴеһ֣"
#endif

#if (CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_EX_EN && (CFG_ADC3_ADTRG_EX_VALUE==0))
#error "ADC3ΪӲԴתδⲿţ"
#endif

#if (CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_MCM1_EN && (CFG_ADC3_ADTRG_MCM1_VALUE==0))
#error "ADC3ΪMCM1ӲԴתδþ崥"
#endif

#if (CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_MCM2_EN && (CFG_ADC3_ADTRG_MCM2_VALUE==0))
#error "ADC3ΪMCM2ӲԴתδþ崥"
#endif

#if (CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_GPT0_EN && (CFG_ADC3_ADTRG_GPT0_VALUE==0))
#error "ADC3ΪGPT0ӲԴתδþ崥"
#endif

#if (CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_GPT1_EN && (CFG_ADC3_ADTRG_GPT1_VALUE==0))
#error "ADC3ΪGPT1ӲԴתδþ崥"
#endif

#if (CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_GPT2_EN && (CFG_ADC3_ADTRG_GPT2_VALUE==0))
#error "ADC3ΪGPT2ӲԴתδþ崥"
#endif

#if (CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_GPT3_EN && (CFG_ADC3_ADTRG_GPT3_VALUE==0))
#error "ADC3ΪGPT3ӲԴתδþ崥"
#endif

#if(CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_EX_EN)
#define CFG_ADC3_ADCON1_INIT ((CFG_ADC3_ADCON1_VALUE & 0x80FF) | (CFG_ADC3_ADTRG_EX_VALUE<<8))
#elif(CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_T8_EN)
#define CFG_ADC3_ADCON1_INIT ((CFG_ADC3_ADCON1_VALUE & 0x80FF) | (1<<12))
#elif(CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_MCM1_EN)
#define CFG_ADC3_ADCON1_INIT ((CFG_ADC3_ADCON1_VALUE & 0x80FF) |(2<<12)|(CFG_ADC3_ADTRG_MCM1_VALUE<<8))
#elif(CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_MCM2_EN)
#define CFG_ADC3_ADCON1_INIT ((CFG_ADC3_ADCON1_VALUE & 0x80FF) |(3<<12)|(CFG_ADC3_ADTRG_MCM2_VALUE<<8))
#elif(CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_GPT0_EN)
#define CFG_ADC3_ADCON1_INIT ((CFG_ADC3_ADCON1_VALUE & 0x80FF) |(4<<12)|(CFG_ADC3_ADTRG_GPT0_VALUE<<8))
#elif(CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_GPT1_EN)
#define CFG_ADC3_ADCON1_INIT ((CFG_ADC3_ADCON1_VALUE & 0x80FF) |(5<<12)|(CFG_ADC3_ADTRG_GPT1_VALUE<<8))
#elif(CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_GPT2_EN)
#define CFG_ADC3_ADCON1_INIT ((CFG_ADC3_ADCON1_VALUE & 0x80FF) |(6<<12)|(CFG_ADC3_ADTRG_GPT2_VALUE<<8))
#elif(CFG_ADC3_ADCON1_ADSTRS && CFG_ADC3_EN && CFG_ADC3_ADTRG_GPT3_EN)
#define CFG_ADC3_ADCON1_INIT ((CFG_ADC3_ADCON1_VALUE & 0x80FF) |(7<<12)|(CFG_ADC3_ADTRG_GPT3_VALUE<<8))
#else
#define CFG_ADC3_ADCON1_INIT (CFG_ADC3_ADCON1_VALUE & 0x80FF)
#endif
//</h>


#if ((CFG_ADC3_ADCON1_INIT & (1<<7)) != 0)
	#define CFG_ADC3_INT_EN 1
#else
	#define CFG_ADC3_INT_EN 0
#endif

//<h>ADCON2_ADCƼĴ2
//<i>0x004  b31~19 b18~16 b15~12 b11~8 b7 b6~4    b3~0 
//<i>ADCON2 -      TGAP   -      TS    -  ADMAXCH TADC 
// <o0.0..3> TADC_ADCʱѡ
//    <0=>ADCʱtAD = 1 tHCLK
//    <1=>ADCʱtAD = 2 tHCLK
//    <2=>ADCʱtAD = 3 tHCLK
//    <3=>ADCʱtAD = 4 tHCLK
//    <4=>ADCʱtAD = 5 tHCLK
//    <5=>ADCʱtAD = 6 tHCLK
//    <6=>ADCʱtAD = 8 tHCLK
//    <7=>ADCʱtAD = 12 tHCLK
//    <8=>ADCʱtAD = 16 tHCLK
//    <9=>ADCʱtAD = 24 tHCLK
//    <10=>ADCʱtAD = 32 tHCLK
//    <11=>ADCʱtAD = 48 tHCLK
//    <12=>ADCʱtAD = 64 tHCLK
//    <13=>ADCʱtAD = 128 tHCLK
//    <14=>ADCʱtAD = 256 tHCLK
//    <15=>ADCʱtAD = 320 tHCLK
//    <i>tHCLKΪHCLKʱ
// <o0.4..6> ADMAXCH_һADת̵ģͨ
//<0=>1
//<1=>2
//<2=>3
//<3=>4
//<4=>5
//<5=>6
//<6=>7
//<7=>8
//    <i>һADת̵ģͨΪADMAxCH1+1
// <o0.8..11> TS _ʱ
//<0=>1ADCʱ
//<1=>2ADCʱ
//<2=>3ADCʱ
//<3=>4ADCʱ
//<4=>5ADCʱ
//<5=>6ADCʱ
//<6=>7ADCʱ
//<7=>8ADCʱ
//<8=>9ADCʱ
//<9=>10ADCʱ
//<10=>11ADCʱ
//<11=>12ADCʱ
//<12=>13ADCʱ
//<13=>14ADCʱ
//<14=>15ADCʱ
//<15=>16ADCʱ
//<i>1 tAD   (TS [3-0]+1) * tAD  16 tAD
//<i>һͨܲʱ:TS + TGAP ˴TS֣
//<i>ܲʱ䷶Χ:1 tAD  ((TS[3~0])+1+TGAP[2~0]*GAPEN)* tAD  144 tAD TGAPGAPENǷʹܣ
//<i>TS[3:0]ǰӵADCŵĴ裬ԻѲȣѡ1 * tADΪʱʱȷӵADCŵĴ迹21.3.10
//<i>TADC豣֤ADCʱ Tadc  25ns
//<i>12bitģʽһܹͨתʱ = 15tAD + ʱ䣻10bitģʽһܹͨתʱ = 13tAD + ʱ
// <o0.16..18> TGAP _ʱ֮ͨʱλ
//<i>һתУһͨתϵһͨʼ֮ʱ
//<0=>޵ȴʱ
//<1=>2ADCʱ
//<2=>4ADCʱ
//<3=>8ADCʱ
//<4=>16ADCʱ
//<5=>32ADCʱ
//<6=>64ADCʱ
//<7=>128ADCʱ
//</h>
#define CFG_ADC3_ADCON2_INIT	0x0

//<h>ADCMPCON_ADCȽϿƼĴ
//<i>0x02C    b31~8 b7    b6    b5    b4    b3 b2~0 
//<i>ADCMPCON -     ADGIE ADGDE ADLIE ADLDE -  CSEL 
// <o0.0..2> CSEL_ڱȽϵĽĴѡλ
//    <0=>ѡADDR0еֵADDGTADDLTȽ
//    <1=>ѡADDR1еֵADDGTADDLTȽ
//    <2=>ѡADDR2еֵADDGTADDLTȽ
//    <3=>ѡADDR3еֵADDGTADDLTȽ
//    <4=>ѡADDR4еֵADDGTADDLTȽ
//    <5=>ѡADDR5еֵADDGTADDLTȽ
//    <6=>ѡADDR6еֵADDGTADDLTȽ
//    <7=>ѡADDR7еֵADDGTADDLTȽ
// <q0.4> ADLDE_ޱȽDMAʹλ
//    0: ֹޱȽDMA
//    1: ʹޱȽDMA
// <q0.5> ADLIE_ޱȽжʹλ
//    0: ֹޱȽж
//    1: ʹޱȽж
// <q0.6> ADGDE_ޱȽDMAʹλ
//    0: ֹޱȽϴDMA
//    1: ʹޱȽϴDMA
// <q0.7> ADGIE_ޱȽжʹλ
//    0: ֹޱȽж
//    1: ʹޱȽж
//</h>
#define CFG_ADC3_ADCMPCON_INIT	0x0

//<h>ADDGT_ADCޱȽϼĴ
//<i>0x030 b31~16 b15~0 
//<i>ADDGT -      GT    
// <o0.0..15> GT_ADCޱȽϼĴ<0-65535>
//һתʱADCMPCONĴCSELλָĴֵADDGTеֵȽϣڵADDGTеֵADCMPCONеADGIFλ1ADGIFλΪ1ֱ 
//</h>
#define CFG_ADC3_ADDGT_INIT	0x0

//<h>ADDLT_ADCޱȽϼĴ
//<i>0x034 b31~16 b15~0 
//<i>ADDLT -      LT    
// <o0.0..15> LT_ADCޱȽϼĴ<0-65535>
//һתʱADCMPCONĴCSELλָĴֵADDLTеֵȽϣСڵADDLTеֵADCMPCONеADLIFλ1ADLIFλΪ1ֱ 
//</h>
#define CFG_ADC3_ADDLT_INIT	0x0

//<h>SEQCHSEL_ADCͨѡĴ
//<i>0x038    b31~28 b27~24 b23~20 b19~16 b15~12 b11~8  b7~4   b3~0   
//<i>SEQCHSEL SEQCH7 SEQCH6 SEQCH5 SEQCH4 SEQCH3 SEQCH2 SEQCH1 SEQCH0 
// <o> SEQCH0_ģͨ0ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <13=>OP3OUT
//    <14=>TPS(¶ȴ)
//    <15=>
#define CFG_ADC3_SEQCH0 0

// <o> SEQCH1_ģͨ1ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <13=>OP3OUT
//    <14=>TPS(¶ȴ)
//    <15=>
#define CFG_ADC3_SEQCH1 0
// <o> SEQCH2_ģͨ2ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <13=>OP3OUT
//    <14=>TPS(¶ȴ)
//    <15=>
#define CFG_ADC3_SEQCH2 0
// <o0> SEQCH3_ģͨ3ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <13=>OP3OUT
//    <14=>TPS(¶ȴ)
//    <15=>
#define CFG_ADC3_SEQCH3 0
// <o> SEQCH4_ģͨ4ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <13=>OP3OUT
//    <14=>TPS(¶ȴ)
//    <15=>
#define CFG_ADC3_SEQCH4 0
// <o> SEQCH5_ģͨ5ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <13=>OP3OUT(ADC2ûдͨ)
//    <14=>TPS(¶ȴ)
//    <15=>
#define CFG_ADC3_SEQCH5 0
// <o> SEQCH6_ģͨ6ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <13=>OP3OUT
//    <14=>TPS(¶ȴ)
//    <15=>
#define CFG_ADC3_SEQCH6 0
// <o> SEQCH7_ģͨ7ѡӦģͨ
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8(ADC1ûдͨ)
//    <9=>AN9(ADC1ûдͨ)
//    <10=>Vref
//    <11=>OP1OUT
//    <13=>OP3OUT
//    <14=>TPS(¶ȴ)
//    <15=>
#define CFG_ADC3_SEQCH7 0
//</h>

#define CFG_ADC3_SEQCHSEL_INIT	(((uint32_t)CFG_ADC3_SEQCH7<<28)\
																|(CFG_ADC3_SEQCH6<<24)\
																|(CFG_ADC3_SEQCH5<<20)\
																|(CFG_ADC3_SEQCH4<<16)\
																|(CFG_ADC3_SEQCH3<<12)\
																|(CFG_ADC3_SEQCH2<<8)\
																|(CFG_ADC3_SEQCH1<<4)\
																|CFG_ADC3_SEQCH0)

//<h>ADGAPON_ADCͨGAPλ
//<i>0x03C   b31~8 b7     b6     b5     b4     b3     b2     b1     b0     
//<i>ADGAPON -     GAPEN7 GAPEN6 GAPEN5 GAPEN4 GAPEN3 GAPEN2 GAPEN1 GAPEN0 
// <q0.0> GAPEN0_ADCͨ0GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.1> GAPEN1_ADCͨ1GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.2> GAPEN2_ADCͨ2GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.3> GAPEN3_ADCͨ3GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.4> GAPEN4_ADCͨ4GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.5> GAPEN5_ADCͨ5GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.6> GAPEN6_ADCͨ6GAPʱʹλ
//0: ֹ
//1: ʹ
// <q0.7> GAPEN7_ADCͨ7GAPʱʹλ
//0: ֹ
//1: ʹ

//</h>

#define CFG_ADC3_ADGAPON_INIT	0x0
//</e>
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0x1)||(CFG_ADC3_SEQCH2 == 0x1)||(CFG_ADC3_SEQCH3 == 0x1)||(CFG_ADC3_SEQCH4 == 0x1)\
											||(CFG_ADC3_SEQCH5 == 0x1)||(CFG_ADC3_SEQCH6 == 0x1)||(CFG_ADC3_SEQCH7 == 0x1))\
									&& (CFG_PE0_AFR != 14))
#error "ADC3 AN1(PE0) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0x2)||(CFG_ADC3_SEQCH2 == 0x2)||(CFG_ADC3_SEQCH3 == 0x2)||(CFG_ADC3_SEQCH4 == 0x2)\
											||(CFG_ADC3_SEQCH5 == 0x2)||(CFG_ADC3_SEQCH6 == 0x2)||(CFG_ADC3_SEQCH7 == 0x2))\
									&& (CFG_PE1_AFR != 14))
#error "ADC3 AN2(PE1) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0x3)||(CFG_ADC3_SEQCH2 == 0x3)||(CFG_ADC3_SEQCH3 == 0x3)||(CFG_ADC3_SEQCH4 == 0x3)\
											||(CFG_ADC3_SEQCH5 == 0x3)||(CFG_ADC3_SEQCH6 == 0x3)||(CFG_ADC3_SEQCH7 == 0x3))\
									&& (CFG_PE2_AFR != 14))
#error "ADC3 AN3(PE2) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0x4)||(CFG_ADC3_SEQCH2 == 0x4)||(CFG_ADC3_SEQCH3 == 0x4)||(CFG_ADC3_SEQCH4 == 0x4)\
											||(CFG_ADC3_SEQCH5 == 0x4)||(CFG_ADC3_SEQCH6 == 0x4)||(CFG_ADC3_SEQCH7 == 0x4))\
									&& (CFG_PC5_AFR != 14))
#error "ADC3 AN4(PC5) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0x5)||(CFG_ADC3_SEQCH2 == 0x5)||(CFG_ADC3_SEQCH3 == 0x5)||(CFG_ADC3_SEQCH4 == 0x5)\
											||(CFG_ADC3_SEQCH5 == 0x5)||(CFG_ADC3_SEQCH6 == 0x5)||(CFG_ADC3_SEQCH7 == 0x5))\
									&& (CFG_PC6_AFR != 14))
#error "ADC3 AN5(PC6) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0x6)||(CFG_ADC3_SEQCH2 == 0x6)||(CFG_ADC3_SEQCH3 == 0x6)||(CFG_ADC3_SEQCH4 == 0x6)\
											||(CFG_ADC3_SEQCH5 == 0x6)||(CFG_ADC3_SEQCH6 == 0x6)||(CFG_ADC3_SEQCH7 == 0x6))\
									&& (CFG_PC7_AFR != 14))
#error "ADC3 AN6(PC7) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0x7)||(CFG_ADC3_SEQCH2 == 0x7)||(CFG_ADC3_SEQCH3 == 0x7)||(CFG_ADC3_SEQCH4 == 0x7)\
											||(CFG_ADC3_SEQCH5 == 0x7)||(CFG_ADC3_SEQCH6 == 0x7)||(CFG_ADC3_SEQCH7 == 0x7))\
									&& (CFG_PC8_AFR != 14))
#error "ADC3 AN7(PC8) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0x8)||(CFG_ADC3_SEQCH2 == 0x8)||(CFG_ADC3_SEQCH3 == 0x8)||(CFG_ADC3_SEQCH4 == 0x8)\
											||(CFG_ADC3_SEQCH5 == 0x8)||(CFG_ADC3_SEQCH6 == 0x8)||(CFG_ADC3_SEQCH7 == 0x8))\
									&& (CFG_PC10_AFR != 14))
#error "ADC3 AN8(PC10) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0x9)||(CFG_ADC3_SEQCH2 == 0x9)||(CFG_ADC3_SEQCH3 == 0x9)||(CFG_ADC3_SEQCH4 == 0x9)\
											||(CFG_ADC3_SEQCH5 == 0x9)||(CFG_ADC3_SEQCH6 == 0x9)||(CFG_ADC3_SEQCH7 == 0x9))\
									&& (CFG_PC9_AFR != 14))
#error "ADC3 AN9(PC9) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0xB )||(CFG_ADC3_SEQCH2 == 0xB)||(CFG_ADC3_SEQCH3 == 0xB)||(CFG_ADC3_SEQCH4 == 0xB)\
											||(CFG_ADC3_SEQCH5 == 0xB)||(CFG_ADC3_SEQCH6 == 0xB)||(CFG_ADC3_SEQCH7 == 0xB))\
									&& (CFG_PD4_AFR != 14))
#error "ADC3 OP1OUT(PD4) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0xC)||(CFG_ADC3_SEQCH2 == 0xC)||(CFG_ADC3_SEQCH3 == 0xC)||(CFG_ADC3_SEQCH4 == 0xC)\
											||(CFG_ADC3_SEQCH5 == 0xC)||(CFG_ADC3_SEQCH6 == 0xC)||(CFG_ADC3_SEQCH7 == 0xC))\
									&& (CFG_PD1_AFR != 14))
#error "ADC3 OP2OUT(PD1) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) \
									&& ((CFG_ADC3_SEQCH1 == 0xD)||(CFG_ADC3_SEQCH2 == 0xD)||(CFG_ADC3_SEQCH3 == 0xD)||(CFG_ADC3_SEQCH4 == 0xD)\
											||(CFG_ADC3_SEQCH5 == 0xD)||(CFG_ADC3_SEQCH6 == 0xD)||(CFG_ADC3_SEQCH7 == 0xD))\
									&& (CFG_PC15_AFR != 14))
#error "ADC3 OP3OUT(PC15) AF14 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC3_EN) && (CFG_ADC3_ADCON1_INIT & (1<<8) == (1<<8)) && ((CFG_PB3_AFR != 10)&&(CFG_PC5_AFR != 10)&&(CFG_PD7_AFR != 10)))
#error "ADTRG1(PB3/PC5/PD7) AF10 function mapping is not enable."
#endif

#if ((CFG_ADC_EN) && (CFG_ADC3_EN) && (CFG_ADC3_ADCON1_INIT & (2<<8) == (2<<8)) && ((CFG_PB4_AFR != 10)&&(CFG_PC6_AFR != 10)&&(CFG_PD6_AFR != 10)))
#error "ADTRG2(PB4/PC6/PD6) AF10 function mapping is not enable."
#endif

#if ((CFG_ADC_EN) && (CFG_ADC3_EN) && (CFG_ADC3_ADCON1_INIT & (4<<8) == (4<<8)) && ((CFG_PB5_AFR != 10)&&(CFG_PC7_AFR != 10)&&(CFG_PD5_AFR != 10)))
#error "ADTRG3(PB5/PC7/PD5) AF10 function mapping is not enable."
#endif
//***********************************************************/
//</e>




//<e>QEI
#define CFG_QEI_EN 0
//<h>QEICON_QEIƼĴ
//<i>0x000  b31~12 b11~8 b7    b6    b5    b4     b3    b2   b1~0  
//<i>QEICON -      QTEPS QPDIR QIDXS QSWAP QIDXEN QEIEN QTSR QPMOD 
// <o0.0..1> QPMOD_QEIλüѡλ
//    <0=>x2ģʽʹINDExλλü
//    <1=>x2ģʽλü0~QPOSMAxԶѭ
//    <2=>x4ģʽʹINDExλλü
//    <3=>x4ģʽλü0~QPOSMAxԶѭ
//<i>QEIܴʱЧ
// <q0.2> QTSR_QEIʱλ
//    0: Qtimer
//    1: Qtimer
//<i>λΪQEIENΪ0ʱQtimerǷĿλQEIENΪ1ʱλЧ
// <o0.3> QEIEN_QEIʹܿλ
//    <0=>QEIܹر
//    <1=>QEIܴ򿪣幤ģʽQPMOD
// <o0.4> QIDXEN_λüλʹλ
//    <0=>INDExܸλλü
//    <1=>INDExԸλλü
//<i>QPMOD=00/10ʱЧ
// <o0.5> QSWAP_QEAQEB뽻ѡλ
//    <0=>QEAQEBδֱṩ
//    <1=>QEAQEBṩ
// <o0.8..11> QTEPS_QEI(QTimer)׽¼Ƶλ 
//    <0=>QCLK/1
//    <1=>QCLK/2
//    <2=>QCLK/4
//    <3=>QCLK/8
//    <4=>QCLK/16
//    <5=>QCLK/32
//    <6=>QCLK/64
//    <7=>QCLK/128
//    <8=>QCLK/256
//    <9=>QCLK/512
//    <10=>QCLK/1024
//    <11=>QCLK/2048
//    Others:
//<i>QEIܴʱЧ
//</h>
#define CFG_QEI_QEICON_INIT	0x000

//<h>QFLTCON_QEI˲ƼĴ
//<i>0x004   b31~8 b7      b6~4    b3     b2~0   
//<i>QFLTCON -     QIDXFEN QIDXCPS QABFEN QABCPS 
// <o0.0..2> QABCPS_QEAQEB˲ʱӷƵϵ
//    <0=>1/1 PCLK1
//    <1=>1/2 PCLK1
//    <2=>1/4 PCLK1
//    <3=>1/16 PCLK1
//    <4=>1/32 PCLK1
//    <5=>1/64 PCLK1
//    <6=>1/128 PCLK1
//    <7=>1/256 PCLK1
// <q0.3> QABFEN_QEAQEB˲ʹλ
//    0: ֹQEAQEBŵ˲
//    1: ʹQEAQEBŵ˲
// <o0.4..6> QIDXCPS_INDEx˲ʱӷƵϵ
//    <0=>1/1 PCLK1
//    <1=>1/2 PCLK1
//    <2=>1/4 PCLK1
//    <3=>1/16 PCLK1
//    <4=>1/32 PCLK1
//    <5=>1/64 PCLK1
//    <6=>1/128 PCLK1
//    <7=>1/256 PCLK1
// <q0.7> QIDXFEN_INDEx˲ʹλ
//    0: ֹINDExŵ˲
//    1: ʹINDExŵ˲
//</h>
#define CFG_QEI_QFLTCON_INIT	0x00

//<h>QPOSMAX_QEIֵĴ
//<i>0x00C   b31~16 b15~0   
//<i>QPOSMAX -      QPOSMAX 
// <o0.0..15> QPOSMAX_λüֵĴ <0-65535>
//</h>
#define CFG_QEI_QPOSMAX_INIT	0x00

//<h>QCNTMIN_QEIڲ׽ʱСֵ
//<i>0x018   b31~16 b15~0   
//<i>QCNTMIN -      QCNTMIN 
// <o0.0..15> QCNTMIN_׽¼ʱQCNTֵСQCNTMINĴֵ˴β׽¼<0-65535>
//<i>ͬʱڲĲ׽Ƶ1ֱ׽QCNTֵQCNTMINѷƵʹʱQCNTԶ浽QTMLATС 
//</h>

#define CFG_QEI_QCNTMIN_INIT	0x0
//<h>QTPR_QEIڼĴ
//<i>0x01C b31~0 
//<i>QTPR  QTPR  
// <o0.0..31> QTPR _32bitڼĴ

//</h>

#define CFG_QEI_QTPR_INIT	0x0000
//<h>QTPSQ_QEIڲ׽ʱСֵ
//<i>0x020 b31~16 b15~0 
//<i>QTPSQ -      QTPSQ 
// <o0.0..15> QTPSQ_ʱķƵֵ <0-65535>

//</h>

#define CFG_QEI_QTPSQ_INIT	0x0000
//<h>QEIINT_QEIжϺ״̬Ĵ
//<i>0x024  b31~10 b9   b8      b7    b6    b5    b4   b3      b2    b1    b0    
//<i>QEIINT -      QTDE QTCAPDE QEIDE QCEDE QPEDE QTIE QTCAPIE QEIIE QCEIE QPEIE 
// <q0.0> QPEIE_λжʹλ
//    0: ֹλж
//    1: ʹλж
//<i>QEA/QEBźͬʱΪλ
// <q0.1> QCEIE_INDExźŸλλüģʽ£жʹλ
//    0: ֹж
//    1: ʹܴж
// <q0.2> QEIIE_QEIжʹλ
//    0: ֹQEIж
//    1: ʹQEIж
// <q0.3> QTCAPIE_QTimer׽¼жʹλ
//    0: ֹ׽¼ʱж
//    1: ׽¼ʱж
//<i>QEIܴʱЧ
// <q0.4> QTIE_Qtimerжʹλ
//    0: ֹQtimer¼ʱж
//    1: Qtimer¼ʱж
// <q0.5> QPEDE_λ󴥷DMAʹλ
//    0: ֹλ󴥷DMA
//    1: ʹλ󴥷DMA
//<i>QEA/QEBźͬʱΪλ
// <q0.6> QCEDE_INDExźŸλλüģʽ£ⴥDMAʹλ
//    0: ֹⴥDMA
//    1: ʹܴⴥDMA
// <q0.7> QEIDE_QEIܴDMAʹλ
//    0: ֹQEIDMAж
//    1: ʹQEIDMAж
// <q0.8> QTCAPDE_QTimer׽¼DMAʹλ
//    0: ֹ׽¼ʱDMA
//    1: ׽¼ʱDMA
//<i>QEIܴʱЧ
// <q0.9> QTDE_QtimerDMAʹλ
//    0: ֹ¼ʱDMA
//    1: ¼ʱDMA

//</h>

#define CFG_QEI_QEIINT_INIT	0x00

#if ((CFG_QEI_QEIINT_INIT & 0x1F) != 0)
	#define CFG_QEI_INT_EN 1
#else
	#define CFG_QEI_INT_EN 0
#endif
//***********************************************************/
//</e>
#if ((CFG_QEI_EN) && (CFG_QEI_QEICON_INIT & (1<<3)) && ((CFG_PA7_AFR != 6)&&(CFG_PC5_AFR != 6)&&(CFG_PE0_AFR != 6)))
#error "QEI QEA(PA7/PC5/PE0) AF6 function mapping is not enable."
#endif

#if ((CFG_QEI_EN) && (CFG_QEI_QEICON_INIT & (1<<3)) && ((CFG_PA8_AFR != 6)&&(CFG_PC6_AFR != 6)&&(CFG_PE1_AFR != 6)))
#error "QEI QEB(PA8/PC6/PE1) AF6 function mapping is not enable."
#endif

#if ((CFG_QEI_EN) && (CFG_QEI_QEICON_INIT & (1<<3)) && ((CFG_PA9_AFR != 6)&&(CFG_PC7_AFR != 6)&&(CFG_PE2_AFR != 6)))
#error "QEI INDEX(PA9/PC7/PE2) AF6 function mapping is not enable."
#endif

//<e>AMOC
#define CFG_AMOC_EN 0
//<h>CMP1CON_Ƚ1ƼĴ
//<i>0x000   b31~20 b19      b18~16  b15  b14~13 b12 b11     b10   b9~8  b7     b6     b5 b4~3   b2~0  
//<i>CMP1CON -      CMP1VCMP CMP1VRS C1DE C1IES  -   C1OUTEN C1OUT C1SMT CMP1EN C1NCHS -  C1PCHS C1DEB 
// <o0.0..2> CP1DEB_Ƚ1ź˲ʱ
//    <0=>˲
//    <1=>˲ʱ䳣Ϊ0.5us
//    <2=>˲ʱ䳣Ϊ1us
//    <3=>˲ʱ䳣Ϊ2us
//    <4=>˲ʱ䳣Ϊ4us
//    <5=>˲ʱ䳣Ϊ8us
//    <6=>˲ʱ䳣Ϊ12us
//    <7=>˲ʱ䳣Ϊ16us
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.3..4> CP1PCHS_Ƚ1ͬѡλ
//    <0=>ѡOP1OUTΪȽ1ͬ
//    <1=>ѡCP1P1ΪȽ1ͬ
//    <2=>
//    <3=>
// <o0.6> CP1NCHS_Ƚ1ѡλ
//    <0=>ѡCP1NΪȽ1
//    <1=>ѡڲοCMP1VRSΪȽ1
//    <i>õڲVREFǰ100us׼Դ򿪣Ĵ[AGCON:VREFEN]λ1
// <q0.7> CMP1EN_Ƚ1ʹܿλ
//    0: Ƚ1ر
//    1: Ƚ1
// <o0.8..9> C1SMT_Ƚ1ʩصѹѡλ
//    <0=>ûʩش
//    <1=>ʩشΪ10mv
//    <2=>ʩشΪ20mv
//    <3=>ʩشΪ50mv
// <o0.11> C1OUTEN_Ƚ1I/Oʹ
//    <0=>ͨȽ1CP1OUTCP1OUTΪͨIO
//    <1=>ͨȽ1CP1OUT
//   <i>I/OǴ˲ܵģ˲ΪC1DEB[2:0]趨ֵ
// <o0.13..14> C1IES_Ƚ1жģʽѡλ
//    <0=>жϱ־
//    <1=>½شȽ1ɸ߱ʱжϱ־
//    <2=>شȽ1ɵͱʱжϱ־
//    <3=>˫شȽ2ɸ߱ʱɵͱʱжϱ־
// <o0.15> C1DE_Ƚ1DMAʹλ
//    <0=>жϱ־λʱDMA
//    <1=>жϱ־λʱDMA
//    <i>жϱ־λʽC1IES[<1=>0]
// <o0.16..18> CMP1VRS_Ƚ1˲οѹѡλ
//    <0=>Vcmp
//    <1=>1Vcmp / 8
//    <2=>2Vcmp / 8
//    <3=>3Vcmp / 8
//    <4=>4Vcmp / 8
//    <5=>5Vcmp / 8
//    <6=>6Vcmp / 8
//    <7=>7Vcmp / 8
// <o0.19> CMP1VCMP_Ƚ1˲οѹԴVcmpѡλ
//    <0=>AVDD
//    <1=>ڽVref
//</h>
#define CFG_AMOC_CMP1CON_INIT	0x0

#if ((CFG_AMOC_CMP1CON_INIT & (3<<13)) != 0)
	#define CFG_CMP1_INT_EN 1
#else
	#define CFG_CMP1_INT_EN 0
#endif



#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP1CON_INIT & (1<<7)) && (CFG_AMOC_CMP1CON_INIT & (1<<11)) && (CFG_PE6_AFR != 10))
#error "CP1OUT(PE6) AF10 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP1CON_INIT & (1<<7)) && (CFG_AMOC_CMP1CON_INIT & (1<<3)) && (CFG_PD6_AFR != 14))
#error "CP1P1(PD6) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP1CON_INIT & (1<<7)) && ((CFG_AMOC_CMP1CON_INIT & (1<<3)) == 0) && (CFG_PD4_AFR != 14))
#error "OP1OUT(PD4) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP1CON_INIT & (1<<7)) && ((CFG_AMOC_CMP1CON_INIT & (1<<6)) == 0) && (CFG_PE5_AFR != 14))
#error "CP1N(PE5) AF14 function mapping is not enable."
#endif

//<h>CMP2CON_Ƚ2ƼĴ
//<i>0x004   b31~20 b19      b18~16  b15  b14~13 b12 b11     b10   b9~8  b7     b6     b5~3   b2~0  
//<i>CMP2CON -      CMP2VCMP CMP2VRS C2DE C2IES  -   C2OUTEN C2OUT C2SMT CMP2EN C2NCHS C2PCHS C2DEB 
// <o0.0..2> C2DEB_Ƚ2ź˲ʱ
//    <0=>˲
//    <1=>˲ʱ䳣Ϊ0.5us
//    <2=>˲ʱ䳣Ϊ1us
//    <3=>˲ʱ䳣Ϊ2us
//    <4=>˲ʱ䳣Ϊ4us
//    <5=>˲ʱ䳣Ϊ8us
//    <6=>˲ʱ䳣Ϊ12us
//    <7=>˲ʱ䳣Ϊ16us
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.3..5> C2PCHS_Ƚ2ͬѡλ
//    <0=>ѡCP2P0ΪȽ2ͬ
//    <1=>ѡCP2P1ΪȽ2ͬ
//    <2=>ѡCP2P2ΪȽ2ͬ
//    <3=>ѡOP1OUTΪȽ2ͬ
//    <4=>ѡOP2OUTΪȽ2ͬ
//    <5=>ѡOP3OUTΪȽ2ͬ
//    <6=>
// <o0.6> C2NCHS_Ƚ2ѡλ
//    <0=>ѡCP2NΪȽ2
//    <1=>ѡڲοCMP2VRSΪȽ2ˣCP2NΪͨIO
//    <i>õڲVREFǰ100us׼Դ򿪣Ĵ[AGCON:VREFEN]λ1
// <q0.7> CMP2EN_Ƚ2ʹܿλ
//    0: Ƚ2ر
//    1: Ƚ2
// <o0.8..9> C2SMT_Ƚ2ʩصѹѡλ
//    <0=>ûʩش
//    <1=>ʩشΪ10mv
//    <2=>ʩشΪ20mv
//    <3=>ʩشΪ50mv
// <o0.11> C2OUTEN_Ƚ2I/Oʹ
//    <0=>ͨȽ2CP2OUTCP2OUTΪͨIO
//    <1=>ͨȽ2CP2OUT
//    <i>I/OǴ˲ܵģ˲ΪC2DEB[2:0]趨ֵ
// <o0.13..14> C2IES_Ƚ2жģʽѡλ
//    <0=>жϱ־
//    <1=>½شȽ2ɸ߱ʱжϱ־
//    <2=>شȽ2ɵͱʱжϱ־
//    <3=>˫شȽ2ɸ߱ʱɵͱʱжϱ־
// <o0.15> C2DE_Ƚ2DMAʹλ
//    <0=>жϱ־λʱDMA
//    <1=>жϱ־λʱDMA
//   <i>жϱ־λʽC2IES[<1=>0]
// <o0.16..18> CMP2VRS_Ƚ2˲οѹѡλ
//    <0=>Vcmp
//    <1=>1Vcmp / 8
//    <2=>2Vcmp / 8
//    <3=>3Vcmp / 8
//    <4=>4Vcmp / 8
//    <5=>5Vcmp / 8
//    <6=>6Vcmp / 8
//    <7=>7Vcmp / 8
// <o0.19> CMP2VCMP_Ƚ2˲οѹԴVcmpѡλ
//    <0=>AVDD
//    <1=>ڽVref
//</h>
#define CFG_AMOC_CMP2CON_INIT	0x0

#if ((CFG_AMOC_CMP2CON_INIT & (3<<13)) != 0)
	#define CFG_CMP2_INT_EN 1
#else
	#define CFG_CMP2_INT_EN 0
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP2CON_INIT & (1<<7)) && (CFG_AMOC_CMP2CON_INIT & (1<<11)) && (CFG_PE3_AFR != 10))
#error "CP2OUT(PE3) AF10 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP2CON_INIT & (1<<7)) && ((CFG_AMOC_CMP2CON_INIT & (1<<3)) == 0) && (CFG_PE1_AFR != 14))
#error "CP2P0(PE1) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP2CON_INIT & (1<<7)) && ((CFG_AMOC_CMP2CON_INIT & (1<<3)) == 1) && (CFG_PE0_AFR != 14))
#error "CP2P1(PE0) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP2CON_INIT & (1<<7)) && ((CFG_AMOC_CMP2CON_INIT & (2<<3)) == 2) && (CFG_PD15_AFR != 14))
#error "CP2P2(PD15) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP2CON_INIT & (1<<7)) && ((CFG_AMOC_CMP2CON_INIT & (3<<3)) == 3) && (CFG_PD4_AFR != 14))
#error "OP1OUT(PD4) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP2CON_INIT & (1<<7)) && ((CFG_AMOC_CMP2CON_INIT & (4<<3)) == 4) && (CFG_PD1_AFR != 14))
#error "OP2OUT(PD1) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP2CON_INIT & (1<<7)) && ((CFG_AMOC_CMP2CON_INIT & (5<<3)) == 5) && (CFG_PC15_AFR != 14))
#error "OP3OUT(PC15) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP2CON_INIT & (1<<7)) && ((CFG_AMOC_CMP2CON_INIT & (1<<6)) == 0) && (CFG_PE2_AFR != 14))
#error "CP2N(PE2) AF14 function mapping is not enable."
#endif

//<h>CMP3CON_Ƚ3ƼĴ
//<i>0x008   b31~20 b19      b18~16  b15  b14~13 b12 b11     b10   b9~8  b7     b6     b5~3   b2~0  
//<i>CMP3CON -      CMP3VCMP CMP3VRS C3DE C3IES  -   C3OUTEN C3OUT C3SMT CMP3EN C3NCHS C3PCHS C3DEB 
// <o0.0..2> C3DEB_Ƚ3ź˲ʱ
//    <0=>˲
//    <1=>˲ʱ䳣Ϊ0.5us
//    <2=>˲ʱ䳣Ϊ1us
//    <3=>˲ʱ䳣Ϊ2us
//    <4=>˲ʱ䳣Ϊ4us
//    <5=>˲ʱ䳣Ϊ8us
//    <6=>˲ʱ䳣Ϊ12us
//    <7=>˲ʱ䳣Ϊ16us
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.3..5> C3PCHS_Ƚ3ͬѡλ
//    <0=>ѡCP3P0ΪȽ3ͬ
//    <1=>ѡCP3P1ΪȽ3ͬ
//    <2=>ѡOP1OUTΪȽ3ͬ
//    <3=>ѡOP2OUTΪȽ3ͬ
//    <4=>ѡOP3OUTΪȽ3ͬ
//    :
// <o0.6> C3NCHS_Ƚ3ѡλ
//    <0=>ѡCP3NΪȽ3
//    <1=>ѡڲοCMP3VRSΪȽ1
//    <i>õڲVREFǰ100us׼Դ򿪣Ĵ[AGCON:VREFEN]λ1
// <q0.7> CMP3EN_Ƚ3ʹܿλ
//    0: Ƚ3ر
//    1: Ƚ3
// <o0.8..9> C3SMT_Ƚ3ʩصѹѡλ
//    <0=>ûʩش
//    <1=>ʩشΪ10mv
//    <2=>ʩشΪ20mv 
//    <3=>ʩشΪ50mv
// <o0.11> C3OUTEN_Ƚ3I/Oʹ
//    <0=>ͨȽ3CP3OUTCP3OUTΪͨIO
//    <1=>ͨȽ3CP3OUT
//    <i>I/OǴ˲ܵģ˲ΪC3DEB[2:0]趨ֵ
// <o0.13..14> C3IES_Ƚ3жģʽѡλ
//    <0=>жϱ־
//    <1=>½شȽ3ɸ߱ʱжϱ־
//    <2=>شȽ3ɵͱʱжϱ־
//    <3=>˫شȽ3ɸ߱ʱɵͱʱжϱ־
// <o0.15> C3DE_Ƚ3DMAʹλ
//    <0=>жϱ־λʱDMA
//    <1=>жϱ־λʱDMA
//    <i>жϱ־λʽC3IES[<1=>0]
// <o0.16..18> CMP3VRS_Ƚ3˲οѹѡλ
//    <0=>Vcmp
//    <1=>1Vcmp / 8
//    <2=>2Vcmp / 8
//    <3=>3Vcmp / 8
//    <4=>4Vcmp / 8
//    <5=>5Vcmp / 8
//    <6=>6Vcmp / 8
//    <7=>7Vcmp / 8
// <o0.19> CMP3VCMP_Ƚ3˲οѹԴVcmpѡλ
//    <0=>AVDD
//    <1=>ڽVref
//</h>
#define CFG_AMOC_CMP3CON_INIT	0x0

#if ((CFG_AMOC_CMP3CON_INIT & (3<<13)) != 0)
	#define CFG_CMP3_INT_EN 1
#else
	#define CFG_CMP3_INT_EN 0
#endif


#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP3CON_INIT & (1<<7)) && (CFG_AMOC_CMP3CON_INIT & (1<<11)) && (CFG_PE7_AFR != 10))
#error "CP3OUT(PE7) AF10 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP3CON_INIT & (1<<7)) && ((CFG_AMOC_CMP3CON_INIT & (1<<3)) == 0) && (CFG_PC12_AFR != 14))
#error "CP3P0(PC12) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP3CON_INIT & (1<<7)) && ((CFG_AMOC_CMP3CON_INIT & (1<<3)) == 1) && (CFG_PC13_AFR != 14))
#error "CP3P1(PC13) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP3CON_INIT & (1<<7)) && ((CFG_AMOC_CMP3CON_INIT & (2<<3)) == 2) && (CFG_PD4_AFR != 14))
#error "OP1OUT(PD4) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP3CON_INIT & (1<<7)) && ((CFG_AMOC_CMP3CON_INIT & (3<<3)) == 3) && (CFG_PD1_AFR != 14))
#error "OP2OUT(PD1) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP3CON_INIT & (1<<7)) && ((CFG_AMOC_CMP3CON_INIT & (4<<3)) == 4) && (CFG_PC15_AFR != 14))
#error "OP3OUT(PC15) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP3CON_INIT & (1<<7)) && ((CFG_AMOC_CMP3CON_INIT & (1<<6)) == 0) && (CFG_PC11_AFR != 14))
#error "CP3N(PC11) AF14 function mapping is not enable."
#endif

//<h>OPCON_ŴƼĴ1
//<i>0x010 b31~3 b2    b1    b0    
//<i>OPCON -     OP3EN OP2EN OP1EN 
// <q0.0> OP1EN_Ŵ1ʹܿλ
//    0: Ŵ1ر
//    1: Ŵ1
//    <i>ŴʱӦI/OܹرգΪģʹ
// <q0.1> OP2EN_Ŵ2ʹܿλ
//    0: Ŵ2ر
//    1: Ŵ2
//    <i>ŴʱӦI/OܹرգΪģʹ
// <q0.2> OP3EN_Ŵ3ʹܿλ
//    0: Ŵ3ر
//    1: Ŵ3
//    <i>ŴʱӦI/OܹرգΪģʹ
//</h>
#define CFG_AMOC_OPCON_INIT	0x0

#if ((CFG_AMOC_EN) && (CFG_AMOC_OPCON_INIT & (1<<0)) && (CFG_PD4_AFR != 14) && (CFG_PD5_AFR != 14) && (CFG_PD6_AFR != 14))
#error "OP1P(PD6),OP1N(PD5),OP1OUT(PD4) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_OPCON_INIT & (1<<1)) && (CFG_PD1_AFR != 14) && (CFG_PD2_AFR != 14) && (CFG_PD3_AFR != 14))
#error "OP2P(PD3),OP2N(PD2),OP2OUT(PD1) AF14 function mapping is not enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_OPCON_INIT & (1<<2)) && (CFG_PC13_AFR != 14) && (CFG_PC14_AFR != 14) && (CFG_PC15_AFR != 14))
#error "OP3P(PC13),OP3N(PC14),OP3OUT(PC15) AF14 function mapping is not enable."
#endif


//<h>AVREFCON_ģģڽVrefƼĴ
//<i>0x014    b31~2 b1      b0     
//<i>AVREFCON -     VREFSEL VREFEN 
// <Q0.0> VREFEN_ڽѹλ
//    0:ֹͣڽVREF
//    1:ڽVREF
//    <i>׼ԴҪʱ䣬100us˵ҪõVREFʱҪǰ100us˱־λ1
// <o0.1> VREFSEL_ڽѹѡλ
//    <0=>ѡ2.5VΪڽVREF
//    <1=>ѡ3.3VΪڽVREF
//</h>
#define CFG_AMOC_AVREFCON_INIT	0x0

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP1CON_INIT & (1<<19)) && ((CFG_AMOC_AVREFCON_INIT & 1) == 0))
#error "VREFEN@AVREFCON must be enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP2CON_INIT & (1<<19)) && ((CFG_AMOC_AVREFCON_INIT & 1) == 0))
#error "VREFEN@AVREFCON must be enable."
#endif

#if ((CFG_AMOC_EN) && (CFG_AMOC_CMP3CON_INIT & (1<<19)) && ((CFG_AMOC_AVREFCON_INIT & 1) == 0))
#error "VREFEN@AVREFCON must be enable."
#endif

#if ((CFG_ADC1_EN) && (CFG_ADC1_ADCON1_INIT & (2<<4)) && ((CFG_AMOC_AVREFCON_INIT & 1) == 0))
#error "Becase of internal Vref as the reference of ADC1, VREFEN@AVREFCON must be enable."
#endif


#if ((CFG_ADC2_EN) && (CFG_ADC2_ADCON1_INIT & (2<<4)) && ((CFG_AMOC_AVREFCON_INIT & 1) == 0))
#error "Becase of internal Vref as the reference of ADC2, VREFEN@AVREFCON must be enable."
#endif


#if ((CFG_ADC3_EN) && (CFG_ADC2_ADCON1_INIT & (2<<4)) && ((CFG_AMOC_AVREFCON_INIT & 1) == 0))
#error "Becase of internal Vref as the reference of ADC3, VREFEN@AVREFCON must be enable."
#endif
//<h>TPSCON_¶ȴƼĴ
//<i>0x018  b31~2 b1      b0    
//<i>TPSCON -     TPSCHOP TPSEN 
// <q0.0> TPSEN_¶ȴ
//    0: ر¶ȴ
//    1: ¶ȴ
//<i>¶ȴӹرյһ̣TPSENΪ1ʼٵȴ100usٿʼADתȡת
// <q0.1> TPSCHOP_¶ȴCHOP
//    0: ¶ȴCHOPܹر
//    1: ¶ȴCHOPܿ
//</h>
#define CFG_AMOC_TPSCON_INIT	0x0
//***********************************************************/
//</e>

//<e>UART
#define CFG_UART_EN 0
//***********************************************************/
//<e>UART1
#define CFG_UART1_EN 0
//       <o>Baudrate
//             <115200=> 115200
//             <57600=>  57600
//             <38400=>  38400
//             <19200=>  19200
//             <9600=>   9600
//             <4800=>   4800     
#define CFG_UART1_BAUDRATE 115200


//<h>ADDR_UARTַüĴ
//<i>0x10 b31~16 b15~8 b7~0  
//<i>ADDR -      SMAR  SADDR 
// <o0.0..7> SADDR_UARTӲַ
// <o0.8..15> SMAR_λμĴSADDRЩλᱻ

//</h>

#define CFG_UART1_ADDR_INIT	0x0


//<h>CR_UARTƼĴ
//<i>0x18 b31~21 b20  b19  b18 b17 b16   b15 b14~13 b12 b11 b10 b9  b8  b7   b6    b5   b4  b3  b2   b1     b0   
//<i>CR   -      DMAT DMAR TEN REN LINEN SBK SM     SM2 PCE PS  TB8 RB8 LBDL LBDIE TCIE TIE RIE SMOD SBRTEN STOP 
// <o0.0> STOP_ֹͣλλѡλ
//     <0=>ѡʹ1λֹͣλ
//     <1=>ѡʹ2λֹͣλ
// <o0.1> SBRTEN_UARTʷʹܿλ
//    <0=>òʷ
//    <1=>ʹܲʷ
// <o0.2> SMOD_UARTʽ2ʿλ
//    <0=>ڷʽ2УΪPCLK1ʱӵ1/256
//    <1=>ڷʽ2УΪPCLK1ʱӵ1/128
// <q0.3> RIE_ֽڽжʹλ
//    0: ֹжϱ־λRIж
//    1: жϱ־λRIж
// <q0.4> TIE_ֽڴжʹλ
//    0: ֹжϱ־λTIж
//    1: жϱ־λTIж 
// <q0.5> TCIE_ȫݷжʹλ
//    0: ֹݷɱ־λTCжϹ
//    1: ݷɱ־λTCжϹ
// <q0.6> LBDIE_LINϷָжʹλ
//    0: ֹLINϷָжϹ
//    1: LINϷָжϹ
// <o0.7> LBDL_ֵͬ
//  <0=>͵ƽȴ10BIT͵ƽ
//  <1=>͵ƽȴ11BIT͵ƽ
// <o0.9> TB8_UARTķʽ23·͵ĵ9λ
// <o0.10> PS_żУѡλ
//  <0=>У
//  <1=>żУ
// <q0.11> PCE_żУʹλ
//  0: ֹżУ
//  1: ʹżУ
// <q0.12> SM2_ͨѶλ
//     0: ڷʽ0£PCLK1ʱӵ1/48
//    <i>ڷʽ1£ֹֹͣλȷϼ飬κֹͣλλRI
//    <i>ڷʽ23£κֽڶλRI
//    1: ڷʽ0£PCLK1ʱӵ1/12
//    <i>ڷʽ1£ֹͣλȷϼ飬ֻЧֹͣλ(1)λRI
//    <i>ڷʽ23£ֻеַֽڣ9λ=1λRI
// <o0.13..14> SM_UARTзʽλ
//    <0=>ʽ0ͬʽ̶
//    <1=>ʽ18λ첽ʽɱ䲨
//    <2=>ʽ29λ첽ʽ̶
//    <3=>ʽ39λ첽ʽɱ䲨
// <o0.15> SBK_LINͬʹλ
//    <0=>ͬ
//    <1=>ͬɺԶ
// <q0.16> LINEN_LINģʽʹλ
//    0: ֹLINģʽ
//    1: ʹLINģʽ
// <q0.17> REN_UARTչʹλ
//    0:ýչ
//    1:ʹܽչ
// <q0.18> TEN_UART͹ʹλ
//    0:÷͹
//    1:ʹܷ͹
// <q0.19> DMAR_UARTDMAͨʹλ
//    0:ݲͨDMA
//    1:ͨDMA
// <q0.20> DMAT_UARTDMAͨʹλ
//    0:ݲͨDMA
//    1:ͨDMA

//</h>

#define CFG_UART1_CR_INIT	0x0

#if ((CFG_UART1_CR_INIT & (0xF<<3)) != 0)
	#define CFG_UART1_INT_EN 1
#else
	#define CFG_UART1_INT_EN 0
#endif



#define CFG_UART1_CLK		(SYS_CLK/APB1_F)
#if ((CFG_UART1_CR_INIT & 0x2000) == 0x2000)
#define CFG_UART1_SBRT_VALUE 	(CFG_UART1_CLK/16/CFG_UART1_BAUDRATE-1)
#define CFG_UART1_BFINE_VALUE 	(CFG_UART1_CLK/CFG_UART1_BAUDRATE - 16*CFG_UART1_SBRT_VALUE)
#define CFG_UART1_BRT_INIT	(CFG_UART1_SBRT_VALUE | (CFG_UART1_BFINE_VALUE<<16))
#else
#define CFG_UART1_BRT_INIT	0
#endif

//</e>

#if ((CFG_UART_EN) && (CFG_UART1_EN) && (CFG_UART1_CR_INIT & (1<<17)) && ((CFG_PA11_AFR != 7)&&(CFG_PD15_AFR != 7)&&(CFG_PA2_AFR != 7)))
#error "UART1 RXD1(PA11/PD15/PA2) AF7 function mapping is not enable."
#endif

#if ((CFG_UART_EN) && (CFG_UART1_EN) && (CFG_UART1_CR_INIT & (1<<18)) && ((CFG_PA12_AFR != 7)&&(CFG_PD14_AFR != 7)&&(CFG_PE8_AFR != 7)))
#error "UART1 TXD1(PA12/PD14/PE8) AF7 function mapping is not enable."
#endif

//***********************************************************/
//<e>UART2
#define CFG_UART2_EN 0
//       <o>Baudrate
//             <115200=> 115200
//             <57600=>  57600
//             <38400=>  38400
//             <19200=>  19200
//             <9600=>   9600
//             <4800=>   4800     
#define CFG_UART2_BAUDRATE 115200

//<h>ADDR_UARTַüĴ
//<i>0x10 b31~16 b15~8 b7~0  
//<i>ADDR -      SMAR  SADDR 
// <o0.0..7> SADDR_UARTӲַ
// <o0.8..15> SMAR_λμĴSADDRЩλᱻ
//</h>
#define CFG_UART2_ADDR_INIT	0x0


//<h>CR_UARTƼĴ
//<i>0x18 b31~21 b20  b19  b18 b17 b16   b15 b14~13 b12 b11 b10 b9  b8  b7   b6    b5   b4  b3  b2   b1     b0   
//<i>CR   -      DMAT DMAR TEN REN LINEN SBK SM     SM2 PCE PS  TB8 RB8 LBDL LBDIE TCIE TIE RIE SMOD SBRTEN STOP 
// <o0.0> STOP_ֹͣλλѡλ
//     <0=>ѡʹ1λֹͣλ
//     <1=>ѡʹ2λֹͣλ
// <o0.1> SBRTEN_UARTʷʹܿλ
//    <0=>òʷ
//    <1=>ʹܲʷ
// <o0.2> SMOD_UARTʽ2ʿλ
//    <0=>ڷʽ2УΪPCLK1ʱӵ1/256
//    <1=>ڷʽ2УΪPCLK1ʱӵ1/128
// <q0.3> RIE_ֽڽжʹλ
//    0: ֹжϱ־λRIж
//    1: жϱ־λRIж
// <q0.4> TIE_ֽڴжʹλ
//    0: ֹжϱ־λTIж
//    1: жϱ־λTIж 
// <q0.5> TCIE_ȫݷжʹλ
//    0: ֹݷɱ־λTCжϹ
//    1: ݷɱ־λTCжϹ
// <q0.6> LBDIE_LINϷָжʹλ
//    0: ֹLINϷָжϹ
//    1: LINϷָжϹ
// <o0.7> LBDL_ֵͬ
//  <0=>͵ƽȴ10BIT͵ƽ
//  <1=>͵ƽȴ11BIT͵ƽ
// <o0.9> TB8_UARTķʽ23·͵ĵ9λ
// <o0.10> PS_żУѡλ
//  <0=>У
//  <1=>żУ
// <q0.11> PCE_żУʹλ
//  0: ֹżУ
//  1: ʹżУ
// <q0.12> SM2_ͨѶλ
//     0: ڷʽ0£PCLK1ʱӵ1/48
//    <i>ڷʽ1£ֹֹͣλȷϼ飬κֹͣλλRI
//    <i>ڷʽ23£κֽڶλRI
//    1: ڷʽ0£PCLK1ʱӵ1/12
//    <i>ڷʽ1£ֹͣλȷϼ飬ֻЧֹͣλ(1)λRI
//    <i>ڷʽ23£ֻеַֽڣ9λ=1λRI
// <o0.13..14> SM_UARTзʽλ
//    <0=>ʽ0ͬʽ̶
//    <1=>ʽ18λ첽ʽɱ䲨
//    <2=>ʽ29λ첽ʽ̶
//    <3=>ʽ39λ첽ʽɱ䲨
// <o0.15> SBK_LINͬʹλ
//    <0=>ͬ
//    <1=>ͬɺԶ
// <q0.16> LINEN_LINģʽʹλ
//    0: ֹLINģʽ
//    1: ʹLINģʽ
// <q0.17> REN_UARTչʹλ
//    0:ýչ
//    1:ʹܽչ
// <q0.18> TEN_UART͹ʹλ
//    0:÷͹
//    1:ʹܷ͹
// <q0.19> DMAR_UARTDMAͨʹλ
//    0:ݲͨDMA
//    1:ͨDMA
// <q0.20> DMAT_UARTDMAͨʹλ
//    0:ݲͨDMA
//    1:ͨDMA

//</h>

#define CFG_UART2_CR_INIT	0x0

#if ((CFG_UART2_CR_INIT & (0xF<<3)) != 0)
	#define CFG_UART2_INT_EN 1
#else
	#define CFG_UART2_INT_EN 0
#endif

#define CFG_UART2_CLK		(SYS_CLK/APB1_F)
#if ((CFG_UART2_CR_INIT & 0x2000) == 0x2000)
#define CFG_UART2_SBRT_VALUE 	(CFG_UART2_CLK/16/CFG_UART2_BAUDRATE-1)
#define CFG_UART2_BFINE_VALUE 	(CFG_UART2_CLK/CFG_UART2_BAUDRATE - 16*CFG_UART2_SBRT_VALUE)
#define CFG_UART2_BRT_INIT	(CFG_UART2_SBRT_VALUE | (CFG_UART2_BFINE_VALUE<<16))
#else
#define CFG_UART2_BRT_INIT	0
#endif
//</e>

#if ((CFG_UART_EN) && (CFG_UART2_EN)&& (CFG_UART2_CR_INIT & (1<<17)) && ((CFG_PA8_AFR != 7)&&(CFG_PB0_AFR != 7)&&(CFG_PB4_AFR != 7)&&(CFG_PB12_AFR != 7)))
#error "UART2 RXD2(PA8/PB4/PB0/PB12) AF7 function mapping is not enable."
#endif

#if ((CFG_UART_EN) && (CFG_UART2_EN)&& (CFG_UART2_CR_INIT & (1<<18)) && ((CFG_PA9_AFR != 7)&&(CFG_PB1_AFR != 7)&&(CFG_PB3_AFR != 7)&&(CFG_PB13_AFR != 7)))
#error "UART2 TXD2(PA9/PB1/PB3/PB13) AF7 function mapping is not enable."
#endif
//***********************************************************/
//<e>UART3
#define CFG_UART3_EN 0
//       <o>Baudrate
//             <115200=> 115200
//             <57600=>  57600
//             <38400=>  38400
//             <19200=>  19200
//             <9600=>   9600
//             <4800=>   4800     
#define CFG_UART3_BAUDRATE 115200

//<h>ADDR_UARTַüĴ
//<i>0x10 b31~16 b15~8 b7~0  
//<i>ADDR -      SMAR  SADDR 
// <o0.0..7> SADDR_UARTӲַ
// <o0.8..15> SMAR_λμĴSADDRЩλᱻ

//</h>
#define CFG_UART3_ADDR_INIT	0x0

//<h>CR_UARTƼĴ
//<i>0x18 b31~21 b20  b19  b18 b17 b16   b15 b14~13 b12 b11 b10 b9  b8  b7   b6    b5   b4  b3  b2   b1     b0   
//<i>CR   -      DMAT DMAR TEN REN LINEN SBK SM     SM2 PCE PS  TB8 RB8 LBDL LBDIE TCIE TIE RIE SMOD SBRTEN STOP 
// <o0.0> STOP_ֹͣλλѡλ
//     <0=>ѡʹ1λֹͣλ
//     <1=>ѡʹ2λֹͣλ
// <o0.1> SBRTEN_UARTʷʹܿλ
//    <0=>òʷ
//    <1=>ʹܲʷ
// <o0.2> SMOD_UARTʽ2ʿλ
//    <0=>ڷʽ2УΪPCLK1ʱӵ1/256
//    <1=>ڷʽ2УΪPCLK1ʱӵ1/128
// <q0.3> RIE_ֽڽжʹλ
//    0: ֹжϱ־λRIж
//    1: жϱ־λRIж
// <q0.4> TIE_ֽڴжʹλ
//    0: ֹжϱ־λTIж
//    1: жϱ־λTIж 
// <q0.5> TCIE_ȫݷжʹλ
//    0: ֹݷɱ־λTCжϹ
//    1: ݷɱ־λTCжϹ
// <q0.6> LBDIE_LINϷָжʹλ
//    0: ֹLINϷָжϹ
//    1: LINϷָжϹ
// <o0.7> LBDL_ֵͬ
//  <0=>͵ƽȴ10BIT͵ƽ
//  <1=>͵ƽȴ11BIT͵ƽ
// <o0.9> TB8_UARTķʽ23·͵ĵ9λ
// <o0.10> PS_żУѡλ
//  <0=>У
//  <1=>żУ
// <q0.11> PCE_żУʹλ
//  0: ֹżУ
//  1: ʹżУ
// <q0.12> SM2_ͨѶλ
//     0: ڷʽ0£PCLK1ʱӵ1/48
//    <i>ڷʽ1£ֹֹͣλȷϼ飬κֹͣλλRI
//    <i>ڷʽ23£κֽڶλRI
//    1: ڷʽ0£PCLK1ʱӵ1/12
//    <i>ڷʽ1£ֹͣλȷϼ飬ֻЧֹͣλ(1)λRI
//    <i>ڷʽ23£ֻеַֽڣ9λ=1λRI
// <o0.13..14> SM_UARTзʽλ
//    <0=>ʽ0ͬʽ̶
//    <1=>ʽ18λ첽ʽɱ䲨
//    <2=>ʽ29λ첽ʽ̶
//    <3=>ʽ39λ첽ʽɱ䲨
// <o0.15> SBK_LINͬʹλ
//    <0=>ͬ
//    <1=>ͬɺԶ
// <q0.16> LINEN_LINģʽʹλ
//    0: ֹLINģʽ
//    1: ʹLINģʽ
// <q0.17> REN_UARTչʹλ
//    0:ýչ
//    1:ʹܽչ
// <q0.18> TEN_UART͹ʹλ
//    0:÷͹
//    1:ʹܷ͹
// <q0.19> DMAR_UARTDMAͨʹλ
//    0:ݲͨDMA
//    1:ͨDMA
// <q0.20> DMAT_UARTDMAͨʹλ
//    0:ݲͨDMA
//    1:ͨDMA
//</h>
#define CFG_UART3_CR_INIT	0x0


#if ((CFG_UART3_CR_INIT & (0xF<<3)) != 0)
	#define CFG_UART3_INT_EN 1
#else
	#define CFG_UART3_INT_EN 0
#endif

#define CFG_UART3_CLK		(SYS_CLK/APB1_F)
#if ((CFG_UART3_CR_INIT & 0x2000) == 0x2000)
#define CFG_UART3_SBRT_VALUE 	(CFG_UART3_CLK/16/CFG_UART3_BAUDRATE-1)
#define CFG_UART3_BFINE_VALUE 	(CFG_UART3_CLK/CFG_UART3_BAUDRATE - 16*CFG_UART3_SBRT_VALUE)
#define CFG_UART3_BRT_INIT	(CFG_UART3_SBRT_VALUE | (CFG_UART3_BFINE_VALUE<<16))
#else
#define CFG_UART3_BRT_INIT	0
#endif
//</e>
#if ((CFG_UART_EN) && (CFG_UART3_EN)&& (CFG_UART3_CR_INIT & (1<<17)) && ((CFG_PA0_AFR != 7)&&(CFG_PA3_AFR != 7)&&(CFG_PB5_AFR != 7)&&(CFG_PD10_AFR != 7)))
#error "UART3 RXD3(PA0/PA3/PB5/PD10) AF7 function mapping is not enable."
#endif

#if ((CFG_UART_EN) && (CFG_UART3_EN)&& (CFG_UART3_CR_INIT & (1<<18)) && ((CFG_PA1_AFR != 7)&&(CFG_PA6_AFR != 7)&&(CFG_PB6_AFR != 7)&&(CFG_PD9_AFR != 7)))
#error "UART3 TXD3(PA1/PA6/PB6/PD9) AF7 function mapping is not enable."
#endif
//***********************************************************/
//</e>

//<e>SPI
#define CFG_SPI_EN 0
//***********************************************************/
//<e>SPI1
#define CFG_SPI1_EN 0
//<h>CR_SPIƼĴ
//<i>0x00C b31~16 b15   b14   b13    b12    b11   b10   b9     b8  b7   b6   b5   b4    b3~0 
//<i>CR    -      SPSFF SPIEN SPDMAT SPDMAR SPTIE SPRIE SPDATL DIR MSTR CPHA CPOL SSDIS SPR  
// <o0.0..3> SPR_ʱӷƵλ
//    <0=>PCLK1 /2
//    <1=>PCLK1 /4
//    <2=>PCLK1 /8
//    <3=>PCLK1 /16
//    <4=>PCLK1 /32
//    <5=>PCLK1 /64
//    <6=>PCLK1 /128
//    <7=>PCLK1 /256
//    <8=>PCLK1 /512
//    <9=>PCLK1 /1024
//    :
// <o0.4> SSDIS_NSSſλ
//    <0=>/ģʽ£NSS
//    <1=>/ģʽ£رNSSţMODFж
//    <i>ڴģʽ£CPHA=0λ
// <o0.5> CPOL_ʱӼԿλ
//    <0=>IDLE״̬CKڵ͵ƽ
//    <1=>IDLE״̬CKڸߵƽ
// <o0.6> CPHA_ʱλλ
//     <0=>CKڵĵһزɼ
//     <1=>CKڵĵڶزɼ
// <o0.7> MSTR_SPI豸λ
//     <0=>SPIΪ豸
//     <1=>SPIΪ豸 
// <o0.8> DIR_ݴͷѡλ
//     <0=>MSBȷ
//     <1=>LSBȷ
// <o0.9> SPDATL_ֳѡλ
//     <0=>ÿη8bit
//     <1=>ÿη16bit 
// <q0.10> SPRIE_SPIĽжϱ־ʹλ
//    0: ֹжϱ־λSPRIж
//    1: жϱ־λSPRIж
// <q0.11> SPTIE_SPIĴжϱ־ʹλ
//    0: ֹжϱ־λSPTIж
//    1: жϱ־λSPTIж
// <o0.12> SPDMAR_SPIݽDMAͨʹ
//    <0=>ʹDMASPIĽ
//    <1=>ʹDMASPIĽ
// <o0.13> SPDMAT_SPIݷDMAͨʹ
//    <0=>ʹDMASPIķ
//    <1=>ʹDMASPIķ
// <o0.14> SPIEN_SPIʹλ
//    <0=>رSPI
//    <1=>ʹSPI
// <o0.15> SPSFF_ӻٷģʽλCPHA=0ʱЧ
//  <0=>ͨģʽ
//  <1=>ģʽ
//<i>ͨģʽ£ӻSSÿδһݣ8λ16λ뱻ߣһǰSSݵλĴ
//<i>ģʽ£ӻ͵ĵһҪSS½ڶϸһCLKصλĴעͻû򲻻أ

//</h>

#define CFG_SPI1_CR_INIT	0x0000

#if ((CFG_SPI1_CR_INIT & (3<<10)) != 0)
	#define CFG_SPI1_INT_EN 1
#else
	#define CFG_SPI1_INT_EN 0
#endif


//</e>
#if ((CFG_SPI_EN) && (CFG_SPI1_EN) && ((CFG_PA13_AFR != 8)&&(CFG_PC12_AFR != 8)&&(CFG_PD13_AFR != 8)))
#error "SPI1 SCK1(PA13/PC12/PD13) AF8 function mapping is not enable."
#endif
#if ((CFG_SPI_EN) && (CFG_SPI1_EN) && ((CFG_PA14_AFR != 8)&&(CFG_PC11_AFR != 8)&&(CFG_PD14_AFR != 8)))
#error "SPI1 MOSI1(PA14/PC11/PD14) AF8 function mapping is not enable."
#endif
#if ((CFG_SPI_EN) && (CFG_SPI1_EN) && ((CFG_PA15_AFR != 8)&&(CFG_PC10_AFR != 8)&&(CFG_PD15_AFR != 8)))
#error "SPI1 MISO1(PA15/PC10/PD15) AF8 function mapping is not enable."
#endif

//***********************************************************/
//<e>SPI2
#define CFG_SPI2_EN 0
//<h>CR_SPIƼĴ
//<i>0x00C b31~16 b15   b14   b13    b12    b11   b10   b9     b8  b7   b6   b5   b4    b3~0 
//<i>CR    -      SPSFF SPIEN SPDMAT SPDMAR SPTIE SPRIE SPDATL DIR MSTR CPHA CPOL SSDIS SPR  
// <o0.0..3> SPR_ʱӷƵλ
//    <0=>PCLK1 /2
//    <1=>PCLK1 /4
//    <2=>PCLK1 /8
//    <3=>PCLK1 /16
//    <4=>PCLK1 /32
//    <5=>PCLK1 /64
//    <6=>PCLK1 /128
//    <7=>PCLK1 /256
//    <8=>PCLK1 /512
//    <9=>PCLK1 /1024
//    :
// <o0.4> SSDIS_NSSſλ
//    <0=>/ģʽ£NSS
//    <1=>/ģʽ£رNSSţMODFж
//    <i>ڴģʽ£CPHA=0λ
// <o0.5> CPOL_ʱӼԿλ
//    <0=>IDLE״̬CKڵ͵ƽ
//    <1=>IDLE״̬CKڸߵƽ
// <o0.6> CPHA_ʱλλ
//     <0=>CKڵĵһزɼ
//     <1=>CKڵĵڶزɼ
// <o0.7> MSTR_SPI豸λ
//     <0=>SPIΪ豸
//     <1=>SPIΪ豸 
// <o0.8> DIR_ݴͷѡλ
//     <0=>MSBȷ
//     <1=>LSBȷ
// <o0.9> SPDATL_ֳѡλ
//     <0=>ÿη8bit
//     <1=>ÿη16bit 
// <q0.10> SPRIE_SPIĽжϱ־ʹλ
//    0: ֹжϱ־λSPRIж
//    1: жϱ־λSPRIж
// <q0.11> SPTIE_SPIĴжϱ־ʹλ
//    0: ֹжϱ־λSPTIж
//    1: жϱ־λSPTIж
// <o0.12> SPDMAR_SPIݽDMAͨʹ
//    <0=>ʹDMASPIĽ
//    <1=>ʹDMASPIĽ
// <o0.13> SPDMAT_SPIݷDMAͨʹ
//    <0=>ʹDMASPIķ
//    <1=>ʹDMASPIķ
// <o0.14> SPIEN_SPIʹλ
//    <0=>رSPI
//    <1=>ʹSPI
// <o0.15> SPSFF_ӻٷģʽλCPHA=0ʱЧ
//  <0=>ͨģʽ
//  <1=>ģʽ
//<i>ͨģʽ£ӻSSÿδһݣ8λ16λ뱻ߣһǰSSݵλĴ
//<i>ģʽ£ӻ͵ĵһҪSS½ڶϸһCLKصλĴעͻû򲻻أ

//</h>

#define CFG_SPI2_CR_INIT	0x0

#if ((CFG_SPI2_CR_INIT & (3<<10)) != 0)
	#define CFG_SPI2_INT_EN 1
#else
	#define CFG_SPI2_INT_EN 0
#endif

//</e>
#if ((CFG_SPI_EN) && (CFG_SPI2_EN) && ((CFG_PB9_AFR != 8)&&(CFG_PB5_AFR != 8)))
#error "SPI2 SCK2(PB9/PB5) AF8 function mapping is not enable."
#endif
#if ((CFG_SPI_EN) && (CFG_SPI2_EN) && ((CFG_PB3_AFR != 8)&&(CFG_PB10_AFR != 8)))
#error "SPI2 MOSI2(PB10/PB3) AF8 function mapping is not enable."
#endif
#if ((CFG_SPI_EN) && (CFG_SPI2_EN) && ((CFG_PB4_AFR != 8)&&(CFG_PB11_AFR != 8)))
#error "SPI2 MISO2(PB11/PB4) AF8 function mapping is not enable."
#endif
//***********************************************************/
//</e>

//<e>TWI
#define CFG_TWI_EN 0

//<h>CR_TWIƼĴ
//<i>0x018 b31~16 b15   b14~11 b10    b9   b8    b7~6 b5~4 b3 b2  b1  b0 
//<i>CR    -      TWIEN -      TWINTE ETOT EFREE CNT  CR   -  STA STO AA 
// <o0.0> AA_Ӧ־λ
//    <0=>ظӦźţSDAߵƽ
//    <1=>ظӦźţSDA͵ƽ 
// <o0.2> STA_ʼλ
//    <0=>ʼ
//    <1=>߿ʱʼ
//<i>STA=1ʱʼģʽѾģʽظʼ
//<i>STASTOλʱģʽ߷һֹͣȻһʼӿڴڴģʽһڲֹͣ͵
// <o0.4..5> CR_TWIƵϵ
//    <0=>64
//    <1=>16
//    <2=>4
//    <3=>1
// <o0.6..7> CNT_߳ʱλ
//    <0=>N=25000
//    <1=>N=50000
//    <2=>N=100000
//    <3=>N=200000
//    <i>Nֵ߳ʱʹ
// <q0.8> EFREE_SCLߵƽʱ־ʹλ
//     0: ֹSCLߵƽʱTFREE־TFREEжҲ޷
//     1: SCLߵƽʱTFREE־TFREEжϣ
// <q0.9> ETOT_߳ʱ־ʹλ
//     0: ֹTWI߳ʱTOUT־TOUTжҲ޷
//     1: TWI߳ʱTOUT־TOUTжϣ
// <q0.10> TWINTE_TWIķͽжϱ־ʹλ
//    0: ֹTWIжϱ־λTWINTж
//    1: TWIжϱ־λTWINTж
// <o0.15> TWIEN_TWIʹλ
//    <0=>رTWI
//    <1=>ʹTWI
//</h>
#define CFG_TWI1_CR_INIT	0x0

//<h>ADDR_TWIַüĴ
//<i>0x014 b31~24 b23~17 b16~8 b7~1 b0 
//<i>ADDR  -      TWIAMR -     ADDR GC 
// <q0.0> GC_ͨõַʹλ
//    0: ֹӦͨõַ
//    1: Ӧͨõַ
// <o0.1..7> ADDR_TWIַλ<0-0x7F>
// <o0.17..23> TWIAMR_TWIַλ<0-0x7F>
//<i>TWIAMRÿһλTWIADRַĴӦĵַλλ1ַƥ߼ĵַλTWIADRеӦַλıȽϽλ0ӦλıȽϽ
//</h>
#define CFG_TWI1_ADDR_INIT	0x0

//<h>BRT_TWIüĴ
//<i>0x00C b31~8 b7~0 
//<i>BRT   -     BRT  
// <o0.0..7> BRT_TWIıλ<0-255>
//</h>
#define CFG_TWI1_BRT_INIT	0x0


//<h>HOC_TWIߵƽʱüĴ
//<i>0x008 b31~8 b7~0 
//<i>HOC   -     HOC  
// <o0.0..7> HOC_TWISCL߸ߵƽʱλ<0-255>
//</h>
#define CFG_TWI1_HOC_INIT	0xFF

#if ((CFG_TWI1_CR_INIT & (1<<10)) != 0)
	#define CFG_TWI_INT_EN 1
#else
	#define CFG_TWI_INT_EN 0
#endif

//***********************************************************/
//</e>
#if ((CFG_TWI_EN) && ((CFG_PA0_AFR != 9)&&(CFG_PB1_AFR != 9)&&(CFG_PD14_AFR != 9)))
#error "TWI SCL(PA0/PB1/PD14) AF9 function mapping is not enable."
#endif

#if ((CFG_TWI_EN) && ((CFG_PA1_AFR != 9)&&(CFG_PB0_AFR != 9)&&(CFG_PD15_AFR != 9)))
#error "TWI SDA(PA1/PB0/PD15) AF9 function mapping is not enable."
#endif


#define CFG_NVIC_ISER0_INIT ((CFG_WWDT_INT_EN << 0)\
													|(CFG_EXTI0_INT_EN << 5)\
													|(CFG_EXTI1_INT_EN << 6)\
													|(CFG_EXTI2_INT_EN << 7)\
													|(CFG_EXTI3_INT_EN << 8)\
													|(CFG_EXTI4_INT_EN << 9)\
													|(CFG_DMA_CH0_INT_EN << 10)\
													|(CFG_DMA_CH1_INT_EN << 11)\
													|(CFG_DMA_CH2_7_INT_EN << 12)\
													|(CFG_MCM1_FLT_INT_EN << 13)\
													|(CFG_MCM1_PWM_INT_EN << 14)\
													|(CFG_MCM2_FLT_INT_EN << 15)\
													|(CFG_MCM2_PWM_INT_EN << 16)\
													|(CFG_ADC1_INT_EN << 17)\
													|(CFG_ADC2_INT_EN << 18)\
													|(CFG_ADC3_INT_EN << 19)\
													|(CFG_GPT0_GTCIV_INT_EN << 22)\
													|(CFG_GPT0_GTCIN_INT_EN << 23)\
													|(CFG_GPT1_GTCIV_INT_EN << 24)\
													|(CFG_GPT1_GTCIN_INT_EN << 25)\
													|(CFG_GPT2_GTCIV_INT_EN << 26)\
													|(CFG_GPT2_GTCIN_INT_EN << 27)\
													|(CFG_GPT3_GTCIV_INT_EN << 28)\
													|(CFG_GPT3_GTCIN_INT_EN << 29)\
													|(CFG_GPT_POE_INT_EN << 30)\
													|(CFG_EXTI9_5_INT_EN << 31))
													
#define CFG_NVIC_ISER1_INIT ((CFG_CMP1_INT_EN << 0)\
													|(CFG_CMP2_INT_EN << 1)\
													|(CFG_CMP3_INT_EN << 2)\
													|(CFG_QEI_INT_EN << 3)\
													|(CFG_TWI_INT_EN << 4)\
													|(CFG_SPI1_INT_EN << 6)\
													|(CFG_SPI2_INT_EN << 7)\
													|(CFG_UART1_INT_EN << 8)\
													|(CFG_UART2_INT_EN << 9)\
													|(CFG_UART3_INT_EN << 10)\
													|(CFG_EXTI15_10_INT_EN << 12)\
													|(CFG_TIM5_INT_EN << 17)\
													|(CFG_TIM6_INT_EN << 18)\
													|(CFG_TIM7_INT_EN << 19)\
													|(CFG_TIM8_INT_EN << 20))
													
													
void IWDT_InitCfg(void);        
void WWDT_InitCfg(void);        
void GPIO_InitCfg(void);        
void EXTI_InitCfg(void);        
void DMA_InitCfg(void);        
void MCM1_InitCfg(void);        
void MCM2_InitCfg(void);        
void GPT_InitCfg(void);        
void MACP_InitCfg(void);           
void TIM_InitCfg(void);        
void ADC_InitCfg(void);        
void QEI_InitCfg(void);        
void AMOC_InitCfg(void);       
void UART_InitCfg(void);       
void SPI_InitCfg(void);        
void TWI_InitCfg(void);        
void SysTick_InitCfg(void);    
void NVIC_InitCfg(void);       
void Peripherals_InitCfg(void);
													

#endif //__CFG32F2053_H__
