/**
  ******************************************************************************
  * @file    sh3xF2xx_sb0.h
  * @version V1.0
  * @date    07-March-2021
  * @brief   CMSIS ARM Star Device Peripheral Access Layer Header File.
  *          This file contains all the peripheral register's definitions, bits
  *          definitions and memory mapping for Sinowealth M3 based devices.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * COPYRIGHT 2021 Sinowealth
  *
  *
  ******************************************************************************
*/

#ifndef __SH3XF2XX_SB0_H__
#define __SH3XF2XX_SB0_H__

#ifdef __cplusplus
extern "C" {
#endif

#define __ARMv8MML_REV            0x0001  /*!< Core revision r0p1                            */
#define __MPU_PRESENT             0       /*!< SH32F2601 provides NO MPU                     */
#define __NVIC_PRIO_BITS          3       /*!< Uses 3 Bits for the Priority Levels */
#define __Vendor_SysTickConfig    0       /*!< Set to 1 if different SysTick Config is used  */
typedef enum
{
/******  CORE Processor Exceptions Numbers ****************************************************************/
  NMI_IRQn                    = -14,    /*!< Non Maskable Interrupt                                            */
  HardFault_IRQn              = -13,    /*!< Hard Fault Interrupt                                              */
  MemManage_IRQn              = -12,    /*!< CORE Memory Management Interrupt                             */
  BusFault_IRQn               = -11,    /*!< CORE Bus Fault Interrupt                                     */
  UsageFault_IRQn             = -10,    /*!< CORE Usage Fault Interrupt                                   */
  SVC_IRQn                    = -5,     /*!< CORE SV Call Interrupt                                       */
  DebugMon_IRQn               = -4,     /*!< CORE Debug Monitor Interrupt                                 */
  PendSV_IRQn                 = -2,     /*!< CORE Pend SV Interrupt                                       */
  SysTick_IRQn                = -1,     /*!< CORE System Tick Interrupt                                   */
/******  SH33Fxxx specific Interrupt Numbers *******************************************************************/
  WWDT_IRQn                   = 0,      /*!< Window WatchDog Interrupt                                         */
  BOD_IRQn                    = 1,      /*!< PVD through EXTI Line detection Interrupt                         */
  RCC_IRQn                    = 2,      /*!< RCC global Interrupt                                              */
  EXTI0_IRQn                  = 3,      /*!< EXTI Line0 Interrupt                                              */
  EXTI1_IRQn                  = 4,      /*!< EXTI Line1 Interrupt                                              */
  EXTI2_IRQn                  = 5,      /*!< EXTI Line2 Interrupt                                              */
  EXTI3_IRQn                  = 6,      /*!< EXTI Line3 Interrupt                                              */
  MCM_FLT_IRQn                = 7,      /*!< MCM FAULT Interrupt                                               */
  MCM_PWM_IRQn                = 8,      /*!< MCM PWM Interrupt                                                 */
  ADC_IRQn                    = 9,      /*!< ADC Interrupt                                                     */
  PCA0_IRQn                   = 10,     /*!< PCA0 Interrupt                                                    */
  PCA1_IRQn                   = 11,     /*!< PCA1 Interrupt                                                    */
  PCA0_FLT_IRQn               = 12,     /*!< PCA0 Fault Interrupt                                                    */
  PCA1_FLT_IRQn               = 13,     /*!< PCA1 Fault Interrupt                                                    */  
  CMP0_IRQn                   = 14,     /*!< CMP0 Interrupt                                                    */
  CMP1_IRQn                   = 15,     /*!< CMP1 Interrupt                                                    */
  QEI_IRQn                    = 16,     /*!< QEI Interrupt                                                     */
  CAN_IRQn                    = 17,     /*!< CAN Interrupt                                                     */
  TWI_IRQn                    = 18,     /*!< TWI Interrupt                                                     */
  SPI_IRQn                    = 19,     /*!< SPI Interrupt                                                     */
  UART0_IRQn                  = 20,     /*!< UART0 Interrupt                                                   */ 
  UART1_IRQn                  = 21,     /*!< UART1 Interrupt                                                   */
  UART2_IRQn                  = 22,     /*!< UART2 Interrupt                                                   */
  TIM7_IRQn                   = 23,     /*!< TIM7 Interrupt                                                    */
  TIM8_IRQn                   = 24,     /*!< TIM8 Interrupt                                                    */
  EXTI7_4_IRQn                = 25,      /*!< EXTI Line4 ~ Line7 Interrupt                                     */
  FIFO0_IRQn                  = 26,      /*!< FIFO0 Interrupt                                     */
  FIFO1_IRQn                  = 27,      /*!< FIFO1 Interrupt                                     */
  FIFO2_IRQn                  = 28,      /*!< FIFO2 Interrupt                                     */
} IRQn_Type;

/* Includes ****************************************************************************************************/
#include "core_armv8mml.h"
#include <stdint.h>

/**
*@brief N_TEST_registers
*/
typedef struct
{
    __IO uint32_t  NTW;                                     /*!< 0000H */
    __IO uint32_t  NTID0;                                   /*!< 0004H */
    __IO uint32_t  NTID1;                                   /*!< 0008H */
    __IO uint32_t  NTID2;                                   /*!< 000CH */
    __IO uint32_t  NTC0;                                    /*!< 0010H */
    __IO uint32_t  NTC1;                                    /*!< 0014H */
    __IO uint32_t  NTC2;                                    /*!< 0018H */
}N_TEST_TypeDef;


/**
*@brief FLASH_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  LATENCY   : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  rev0      : 5;  /*!< [b7~b3]*/
            __IO  uint32_t  PRFTEN    : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  DCEN      : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  CRST      : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  rev2      : 4;  /*!< [b15~b12]*/
            __O   uint32_t  LOCK      :16;  /*!< [b31~b16]*/
        }BIT;
    }ACR;                               /*!< 0000H */
    __O  uint32_t  MKYR;                                    /*!< 0004H */
    __O  uint32_t  E2KYR;                                   /*!< 0008H */
    union {
        __IO  uint32_t  V32;                                /*!< 000CH */
        struct {
            __I   uint32_t  EOP       : 1;  /*!< [b0~b0]*/
            __I   uint32_t  OPERR     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b2~b2]*/
            __I   uint32_t  FLSERR    : 1;  /*!< [b3~b3]*/
            __I   uint32_t  WRPRTERR  : 1;  /*!< [b4~b4]*/
            __I   uint32_t  PGPERR    : 1;  /*!< [b5~b5]*/
            __I   uint32_t  PGWERR    : 1;  /*!< [b6~b6]*/
            __I   uint32_t  STAERR    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev1      : 7;  /*!< [b14~b8]*/
            __I   uint32_t  BSY       : 1;  /*!< [b15~b15]*/
            __O   uint32_t  EOPC      : 1;  /*!< [b16~b16]*/
            __O   uint32_t  OPERRC    : 1;  /*!< [b17~b17]*/
            __IO  uint32_t  rev2      : 1;  /*!< [b18~b18]*/
            __O   uint32_t  FLSERRC   : 1;  /*!< [b19~b19]*/
            __O   uint32_t  WRPRTERRC : 1;  /*!< [b20~b20]*/
            __O   uint32_t  PGPERRC   : 1;  /*!< [b21~b21]*/
            __O   uint32_t  PGWERRC   : 1;  /*!< [b22~b22]*/
            __O   uint32_t  STAERRC   : 1;  /*!< [b23~b23]*/
            __IO  uint32_t  rev3      : 8;  /*!< [b31~b24]*/
        }BIT;
    }SR;                               /*!< 000CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0010H */
        struct {
            __IO  uint32_t  SNB       : 7;  /*!< [b6~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  STRT      : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  rev1      : 2;  /*!< [b10~b9]*/
            __IO  uint32_t  PSIZE     : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  INFLCK    : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  rev2      : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  E2LCK     : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  MNLCK     : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  CMD       :16;  /*!< [b31~b16]*/
        }BIT;
    }CR;                               /*!< 0010H */
    __IO uint32_t  Reserved0[2];                            /*!< 0014H */
    union {
        __I   uint32_t  V32;                                /*!< 001CH */
        struct {
    __I  uint32_t  OPT0:8;                                  /*!< 001CH */
    __I  uint32_t  OPT1:8;                                  /*!< 001DH */
    __I  uint32_t  OPT2:8;                                  /*!< 001EH */
    __I  uint32_t  OPT3:8;                                  /*!< 001FH */
        }BIT;
    }OPR;                              /*!< 001CH */
    __I  uint32_t  RPR;                                     /*!< 0020H */
    __I  uint32_t  WRPR;                                    /*!< 0024H */
    __IO uint32_t  Reserved1[2];                            /*!< 0028H */
    __IO uint32_t  CNTR;                                    /*!< 0030H */
    __IO uint32_t  UPCNTR;                                  /*!< 0034H */
    __IO uint32_t  CNTCR;                                   /*!< 0038H */
    __IO uint32_t  Reserved2[1];                            /*!< 003CH */
    __O  uint32_t  IKYR;                                    /*!< 0040H */
    __IO uint32_t  Reserved3[47];                           /*!< 0044H */
    __IO uint32_t  MEMRMP;                                  /*!< 0100H */
    __IO uint32_t  Reserved4[63];                           /*!< 0104H */
    union {
        __I   uint32_t  V32;                                /*!< 0200H */
        struct {
    __I  uint32_t  OPT0:8;                                  /*!< 0200H */
    __I  uint32_t  OPT1:8;                                  /*!< 0201H */
    __I  uint32_t  OPT2:8;                                  /*!< 0202H */
    __I  uint32_t  OPT3:8;                                  /*!< 0203H */
        }BIT;
    }OPR_CUST1;                              /*!< 0200H */
    union {
        __I   uint32_t  V32;                                /*!< 0204H */
        struct {
    __I  uint32_t  OPT0:8;                                  /*!< 0204H */
    __I  uint32_t  OPT1:8;                                  /*!< 0205H */
    __I  uint32_t  OPT2:8;                                  /*!< 0206H */
    __I  uint32_t  OPT3:8;                                  /*!< 0207H */
        }BIT;
    }OPR_DESI0;                              /*!< 0204H */
    union {
        __I   uint32_t  V32;                                /*!< 0208H */
        struct {
    __I  uint32_t  OPT0:8;                                  /*!< 0208H */
    __I  uint32_t  OPT1:8;                                  /*!< 0209H */
    __I  uint32_t  OPT2:8;                                  /*!< 020AH */
    __I  uint32_t  OPT3:8;                                  /*!< 020BH */
        }BIT;
    }OPR_DESI1;                              /*!< 0208H */
    union {
        __I   uint32_t  V32;                                /*!< 020CH */
        struct {
    __I  uint32_t  OPT0:8;                                  /*!< 020CH */
    __I  uint32_t  OPT1:8;                                  /*!< 020DH */
    __I  uint32_t  OPT2:8;                                  /*!< 020EH */
    __I  uint32_t  OPT3:8;                                  /*!< 020FH */
        }BIT;
    }OPR_DESI2;                              /*!< 020CH */
    union {
        __I   uint32_t  V32;                                /*!< 0210H */
        struct {
    __I  uint32_t  OPT0:8;                                  /*!< 0210H */
    __I  uint32_t  OPT1:8;                                  /*!< 0211H */
    __I  uint32_t  OPT2:8;                                  /*!< 0212H */
    __I  uint32_t  OPT3:8;                                  /*!< 0213H */
        }BIT;
    }OPR_DESI3;                              /*!< 0210H */
}FLASH_TypeDef;


/**
*@brief SYSCFG_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  VBOD      : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  BODMD     : 2;  /*!< [b5~b4]*/
            __IO  uint32_t  BODIE     : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  BODEN     : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  VLVR      : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  LVREN     : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  rev0      :22;  /*!< [b31~b10]*/
        }BIT;
    }PWRCR;                               /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  BODIF     : 1;  /*!< [b0~b0]*/
            __I   uint32_t  BODF      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  rev0      :30;  /*!< [b31~b2]*/
        }BIT;
    }PWRSR;                               /*!< 0004H */
    union {
        __IO  uint32_t  V32;                                /*!< 0008H */
        struct {
            __IO  uint32_t  OSCCFG    : 2;  /*!< [b1~b0]*/
            __IO  uint32_t  SWJCFG    : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  rev0      : 2;  /*!< [b4~b3]*/
            __IO  uint32_t  IEN_EXTI0 : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  IEN_BOD   : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  IEN_CSM   : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev1      : 8;  /*!< [b15~b8]*/
            __O   uint32_t  LOCK      :16;  /*!< [b31~b16]*/
        }BIT;
    }SAFR;                               /*!< 0008H */
    __IO uint32_t  Reserved0[1];                            /*!< 000CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0010H */
        struct {
            __IO  uint32_t  DBG_SLEEP : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  DBG_STOP  : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b5~b2]*/
            __IO  uint32_t  DBG_CAN   : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  DBG_QEI   : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  DBG_IWDT  : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  DBG_WWDT  : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  DBG_PCA   : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  DBG_TIM   : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  DBG_MCM   : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  DBG_UART  : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  DBG_SPI   : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  DBG_TWI   : 1;  /*!< [b15~b15]*/
            __O   uint32_t  LOCK      :16;  /*!< [b31~b16]*/
        }BIT;
    }DBGCR;                               /*!< 0010H */
}SYSCFG_TypeDef;


/**
*@brief RCC_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  SW        : 2;  /*!< [b1~b0]*/
            __I   uint32_t  SWS       : 2;  /*!< [b3~b2]*/
            __IO  uint32_t  HSEON     : 1;  /*!< [b4~b4]*/
            __I   uint32_t  HSERDY    : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  PLLON     : 1;  /*!< [b6~b6]*/
            __I   uint32_t  PLLRDY    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  CSMON     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  rev0      :23;  /*!< [b31~b9]*/
        }BIT;
    }CR;                               /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  HPRE      : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  PPRE      : 3;  /*!< [b5~b3]*/
            __IO  uint32_t  rev0      : 3;  /*!< [b8~b6]*/
            __IO  uint32_t  PLLK      : 3;  /*!< [b11~b9]*/
            __IO  uint32_t  PLLF      : 6;  /*!< [b17~b12]*/
            __IO  uint32_t  PLLSRC    : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  PLLXTPRE  : 1;  /*!< [b19~b19]*/
            __IO  uint32_t  HSE16M    : 1;  /*!< [b20~b20]*/
            __IO  uint32_t  rev1      :11;  /*!< [b31~b21]*/
        }BIT;
    }CFGR;                               /*!< 0004H */
    union {
        __IO  uint32_t  V32;                                /*!< 0008H */
        struct {
            __IO  uint32_t  rev0      : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  HSERDYIE  : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  PLLRDYIE  : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  rev1      :27;  /*!< [b31~b5]*/
        }BIT;
    }CIENR;                               /*!< 0008H */
    union {
        __I   uint32_t  V32;                                /*!< 000CH */
        struct {
            __IO  uint32_t  rev0      : 3;  /*!< [b2~b0]*/
            __I   uint32_t  HSERDYIF  : 1;  /*!< [b3~b3]*/
            __I   uint32_t  PLLRDYIF  : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b5~b5]*/
            __I   uint32_t  CSMHSEF   : 1;  /*!< [b6~b6]*/
            __I   uint32_t  CSMPLLF   : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev2      :24;  /*!< [b31~b8]*/
        }BIT;
    }CISTR;                               /*!< 000CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0010H */
        struct {
            __IO  uint32_t  rev0      : 3;  /*!< [b2~b0]*/
            __O   uint32_t  HSERDYC   : 1;  /*!< [b3~b3]*/
            __O   uint32_t  PLLRDYC   : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  rev1      : 2;  /*!< [b6~b5]*/
            __O   uint32_t  CSMC      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev2      :24;  /*!< [b31~b8]*/
        }BIT;
    }CICLR;                               /*!< 0010H */
    union {
        __IO  uint32_t  V32;                                /*!< 0014H */
        struct {
            __IO  uint32_t  GPIORST   : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  MCMRST    : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  SYSCFGRST : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  CRCRST    : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  MACPRST   : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  rev0      :27;  /*!< [b31~b5]*/
        }BIT;
    }AHBRSTR;                               /*!< 0014H */
    __IO uint32_t  Reserved0[1];                            /*!< 0018H */
    union {
        __IO  uint32_t  V32;                                /*!< 001CH */
        struct {
            __IO  uint32_t  TIM7RST   : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  TIM8RST   : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  QEIRST    : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  UART0RST  : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  UART1RST  : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  UART2RST  : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  SPI0RST   : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  TWI0RST   : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  WWDTRST   : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  AMOCRST   : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  PCA0RST   : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  PCA1RST   : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  ADCRST    : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  CAN0RST   : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  FIFO0RST  : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  FIFO1RST  : 1;  /*!< [b16~b16]*/
            __IO  uint32_t  FIFO2RST  : 1;  /*!< [b17~b17]*/
            __IO  uint32_t  rev1      :14;  /*!< [b31~b18]*/
        }BIT;
    }APB0RSTR;                               /*!< 001CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0020H */
        struct {
            __IO  uint32_t  GPIOEN    : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  MCMEN     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  SYSCFGEN  : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  CRCEN     : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  MACPEN    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  rev0      :27;  /*!< [b31~b5]*/
        }BIT;
    }AHBENR;                               /*!< 0020H */
    __IO uint32_t  Reserved1[1];                            /*!< 0024H */
    union {
        __IO  uint32_t  V32;                                /*!< 0028H */
        struct {
            __IO  uint32_t  TIM7EN    : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  TIM8EN    : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  QEIEN     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  UART0EN   : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  UART1EN   : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  UART2EN   : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  SPI0EN    : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  TWI0EN    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  WWDTEN    : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  AMOCEN    : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  PCA0EN    : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  PCA1EN    : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  ADCEN     : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  CAN0EN    : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  FIFO0EN   : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  FIFO1EN   : 1;  /*!< [b16~b16]*/
            __IO  uint32_t  FIFO2EN   : 1;  /*!< [b17~b17]*/
            __IO  uint32_t  rev1      :14;  /*!< [b31~b18]*/
        }BIT;
    }APB0ENR;                               /*!< 0028H */
    union {
        __I   uint32_t  V32;                                /*!< 002CH */
        struct {
            __I   uint32_t  PINRSTF   : 1;  /*!< [b0~b0]*/
            __I   uint32_t  LVRSTF    : 1;  /*!< [b1~b1]*/
            __I   uint32_t  PORSTF    : 1;  /*!< [b2~b2]*/
            __I   uint32_t  SWRSTF    : 1;  /*!< [b3~b3]*/
            __I   uint32_t  IWDTRSTF  : 1;  /*!< [b4~b4]*/
            __I   uint32_t  WWDTRSTF  : 1;  /*!< [b5~b5]*/
            __I   uint32_t  LVRSTF2   : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  rev0      :25;  /*!< [b31~b7]*/
        }BIT;
    }RSTSTR;                               /*!< 002CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0030H */
        struct {
            __O   uint32_t  PINRSTFC  : 1;  /*!< [b0~b0]*/
            __O   uint32_t  LVRSTFC   : 1;  /*!< [b1~b1]*/
            __O   uint32_t  PORSTFC   : 1;  /*!< [b2~b2]*/
            __O   uint32_t  SWRSTFC   : 1;  /*!< [b3~b3]*/
            __O   uint32_t  IWDTRSTFC : 1;  /*!< [b4~b4]*/
            __O   uint32_t  WWDTRSTFC : 1;  /*!< [b5~b5]*/
            __O   uint32_t  LVRSTF2C  : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  rev0      :25;  /*!< [b31~b7]*/
        }BIT;
    }RSTCLR;                               /*!< 0030H */
    union {
        __IO  uint32_t  V32;                                /*!< 0034H */
        struct {
            __IO  uint32_t  HSITRIM   : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  rev0      : 5;  /*!< [b7~b3]*/
            __I   uint32_t  HSICAL    : 8;  /*!< [b15~b8]*/
            __I   uint32_t  TRIMREF   :13;  /*!< [b28~b16]*/
            __IO  uint32_t  rev1      : 2;  /*!< [b30~b29]*/
            __IO  uint32_t  TRIMRUN   : 1;  /*!< [b31~b31]*/
        }BIT;
    }HSICAL;                               /*!< 0034H */
    __IO uint32_t  RCCLOCK;                                 /*!< 0038H */
}RCC_TypeDef;


/**
*@brief IWDT_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  IWDTRLR   :12;  /*!< [b11~b0]*/
            __IO  uint32_t  IWDTPR    : 3;  /*!< [b14~b12]*/
            __IO  uint32_t  IWDTON    : 1;  /*!< [b15~b15]*/
            __O   uint32_t  LOCK      :16;  /*!< [b31~b16]*/
        }BIT;
    }CR;                               /*!< 0000H */
    __O  uint32_t  CLR;                                     /*!< 0004H */
}IWDT_TypeDef;


/**
*@brief WWDT_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  WWDTRLR   : 8;  /*!< [b7~b0]*/
            __IO  uint32_t  WWDTPR    : 3;  /*!< [b10~b8]*/
            __IO  uint32_t  rev0      : 3;  /*!< [b13~b11]*/
            __IO  uint32_t  WWDTIE    : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  WWDTON    : 1;  /*!< [b15~b15]*/
            __O   uint32_t  LOCK      :16;  /*!< [b31~b16]*/
        }BIT;
    }CR;                               /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __I   uint32_t  TCNT      : 8;  /*!< [b7~b0]*/
            __IO  uint32_t  rev0      : 7;  /*!< [b14~b8]*/
            __IO  uint32_t  WWDTIF    : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }SR;                               /*!< 0004H */
    __O  uint32_t  CLR;                                     /*!< 0008H */
    union {
        __IO  uint32_t  V32;                                /*!< 000CH */
        struct {
    __IO uint32_t  WWDTWTR:8;                               /*!< 000CH */
    __IO uint32_t  rev0:8;                                  /*!< 000DH */
    __O  uint32_t  LOCK:16;                                 /*!< 000EH */
        }BIT;
    }WTR;                              /*!< 000CH */
}WWDT_TypeDef;


/**
*@brief CRC_registers
*/
typedef struct
{
    __IO uint32_t  DR;                                      /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __O   uint32_t  RELOAD    : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  rev0      : 7;  /*!< [b7~b1]*/
            __IO  uint32_t  MODE      : 2;  /*!< [b9~b8]*/
            __IO  uint32_t  COMPLW    : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  RBITW     : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  RBYTEW    : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  COMPLR    : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  RBITR     : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  RBYTER    : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }CR;                               /*!< 0004H */
    __IO uint32_t  INIT;                                    /*!< 0008H */
}CRC_TypeDef;


/**
*@brief RAMBIST_registers
*/
typedef struct
{
    __IO uint32_t  ADDR;                                    /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  BLKSZ     : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  rev0      :12;  /*!< [b14~b3]*/
            __IO  uint32_t  SEL       : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }CFG;                               /*!< 0004H */
    union {
        __IO  uint32_t  V32;                                /*!< 0008H */
        struct {
            __O   uint32_t  RUN       :16;  /*!< [b15~b0]*/
            __IO  uint32_t  MOD       : 1;  /*!< [b16~b16]*/
            __I   uint32_t  BSY       : 1;  /*!< [b17~b17]*/
            __IO  uint32_t  ERR       : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  rev0      :13;  /*!< [b31~b19]*/
        }BIT;
    }CSR;                               /*!< 0008H */
}RAMBIST_TypeDef;


/**
*@brief GPIO_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  MODER0    : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  MODER1    : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  MODER2    : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  MODER3    : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  MODER4    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  MODER5    : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  MODER6    : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  MODER7    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  MODER8    : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  MODER9    : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  MODER10   : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  MODER11   : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  MODER12   : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  MODER13   : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  MODER14   : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  MODER15   : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }MODER;                               /*!< 0000H */
    __I  uint32_t  IDR;                                     /*!< 0004H */
    __IO uint32_t  ODR;                                     /*!< 0008H */
    union {
        __IO  uint32_t  V32;                                /*!< 000CH */
        struct {
    __O  uint32_t  BS:16;                                   /*!< 000CH */
    __O  uint32_t  BR:16;                                   /*!< 000EH */
        }BIT;
    }BSRR;                              /*!< 000CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0010H */
        struct {
            __IO  uint32_t  LCK0      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  LCK1      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  LCK2      : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  LCK3      : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  LCK4      : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  LCK5      : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  LCK6      : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  LCK7      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  LCK8      : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  LCK9      : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  LCK10     : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  LCK11     : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  LCK12     : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  LCK13     : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  LCK14     : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  LCK15     : 1;  /*!< [b15~b15]*/
            __O   uint32_t  LOCK      :16;  /*!< [b31~b16]*/
        }BIT;
    }LCKR;                               /*!< 0010H */
    union {
        __IO  uint32_t  V32;                                /*!< 0014H */
        struct {
            __IO  uint32_t  IE0       : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  IE1       : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  IE2       : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  IE3       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  IE4       : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IE5       : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  IE6       : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  IE7       : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  IE8       : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  IE9       : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  IE10      : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  IE11      : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  IE12      : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  IE13      : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  IE14      : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  IE15      : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }IE;                               /*!< 0014H */
    union {
        __IO  uint32_t  V32;                                /*!< 0018H */
        struct {
            __IO  uint32_t  OT0       : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  OT2       : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  rev1      :10;  /*!< [b12~b3]*/
            __IO  uint32_t  OT13      : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  OT14      : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  rev2      :17;  /*!< [b31~b15]*/
        }BIT;
    }OTYPER;                               /*!< 0018H */
    __IO uint32_t  ODRVR;                                   /*!< 001CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0020H */
        struct {
            __IO  uint32_t  PHDR0     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  PHDR1     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  PHDR2     : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  rev2      : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  PHDR3     : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  rev3      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  PHDR4     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  rev4      : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  PHDR5     : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  rev5      : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  PHDR6     : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  rev6      : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  PHDR7     : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  rev7      : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  PHDR8     : 1;  /*!< [b16~b16]*/
            __IO  uint32_t  rev8      : 1;  /*!< [b17~b17]*/
            __IO  uint32_t  PHDR9     : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  rev9      : 1;  /*!< [b19~b19]*/
            __IO  uint32_t  PHDR10    : 1;  /*!< [b20~b20]*/
            __IO  uint32_t  rev10     : 1;  /*!< [b21~b21]*/
            __IO  uint32_t  PHDR11    : 1;  /*!< [b22~b22]*/
            __IO  uint32_t  rev11     : 1;  /*!< [b23~b23]*/
            __IO  uint32_t  PHDR12    : 1;  /*!< [b24~b24]*/
            __IO  uint32_t  rev12     : 1;  /*!< [b25~b25]*/
            __IO  uint32_t  PHDR13    : 1;  /*!< [b26~b26]*/
            __IO  uint32_t  rev13     : 1;  /*!< [b27~b27]*/
            __IO  uint32_t  PHDR14    : 1;  /*!< [b28~b28]*/
            __IO  uint32_t  rev14     : 1;  /*!< [b29~b29]*/
            __IO  uint32_t  PHDR15    : 1;  /*!< [b30~b30]*/
            __IO  uint32_t  rev15     : 1;  /*!< [b31~b31]*/
        }BIT;
    }PUPDR;                               /*!< 0020H */
    union {
        __IO  uint32_t  V32;                                /*!< 0024H */
        struct {
            __IO  uint32_t  TTLEN0    : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  TTLEN1    : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  TTLEN2    : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  rev0      : 3;  /*!< [b5~b3]*/
            __IO  uint32_t  TTLEN6    : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  rev1      : 2;  /*!< [b8~b7]*/
            __IO  uint32_t  TTLEN9    : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  rev2      : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  TTLEN11   : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  TTLEN12   : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  TTLEN13   : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  TTLEN14   : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  rev3      :17;  /*!< [b31~b15]*/
        }BIT;
    }TTLEN;                               /*!< 0024H */
    union {
        __IO  uint32_t  V32;                                /*!< 0028H */
        struct {
            __IO  uint32_t  AFR0      : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  AFR1      : 3;  /*!< [b6~b4]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  AFR2      : 3;  /*!< [b10~b8]*/
            __IO  uint32_t  rev2      : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  AFR3      : 3;  /*!< [b14~b12]*/
            __IO  uint32_t  rev3      : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  AFR4      : 3;  /*!< [b18~b16]*/
            __IO  uint32_t  rev4      : 1;  /*!< [b19~b19]*/
            __IO  uint32_t  AFR5      : 3;  /*!< [b22~b20]*/
            __IO  uint32_t  rev5      : 1;  /*!< [b23~b23]*/
            __IO  uint32_t  AFR6      : 3;  /*!< [b26~b24]*/
            __IO  uint32_t  rev6      : 1;  /*!< [b27~b27]*/
            __IO  uint32_t  AFR7      : 3;  /*!< [b30~b28]*/
            __IO  uint32_t  rev7      : 1;  /*!< [b31~b31]*/
        }BIT;
    }AFRL;                               /*!< 0028H */
    union {
        __IO  uint32_t  V32;                                /*!< 002CH */
        struct {
            __IO  uint32_t  AFR8      : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  AFR9      : 3;  /*!< [b6~b4]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  AFR10     : 3;  /*!< [b10~b8]*/
            __IO  uint32_t  rev2      : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  AFR11     : 3;  /*!< [b14~b12]*/
            __IO  uint32_t  rev3      : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  AFR12     : 3;  /*!< [b18~b16]*/
            __IO  uint32_t  rev4      : 1;  /*!< [b19~b19]*/
            __IO  uint32_t  AFR13     : 3;  /*!< [b22~b20]*/
            __IO  uint32_t  rev5      : 1;  /*!< [b23~b23]*/
            __IO  uint32_t  AFR14     : 3;  /*!< [b26~b24]*/
            __IO  uint32_t  rev6      : 1;  /*!< [b27~b27]*/
            __IO  uint32_t  AFR15     : 3;  /*!< [b30~b28]*/
            __IO  uint32_t  rev7      : 1;  /*!< [b31~b31]*/
        }BIT;
    }AFRH;                               /*!< 002CH */
}GPIO_TypeDef;


/**
*@brief EXTI_registers
*/
typedef struct
{
    __IO uint32_t  IMR;                                     /*!< 0000H */
    __IO uint32_t  EMR;                                     /*!< 0004H */
    __IO uint32_t  TMSR;                                    /*!< 0008H */
    __IO uint32_t  RTSR;                                    /*!< 000CH */
    __IO uint32_t  FTSR;                                    /*!< 0010H */
    __O  uint32_t  SWIER;                                   /*!< 0014H */
    union {
        __IO  uint32_t  V32;                                /*!< 0018H */
        struct {
    __I  uint32_t  PR:8;                                    /*!< 0018H */
    __IO uint32_t  rev0:8;                                  /*!< 0019H */
    __O  uint32_t  PRC:8;                                   /*!< 001AH */
    __IO uint32_t  rev1:8;                                  /*!< 001BH */
        }BIT;
    }PR;                              /*!< 0018H */
    union {
        __IO  uint32_t  V32;                                /*!< 001CH */
        struct {
            __IO  uint32_t  EXTI0_EN  : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  EXTI1_EN  : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  EXTI2_EN  : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  EXTI3_EN  : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  EXTI4_EN  : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  EXTI5_EN  : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  EXTI6_EN  : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  EXTI7_EN  : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev0      :24;  /*!< [b31~b8]*/
        }BIT;
    }CFG;                               /*!< 001CH */
    __IO uint32_t  CFGH;                                    /*!< 0020H */
    union {
        __IO  uint32_t  V32;                                /*!< 0024H */
        struct {
            __IO  uint32_t  SN0       : 2;  /*!< [b1~b0]*/
            __IO  uint32_t  PS0       : 2;  /*!< [b3~b2]*/
            __IO  uint32_t  SN1       : 2;  /*!< [b5~b4]*/
            __IO  uint32_t  PS1       : 2;  /*!< [b7~b6]*/
            __IO  uint32_t  SN2       : 2;  /*!< [b9~b8]*/
            __IO  uint32_t  PS2       : 2;  /*!< [b11~b10]*/
            __IO  uint32_t  SN3       : 2;  /*!< [b13~b12]*/
            __IO  uint32_t  PS3       : 2;  /*!< [b15~b14]*/
            __IO  uint32_t  SN4       : 2;  /*!< [b17~b16]*/
            __IO  uint32_t  PS4       : 2;  /*!< [b19~b18]*/
            __IO  uint32_t  SN5       : 2;  /*!< [b21~b20]*/
            __IO  uint32_t  PS5       : 2;  /*!< [b23~b22]*/
            __IO  uint32_t  SN6       : 2;  /*!< [b25~b24]*/
            __IO  uint32_t  PS6       : 2;  /*!< [b27~b26]*/
            __IO  uint32_t  SN7       : 2;  /*!< [b29~b28]*/
            __IO  uint32_t  PS7       : 2;  /*!< [b31~b30]*/
        }BIT;
    }SAMP;                               /*!< 0024H */
}EXTI_TypeDef;


/**
*@brief MCM_registers
*/
typedef struct
{
    __IO uint32_t  PWMOE;                                   /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  PWM0S     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  PWM1S     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  PWM2S     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  PWM01S    : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  PWM11S    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  PWM21S    : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  PDCON0    : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  PDCON1    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  PDCON2    : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  PWMSYM    : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  PTMOD     : 2;  /*!< [b11~b10]*/
            __IO  uint32_t  POSTPS    : 3;  /*!< [b14~b12]*/
            __IO  uint32_t  POUTMOD   : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }PWMCON1;                               /*!< 0004H */
    union {
        __IO  uint32_t  V32;                                /*!< 0008H */
        struct {
            __IO  uint32_t  CMP1      : 2;  /*!< [b1~b0]*/
            __IO  uint32_t  CMP2      : 2;  /*!< [b3~b2]*/
            __IO  uint32_t  CMP3      : 2;  /*!< [b5~b4]*/
            __IO  uint32_t  CMP4      : 2;  /*!< [b7~b6]*/
            __IO  uint32_t  OSYNC     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  DILDEN    : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  CILDEN    : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  ZDLDEN    : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  PDLDEN    : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  ZCMLDEN   : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  PCMLDEN   : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  rev0      :17;  /*!< [b31~b15]*/
        }BIT;
    }PWMCON2;                               /*!< 0008H */
    __IO uint32_t  PWMP;                                    /*!< 000CH */
    __IO uint32_t  PWMC;                                    /*!< 0010H */
    __IO uint32_t  PWMPSQ;                                  /*!< 0014H */
    __IO uint32_t  PWM0D;                                   /*!< 0018H */
    __IO uint32_t  PWM1D;                                   /*!< 001CH */
    __IO uint32_t  PWM2D;                                   /*!< 0020H */
    __IO uint32_t  PWM01D;                                  /*!< 0024H */
    __IO uint32_t  PWM11D;                                  /*!< 0028H */
    __IO uint32_t  PWM21D;                                  /*!< 002CH */
    __IO uint32_t  PWMCMP1;                                 /*!< 0030H */
    __IO uint32_t  PWMCMP2;                                 /*!< 0034H */
    __IO uint32_t  PWMCMP3;                                 /*!< 0038H */
    __IO uint32_t  PWMCMP4;                                 /*!< 003CH */
    __IO uint32_t  PWMDT00;                                 /*!< 0040H */
    __IO uint32_t  PWMDT01;                                 /*!< 0044H */
    __IO uint32_t  PWMDT10;                                 /*!< 0048H */
    __IO uint32_t  PWMDT11;                                 /*!< 004CH */
    __IO uint32_t  PWMDT20;                                 /*!< 0050H */
    __IO uint32_t  PWMDT21;                                 /*!< 0054H */
    union {
        __IO  uint32_t  V32;                                /*!< 0058H */
        struct {
            __IO  uint32_t  PMANUAL0  : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  PMANUAL1  : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  PMANUAL2  : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  PMANUAL01 : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  PMANUAL11 : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  PMANUAL21 : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  rev0      :26;  /*!< [b31~b6]*/
        }BIT;
    }PMANUALCON1;                               /*!< 0058H */
    union {
        __IO  uint32_t  V32;                                /*!< 005CH */
        struct {
            __IO  uint32_t  POUT0     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  POUT1     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  POUT2     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  POUT01    : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  POUT11    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  POUT21    : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  rev0      :26;  /*!< [b31~b6]*/
        }BIT;
    }PMANUALCON2;                               /*!< 005CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0060H */
        struct {
            __I   uint32_t  FLT2STAT  : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  FLT2M     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  FLT2S     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  FLT2EN    : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  FLT2DEB   : 4;  /*!< [b7~b4]*/
            __I   uint32_t  FLT1STAT  : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  FLT1M     : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  FLT1S     : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  FLT1EN    : 1;  /*!< [b11~b11]*/
            __I   uint32_t  FLT0STAT  : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  FLT0M     : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  FLT0S     : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  FLT0EN    : 1;  /*!< [b15~b15]*/
            __O   uint32_t  FLT2STATC : 1;  /*!< [b16~b16]*/
            __O   uint32_t  FLT1STATC : 1;  /*!< [b17~b17]*/
            __O   uint32_t  FLT0STATC : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b19~b19]*/
            __IO  uint32_t  FOUT0     : 2;  /*!< [b21~b20]*/
            __IO  uint32_t  FOUT1     : 2;  /*!< [b23~b22]*/
            __IO  uint32_t  rev1      : 8;  /*!< [b31~b24]*/
        }BIT;
    }FLTCON;                               /*!< 0060H */
    union {
        __IO  uint32_t  V32;                                /*!< 0064H */
        struct {
            __IO  uint32_t  OLSG0     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  OLSG1     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  OLSG2     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  OLSG01    : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  OLSG11    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  OLSG21    : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  OLSEN     : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev1      :24;  /*!< [b31~b8]*/
        }BIT;
    }POSCR;                               /*!< 0064H */
    __IO uint32_t  Reserved0[2];                            /*!< 0068H */
    union {
        __IO  uint32_t  V32;                                /*!< 0070H */
        struct {
            __IO  uint32_t  rev0      : 7;  /*!< [b6~b0]*/
            __IO  uint32_t  OSTDEN    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev1      :24;  /*!< [b31~b8]*/
        }BIT;
    }POSTDCR;                               /*!< 0070H */
    union {
        __IO  uint32_t  V32;                                /*!< 0074H */
        struct {
            __IO  uint32_t  PTUD0IE   : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  PTDD0IE   : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  PTUD1IE   : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  PTDD1IE   : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  PTUD2IE   : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  PTDD2IE   : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  PWMZIE    : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  PWMPIE    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  FLTIE     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  FLTCMP0IE : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  FLTCMP1IE : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  OIE       : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  OSTDIE    : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  rev0      :19;  /*!< [b31~b13]*/
        }BIT;
    }PWMINTEN;                               /*!< 0074H */
    union {
        __IO  uint32_t  V32;                                /*!< 0078H */
        struct {
            __I   uint32_t  PTUD0IF   : 1;  /*!< [b0~b0]*/
            __I   uint32_t  PTDD0IF   : 1;  /*!< [b1~b1]*/
            __I   uint32_t  PTUD1IF   : 1;  /*!< [b2~b2]*/
            __I   uint32_t  PTDD1IF   : 1;  /*!< [b3~b3]*/
            __I   uint32_t  PTUD2IF   : 1;  /*!< [b4~b4]*/
            __I   uint32_t  PTDD2IF   : 1;  /*!< [b5~b5]*/
            __I   uint32_t  PWMZIF    : 1;  /*!< [b6~b6]*/
            __I   uint32_t  PWMPIF    : 1;  /*!< [b7~b7]*/
            __I   uint32_t  FLTIF     : 1;  /*!< [b8~b8]*/
            __I   uint32_t  FLTCMP0IF : 1;  /*!< [b9~b9]*/
            __I   uint32_t  FLTCMP1IF : 1;  /*!< [b10~b10]*/
            __I   uint32_t  OSF       : 1;  /*!< [b11~b11]*/
            __I   uint32_t  OSTDF     : 1;  /*!< [b12~b12]*/
            __I   uint32_t  SC0STAT   : 1;  /*!< [b13~b13]*/
            __I   uint32_t  SC1STAT   : 1;  /*!< [b14~b14]*/
            __I   uint32_t  SC2STAT   : 1;  /*!< [b15~b15]*/
            __O   uint32_t  PTUD0IFC  : 1;  /*!< [b16~b16]*/
            __O   uint32_t  PTDD0IFC  : 1;  /*!< [b17~b17]*/
            __O   uint32_t  PTUD1IFC  : 1;  /*!< [b18~b18]*/
            __O   uint32_t  PTDD1IFC  : 1;  /*!< [b19~b19]*/
            __O   uint32_t  PTUD2IFC  : 1;  /*!< [b20~b20]*/
            __O   uint32_t  PTDD2IFC  : 1;  /*!< [b21~b21]*/
            __O   uint32_t  PWMZIFC   : 1;  /*!< [b22~b22]*/
            __O   uint32_t  PWMPIFC   : 1;  /*!< [b23~b23]*/
            __O   uint32_t  FLTIFC    : 1;  /*!< [b24~b24]*/
            __O   uint32_t  FLTCMP0IFC: 1;  /*!< [b25~b25]*/
            __O   uint32_t  FLTCMP1IFC: 1;  /*!< [b26~b26]*/
            __O   uint32_t  OSFC      : 1;  /*!< [b27~b27]*/
            __O   uint32_t  OSTDFC    : 1;  /*!< [b28~b28]*/
            __O   uint32_t  SC0STATC  : 1;  /*!< [b29~b29]*/
            __O   uint32_t  SC1STATC  : 1;  /*!< [b30~b30]*/
            __O   uint32_t  SC2STATC  : 1;  /*!< [b31~b31]*/
        }BIT;
    }PWMINTF;                               /*!< 0078H */
    __IO uint32_t  PWMRLDEN;                                /*!< 007CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0080H */
        struct {
            __IO  uint32_t  SHIFTRUN  : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  STATRUN   : 1;  /*!< [b1~b1]*/
            __I   uint32_t  OVER      : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b3~b3]*/
            __I   uint32_t  SECTOR    : 3;  /*!< [b6~b4]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  MAXSELECT : 2;  /*!< [b9~b8]*/
            __IO  uint32_t  MINSELECT : 2;  /*!< [b11~b10]*/
            __IO  uint32_t  rev2      :20;  /*!< [b31~b12]*/
        }BIT;
    }PSCON;                               /*!< 0080H */
    __IO uint32_t  PWMDMAX;                                 /*!< 0084H */
    __IO uint32_t  PWMDMIN;                                 /*!< 0088H */
    __IO uint32_t  PWMDCMP1;                                /*!< 008CH */
    __IO uint32_t  PWMDCMP2;                                /*!< 0090H */
    union {
        __IO  uint32_t  V32;                                /*!< 0094H */
        struct {
            __IO  uint32_t  SCTIME    : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  SCDEB     : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  SCPWM0EN  : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  SCPWM1EN  : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  SCPWM2EN  : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  SCS       : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  SCEN      : 2;  /*!< [b13~b12]*/
            __IO  uint32_t  rev0      :18;  /*!< [b31~b14]*/
        }BIT;
    }SC0CON;                               /*!< 0094H */
    union {
        __IO  uint32_t  V32;                                /*!< 0098H */
        struct {
            __IO  uint32_t  SCTIME    : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  SCDEB     : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  SCPWM0EN  : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  SCPWM1EN  : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  SCPWM2EN  : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  SCS       : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  SCEN      : 2;  /*!< [b13~b12]*/
            __IO  uint32_t  rev0      :18;  /*!< [b31~b14]*/
        }BIT;
    }SC1CON;                               /*!< 0098H */
    union {
        __IO  uint32_t  V32;                                /*!< 009CH */
        struct {
            __IO  uint32_t  SCTIME    : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  SCDEB     : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  SCPWM0EN  : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  SCPWM1EN  : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  SCPWM2EN  : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  SCS       : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  SCEN      : 2;  /*!< [b13~b12]*/
            __IO  uint32_t  rev0      :18;  /*!< [b31~b14]*/
        }BIT;
    }SC2CON;                               /*!< 009CH */
    __IO uint32_t  FLTWEN;                                  /*!< 00A0H */
}MCM_TypeDef;


/**
*@brief PCA_registers
*/
typedef struct
{
    __IO uint32_t  CR;                                      /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  CPS       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  rev0      : 3;  /*!< [b5~b3]*/
            __IO  uint32_t  SDEN      : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  CIE       : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  PIE       : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  ADTSEL    : 2;  /*!< [b10~b9]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  CC0UE     : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  CC1UE     : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  CC2UE     : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  PUE       : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  ECF       : 2;  /*!< [b17~b16]*/
            __IO  uint32_t  SYN       : 2;  /*!< [b19~b18]*/
            __IO  uint32_t  rev2      :12;  /*!< [b31~b20]*/
        }BIT;
    }CFGR;                               /*!< 0004H */
    union {
        __IO  uint32_t  V32;                                /*!< 0008H */
        struct {
            __I   uint32_t  CC0IF     : 1;  /*!< [b0~b0]*/
            __I   uint32_t  CC1IF     : 1;  /*!< [b1~b1]*/
            __I   uint32_t  CC2IF     : 1;  /*!< [b2~b2]*/
            __I   uint32_t  FLTIF     : 1;  /*!< [b3~b3]*/
            __I   uint32_t  PIF       : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  rev0      : 2;  /*!< [b6~b5]*/
            __I   uint32_t  CIF       : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev1      : 8;  /*!< [b15~b8]*/
            __O   uint32_t  CC0IFC    : 1;  /*!< [b16~b16]*/
            __O   uint32_t  CC1IFC    : 1;  /*!< [b17~b17]*/
            __O   uint32_t  CC2IFC    : 1;  /*!< [b18~b18]*/
            __O   uint32_t  FLTIFC    : 1;  /*!< [b19~b19]*/
            __O   uint32_t  PIFC      : 1;  /*!< [b20~b20]*/
            __IO  uint32_t  rev2      : 2;  /*!< [b22~b21]*/
            __O   uint32_t  CIFC      : 1;  /*!< [b23~b23]*/
            __IO  uint32_t  rev3      : 8;  /*!< [b31~b24]*/
        }BIT;
    }SR;                               /*!< 0008H */
    union {
        __IO  uint32_t  V32;                                /*!< 000CH */
        struct {
            __IO  uint32_t  FCO0      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  FCO1      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  FCO2      : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  rev0      :29;  /*!< [b31~b3]*/
        }BIT;
    }FORCE;                               /*!< 000CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0010H */
        struct {
    __IO uint32_t  CNTL:16;                                 /*!< 0010H */
    __IO uint32_t  CNTH:16;                                 /*!< 0012H */
        }BIT;
    }CNT;                              /*!< 0010H */
    __IO uint32_t  PSC;                                     /*!< 0014H */
    union {
        __IO  uint32_t  V32;                                /*!< 0018H */
        struct {
    __IO uint32_t  PRL:16;                                  /*!< 0018H */
    __IO uint32_t  PRH:16;                                  /*!< 001AH */
        }BIT;
    }PR;                              /*!< 0018H */
    union {
        __IO  uint32_t  V32;                                /*!< 001CH */
        struct {
            __IO  uint32_t  CCIE      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  TCP       : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  CEN       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  FS        : 2;  /*!< [b5~b4]*/
            __IO  uint32_t  SM        : 2;  /*!< [b7~b6]*/
            __IO  uint32_t  CC        : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  ICF       : 3;  /*!< [b11~b9]*/
            __IO  uint32_t  CSSEL     : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  rev1      :19;  /*!< [b31~b13]*/
        }BIT;
    }CCMR0;                               /*!< 001CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0020H */
        struct {
            __IO  uint32_t  CCIE      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  TCP       : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  CEN       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  FS        : 2;  /*!< [b5~b4]*/
            __IO  uint32_t  SM        : 2;  /*!< [b7~b6]*/
            __IO  uint32_t  CC        : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  ICF       : 3;  /*!< [b11~b9]*/
            __IO  uint32_t  CSSEL     : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  rev1      :19;  /*!< [b31~b13]*/
        }BIT;
    }CCMR1;                               /*!< 0020H */
    union {
        __IO  uint32_t  V32;                                /*!< 0024H */
        struct {
            __IO  uint32_t  CCIE      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  TCP       : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  CEN       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  FS        : 2;  /*!< [b5~b4]*/
            __IO  uint32_t  SM        : 2;  /*!< [b7~b6]*/
            __IO  uint32_t  CC        : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  ICF       : 3;  /*!< [b11~b9]*/
            __IO  uint32_t  CSSEL     : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  rev1      :19;  /*!< [b31~b13]*/
        }BIT;
    }CCMR2;                               /*!< 0024H */
    union {
        __IO  uint32_t  V32;                                /*!< 0028H */
        struct {
    __IO uint32_t  CCR0L:16;                                /*!< 0028H */
    __IO uint32_t  CCR0H:16;                                /*!< 002AH */
        }BIT;
    }CCR0;                              /*!< 0028H */
    union {
        __IO  uint32_t  V32;                                /*!< 002CH */
        struct {
    __IO uint32_t  CCR1L:16;                                /*!< 002CH */
    __IO uint32_t  CCR1H:16;                                /*!< 002EH */
        }BIT;
    }CCR1;                              /*!< 002CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0030H */
        struct {
    __IO uint32_t  CCR2L:16;                                /*!< 0030H */
    __IO uint32_t  CCR2H:16;                                /*!< 0032H */
        }BIT;
    }CCR2;                              /*!< 0030H */
    __IO uint32_t  LCKR;                                    /*!< 0034H */
    __IO uint32_t  ADTR;                                    /*!< 0038H */
    __IO uint32_t  FLTWPR;                                  /*!< 003CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0040H */
        struct {
            __IO  uint32_t  FLTSTAT   : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  FLTM      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  FLT2S     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  FLT2EN    : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  FLT2DEB   : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  FLT1SEL   : 2;  /*!< [b9~b8]*/
            __IO  uint32_t  FLT1EN    : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  FLTSYN    : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  FOUT      : 2;  /*!< [b13~b12]*/
            __IO  uint32_t  FLTIE     : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  rev0      :17;  /*!< [b31~b15]*/
        }BIT;
    }FLTCR;                               /*!< 0040H */
}PCA_TypeDef;


/**
*@brief TIM_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  STR       : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  rev0      : 2;  /*!< [b2~b1]*/
            __IO  uint32_t  OPM       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  CLKS      : 2;  /*!< [b5~b4]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  IE        : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  TRIGEN    : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  ETEN      : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  TC        : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  rev2      : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  ECF       : 2;  /*!< [b13~b12]*/
            __IO  uint32_t  rev3      : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  CASCEN    : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev4      :16;  /*!< [b31~b16]*/
        }BIT;
    }CR;                               /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
    __IO uint32_t  TCNTL:16;                                /*!< 0004H */
    __IO uint32_t  TCNTH:16;                                /*!< 0006H */
        }BIT;
    }TCNT;                              /*!< 0004H */
    union {
        __IO  uint32_t  V32;                                /*!< 0008H */
        struct {
    __IO uint32_t  TPRL:16;                                 /*!< 0008H */
    __IO uint32_t  TPRH:16;                                 /*!< 000AH */
        }BIT;
    }TPR;                              /*!< 0008H */
    union {
        __IO  uint32_t  V32;                                /*!< 000CH */
        struct {
    __IO uint32_t  PSQL:16;                                 /*!< 000CH */
    __IO uint32_t  PSQH:16;                                 /*!< 000EH */
        }BIT;
    }PSQ;                              /*!< 000CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0010H */
        struct {
            __I   uint32_t  TF        : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  rev0      :15;  /*!< [b15~b1]*/
            __O   uint32_t  TFC       : 1;  /*!< [b16~b16]*/
            __IO  uint32_t  rev1      :15;  /*!< [b31~b17]*/
        }BIT;
    }TIMINTF;                               /*!< 0010H */
}TIM_TypeDef;


/**
*@brief QEI_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  QPMOD     : 2;  /*!< [b1~b0]*/
            __IO  uint32_t  QTSR      : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  QEIEN     : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  QIDXEN    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  QSWAP     : 1;  /*!< [b5~b5]*/
            __I   uint32_t  QIDXS     : 1;  /*!< [b6~b6]*/
            __I   uint32_t  QPDIR     : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  QTEPS     : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  rev0      :20;  /*!< [b31~b12]*/
        }BIT;
    }QEICON;                               /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  QABCPS    : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  QABFEN    : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  QIDXCPS   : 3;  /*!< [b6~b4]*/
            __IO  uint32_t  QIDXFEN   : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev0      :24;  /*!< [b31~b8]*/
        }BIT;
    }QFLTCON;                               /*!< 0004H */
    __IO uint32_t  QPOSCNT;                                 /*!< 0008H */
    __IO uint32_t  QPOSMAX;                                 /*!< 000CH */
    __I  uint32_t  QTMLAT;                                  /*!< 0010H */
    __IO uint32_t  QCNT;                                    /*!< 0014H */
    __IO uint32_t  QCNTMIN;                                 /*!< 0018H */
    __IO uint32_t  QTPR;                                    /*!< 001CH */
    __IO uint32_t  QTPSQ;                                   /*!< 0020H */
    union {
        __IO  uint32_t  V32;                                /*!< 0024H */
        struct {
            __IO  uint32_t  QPEIE     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  QCEIE     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  QEIIE     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  QTCAPIE   : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  QTIE      : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  rev0      :27;  /*!< [b31~b5]*/
        }BIT;
    }QEIINT;                               /*!< 0024H */
    union {
        __IO  uint32_t  V32;                                /*!< 0028H */
        struct {
            __I   uint32_t  QPEIF     : 1;  /*!< [b0~b0]*/
            __I   uint32_t  QCEIF     : 1;  /*!< [b1~b1]*/
            __I   uint32_t  QEIIF     : 1;  /*!< [b2~b2]*/
            __I   uint32_t  QTCAPIF   : 1;  /*!< [b3~b3]*/
            __I   uint32_t  QTIF      : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  rev0      :11;  /*!< [b15~b5]*/
            __O   uint32_t  QPEIFC    : 1;  /*!< [b16~b16]*/
            __O   uint32_t  QCEIFC    : 1;  /*!< [b17~b17]*/
            __O   uint32_t  QEIIFC    : 1;  /*!< [b18~b18]*/
            __O   uint32_t  QTCAPIFC  : 1;  /*!< [b19~b19]*/
            __O   uint32_t  QTIFC     : 1;  /*!< [b20~b20]*/
            __IO  uint32_t  rev1      :11;  /*!< [b31~b21]*/
        }BIT;
    }QTINTF;                               /*!< 0028H */
}QEI_TypeDef;


/**
*@brief MACP_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  RUN       : 1;  /*!< [b0~b0]*/
            __I   uint32_t  OVF       : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  KADJ      : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  XYMRS     : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  FORMAT    : 2;  /*!< [b6~b5]*/
            __IO  uint32_t  MODE      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  ITERA     : 5;  /*!< [b12~b8]*/
            __IO  uint32_t  ARITH     : 2;  /*!< [b14~b13]*/
            __IO  uint32_t  rev1      :17;  /*!< [b31~b15]*/
        }BIT;
    }CORDCSR0;                               /*!< 0000H */
    __IO uint32_t  OPRDX0;                                  /*!< 0004H */
    __IO uint32_t  OPRDY0;                                  /*!< 0008H */
    __IO uint32_t  OPRDZ0;                                  /*!< 000CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0010H */
        struct {
            __IO  uint32_t  RUN       : 1;  /*!< [b0~b0]*/
            __I   uint32_t  OVF       : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  KADJ      : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  XYMRS     : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  FORMAT    : 2;  /*!< [b6~b5]*/
            __IO  uint32_t  MODE      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  ITERA     : 5;  /*!< [b12~b8]*/
            __IO  uint32_t  ARITH     : 2;  /*!< [b14~b13]*/
            __IO  uint32_t  rev1      :17;  /*!< [b31~b15]*/
        }BIT;
    }CORDCSR1;                               /*!< 0010H */
    __IO uint32_t  OPRDX1;                                  /*!< 0014H */
    __IO uint32_t  OPRDY1;                                  /*!< 0018H */
    __IO uint32_t  OPRDZ1;                                  /*!< 001CH */
    __IO uint32_t  Reserved0[120];                          /*!< 0020H */
    __IO uint32_t  SVCON;                                   /*!< 0200H */
    __IO int32_t   SVUALPHA;                                /*!< 0204H */
    __IO int32_t   SVUBETA;                                 /*!< 0208H */
    union {
        __IO  uint32_t  V32;                                /*!< 020CH */
        struct {
            __IO  uint32_t  SVIQN     : 8;  /*!< [b7~b0]*/
            __IO  uint32_t  SVTYP     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  SATEN     : 1;  /*!< [b9~b9]*/
            __I   uint32_t  OVERAL    : 1;  /*!< [b10~b10]*/
            __I   uint32_t  OVERBL    : 1;  /*!< [b11~b11]*/
            __I   uint32_t  OVERCL    : 1;  /*!< [b12~b12]*/
            __I   uint32_t  OVERAH    : 1;  /*!< [b13~b13]*/
            __I   uint32_t  OVERBH    : 1;  /*!< [b14~b14]*/
            __I   uint32_t  OVERCH    : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }SVIQN;                               /*!< 020CH */
    __I  int32_t   SVTA;                                    /*!< 0210H */
    __I  int32_t   SVTB;                                    /*!< 0214H */
    __I  int32_t   SVTC;                                    /*!< 0218H */
    __I  uint32_t  SVSECTOR;                                /*!< 021CH */
}MACP_TypeDef;


/**
*@brief ADC_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  ADSOC     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  ADCTU     : 2;  /*!< [b2~b1]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  REFC      : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  ADTGREN   : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  ADIE      : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  ADON      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  ADOUT     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  rev1      :23;  /*!< [b31~b9]*/
        }BIT;
    }ADCON1;                               /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  TADC      : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  ADMAXCH   : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  TS        : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  TGAP      : 3;  /*!< [b14~b12]*/
            __IO  uint32_t  rev0      :17;  /*!< [b31~b15]*/
        }BIT;
    }ADCON2;                               /*!< 0004H */
    __IO uint32_t  ADPCH;                                   /*!< 0008H */
    __I  uint32_t  ADDR0;                                   /*!< 000CH */
    __I  uint32_t  ADDR1;                                   /*!< 0010H */
    __I  uint32_t  ADDR2;                                   /*!< 0014H */
    __I  uint32_t  ADDR3;                                   /*!< 0018H */
    __I  uint32_t  ADDR4;                                   /*!< 001CH */
    __I  uint32_t  ADDR5;                                   /*!< 0020H */
    __I  uint32_t  ADDR6;                                   /*!< 0024H */
    __I  uint32_t  ADDR7;                                   /*!< 0028H */
    __I  uint32_t  ADDR8;                                   /*!< 002CH */
    __I  uint32_t  ADDR9;                                   /*!< 0030H */
    __I  uint32_t  ADDR10;                                  /*!< 0034H */
    __I  uint32_t  ADDR11;                                  /*!< 0038H */
    __I  uint32_t  ADDR12;                                  /*!< 003CH */
    __I  uint32_t  ADDR13;                                  /*!< 0040H */
    __I  uint32_t  ADDR14;                                  /*!< 0044H */
    __I  uint32_t  ADDR15;                                  /*!< 0048H */
    union {
        __IO  uint32_t  V32;                                /*!< 004CH */
        struct {
            __IO  uint32_t  CSEL      : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  ADLIE     : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  ADGIE     : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev2      :24;  /*!< [b31~b8]*/
        }BIT;
    }ADCMPCON;                               /*!< 004CH */
    __IO uint32_t  ADDGT;                                   /*!< 0050H */
    __IO uint32_t  ADDLT;                                   /*!< 0054H */
    union {
        __IO  uint32_t  V32;                                /*!< 0058H */
        struct {
            __IO  uint32_t  SEQCH0    : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  SEQCH1    : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  SEQCH2    : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  SEQCH3    : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  SEQCH4    : 4;  /*!< [b19~b16]*/
            __IO  uint32_t  SEQCH5    : 4;  /*!< [b23~b20]*/
            __IO  uint32_t  SEQCH6    : 4;  /*!< [b27~b24]*/
            __IO  uint32_t  SEQCH7    : 4;  /*!< [b31~b28]*/
        }BIT;
    }SEQCHSEL0;                               /*!< 0058H */
    union {
        __IO  uint32_t  V32;                                /*!< 005CH */
        struct {
            __IO  uint32_t  SEQCH8    : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  SEQCH9    : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  SEQCH10   : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  SEQCH11   : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  SEQCH12   : 4;  /*!< [b19~b16]*/
            __IO  uint32_t  SEQCH13   : 4;  /*!< [b23~b20]*/
            __IO  uint32_t  SEQCH14   : 4;  /*!< [b27~b24]*/
            __IO  uint32_t  SEQCH15   : 4;  /*!< [b31~b28]*/
        }BIT;
    }SEQCHSEL1;                               /*!< 005CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0060H */
        struct {
            __IO  uint32_t  PWMCMP1   : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PWMCMP2   : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  PWMCMP3   : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  PWMCMP4   : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  PCA0SEL   : 4;  /*!< [b19~b16]*/
            __IO  uint32_t  PCA1SEL   : 4;  /*!< [b23~b20]*/
            __IO  uint32_t  TIM8SEL   : 4;  /*!< [b27~b24]*/
            __IO  uint32_t  ADTRG     : 4;  /*!< [b31~b28]*/
        }BIT;
    }HARDCHSEL;                               /*!< 0060H */
    union {
        __IO  uint32_t  V32;                                /*!< 0064H */
        struct {
            __IO  uint32_t  PWMCMP1   : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PWMCMP2   : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  PWMCMP3   : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  PWMCMP4   : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  PCA0LH    : 4;  /*!< [b19~b16]*/
            __IO  uint32_t  PCA1LH    : 4;  /*!< [b23~b20]*/
            __IO  uint32_t  TIM8LH    : 4;  /*!< [b27~b24]*/
            __IO  uint32_t  ADTRG     : 4;  /*!< [b31~b28]*/
        }BIT;
    }HARDCHLH;                               /*!< 0064H */
    __IO uint32_t  ADGAPON;                                 /*!< 0068H */
    union {
        __IO  uint32_t  V32;                                /*!< 006CH */
        struct {
            __I   uint32_t  ADLIF     : 1;  /*!< [b0~b0]*/
            __I   uint32_t  ADGIF     : 1;  /*!< [b1~b1]*/
            __I   uint32_t  ADIF      : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  rev0      :13;  /*!< [b15~b3]*/
            __O   uint32_t  ADLIFC    : 1;  /*!< [b16~b16]*/
            __O   uint32_t  ADGIFC    : 1;  /*!< [b17~b17]*/
            __O   uint32_t  ADIFC     : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  rev1      :13;  /*!< [b31~b19]*/
        }BIT;
    }ADINTF;                               /*!< 006CH */
}ADC_TypeDef;


/**
*@brief AMOC_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  C0DEB     : 3;  /*!< [b2~b0]*/
            __I   uint32_t  C0OUT     : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  C0PCHS    : 3;  /*!< [b6~b4]*/
            __IO  uint32_t  C0NCHS    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev0      : 2;  /*!< [b9~b8]*/
            __IO  uint32_t  C0IES     : 2;  /*!< [b11~b10]*/
            __IO  uint32_t  C0OUTEN   : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  CP0NOUTEN : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  CMP0VCMP  : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  CMP0EN    : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  CMP0VRS   : 6;  /*!< [b21~b16]*/
            __IO  uint32_t  CMPGAP    : 2;  /*!< [b23~b22]*/
            __IO  uint32_t  PWMTRGS   : 2;  /*!< [b25~b24]*/
            __IO  uint32_t  TRGPOL    : 1;  /*!< [b26~b26]*/
            __IO  uint32_t  CMPAUTO   : 1;  /*!< [b27~b27]*/
            __I   uint32_t  C0OUT0    : 1;  /*!< [b28~b28]*/
            __I   uint32_t  C0OUT1    : 1;  /*!< [b29~b29]*/
            __I   uint32_t  C0OUT2    : 1;  /*!< [b30~b30]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b31~b31]*/
        }BIT;
    }CMP0CON;                               /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  C1DEB     : 3;  /*!< [b2~b0]*/
            __I   uint32_t  C1OUT     : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  C1PCHS    : 3;  /*!< [b6~b4]*/
            __IO  uint32_t  C1NCHS    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  C1SMT     : 2;  /*!< [b9~b8]*/
            __IO  uint32_t  C1IES     : 2;  /*!< [b11~b10]*/
            __IO  uint32_t  C1OUTEN   : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  CP1NOUTEN : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  CMP1VCMP  : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  CMP1EN    : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  CMP1VRS   : 6;  /*!< [b21~b16]*/
            __IO  uint32_t  rev0      : 2;  /*!< [b23~b22]*/
            __IO  uint32_t  PWMTRGS   : 2;  /*!< [b25~b24]*/
            __IO  uint32_t  TRGPOL    : 1;  /*!< [b26~b26]*/
            __IO  uint32_t  rev1      : 5;  /*!< [b31~b27]*/
        }BIT;
    }CMP1CON;                               /*!< 0004H */
    union {
        __IO  uint32_t  V32;                                /*!< 0008H */
        struct {
            __I   uint32_t  C0IF      : 1;  /*!< [b0~b0]*/
            __I   uint32_t  C1IF      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  rev0      :14;  /*!< [b15~b2]*/
            __O   uint32_t  C0IFC     : 1;  /*!< [b16~b16]*/
            __O   uint32_t  C1IFC     : 1;  /*!< [b17~b17]*/
            __IO  uint32_t  rev1      :14;  /*!< [b31~b18]*/
        }BIT;
    }CMPINTF;                               /*!< 0008H */
    union {
        __IO  uint32_t  V32;                                /*!< 000CH */
        struct {
            __IO  uint32_t  OP0EN     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  OP1EN     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  OP2EN     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  OP3EN     : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  OP0GSEL   : 3;  /*!< [b6~b4]*/
            __IO  uint32_t  OP0GEN    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev0      :24;  /*!< [b31~b8]*/
        }BIT;
    }OPCON;                               /*!< 000CH */
}AMOC_TypeDef;


/**
*@brief UART_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __I   uint32_t  RI        : 1;  /*!< [b0~b0]*/
            __I   uint32_t  TI        : 1;  /*!< [b1~b1]*/
            __I   uint32_t  TC        : 1;  /*!< [b2~b2]*/
            __I   uint32_t  TXCOL     : 1;  /*!< [b3~b3]*/
            __I   uint32_t  RXOV      : 1;  /*!< [b4~b4]*/
            __I   uint32_t  FE        : 1;  /*!< [b5~b5]*/
            __I   uint32_t  PE        : 1;  /*!< [b6~b6]*/
            __I   uint32_t  LBD       : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev0      : 8;  /*!< [b15~b8]*/
            __O   uint32_t  RIC       : 1;  /*!< [b16~b16]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b17~b17]*/
            __O   uint32_t  TCC       : 1;  /*!< [b18~b18]*/
            __O   uint32_t  TXCOLC    : 1;  /*!< [b19~b19]*/
            __O   uint32_t  RXOVC     : 1;  /*!< [b20~b20]*/
            __O   uint32_t  FEC       : 1;  /*!< [b21~b21]*/
            __O   uint32_t  PEC       : 1;  /*!< [b22~b22]*/
            __O   uint32_t  LBDC      : 1;  /*!< [b23~b23]*/
            __IO  uint32_t  rev2      : 8;  /*!< [b31~b24]*/
        }BIT;
    }FR;                               /*!< 0000H */
    __IO uint32_t  Reserved0[1];                            /*!< 0004H */
    union {
        __IO  uint32_t  V32;                                /*!< 0008H */
        struct {
            __IO  uint32_t  TDR       : 8;  /*!< [b7~b0]*/
            __IO  uint32_t  TB8       : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  FIFOTDH   :23;  /*!< [b31~b9]*/
        }BIT;
    }TDR;                               /*!< 0008H */
    union {
        __I   uint32_t  V32;                                /*!< 000CH */
        struct {
            __I   uint32_t  RDR       : 8;  /*!< [b7~b0]*/
            __I   uint32_t  RB8       : 1;  /*!< [b8~b8]*/
            __I   uint32_t  FIFORDH   :23;  /*!< [b31~b9]*/
        }BIT;
    }RDR;                               /*!< 000CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0010H */
        struct {
    __IO uint32_t  SADDR:8;                                 /*!< 0010H */
    __IO uint32_t  SMAR:8;                                  /*!< 0011H */
    __IO uint32_t  rev0:16;                                 /*!< 0012H */
        }BIT;
    }ADDR;                              /*!< 0010H */
    union {
        __IO  uint32_t  V32;                                /*!< 0014H */
        struct {
            __IO  uint32_t  SBRT      :15;  /*!< [b14~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  BFINE     : 4;  /*!< [b19~b16]*/
            __IO  uint32_t  rev1      :12;  /*!< [b31~b20]*/
        }BIT;
    }BRT;                               /*!< 0014H */
    union {
        __IO  uint32_t  V32;                                /*!< 0018H */
        struct {
            __IO  uint32_t  STOP      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  SBRTEN    : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  SMOD2     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  RIE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  TIE       : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  TCIE      : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  LBDIE     : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  LBDL      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  SMOD0     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  PS        : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  MULTIE    : 2;  /*!< [b12~b11]*/
            __IO  uint32_t  SM        : 2;  /*!< [b14~b13]*/
            __IO  uint32_t  SBK       : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  LINEN     : 1;  /*!< [b16~b16]*/
            __IO  uint32_t  REN       : 1;  /*!< [b17~b17]*/
            __IO  uint32_t  TEN       : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b19~b19]*/
            __IO  uint32_t  rev2      : 1;  /*!< [b20~b20]*/
            __IO  uint32_t  RNEG      : 1;  /*!< [b21~b21]*/
            __IO  uint32_t  TNEG      : 1;  /*!< [b22~b22]*/
            __IO  uint32_t  FER       : 1;  /*!< [b23~b23]*/
            __IO  uint32_t  rev3      : 1;  /*!< [b24~b24]*/
            __IO  uint32_t  UARXFIFO  : 1;  /*!< [b25~b25]*/
            __IO  uint32_t  UATXFIFO  : 1;  /*!< [b26~b26]*/
            __IO  uint32_t  rev4      : 5;  /*!< [b31~b27]*/
        }BIT;
    }CR;                               /*!< 0018H */
}UART_TypeDef;


/**
*@brief SPI_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __I   uint32_t  SPRI      : 1;  /*!< [b0~b0]*/
            __I   uint32_t  SPTI      : 1;  /*!< [b1~b1]*/
            __I   uint32_t  BUSY      : 1;  /*!< [b2~b2]*/
            __I   uint32_t  MODF      : 1;  /*!< [b3~b3]*/
            __I   uint32_t  RXOV      : 1;  /*!< [b4~b4]*/
            __I   uint32_t  WCOL      : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  rev0      :10;  /*!< [b15~b6]*/
            __O   uint32_t  SPRIC     : 1;  /*!< [b16~b16]*/
            __O   uint32_t  rev1      : 2;  /*!< [b18~b17]*/
            __O   uint32_t  MODFC     : 1;  /*!< [b19~b19]*/
            __O   uint32_t  RXOVC     : 1;  /*!< [b20~b20]*/
            __O   uint32_t  WCOLC     : 1;  /*!< [b21~b21]*/
            __IO  uint32_t  rev2      :10;  /*!< [b31~b22]*/
        }BIT;
    }FR;                               /*!< 0000H */
    __IO uint32_t  TDR;                                     /*!< 0004H */
    __I  uint32_t  RDR;                                     /*!< 0008H */
    union {
        __IO  uint32_t  V32;                                /*!< 000CH */
        struct {
            __IO  uint32_t  SPR       : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  SSDIS     : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  CPOL      : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  CPHA      : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  MSTR      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  DIR       : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  SPRIE     : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  SPTIE     : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  rev1      : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  rev2      : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  SPIEN     : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  SPSFF     : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  SPDATL    : 2;  /*!< [b17~b16]*/
            __IO  uint32_t  FIFOEN    : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  rev3      :13;  /*!< [b31~b19]*/
        }BIT;
    }CR;                               /*!< 000CH */
}SPI_TypeDef;


/**
*@brief TWI_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __I   uint32_t  TWINT     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b1~b1]*/
            __I   uint32_t  TFREE     : 1;  /*!< [b2~b2]*/
            __I   uint32_t  TOUT      : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  rev1      :12;  /*!< [b15~b4]*/
            __O   uint32_t  TWINTC    : 1;  /*!< [b16~b16]*/
            __IO  uint32_t  rev2      : 1;  /*!< [b17~b17]*/
            __O   uint32_t  TFREEC    : 1;  /*!< [b18~b18]*/
            __O   uint32_t  TOUTC     : 1;  /*!< [b19~b19]*/
            __IO  uint32_t  rev3      :12;  /*!< [b31~b20]*/
        }BIT;
    }FR;                               /*!< 0000H */
    union {
        __I   uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  rev0      : 3;  /*!< [b2~b0]*/
            __I   uint32_t  SR        : 5;  /*!< [b7~b3]*/
            __IO  uint32_t  rev1      :24;  /*!< [b31~b8]*/
        }BIT;
    }STAT;                               /*!< 0004H */
    __IO uint32_t  HOC;                                     /*!< 0008H */
    __IO uint32_t  BRT;                                     /*!< 000CH */
    __IO uint32_t  DR;                                      /*!< 0010H */
    union {
        __IO  uint32_t  V32;                                /*!< 0014H */
        struct {
            __IO  uint32_t  GC        : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  ADDR      : 7;  /*!< [b7~b1]*/
            __IO  uint32_t  rev0      : 9;  /*!< [b16~b8]*/
            __IO  uint32_t  TWIAMR    : 7;  /*!< [b23~b17]*/
            __IO  uint32_t  rev1      : 8;  /*!< [b31~b24]*/
        }BIT;
    }ADDR;                               /*!< 0014H */
    union {
        __IO  uint32_t  V32;                                /*!< 0018H */
        struct {
            __IO  uint32_t  AA        : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  STO       : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  STA       : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  CR        : 2;  /*!< [b5~b4]*/
            __IO  uint32_t  CNT       : 2;  /*!< [b7~b6]*/
            __IO  uint32_t  EFREE     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  ETOT      : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  TWINTE    : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  rev1      : 4;  /*!< [b14~b11]*/
            __IO  uint32_t  TWIEN     : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev2      :16;  /*!< [b31~b16]*/
        }BIT;
    }CR;                               /*!< 0018H */
}TWI_TypeDef;


/**
*@brief CAN_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF0_CNTSTAT;                               /*!< 0000H */
    __IO uint32_t  BUF0_TSTP;                               /*!< 0004H */
    union {
        __IO  uint32_t  V32;                                /*!< 0008H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0008H */
    __IO uint32_t  DATAH:8;                                 /*!< 0009H */
    __IO uint32_t  rev0:16;                                 /*!< 000AH */
        }BIT;
    }BUF0_DATA3;                              /*!< 0008H */
    union {
        __IO  uint32_t  V32;                                /*!< 000CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 000CH */
    __IO uint32_t  DATAH:8;                                 /*!< 000DH */
    __IO uint32_t  rev0:16;                                 /*!< 000EH */
        }BIT;
    }BUF0_DATA2;                              /*!< 000CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0010H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0010H */
    __IO uint32_t  DATAH:8;                                 /*!< 0011H */
    __IO uint32_t  rev0:16;                                 /*!< 0012H */
        }BIT;
    }BUF0_DATA1;                              /*!< 0010H */
    union {
        __IO  uint32_t  V32;                                /*!< 0014H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0014H */
    __IO uint32_t  DATAH:8;                                 /*!< 0015H */
    __IO uint32_t  rev0:16;                                 /*!< 0016H */
        }BIT;
    }BUF0_DATA0;                              /*!< 0014H */
    union {
        __IO  uint32_t  V32;                                /*!< 0018H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF0_ID0;                               /*!< 0018H */
    union {
        __IO  uint32_t  V32;                                /*!< 001CH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF0_ID1;                               /*!< 001CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0020H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF1_CNTSTAT;                               /*!< 0020H */
    __IO uint32_t  BUF1_TSTP;                               /*!< 0024H */
    union {
        __IO  uint32_t  V32;                                /*!< 0028H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0028H */
    __IO uint32_t  DATAH:8;                                 /*!< 0029H */
    __IO uint32_t  rev0:16;                                 /*!< 002AH */
        }BIT;
    }BUF1_DATA3;                              /*!< 0028H */
    union {
        __IO  uint32_t  V32;                                /*!< 002CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 002CH */
    __IO uint32_t  DATAH:8;                                 /*!< 002DH */
    __IO uint32_t  rev0:16;                                 /*!< 002EH */
        }BIT;
    }BUF1_DATA2;                              /*!< 002CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0030H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0030H */
    __IO uint32_t  DATAH:8;                                 /*!< 0031H */
    __IO uint32_t  rev0:16;                                 /*!< 0032H */
        }BIT;
    }BUF1_DATA1;                              /*!< 0030H */
    union {
        __IO  uint32_t  V32;                                /*!< 0034H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0034H */
    __IO uint32_t  DATAH:8;                                 /*!< 0035H */
    __IO uint32_t  rev0:16;                                 /*!< 0036H */
        }BIT;
    }BUF1_DATA0;                              /*!< 0034H */
    union {
        __IO  uint32_t  V32;                                /*!< 0038H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF1_ID0;                               /*!< 0038H */
    union {
        __IO  uint32_t  V32;                                /*!< 003CH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF1_ID1;                               /*!< 003CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0040H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF2_CNTSTAT;                               /*!< 0040H */
    __IO uint32_t  BUF2_TSTP;                               /*!< 0044H */
    union {
        __IO  uint32_t  V32;                                /*!< 0048H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0048H */
    __IO uint32_t  DATAH:8;                                 /*!< 0049H */
    __IO uint32_t  rev0:16;                                 /*!< 004AH */
        }BIT;
    }BUF2_DATA3;                              /*!< 0048H */
    union {
        __IO  uint32_t  V32;                                /*!< 004CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 004CH */
    __IO uint32_t  DATAH:8;                                 /*!< 004DH */
    __IO uint32_t  rev0:16;                                 /*!< 004EH */
        }BIT;
    }BUF2_DATA2;                              /*!< 004CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0050H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0050H */
    __IO uint32_t  DATAH:8;                                 /*!< 0051H */
    __IO uint32_t  rev0:16;                                 /*!< 0052H */
        }BIT;
    }BUF2_DATA1;                              /*!< 0050H */
    union {
        __IO  uint32_t  V32;                                /*!< 0054H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0054H */
    __IO uint32_t  DATAH:8;                                 /*!< 0055H */
    __IO uint32_t  rev0:16;                                 /*!< 0056H */
        }BIT;
    }BUF2_DATA0;                              /*!< 0054H */
    union {
        __IO  uint32_t  V32;                                /*!< 0058H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF2_ID0;                               /*!< 0058H */
    union {
        __IO  uint32_t  V32;                                /*!< 005CH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF2_ID1;                               /*!< 005CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0060H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF3_CNTSTAT;                               /*!< 0060H */
    __IO uint32_t  BUF3_TSTP;                               /*!< 0064H */
    union {
        __IO  uint32_t  V32;                                /*!< 0068H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0068H */
    __IO uint32_t  DATAH:8;                                 /*!< 0069H */
    __IO uint32_t  rev0:16;                                 /*!< 006AH */
        }BIT;
    }BUF3_DATA3;                              /*!< 0068H */
    union {
        __IO  uint32_t  V32;                                /*!< 006CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 006CH */
    __IO uint32_t  DATAH:8;                                 /*!< 006DH */
    __IO uint32_t  rev0:16;                                 /*!< 006EH */
        }BIT;
    }BUF3_DATA2;                              /*!< 006CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0070H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0070H */
    __IO uint32_t  DATAH:8;                                 /*!< 0071H */
    __IO uint32_t  rev0:16;                                 /*!< 0072H */
        }BIT;
    }BUF3_DATA1;                              /*!< 0070H */
    union {
        __IO  uint32_t  V32;                                /*!< 0074H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0074H */
    __IO uint32_t  DATAH:8;                                 /*!< 0075H */
    __IO uint32_t  rev0:16;                                 /*!< 0076H */
        }BIT;
    }BUF3_DATA0;                              /*!< 0074H */
    union {
        __IO  uint32_t  V32;                                /*!< 0078H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF3_ID0;                               /*!< 0078H */
    union {
        __IO  uint32_t  V32;                                /*!< 007CH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF3_ID1;                               /*!< 007CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0080H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF4_CNTSTAT;                               /*!< 0080H */
    __IO uint32_t  BUF4_TSTP;                               /*!< 0084H */
    union {
        __IO  uint32_t  V32;                                /*!< 0088H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0088H */
    __IO uint32_t  DATAH:8;                                 /*!< 0089H */
    __IO uint32_t  rev0:16;                                 /*!< 008AH */
        }BIT;
    }BUF4_DATA3;                              /*!< 0088H */
    union {
        __IO  uint32_t  V32;                                /*!< 008CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 008CH */
    __IO uint32_t  DATAH:8;                                 /*!< 008DH */
    __IO uint32_t  rev0:16;                                 /*!< 008EH */
        }BIT;
    }BUF4_DATA2;                              /*!< 008CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0090H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0090H */
    __IO uint32_t  DATAH:8;                                 /*!< 0091H */
    __IO uint32_t  rev0:16;                                 /*!< 0092H */
        }BIT;
    }BUF4_DATA1;                              /*!< 0090H */
    union {
        __IO  uint32_t  V32;                                /*!< 0094H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0094H */
    __IO uint32_t  DATAH:8;                                 /*!< 0095H */
    __IO uint32_t  rev0:16;                                 /*!< 0096H */
        }BIT;
    }BUF4_DATA0;                              /*!< 0094H */
    union {
        __IO  uint32_t  V32;                                /*!< 0098H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF4_ID0;                               /*!< 0098H */
    union {
        __IO  uint32_t  V32;                                /*!< 009CH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF4_ID1;                               /*!< 009CH */
    union {
        __IO  uint32_t  V32;                                /*!< 00A0H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF5_CNTSTAT;                               /*!< 00A0H */
    __IO uint32_t  BUF5_TSTP;                               /*!< 00A4H */
    union {
        __IO  uint32_t  V32;                                /*!< 00A8H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00A8H */
    __IO uint32_t  DATAH:8;                                 /*!< 00A9H */
    __IO uint32_t  rev0:16;                                 /*!< 00AAH */
        }BIT;
    }BUF5_DATA3;                              /*!< 00A8H */
    union {
        __IO  uint32_t  V32;                                /*!< 00ACH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00ACH */
    __IO uint32_t  DATAH:8;                                 /*!< 00ADH */
    __IO uint32_t  rev0:16;                                 /*!< 00AEH */
        }BIT;
    }BUF5_DATA2;                              /*!< 00ACH */
    union {
        __IO  uint32_t  V32;                                /*!< 00B0H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00B0H */
    __IO uint32_t  DATAH:8;                                 /*!< 00B1H */
    __IO uint32_t  rev0:16;                                 /*!< 00B2H */
        }BIT;
    }BUF5_DATA1;                              /*!< 00B0H */
    union {
        __IO  uint32_t  V32;                                /*!< 00B4H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00B4H */
    __IO uint32_t  DATAH:8;                                 /*!< 00B5H */
    __IO uint32_t  rev0:16;                                 /*!< 00B6H */
        }BIT;
    }BUF5_DATA0;                              /*!< 00B4H */
    union {
        __IO  uint32_t  V32;                                /*!< 00B8H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF5_ID0;                               /*!< 00B8H */
    union {
        __IO  uint32_t  V32;                                /*!< 00BCH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF5_ID1;                               /*!< 00BCH */
    union {
        __IO  uint32_t  V32;                                /*!< 00C0H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF6_CNTSTAT;                               /*!< 00C0H */
    __IO uint32_t  BUF6_TSTP;                               /*!< 00C4H */
    union {
        __IO  uint32_t  V32;                                /*!< 00C8H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00C8H */
    __IO uint32_t  DATAH:8;                                 /*!< 00C9H */
    __IO uint32_t  rev0:16;                                 /*!< 00CAH */
        }BIT;
    }BUF6_DATA3;                              /*!< 00C8H */
    union {
        __IO  uint32_t  V32;                                /*!< 00CCH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00CCH */
    __IO uint32_t  DATAH:8;                                 /*!< 00CDH */
    __IO uint32_t  rev0:16;                                 /*!< 00CEH */
        }BIT;
    }BUF6_DATA2;                              /*!< 00CCH */
    union {
        __IO  uint32_t  V32;                                /*!< 00D0H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00D0H */
    __IO uint32_t  DATAH:8;                                 /*!< 00D1H */
    __IO uint32_t  rev0:16;                                 /*!< 00D2H */
        }BIT;
    }BUF6_DATA1;                              /*!< 00D0H */
    union {
        __IO  uint32_t  V32;                                /*!< 00D4H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00D4H */
    __IO uint32_t  DATAH:8;                                 /*!< 00D5H */
    __IO uint32_t  rev0:16;                                 /*!< 00D6H */
        }BIT;
    }BUF6_DATA0;                              /*!< 00D4H */
    union {
        __IO  uint32_t  V32;                                /*!< 00D8H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF6_ID0;                               /*!< 00D8H */
    union {
        __IO  uint32_t  V32;                                /*!< 00DCH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF6_ID1;                               /*!< 00DCH */
    union {
        __IO  uint32_t  V32;                                /*!< 00E0H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF7_CNTSTAT;                               /*!< 00E0H */
    __IO uint32_t  BUF7_TSTP;                               /*!< 00E4H */
    union {
        __IO  uint32_t  V32;                                /*!< 00E8H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00E8H */
    __IO uint32_t  DATAH:8;                                 /*!< 00E9H */
    __IO uint32_t  rev0:16;                                 /*!< 00EAH */
        }BIT;
    }BUF7_DATA3;                              /*!< 00E8H */
    union {
        __IO  uint32_t  V32;                                /*!< 00ECH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00ECH */
    __IO uint32_t  DATAH:8;                                 /*!< 00EDH */
    __IO uint32_t  rev0:16;                                 /*!< 00EEH */
        }BIT;
    }BUF7_DATA2;                              /*!< 00ECH */
    union {
        __IO  uint32_t  V32;                                /*!< 00F0H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00F0H */
    __IO uint32_t  DATAH:8;                                 /*!< 00F1H */
    __IO uint32_t  rev0:16;                                 /*!< 00F2H */
        }BIT;
    }BUF7_DATA1;                              /*!< 00F0H */
    union {
        __IO  uint32_t  V32;                                /*!< 00F4H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 00F4H */
    __IO uint32_t  DATAH:8;                                 /*!< 00F5H */
    __IO uint32_t  rev0:16;                                 /*!< 00F6H */
        }BIT;
    }BUF7_DATA0;                              /*!< 00F4H */
    union {
        __IO  uint32_t  V32;                                /*!< 00F8H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF7_ID0;                               /*!< 00F8H */
    union {
        __IO  uint32_t  V32;                                /*!< 00FCH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF7_ID1;                               /*!< 00FCH */
    union {
        __IO  uint32_t  V32;                                /*!< 0100H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF8_CNTSTAT;                               /*!< 0100H */
    __IO uint32_t  BUF8_TSTP;                               /*!< 0104H */
    union {
        __IO  uint32_t  V32;                                /*!< 0108H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0108H */
    __IO uint32_t  DATAH:8;                                 /*!< 0109H */
    __IO uint32_t  rev0:16;                                 /*!< 010AH */
        }BIT;
    }BUF8_DATA3;                              /*!< 0108H */
    union {
        __IO  uint32_t  V32;                                /*!< 010CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 010CH */
    __IO uint32_t  DATAH:8;                                 /*!< 010DH */
    __IO uint32_t  rev0:16;                                 /*!< 010EH */
        }BIT;
    }BUF8_DATA2;                              /*!< 010CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0110H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0110H */
    __IO uint32_t  DATAH:8;                                 /*!< 0111H */
    __IO uint32_t  rev0:16;                                 /*!< 0112H */
        }BIT;
    }BUF8_DATA1;                              /*!< 0110H */
    union {
        __IO  uint32_t  V32;                                /*!< 0114H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0114H */
    __IO uint32_t  DATAH:8;                                 /*!< 0115H */
    __IO uint32_t  rev0:16;                                 /*!< 0116H */
        }BIT;
    }BUF8_DATA0;                              /*!< 0114H */
    union {
        __IO  uint32_t  V32;                                /*!< 0118H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF8_ID0;                               /*!< 0118H */
    union {
        __IO  uint32_t  V32;                                /*!< 011CH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF8_ID1;                               /*!< 011CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0120H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF9_CNTSTAT;                               /*!< 0120H */
    __IO uint32_t  BUF9_TSTP;                               /*!< 0124H */
    union {
        __IO  uint32_t  V32;                                /*!< 0128H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0128H */
    __IO uint32_t  DATAH:8;                                 /*!< 0129H */
    __IO uint32_t  rev0:16;                                 /*!< 012AH */
        }BIT;
    }BUF9_DATA3;                              /*!< 0128H */
    union {
        __IO  uint32_t  V32;                                /*!< 012CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 012CH */
    __IO uint32_t  DATAH:8;                                 /*!< 012DH */
    __IO uint32_t  rev0:16;                                 /*!< 012EH */
        }BIT;
    }BUF9_DATA2;                              /*!< 012CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0130H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0130H */
    __IO uint32_t  DATAH:8;                                 /*!< 0131H */
    __IO uint32_t  rev0:16;                                 /*!< 0132H */
        }BIT;
    }BUF9_DATA1;                              /*!< 0130H */
    union {
        __IO  uint32_t  V32;                                /*!< 0134H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0134H */
    __IO uint32_t  DATAH:8;                                 /*!< 0135H */
    __IO uint32_t  rev0:16;                                 /*!< 0136H */
        }BIT;
    }BUF9_DATA0;                              /*!< 0134H */
    union {
        __IO  uint32_t  V32;                                /*!< 0138H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF9_ID0;                               /*!< 0138H */
    union {
        __IO  uint32_t  V32;                                /*!< 013CH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF9_ID1;                               /*!< 013CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0140H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF10_CNTSTAT;                               /*!< 0140H */
    __IO uint32_t  BUF10_TSTP;                              /*!< 0144H */
    union {
        __IO  uint32_t  V32;                                /*!< 0148H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0148H */
    __IO uint32_t  DATAH:8;                                 /*!< 0149H */
    __IO uint32_t  rev0:16;                                 /*!< 014AH */
        }BIT;
    }BUF10_DATA3;                              /*!< 0148H */
    union {
        __IO  uint32_t  V32;                                /*!< 014CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 014CH */
    __IO uint32_t  DATAH:8;                                 /*!< 014DH */
    __IO uint32_t  rev0:16;                                 /*!< 014EH */
        }BIT;
    }BUF10_DATA2;                              /*!< 014CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0150H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0150H */
    __IO uint32_t  DATAH:8;                                 /*!< 0151H */
    __IO uint32_t  rev0:16;                                 /*!< 0152H */
        }BIT;
    }BUF10_DATA1;                              /*!< 0150H */
    union {
        __IO  uint32_t  V32;                                /*!< 0154H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0154H */
    __IO uint32_t  DATAH:8;                                 /*!< 0155H */
    __IO uint32_t  rev0:16;                                 /*!< 0156H */
        }BIT;
    }BUF10_DATA0;                              /*!< 0154H */
    union {
        __IO  uint32_t  V32;                                /*!< 0158H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF10_ID0;                               /*!< 0158H */
    union {
        __IO  uint32_t  V32;                                /*!< 015CH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF10_ID1;                               /*!< 015CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0160H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF11_CNTSTAT;                               /*!< 0160H */
    __IO uint32_t  BUF11_TSTP;                              /*!< 0164H */
    union {
        __IO  uint32_t  V32;                                /*!< 0168H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0168H */
    __IO uint32_t  DATAH:8;                                 /*!< 0169H */
    __IO uint32_t  rev0:16;                                 /*!< 016AH */
        }BIT;
    }BUF11_DATA3;                              /*!< 0168H */
    union {
        __IO  uint32_t  V32;                                /*!< 016CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 016CH */
    __IO uint32_t  DATAH:8;                                 /*!< 016DH */
    __IO uint32_t  rev0:16;                                 /*!< 016EH */
        }BIT;
    }BUF11_DATA2;                              /*!< 016CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0170H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0170H */
    __IO uint32_t  DATAH:8;                                 /*!< 0171H */
    __IO uint32_t  rev0:16;                                 /*!< 0172H */
        }BIT;
    }BUF11_DATA1;                              /*!< 0170H */
    union {
        __IO  uint32_t  V32;                                /*!< 0174H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0174H */
    __IO uint32_t  DATAH:8;                                 /*!< 0175H */
    __IO uint32_t  rev0:16;                                 /*!< 0176H */
        }BIT;
    }BUF11_DATA0;                              /*!< 0174H */
    union {
        __IO  uint32_t  V32;                                /*!< 0178H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF11_ID0;                               /*!< 0178H */
    union {
        __IO  uint32_t  V32;                                /*!< 017CH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF11_ID1;                               /*!< 017CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0180H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF12_CNTSTAT;                               /*!< 0180H */
    __IO uint32_t  BUF12_TSTP;                              /*!< 0184H */
    union {
        __IO  uint32_t  V32;                                /*!< 0188H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0188H */
    __IO uint32_t  DATAH:8;                                 /*!< 0189H */
    __IO uint32_t  rev0:16;                                 /*!< 018AH */
        }BIT;
    }BUF12_DATA3;                              /*!< 0188H */
    union {
        __IO  uint32_t  V32;                                /*!< 018CH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 018CH */
    __IO uint32_t  DATAH:8;                                 /*!< 018DH */
    __IO uint32_t  rev0:16;                                 /*!< 018EH */
        }BIT;
    }BUF12_DATA2;                              /*!< 018CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0190H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0190H */
    __IO uint32_t  DATAH:8;                                 /*!< 0191H */
    __IO uint32_t  rev0:16;                                 /*!< 0192H */
        }BIT;
    }BUF12_DATA1;                              /*!< 0190H */
    union {
        __IO  uint32_t  V32;                                /*!< 0194H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 0194H */
    __IO uint32_t  DATAH:8;                                 /*!< 0195H */
    __IO uint32_t  rev0:16;                                 /*!< 0196H */
        }BIT;
    }BUF12_DATA0;                              /*!< 0194H */
    union {
        __IO  uint32_t  V32;                                /*!< 0198H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF12_ID0;                               /*!< 0198H */
    union {
        __IO  uint32_t  V32;                                /*!< 019CH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF12_ID1;                               /*!< 019CH */
    union {
        __IO  uint32_t  V32;                                /*!< 01A0H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF13_CNTSTAT;                               /*!< 01A0H */
    __IO uint32_t  BUF13_TSTP;                              /*!< 01A4H */
    union {
        __IO  uint32_t  V32;                                /*!< 01A8H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 01A8H */
    __IO uint32_t  DATAH:8;                                 /*!< 01A9H */
    __IO uint32_t  rev0:16;                                 /*!< 01AAH */
        }BIT;
    }BUF13_DATA3;                              /*!< 01A8H */
    union {
        __IO  uint32_t  V32;                                /*!< 01ACH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 01ACH */
    __IO uint32_t  DATAH:8;                                 /*!< 01ADH */
    __IO uint32_t  rev0:16;                                 /*!< 01AEH */
        }BIT;
    }BUF13_DATA2;                              /*!< 01ACH */
    union {
        __IO  uint32_t  V32;                                /*!< 01B0H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 01B0H */
    __IO uint32_t  DATAH:8;                                 /*!< 01B1H */
    __IO uint32_t  rev0:16;                                 /*!< 01B2H */
        }BIT;
    }BUF13_DATA1;                              /*!< 01B0H */
    union {
        __IO  uint32_t  V32;                                /*!< 01B4H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 01B4H */
    __IO uint32_t  DATAH:8;                                 /*!< 01B5H */
    __IO uint32_t  rev0:16;                                 /*!< 01B6H */
        }BIT;
    }BUF13_DATA0;                              /*!< 01B4H */
    union {
        __IO  uint32_t  V32;                                /*!< 01B8H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF13_ID0;                               /*!< 01B8H */
    union {
        __IO  uint32_t  V32;                                /*!< 01BCH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF13_ID1;                               /*!< 01BCH */
    union {
        __IO  uint32_t  V32;                                /*!< 01C0H */
        struct {
            __IO  uint32_t  ST        : 4;  /*!< [b3~b0]*/
            __IO  uint32_t  PRI       : 4;  /*!< [b7~b4]*/
            __IO  uint32_t  rev0      : 4;  /*!< [b11~b8]*/
            __IO  uint32_t  DLC       : 4;  /*!< [b15~b12]*/
            __IO  uint32_t  rev1      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF14_CNTSTAT;                               /*!< 01C0H */
    __IO uint32_t  BUF14_TSTP;                              /*!< 01C4H */
    union {
        __IO  uint32_t  V32;                                /*!< 01C8H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 01C8H */
    __IO uint32_t  DATAH:8;                                 /*!< 01C9H */
    __IO uint32_t  rev0:16;                                 /*!< 01CAH */
        }BIT;
    }BUF14_DATA3;                              /*!< 01C8H */
    union {
        __IO  uint32_t  V32;                                /*!< 01CCH */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 01CCH */
    __IO uint32_t  DATAH:8;                                 /*!< 01CDH */
    __IO uint32_t  rev0:16;                                 /*!< 01CEH */
        }BIT;
    }BUF14_DATA2;                              /*!< 01CCH */
    union {
        __IO  uint32_t  V32;                                /*!< 01D0H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 01D0H */
    __IO uint32_t  DATAH:8;                                 /*!< 01D1H */
    __IO uint32_t  rev0:16;                                 /*!< 01D2H */
        }BIT;
    }BUF14_DATA1;                              /*!< 01D0H */
    union {
        __IO  uint32_t  V32;                                /*!< 01D4H */
        struct {
    __IO uint32_t  DATAL:8;                                 /*!< 01D4H */
    __IO uint32_t  DATAH:8;                                 /*!< 01D5H */
    __IO uint32_t  rev0:16;                                 /*!< 01D6H */
        }BIT;
    }BUF14_DATA0;                              /*!< 01D4H */
    union {
        __IO  uint32_t  V32;                                /*!< 01D8H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XID       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF14_ID0;                               /*!< 01D8H */
    union {
        __IO  uint32_t  V32;                                /*!< 01DCH */
        struct {
            __IO  uint32_t  XID       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IDXID     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BUF14_ID1;                               /*!< 01DCH */
    __IO uint32_t  Reserved0[8];                            /*!< 01E0H */
    union {
        __IO  uint32_t  V32;                                /*!< 0200H */
        struct {
            __IO  uint32_t  CANEN     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  CRX       : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  CTX       : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  BUFFLOCK  : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  TSTPEN    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  DDIR      : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  LO        : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  IGNACK    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  LOOPBACK  : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  INTERNAL  : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  DIAGEN    : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  EIT       : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  rev0      :20;  /*!< [b31~b12]*/
        }BIT;
    }CGCR;                               /*!< 0200H */
    union {
        __IO  uint32_t  V32;                                /*!< 0204H */
        struct {
            __IO  uint32_t  TSEG2     : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  TSEG1     : 4;  /*!< [b6~b3]*/
            __IO  uint32_t  SJW       : 2;  /*!< [b8~b7]*/
            __IO  uint32_t  PSC       : 7;  /*!< [b15~b9]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }CTIM;                               /*!< 0204H */
    union {
        __IO  uint32_t  V32;                                /*!< 0208H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XGM       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }GMSKX;                               /*!< 0208H */
    union {
        __IO  uint32_t  V32;                                /*!< 020CH */
        struct {
            __IO  uint32_t  XGM       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  GMXGM     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }GMSKB;                               /*!< 020CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0210H */
        struct {
            __IO  uint32_t  XRTR      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  XBM       :15;  /*!< [b15~b1]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BMSKX;                               /*!< 0210H */
    union {
        __IO  uint32_t  V32;                                /*!< 0214H */
        struct {
            __IO  uint32_t  XBM       : 3;  /*!< [b2~b0]*/
            __IO  uint32_t  IDE       : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RTRSRR    : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  BMXBM     :11;  /*!< [b15~b5]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }BMSKB;                               /*!< 0214H */
    union {
        __IO  uint32_t  V32;                                /*!< 0218H */
        struct {
            __IO  uint32_t  IEN0      : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  IEN1      : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  IEN2      : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  IEN3      : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  IEN4      : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IEN5      : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  IEN6      : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  IEN7      : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  IEN8      : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  IEN9      : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  IEN10     : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  IEN11     : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  IEN12     : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  IEN13     : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  IEN14     : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  EIEN      : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }CIEN;                               /*!< 0218H */
    union {
        __IO  uint32_t  V32;                                /*!< 021CH */
        struct {
            __IO  uint32_t  IPND0     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  IPND1     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  IPND2     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  IPND3     : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  IPND4     : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  IPND5     : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  IPND6     : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  IPND7     : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  IPND8     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  IPND9     : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  IPND10    : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  IPND11    : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  IPND12    : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  IPND13    : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  IPND14    : 1;  /*!< [b14~b14]*/
            __I   uint32_t  EIPND     : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }CIPND;                               /*!< 021CH */
    union {
        __IO  uint32_t  V32;                                /*!< 0220H */
        struct {
            __IO  uint32_t  ICLR0     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  ICLR1     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  ICLR2     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  ICLR3     : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  ICLR4     : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  ICLR5     : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  ICLR6     : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  ICLR7     : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  ICLR8     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  ICLR9     : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  ICLR10    : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  ICLR11    : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  ICLR12    : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  ICLR13    : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  ICLR14    : 1;  /*!< [b14~b14]*/
            __O   uint32_t  EICLR     : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }CICLR;                               /*!< 0220H */
    union {
        __IO  uint32_t  V32;                                /*!< 0224H */
        struct {
            __IO  uint32_t  ICEN0     : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  ICEN1     : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  ICEN2     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  ICEN3     : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  ICEN4     : 1;  /*!< [b4~b4]*/
            __IO  uint32_t  ICEN5     : 1;  /*!< [b5~b5]*/
            __IO  uint32_t  ICEN6     : 1;  /*!< [b6~b6]*/
            __IO  uint32_t  ICEN7     : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  ICEN8     : 1;  /*!< [b8~b8]*/
            __IO  uint32_t  ICEN9     : 1;  /*!< [b9~b9]*/
            __IO  uint32_t  ICEN10    : 1;  /*!< [b10~b10]*/
            __IO  uint32_t  ICEN11    : 1;  /*!< [b11~b11]*/
            __IO  uint32_t  ICEN12    : 1;  /*!< [b12~b12]*/
            __IO  uint32_t  ICEN13    : 1;  /*!< [b13~b13]*/
            __IO  uint32_t  ICEN14    : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  EICEN     : 1;  /*!< [b15~b15]*/
            __IO  uint32_t  rev0      :16;  /*!< [b31~b16]*/
        }BIT;
    }CICEN;                               /*!< 0224H */
    union {
        __I   uint32_t  V32;                                /*!< 0228H */
        struct {
            __I   uint32_t  IST       : 4;  /*!< [b3~b0]*/
            __I   uint32_t  IRQ       : 1;  /*!< [b4~b4]*/
            __I   uint32_t  NS        : 3;  /*!< [b7~b5]*/
            __IO  uint32_t  rev0      :24;  /*!< [b31~b8]*/
        }BIT;
    }CSTPND;                               /*!< 0228H */
    union {
        __IO  uint32_t  V32;                                /*!< 022CH */
        struct {
    __IO uint32_t  TEC:8;                                   /*!< 022CH */
    __IO uint32_t  REC:8;                                   /*!< 022DH */
    __IO uint32_t  rev0:16;                                 /*!< 022EH */
        }BIT;
    }CANEC;                              /*!< 022CH */
    union {
        __I   uint32_t  V32;                                /*!< 0230H */
        struct {
            __I   uint32_t  EFID      : 4;  /*!< [b3~b0]*/
            __I   uint32_t  EBID      : 6;  /*!< [b9~b4]*/
            __I   uint32_t  TXE       : 1;  /*!< [b10~b10]*/
            __I   uint32_t  STUFF     : 1;  /*!< [b11~b11]*/
            __I   uint32_t  CRCERR    : 1;  /*!< [b12~b12]*/
            __I   uint32_t  MON       : 1;  /*!< [b13~b13]*/
            __I   uint32_t  DRIVE     : 1;  /*!< [b14~b14]*/
            __IO  uint32_t  rev0      :17;  /*!< [b31~b15]*/
        }BIT;
    }CEDIAG;                               /*!< 0230H */
    __IO uint32_t  CTMR;                                    /*!< 0234H */
}CAN_TypeDef;

/**
*@brief FIFO4L_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __I   uint32_t  RXTRIGF   : 1;  /*!< [b0~b0]*/
            __I   uint32_t  TXTRIGF   : 1;  /*!< [b1~b1]*/
            __I   uint32_t  RXOVF     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b3~b3]*/
            __I   uint32_t  RXEMPT    : 1;  /*!< [b4~b4]*/
            __I   uint32_t  TXEMPT    : 1;  /*!< [b5~b5]*/
            __I   uint32_t  RXFULL    : 1;  /*!< [b6~b6]*/
            __I   uint32_t  TXFULL    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev1      : 8;  /*!< [b15~b8]*/
            __O   uint32_t  RXTRIGFC  : 1;  /*!< [b16~b16]*/
            __O   uint32_t  TXTRIGFC  : 1;  /*!< [b17~b17]*/
            __O   uint32_t  RXOVFC    : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  rev2      :13;  /*!< [b31~b19]*/
        }BIT;
    }FR;                               /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  RXTRIGIE  : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  TXTRIGIE  : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  RXOVFIE   : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  RXMODE    : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RXMAP     : 2;  /*!< [b5~b4]*/
            __IO  uint32_t  TXMAP     : 2;  /*!< [b7~b6]*/
            __IO  uint32_t  RXRDBITW  : 2;  /*!< [b9~b8]*/
            __IO  uint32_t  TXWRBITW  : 2;  /*!< [b11~b10]*/
            __IO  uint32_t  RXTRIG    : 2;  /*!< [b13~b12]*/
            __IO  uint32_t  TXTRIG    : 2;  /*!< [b15~b14]*/
            __IO  uint32_t  RXFRST    : 1;  /*!< [b16~b16]*/
            __IO  uint32_t  TXFRST    : 1;  /*!< [b17~b17]*/
            __IO  uint32_t  RXFEN     : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  TXFEN     : 1;  /*!< [b19~b19]*/
            __IO  uint32_t  rev0      :12;  /*!< [b31~b20]*/
        }BIT;
    }CR;                               /*!< 0004H */
}FIFO4L_TypeDef;


/**
*@brief FIFO8L_registers
*/
typedef struct
{
    union {
        __IO  uint32_t  V32;                                /*!< 0000H */
        struct {
            __I   uint32_t  RXTRIGF   : 1;  /*!< [b0~b0]*/
            __I   uint32_t  TXTRIGF   : 1;  /*!< [b1~b1]*/
            __I   uint32_t  RXOVF     : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  rev0      : 1;  /*!< [b3~b3]*/
            __I   uint32_t  RXEMPT    : 1;  /*!< [b4~b4]*/
            __I   uint32_t  TXEMPT    : 1;  /*!< [b5~b5]*/
            __I   uint32_t  RXFULL    : 1;  /*!< [b6~b6]*/
            __I   uint32_t  TXFULL    : 1;  /*!< [b7~b7]*/
            __IO  uint32_t  rev1      : 8;  /*!< [b15~b8]*/
            __O   uint32_t  RXTRIGFC  : 1;  /*!< [b16~b16]*/
            __O   uint32_t  TXTRIGFC  : 1;  /*!< [b17~b17]*/
            __O   uint32_t  RXOVFC    : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  rev2      :13;  /*!< [b31~b19]*/
        }BIT;
    }FR;                               /*!< 0000H */
    union {
        __IO  uint32_t  V32;                                /*!< 0004H */
        struct {
            __IO  uint32_t  RXTRIGIE  : 1;  /*!< [b0~b0]*/
            __IO  uint32_t  TXTRIGIE  : 1;  /*!< [b1~b1]*/
            __IO  uint32_t  RXOVFIE   : 1;  /*!< [b2~b2]*/
            __IO  uint32_t  RXMODE    : 1;  /*!< [b3~b3]*/
            __IO  uint32_t  RXMAP     : 2;  /*!< [b5~b4]*/
            __IO  uint32_t  TXMAP     : 2;  /*!< [b7~b6]*/
            __IO  uint32_t  RXRDBITW  : 2;  /*!< [b9~b8]*/
            __IO  uint32_t  TXWRBITW  : 2;  /*!< [b11~b10]*/
            __IO  uint32_t  RXTRIG    : 2;  /*!< [b13~b12]*/
            __IO  uint32_t  TXTRIG    : 2;  /*!< [b15~b14]*/
            __IO  uint32_t  RXFRST    : 1;  /*!< [b16~b16]*/
            __IO  uint32_t  TXFRST    : 1;  /*!< [b17~b17]*/
            __IO  uint32_t  RXFEN     : 1;  /*!< [b18~b18]*/
            __IO  uint32_t  TXFEN     : 1;  /*!< [b19~b19]*/
            __IO  uint32_t  rev0      :12;  /*!< [b31~b20]*/
        }BIT;
    }CR;                               /*!< 0004H */
}FIFO8L_TypeDef;


/* @addtogroup  Peripheral base address*/

#define PCA0_BASE                      ((uint32_t)0x40000400)    /* Bus:APB0        Module:PCA        */
#define PCA1_BASE                      ((uint32_t)0x40000800)    /* Bus:APB0        Module:PCA        */
#define TIM7_BASE                      ((uint32_t)0x40000C00)    /* Bus:APB0        Module:TIM        */
#define TIM8_BASE                      ((uint32_t)0x40001000)    /* Bus:APB0        Module:TIM        */
#define QEI_BASE                       ((uint32_t)0x40001400)    /* Bus:APB0        Module:QEI        */
#define UART0_BASE                     ((uint32_t)0x40001800)    /* Bus:APB0        Module:UART       */
#define UART1_BASE                     ((uint32_t)0x40001C00)    /* Bus:APB0        Module:UART       */
#define UART2_BASE                     ((uint32_t)0x40002000)    /* Bus:APB0        Module:UART       */
#define SPI0_BASE                      ((uint32_t)0x40002400)    /* Bus:APB0        Module:SPI        */
#define TWI0_BASE                      ((uint32_t)0x40002800)    /* Bus:APB0        Module:TWI        */
#define CAN0_BASE                      ((uint32_t)0x40002C00)    /* Bus:APB0        Module:CAN        */
#define IWDT_BASE                      ((uint32_t)0x40003000)    /* Bus:APB0        Module:IWDT       */
#define WWDT_BASE                      ((uint32_t)0x40003400)    /* Bus:APB0        Module:WWDT       */
#define AMOC_BASE                      ((uint32_t)0x40003800)    /* Bus:APB0        Module:AMOC       */
#define ADC_BASE                       ((uint32_t)0x40003C00)    /* Bus:APB0        Module:ADC        */
#define EXTI_BASE                      ((uint32_t)0x40004000)    /* Bus:APB0        Module:EXTI       */
#define FIFO0_BASE                     ((uint32_t)0x40004400)    /* Bus:APB0        Module:FIFO4L     */
#define FIFO1_BASE                     ((uint32_t)0x40004800)    /* Bus:APB0        Module:FIFO4L     */
#define FIFO2_BASE                     ((uint32_t)0x40004C00)    /* Bus:APB0        Module:FIFO8L     */
#define N_TEST_BASE                    ((uint32_t)0x4001F000)    /* Bus:APB0        Module:N_TEST     */
#define GPIOA_BASE                     ((uint32_t)0x40040000)    /* Bus:AHB         Module:GPIO       */
#define GPIOB_BASE                     ((uint32_t)0x40040080)    /* Bus:AHB         Module:GPIO       */
#define GPIOC_BASE                     ((uint32_t)0x40040100)    /* Bus:AHB         Module:GPIO       */
#define MCM_BASE                       ((uint32_t)0x40040400)    /* Bus:AHB         Module:MCM        */
#define SYSCFG_BASE                    ((uint32_t)0x40040800)    /* Bus:AHB         Module:SYSCFG     */
#define RCC_BASE                       ((uint32_t)0x40040C00)    /* Bus:AHB         Module:RCC        */
#define FLASH_BASE                     ((uint32_t)0x40041000)    /* Bus:AHB         Module:FLASH      */
#define MACP_BASE                      ((uint32_t)0x40041400)    /* Bus:AHB         Module:MACP       */
#define CRC_BASE                       ((uint32_t)0x40041800)    /* Bus:AHB         Module:CRC        */
#define RAMBIST_BASE                   ((uint32_t)0x40041C00)    /* Bus:AHB         Module:RAMBIST    */

/* @addtogroup Peripheral_declaration */

#define N_TEST               ((N_TEST_TypeDef *)      N_TEST_BASE)
#define FLASH                ((FLASH_TypeDef *)       FLASH_BASE)
#define SYSCFG               ((SYSCFG_TypeDef *)      SYSCFG_BASE)
#define RCC                  ((RCC_TypeDef *)         RCC_BASE)
#define IWDT                 ((IWDT_TypeDef *)        IWDT_BASE)
#define WWDT                 ((WWDT_TypeDef *)        WWDT_BASE)
#define CRC                  ((CRC_TypeDef *)         CRC_BASE)
#define RAMBIST              ((RAMBIST_TypeDef *)     RAMBIST_BASE)
#define GPIOA                ((GPIO_TypeDef *)        GPIOA_BASE)
#define GPIOB                ((GPIO_TypeDef *)        GPIOB_BASE)
#define GPIOC                ((GPIO_TypeDef *)        GPIOC_BASE)
#define EXTI                 ((EXTI_TypeDef *)        EXTI_BASE)
#define MCM                  ((MCM_TypeDef *)         MCM_BASE)
#define PCA0                 ((PCA_TypeDef *)         PCA0_BASE)
#define PCA1                 ((PCA_TypeDef *)         PCA1_BASE)
#define TIM7                 ((TIM_TypeDef *)         TIM7_BASE)
#define TIM8                 ((TIM_TypeDef *)         TIM8_BASE)
#define QEI                  ((QEI_TypeDef *)         QEI_BASE)
#define MACP                 ((MACP_TypeDef *)        MACP_BASE)
#define ADC                  ((ADC_TypeDef *)         ADC_BASE)
#define AMOC                 ((AMOC_TypeDef *)        AMOC_BASE)
#define UART0                ((UART_TypeDef *)        UART0_BASE)
#define UART1                ((UART_TypeDef *)        UART1_BASE)
#define UART2                ((UART_TypeDef *)        UART2_BASE)
#define SPI0                 ((SPI_TypeDef *)         SPI0_BASE)
#define TWI0                 ((TWI_TypeDef *)         TWI0_BASE)
#define CAN0                 ((CAN_TypeDef *)         CAN0_BASE)
#define FIFO0                ((FIFO4L_TypeDef *)      FIFO0_BASE)
#define FIFO1                ((FIFO4L_TypeDef *)      FIFO1_BASE)
#define FIFO2                ((FIFO8L_TypeDef *)      FIFO2_BASE)

/* @addtogroup Peripheral Field Postion and mask */

#define N_TEST_NTW_WDT_Pos           0                                            /*!<N_TEST NTW: WDT Position */
#define N_TEST_NTW_WDT_Msk           (0xFFUL /*<< N_TEST_NTW_WDT_Pos*/)           /*!<N_TEST NTW: WDT Mask */

#define N_TEST_NTW_Msk_ALL           (N_TEST_NTW_WDT_Msk          )

#define N_TEST_NTID0_CODE_Pos        0                                            /*!<N_TEST NTID0: CODE Position */
#define N_TEST_NTID0_CODE_Msk        (0xFFFFUL /*<< N_TEST_NTID0_CODE_Pos*/)      /*!<N_TEST NTID0: CODE Mask */

#define N_TEST_NTID0_Msk_ALL         (N_TEST_NTID0_CODE_Msk       )

#define N_TEST_NTID1_CODE_Pos        0                                            /*!<N_TEST NTID1: CODE Position */
#define N_TEST_NTID1_CODE_Msk        (0xFFFFUL /*<< N_TEST_NTID1_CODE_Pos*/)      /*!<N_TEST NTID1: CODE Mask */

#define N_TEST_NTID1_Msk_ALL         (N_TEST_NTID1_CODE_Msk       )

#define N_TEST_NTID2_CODE_Pos        0                                            /*!<N_TEST NTID2: CODE Position */
#define N_TEST_NTID2_CODE_Msk        (0xFFFFUL /*<< N_TEST_NTID2_CODE_Pos*/)      /*!<N_TEST NTID2: CODE Mask */

#define N_TEST_NTID2_Msk_ALL         (N_TEST_NTID2_CODE_Msk       )

#define FLASH_ACR_LATENCY_Pos        0                                            /*!<FLASH ACR: LATENCY Position */
#define FLASH_ACR_LATENCY_Msk        (0x7UL /*<< FLASH_ACR_LATENCY_Pos*/)         /*!<FLASH ACR: LATENCY Mask */

#define FLASH_ACR_PRFTEN_Pos         8                                            /*!<FLASH ACR: PRFTEN Position */
#define FLASH_ACR_PRFTEN_Msk         (0x1UL << FLASH_ACR_PRFTEN_Pos)              /*!<FLASH ACR: PRFTEN Mask */

#define FLASH_ACR_DCEN_Pos           10                                           /*!<FLASH ACR: DCEN Position */
#define FLASH_ACR_DCEN_Msk           (0x1UL << FLASH_ACR_DCEN_Pos)                /*!<FLASH ACR: DCEN Mask */

#define FLASH_ACR_CRST_Pos           11                                           /*!<FLASH ACR: CRST Position */
#define FLASH_ACR_CRST_Msk           (0x1UL << FLASH_ACR_CRST_Pos)                /*!<FLASH ACR: CRST Mask */

#define FLASH_ACR_LOCK_Pos           16                                           /*!<FLASH ACR: LOCK Position */
#define FLASH_ACR_LOCK_Msk           (0xFFFFUL << FLASH_ACR_LOCK_Pos)             /*!<FLASH ACR: LOCK Mask */

#define FLASH_ACR_Msk_ALL            (FLASH_ACR_LATENCY_Msk        |\
                                      FLASH_ACR_PRFTEN_Msk         |\
                                      FLASH_ACR_DCEN_Msk           |\
                                      FLASH_ACR_CRST_Msk           |\
                                      FLASH_ACR_LOCK_Msk           )

#define FLASH_SR_EOP_Pos             0                                            /*!<FLASH SR: EOP Position */
#define FLASH_SR_EOP_Msk             (0x1UL /*<< FLASH_SR_EOP_Pos*/)              /*!<FLASH SR: EOP Mask */

#define FLASH_SR_OPERR_Pos           1                                            /*!<FLASH SR: OPERR Position */
#define FLASH_SR_OPERR_Msk           (0x1UL << FLASH_SR_OPERR_Pos)                /*!<FLASH SR: OPERR Mask */

#define FLASH_SR_FLSERR_Pos          3                                            /*!<FLASH SR: FLSERR Position */
#define FLASH_SR_FLSERR_Msk          (0x1UL << FLASH_SR_FLSERR_Pos)               /*!<FLASH SR: FLSERR Mask */

#define FLASH_SR_WRPRTERR_Pos        4                                            /*!<FLASH SR: WRPRTERR Position */
#define FLASH_SR_WRPRTERR_Msk        (0x1UL << FLASH_SR_WRPRTERR_Pos)             /*!<FLASH SR: WRPRTERR Mask */

#define FLASH_SR_PGPERR_Pos          5                                            /*!<FLASH SR: PGPERR Position */
#define FLASH_SR_PGPERR_Msk          (0x1UL << FLASH_SR_PGPERR_Pos)               /*!<FLASH SR: PGPERR Mask */

#define FLASH_SR_PGWERR_Pos          6                                            /*!<FLASH SR: PGWERR Position */
#define FLASH_SR_PGWERR_Msk          (0x1UL << FLASH_SR_PGWERR_Pos)               /*!<FLASH SR: PGWERR Mask */

#define FLASH_SR_STAERR_Pos          7                                            /*!<FLASH SR: STAERR Position */
#define FLASH_SR_STAERR_Msk          (0x1UL << FLASH_SR_STAERR_Pos)               /*!<FLASH SR: STAERR Mask */

#define FLASH_SR_BSY_Pos             15                                           /*!<FLASH SR: BSY Position */
#define FLASH_SR_BSY_Msk             (0x1UL << FLASH_SR_BSY_Pos)                  /*!<FLASH SR: BSY Mask */

#define FLASH_SR_EOPC_Pos            16                                           /*!<FLASH SR: EOPC Position */
#define FLASH_SR_EOPC_Msk            (0x1UL << FLASH_SR_EOPC_Pos)                 /*!<FLASH SR: EOPC Mask */

#define FLASH_SR_OPERRC_Pos          17                                           /*!<FLASH SR: OPERRC Position */
#define FLASH_SR_OPERRC_Msk          (0x1UL << FLASH_SR_OPERRC_Pos)               /*!<FLASH SR: OPERRC Mask */

#define FLASH_SR_FLSERRC_Pos         19                                           /*!<FLASH SR: FLSERRC Position */
#define FLASH_SR_FLSERRC_Msk         (0x1UL << FLASH_SR_FLSERRC_Pos)              /*!<FLASH SR: FLSERRC Mask */

#define FLASH_SR_WRPRTERRC_Pos       20                                           /*!<FLASH SR: WRPRTERRC Position */
#define FLASH_SR_WRPRTERRC_Msk       (0x1UL << FLASH_SR_WRPRTERRC_Pos)            /*!<FLASH SR: WRPRTERRC Mask */

#define FLASH_SR_PGPERRC_Pos         21                                           /*!<FLASH SR: PGPERRC Position */
#define FLASH_SR_PGPERRC_Msk         (0x1UL << FLASH_SR_PGPERRC_Pos)              /*!<FLASH SR: PGPERRC Mask */

#define FLASH_SR_PGWERRC_Pos         22                                           /*!<FLASH SR: PGWERRC Position */
#define FLASH_SR_PGWERRC_Msk         (0x1UL << FLASH_SR_PGWERRC_Pos)              /*!<FLASH SR: PGWERRC Mask */

#define FLASH_SR_STAERRC_Pos         23                                           /*!<FLASH SR: STAERRC Position */
#define FLASH_SR_STAERRC_Msk         (0x1UL << FLASH_SR_STAERRC_Pos)              /*!<FLASH SR: STAERRC Mask */

#define FLASH_SR_Msk_ALL             (FLASH_SR_EOP_Msk             |\
                                      FLASH_SR_OPERR_Msk           |\
                                      FLASH_SR_FLSERR_Msk          |\
                                      FLASH_SR_WRPRTERR_Msk        |\
                                      FLASH_SR_PGPERR_Msk          |\
                                      FLASH_SR_PGWERR_Msk          |\
                                      FLASH_SR_STAERR_Msk          |\
                                      FLASH_SR_BSY_Msk             |\
                                      FLASH_SR_EOPC_Msk            |\
                                      FLASH_SR_OPERRC_Msk          |\
                                      FLASH_SR_FLSERRC_Msk         |\
                                      FLASH_SR_WRPRTERRC_Msk       |\
                                      FLASH_SR_PGPERRC_Msk         |\
                                      FLASH_SR_PGWERRC_Msk         |\
                                      FLASH_SR_STAERRC_Msk         )

#define FLASH_CR_SNB_Pos             0                                            /*!<FLASH CR: SNB Position */
#define FLASH_CR_SNB_Msk             (0x7FUL /*<< FLASH_CR_SNB_Pos*/)             /*!<FLASH CR: SNB Mask */

#define FLASH_CR_STRT_Pos            8                                            /*!<FLASH CR: STRT Position */
#define FLASH_CR_STRT_Msk            (0x1UL << FLASH_CR_STRT_Pos)                 /*!<FLASH CR: STRT Mask */

#define FLASH_CR_PSIZE_Pos           11                                           /*!<FLASH CR: PSIZE Position */
#define FLASH_CR_PSIZE_Msk           (0x1UL << FLASH_CR_PSIZE_Pos)                /*!<FLASH CR: PSIZE Mask */

#define FLASH_CR_INFLCK_Pos          12                                           /*!<FLASH CR: INFLCK Position */
#define FLASH_CR_INFLCK_Msk          (0x1UL << FLASH_CR_INFLCK_Pos)               /*!<FLASH CR: INFLCK Mask */

#define FLASH_CR_E2LCK_Pos           14                                           /*!<FLASH CR: E2LCK Position */
#define FLASH_CR_E2LCK_Msk           (0x1UL << FLASH_CR_E2LCK_Pos)                /*!<FLASH CR: E2LCK Mask */

#define FLASH_CR_MNLCK_Pos           15                                           /*!<FLASH CR: MNLCK Position */
#define FLASH_CR_MNLCK_Msk           (0x1UL << FLASH_CR_MNLCK_Pos)                /*!<FLASH CR: MNLCK Mask */

#define FLASH_CR_CMD_Pos             16                                           /*!<FLASH CR: CMD Position */
#define FLASH_CR_CMD_Msk             (0xFFFFUL << FLASH_CR_CMD_Pos)               /*!<FLASH CR: CMD Mask */

#define FLASH_CR_Msk_ALL             (FLASH_CR_SNB_Msk             |\
                                      FLASH_CR_STRT_Msk            |\
                                      FLASH_CR_PSIZE_Msk           |\
                                      FLASH_CR_INFLCK_Msk          |\
                                      FLASH_CR_E2LCK_Msk           |\
                                      FLASH_CR_MNLCK_Msk           |\
                                      FLASH_CR_CMD_Msk             )

#define FLASH_OPR_OPT0_Pos           0                                            /*!<FLASH OPR: OPT0 Position */
#define FLASH_OPR_OPT0_Msk           (0xFFUL /*<< FLASH_OPR_OPT0_Pos*/)           /*!<FLASH OPR: OPT0 Mask */

#define FLASH_OPR_OPT1_Pos           8                                            /*!<FLASH OPR: OPT1 Position */
#define FLASH_OPR_OPT1_Msk           (0xFFUL << FLASH_OPR_OPT1_Pos)               /*!<FLASH OPR: OPT1 Mask */

#define FLASH_OPR_OPT2_Pos           16                                           /*!<FLASH OPR: OPT2 Position */
#define FLASH_OPR_OPT2_Msk           (0xFFUL << FLASH_OPR_OPT2_Pos)               /*!<FLASH OPR: OPT2 Mask */

#define FLASH_OPR_OPT3_Pos           24                                           /*!<FLASH OPR: OPT3 Position */
#define FLASH_OPR_OPT3_Msk           (0xFFUL << FLASH_OPR_OPT3_Pos)               /*!<FLASH OPR: OPT3 Mask */

#define FLASH_OPR_Msk_ALL            (FLASH_OPR_OPT0_Msk           |\
                                      FLASH_OPR_OPT1_Msk           |\
                                      FLASH_OPR_OPT2_Msk           |\
                                      FLASH_OPR_OPT3_Msk           )

#define FLASH_RPR_RDP_Pos            0                                            /*!<FLASH RPR: RDP Position */
#define FLASH_RPR_RDP_Msk            (0xFFFFUL /*<< FLASH_RPR_RDP_Pos*/)          /*!<FLASH RPR: RDP Mask */

#define FLASH_RPR_Msk_ALL            (FLASH_RPR_RDP_Msk           )

#define FLASH_CNTCR_CNTEN_Pos        0                                            /*!<FLASH CNTCR: CNTEN Position */
#define FLASH_CNTCR_CNTEN_Msk        (0x1UL /*<< FLASH_CNTCR_CNTEN_Pos*/)         /*!<FLASH CNTCR: CNTEN Mask */

#define FLASH_CNTCR_Msk_ALL          (FLASH_CNTCR_CNTEN_Msk       )

#define FLASH_MEMRMP_MEMMODE_Pos     0                                            /*!<FLASH MEMRMP: MEMMODE Position */
#define FLASH_MEMRMP_MEMMODE_Msk     (0xFFFFUL /*<< FLASH_MEMRMP_MEMMODE_Pos*/)   /*!<FLASH MEMRMP: MEMMODE Mask */

#define FLASH_MEMRMP_Msk_ALL         (FLASH_MEMRMP_MEMMODE_Msk    )

#define FLASH_OPR_CUST1_OPT0_Pos     0                                            /*!<FLASH OPR_CUST1: OPT0 Position */
#define FLASH_OPR_CUST1_OPT0_Msk     (0xFFUL /*<< FLASH_OPR_CUST1_OPT0_Pos*/)     /*!<FLASH OPR_CUST1: OPT0 Mask */

#define FLASH_OPR_CUST1_OPT1_Pos     8                                            /*!<FLASH OPR_CUST1: OPT1 Position */
#define FLASH_OPR_CUST1_OPT1_Msk     (0xFFUL << FLASH_OPR_CUST1_OPT1_Pos)         /*!<FLASH OPR_CUST1: OPT1 Mask */

#define FLASH_OPR_CUST1_OPT2_Pos     16                                           /*!<FLASH OPR_CUST1: OPT2 Position */
#define FLASH_OPR_CUST1_OPT2_Msk     (0xFFUL << FLASH_OPR_CUST1_OPT2_Pos)         /*!<FLASH OPR_CUST1: OPT2 Mask */

#define FLASH_OPR_CUST1_OPT3_Pos     24                                           /*!<FLASH OPR_CUST1: OPT3 Position */
#define FLASH_OPR_CUST1_OPT3_Msk     (0xFFUL << FLASH_OPR_CUST1_OPT3_Pos)         /*!<FLASH OPR_CUST1: OPT3 Mask */

#define FLASH_OPR_CUST1_Msk_ALL      (FLASH_OPR_CUST1_OPT0_Msk     |\
                                      FLASH_OPR_CUST1_OPT1_Msk     |\
                                      FLASH_OPR_CUST1_OPT2_Msk     |\
                                      FLASH_OPR_CUST1_OPT3_Msk     )

#define FLASH_OPR_DESI0_OPT0_Pos     0                                            /*!<FLASH OPR_DESI0: OPT0 Position */
#define FLASH_OPR_DESI0_OPT0_Msk     (0xFFUL /*<< FLASH_OPR_DESI0_OPT0_Pos*/)     /*!<FLASH OPR_DESI0: OPT0 Mask */

#define FLASH_OPR_DESI0_OPT1_Pos     8                                            /*!<FLASH OPR_DESI0: OPT1 Position */
#define FLASH_OPR_DESI0_OPT1_Msk     (0xFFUL << FLASH_OPR_DESI0_OPT1_Pos)         /*!<FLASH OPR_DESI0: OPT1 Mask */

#define FLASH_OPR_DESI0_OPT2_Pos     16                                           /*!<FLASH OPR_DESI0: OPT2 Position */
#define FLASH_OPR_DESI0_OPT2_Msk     (0xFFUL << FLASH_OPR_DESI0_OPT2_Pos)         /*!<FLASH OPR_DESI0: OPT2 Mask */

#define FLASH_OPR_DESI0_OPT3_Pos     24                                           /*!<FLASH OPR_DESI0: OPT3 Position */
#define FLASH_OPR_DESI0_OPT3_Msk     (0xFFUL << FLASH_OPR_DESI0_OPT3_Pos)         /*!<FLASH OPR_DESI0: OPT3 Mask */

#define FLASH_OPR_DESI0_Msk_ALL      (FLASH_OPR_DESI0_OPT0_Msk     |\
                                      FLASH_OPR_DESI0_OPT1_Msk     |\
                                      FLASH_OPR_DESI0_OPT2_Msk     |\
                                      FLASH_OPR_DESI0_OPT3_Msk     )

#define FLASH_OPR_DESI1_OPT0_Pos     0                                            /*!<FLASH OPR_DESI1: OPT0 Position */
#define FLASH_OPR_DESI1_OPT0_Msk     (0xFFUL /*<< FLASH_OPR_DESI1_OPT0_Pos*/)     /*!<FLASH OPR_DESI1: OPT0 Mask */

#define FLASH_OPR_DESI1_OPT1_Pos     8                                            /*!<FLASH OPR_DESI1: OPT1 Position */
#define FLASH_OPR_DESI1_OPT1_Msk     (0xFFUL << FLASH_OPR_DESI1_OPT1_Pos)         /*!<FLASH OPR_DESI1: OPT1 Mask */

#define FLASH_OPR_DESI1_OPT2_Pos     16                                           /*!<FLASH OPR_DESI1: OPT2 Position */
#define FLASH_OPR_DESI1_OPT2_Msk     (0xFFUL << FLASH_OPR_DESI1_OPT2_Pos)         /*!<FLASH OPR_DESI1: OPT2 Mask */

#define FLASH_OPR_DESI1_OPT3_Pos     24                                           /*!<FLASH OPR_DESI1: OPT3 Position */
#define FLASH_OPR_DESI1_OPT3_Msk     (0xFFUL << FLASH_OPR_DESI1_OPT3_Pos)         /*!<FLASH OPR_DESI1: OPT3 Mask */

#define FLASH_OPR_DESI1_Msk_ALL      (FLASH_OPR_DESI1_OPT0_Msk     |\
                                      FLASH_OPR_DESI1_OPT1_Msk     |\
                                      FLASH_OPR_DESI1_OPT2_Msk     |\
                                      FLASH_OPR_DESI1_OPT3_Msk     )

#define FLASH_OPR_DESI2_OPT0_Pos     0                                            /*!<FLASH OPR_DESI2: OPT0 Position */
#define FLASH_OPR_DESI2_OPT0_Msk     (0xFFUL /*<< FLASH_OPR_DESI2_OPT0_Pos*/)     /*!<FLASH OPR_DESI2: OPT0 Mask */

#define FLASH_OPR_DESI2_OPT1_Pos     8                                            /*!<FLASH OPR_DESI2: OPT1 Position */
#define FLASH_OPR_DESI2_OPT1_Msk     (0xFFUL << FLASH_OPR_DESI2_OPT1_Pos)         /*!<FLASH OPR_DESI2: OPT1 Mask */

#define FLASH_OPR_DESI2_OPT2_Pos     16                                           /*!<FLASH OPR_DESI2: OPT2 Position */
#define FLASH_OPR_DESI2_OPT2_Msk     (0xFFUL << FLASH_OPR_DESI2_OPT2_Pos)         /*!<FLASH OPR_DESI2: OPT2 Mask */

#define FLASH_OPR_DESI2_OPT3_Pos     24                                           /*!<FLASH OPR_DESI2: OPT3 Position */
#define FLASH_OPR_DESI2_OPT3_Msk     (0xFFUL << FLASH_OPR_DESI2_OPT3_Pos)         /*!<FLASH OPR_DESI2: OPT3 Mask */

#define FLASH_OPR_DESI2_Msk_ALL      (FLASH_OPR_DESI2_OPT0_Msk     |\
                                      FLASH_OPR_DESI2_OPT1_Msk     |\
                                      FLASH_OPR_DESI2_OPT2_Msk     |\
                                      FLASH_OPR_DESI2_OPT3_Msk     )

#define FLASH_OPR_DESI3_OPT0_Pos     0                                            /*!<FLASH OPR_DESI3: OPT0 Position */
#define FLASH_OPR_DESI3_OPT0_Msk     (0xFFUL /*<< FLASH_OPR_DESI3_OPT0_Pos*/)     /*!<FLASH OPR_DESI3: OPT0 Mask */

#define FLASH_OPR_DESI3_OPT1_Pos     8                                            /*!<FLASH OPR_DESI3: OPT1 Position */
#define FLASH_OPR_DESI3_OPT1_Msk     (0xFFUL << FLASH_OPR_DESI3_OPT1_Pos)         /*!<FLASH OPR_DESI3: OPT1 Mask */

#define FLASH_OPR_DESI3_OPT2_Pos     16                                           /*!<FLASH OPR_DESI3: OPT2 Position */
#define FLASH_OPR_DESI3_OPT2_Msk     (0xFFUL << FLASH_OPR_DESI3_OPT2_Pos)         /*!<FLASH OPR_DESI3: OPT2 Mask */

#define FLASH_OPR_DESI3_OPT3_Pos     24                                           /*!<FLASH OPR_DESI3: OPT3 Position */
#define FLASH_OPR_DESI3_OPT3_Msk     (0xFFUL << FLASH_OPR_DESI3_OPT3_Pos)         /*!<FLASH OPR_DESI3: OPT3 Mask */

#define FLASH_OPR_DESI3_Msk_ALL      (FLASH_OPR_DESI3_OPT0_Msk     |\
                                      FLASH_OPR_DESI3_OPT1_Msk     |\
                                      FLASH_OPR_DESI3_OPT2_Msk     |\
                                      FLASH_OPR_DESI3_OPT3_Msk     )

#define SYSCFG_PWRCR_VBOD_Pos        0                                            /*!<SYSCFG PWRCR: VBOD Position */
#define SYSCFG_PWRCR_VBOD_Msk        (0xFUL /*<< SYSCFG_PWRCR_VBOD_Pos*/)         /*!<SYSCFG PWRCR: VBOD Mask */

#define SYSCFG_PWRCR_BODMD_Pos       4                                            /*!<SYSCFG PWRCR: BODMD Position */
#define SYSCFG_PWRCR_BODMD_Msk       (0x3UL << SYSCFG_PWRCR_BODMD_Pos)            /*!<SYSCFG PWRCR: BODMD Mask */

#define SYSCFG_PWRCR_BODIE_Pos       6                                            /*!<SYSCFG PWRCR: BODIE Position */
#define SYSCFG_PWRCR_BODIE_Msk       (0x1UL << SYSCFG_PWRCR_BODIE_Pos)            /*!<SYSCFG PWRCR: BODIE Mask */

#define SYSCFG_PWRCR_BODEN_Pos       7                                            /*!<SYSCFG PWRCR: BODEN Position */
#define SYSCFG_PWRCR_BODEN_Msk       (0x1UL << SYSCFG_PWRCR_BODEN_Pos)            /*!<SYSCFG PWRCR: BODEN Mask */

#define SYSCFG_PWRCR_VLVR_Pos        8                                            /*!<SYSCFG PWRCR: VLVR Position */
#define SYSCFG_PWRCR_VLVR_Msk        (0x1UL << SYSCFG_PWRCR_VLVR_Pos)             /*!<SYSCFG PWRCR: VLVR Mask */

#define SYSCFG_PWRCR_LVREN_Pos       9                                            /*!<SYSCFG PWRCR: LVREN Position */
#define SYSCFG_PWRCR_LVREN_Msk       (0x1UL << SYSCFG_PWRCR_LVREN_Pos)            /*!<SYSCFG PWRCR: LVREN Mask */

#define SYSCFG_PWRCR_Msk_ALL         (SYSCFG_PWRCR_VBOD_Msk        |\
                                      SYSCFG_PWRCR_BODMD_Msk       |\
                                      SYSCFG_PWRCR_BODIE_Msk       |\
                                      SYSCFG_PWRCR_BODEN_Msk       |\
                                      SYSCFG_PWRCR_VLVR_Msk        |\
                                      SYSCFG_PWRCR_LVREN_Msk       )

#define SYSCFG_PWRSR_BODIF_Pos       0                                            /*!<SYSCFG PWRSR: BODIF Position */
#define SYSCFG_PWRSR_BODIF_Msk       (0x1UL /*<< SYSCFG_PWRSR_BODIF_Pos*/)        /*!<SYSCFG PWRSR: BODIF Mask */

#define SYSCFG_PWRSR_BODF_Pos        1                                            /*!<SYSCFG PWRSR: BODF Position */
#define SYSCFG_PWRSR_BODF_Msk        (0x1UL << SYSCFG_PWRSR_BODF_Pos)             /*!<SYSCFG PWRSR: BODF Mask */

#define SYSCFG_PWRSR_Msk_ALL         (SYSCFG_PWRSR_BODIF_Msk       |\
                                      SYSCFG_PWRSR_BODF_Msk        )

#define SYSCFG_SAFR_OSCCFG_Pos       0                                            /*!<SYSCFG SAFR: OSCCFG Position */
#define SYSCFG_SAFR_OSCCFG_Msk       (0x3UL /*<< SYSCFG_SAFR_OSCCFG_Pos*/)        /*!<SYSCFG SAFR: OSCCFG Mask */

#define SYSCFG_SAFR_SWJCFG_Pos       2                                            /*!<SYSCFG SAFR: SWJCFG Position */
#define SYSCFG_SAFR_SWJCFG_Msk       (0x1UL << SYSCFG_SAFR_SWJCFG_Pos)            /*!<SYSCFG SAFR: SWJCFG Mask */

#define SYSCFG_SAFR_IEN_EXTI0_Pos    5                                            /*!<SYSCFG SAFR: IEN_EXTI0 Position */
#define SYSCFG_SAFR_IEN_EXTI0_Msk    (0x1UL << SYSCFG_SAFR_IEN_EXTI0_Pos)         /*!<SYSCFG SAFR: IEN_EXTI0 Mask */

#define SYSCFG_SAFR_IEN_BOD_Pos      6                                            /*!<SYSCFG SAFR: IEN_BOD Position */
#define SYSCFG_SAFR_IEN_BOD_Msk      (0x1UL << SYSCFG_SAFR_IEN_BOD_Pos)           /*!<SYSCFG SAFR: IEN_BOD Mask */

#define SYSCFG_SAFR_IEN_CSM_Pos      7                                            /*!<SYSCFG SAFR: IEN_CSM Position */
#define SYSCFG_SAFR_IEN_CSM_Msk      (0x1UL << SYSCFG_SAFR_IEN_CSM_Pos)           /*!<SYSCFG SAFR: IEN_CSM Mask */

#define SYSCFG_SAFR_LOCK_Pos         16                                           /*!<SYSCFG SAFR: LOCK Position */
#define SYSCFG_SAFR_LOCK_Msk         (0xFFFFUL << SYSCFG_SAFR_LOCK_Pos)           /*!<SYSCFG SAFR: LOCK Mask */

#define SYSCFG_SAFR_Msk_ALL          (SYSCFG_SAFR_OSCCFG_Msk       |\
                                      SYSCFG_SAFR_SWJCFG_Msk       |\
                                      SYSCFG_SAFR_IEN_EXTI0_Msk    |\
                                      SYSCFG_SAFR_IEN_BOD_Msk      |\
                                      SYSCFG_SAFR_IEN_CSM_Msk      |\
                                      SYSCFG_SAFR_LOCK_Msk         )

#define SYSCFG_DBGCR_DBG_SLEEP_Pos   0                                            /*!<SYSCFG DBGCR: DBG_SLEEP Position */
#define SYSCFG_DBGCR_DBG_SLEEP_Msk   (0x1UL /*<< SYSCFG_DBGCR_DBG_SLEEP_Pos*/)    /*!<SYSCFG DBGCR: DBG_SLEEP Mask */

#define SYSCFG_DBGCR_DBG_STOP_Pos    1                                            /*!<SYSCFG DBGCR: DBG_STOP Position */
#define SYSCFG_DBGCR_DBG_STOP_Msk    (0x1UL << SYSCFG_DBGCR_DBG_STOP_Pos)         /*!<SYSCFG DBGCR: DBG_STOP Mask */

#define SYSCFG_DBGCR_DBG_CAN_Pos     6                                            /*!<SYSCFG DBGCR: DBG_CAN Position */
#define SYSCFG_DBGCR_DBG_CAN_Msk     (0x1UL << SYSCFG_DBGCR_DBG_CAN_Pos)          /*!<SYSCFG DBGCR: DBG_CAN Mask */

#define SYSCFG_DBGCR_DBG_QEI_Pos     7                                            /*!<SYSCFG DBGCR: DBG_QEI Position */
#define SYSCFG_DBGCR_DBG_QEI_Msk     (0x1UL << SYSCFG_DBGCR_DBG_QEI_Pos)          /*!<SYSCFG DBGCR: DBG_QEI Mask */

#define SYSCFG_DBGCR_DBG_IWDT_Pos    8                                            /*!<SYSCFG DBGCR: DBG_IWDT Position */
#define SYSCFG_DBGCR_DBG_IWDT_Msk    (0x1UL << SYSCFG_DBGCR_DBG_IWDT_Pos)         /*!<SYSCFG DBGCR: DBG_IWDT Mask */

#define SYSCFG_DBGCR_DBG_WWDT_Pos    9                                            /*!<SYSCFG DBGCR: DBG_WWDT Position */
#define SYSCFG_DBGCR_DBG_WWDT_Msk    (0x1UL << SYSCFG_DBGCR_DBG_WWDT_Pos)         /*!<SYSCFG DBGCR: DBG_WWDT Mask */

#define SYSCFG_DBGCR_DBG_PCA_Pos     10                                           /*!<SYSCFG DBGCR: DBG_PCA Position */
#define SYSCFG_DBGCR_DBG_PCA_Msk     (0x1UL << SYSCFG_DBGCR_DBG_PCA_Pos)          /*!<SYSCFG DBGCR: DBG_PCA Mask */

#define SYSCFG_DBGCR_DBG_TIM_Pos     11                                           /*!<SYSCFG DBGCR: DBG_TIM Position */
#define SYSCFG_DBGCR_DBG_TIM_Msk     (0x1UL << SYSCFG_DBGCR_DBG_TIM_Pos)          /*!<SYSCFG DBGCR: DBG_TIM Mask */

#define SYSCFG_DBGCR_DBG_MCM_Pos     12                                           /*!<SYSCFG DBGCR: DBG_MCM Position */
#define SYSCFG_DBGCR_DBG_MCM_Msk     (0x1UL << SYSCFG_DBGCR_DBG_MCM_Pos)          /*!<SYSCFG DBGCR: DBG_MCM Mask */

#define SYSCFG_DBGCR_DBG_UART_Pos    13                                           /*!<SYSCFG DBGCR: DBG_UART Position */
#define SYSCFG_DBGCR_DBG_UART_Msk    (0x1UL << SYSCFG_DBGCR_DBG_UART_Pos)         /*!<SYSCFG DBGCR: DBG_UART Mask */

#define SYSCFG_DBGCR_DBG_SPI_Pos     14                                           /*!<SYSCFG DBGCR: DBG_SPI Position */
#define SYSCFG_DBGCR_DBG_SPI_Msk     (0x1UL << SYSCFG_DBGCR_DBG_SPI_Pos)          /*!<SYSCFG DBGCR: DBG_SPI Mask */

#define SYSCFG_DBGCR_DBG_TWI_Pos     15                                           /*!<SYSCFG DBGCR: DBG_TWI Position */
#define SYSCFG_DBGCR_DBG_TWI_Msk     (0x1UL << SYSCFG_DBGCR_DBG_TWI_Pos)          /*!<SYSCFG DBGCR: DBG_TWI Mask */

#define SYSCFG_DBGCR_LOCK_Pos        16                                           /*!<SYSCFG DBGCR: LOCK Position */
#define SYSCFG_DBGCR_LOCK_Msk        (0xFFFFUL << SYSCFG_DBGCR_LOCK_Pos)          /*!<SYSCFG DBGCR: LOCK Mask */

#define SYSCFG_DBGCR_Msk_ALL         (SYSCFG_DBGCR_DBG_SLEEP_Msk   |\
                                      SYSCFG_DBGCR_DBG_STOP_Msk    |\
                                      SYSCFG_DBGCR_DBG_CAN_Msk     |\
                                      SYSCFG_DBGCR_DBG_QEI_Msk     |\
                                      SYSCFG_DBGCR_DBG_IWDT_Msk    |\
                                      SYSCFG_DBGCR_DBG_WWDT_Msk    |\
                                      SYSCFG_DBGCR_DBG_PCA_Msk     |\
                                      SYSCFG_DBGCR_DBG_TIM_Msk     |\
                                      SYSCFG_DBGCR_DBG_MCM_Msk     |\
                                      SYSCFG_DBGCR_DBG_UART_Msk    |\
                                      SYSCFG_DBGCR_DBG_SPI_Msk     |\
                                      SYSCFG_DBGCR_DBG_TWI_Msk     |\
                                      SYSCFG_DBGCR_LOCK_Msk        )

#define RCC_CR_SW_Pos                0                                            /*!<RCC CR: SW Position */
#define RCC_CR_SW_Msk                (0x3UL /*<< RCC_CR_SW_Pos*/)                 /*!<RCC CR: SW Mask */

#define RCC_CR_SWS_Pos               2                                            /*!<RCC CR: SWS Position */
#define RCC_CR_SWS_Msk               (0x3UL << RCC_CR_SWS_Pos)                    /*!<RCC CR: SWS Mask */

#define RCC_CR_HSEON_Pos             4                                            /*!<RCC CR: HSEON Position */
#define RCC_CR_HSEON_Msk             (0x1UL << RCC_CR_HSEON_Pos)                  /*!<RCC CR: HSEON Mask */

#define RCC_CR_HSERDY_Pos            5                                            /*!<RCC CR: HSERDY Position */
#define RCC_CR_HSERDY_Msk            (0x1UL << RCC_CR_HSERDY_Pos)                 /*!<RCC CR: HSERDY Mask */

#define RCC_CR_PLLON_Pos             6                                            /*!<RCC CR: PLLON Position */
#define RCC_CR_PLLON_Msk             (0x1UL << RCC_CR_PLLON_Pos)                  /*!<RCC CR: PLLON Mask */

#define RCC_CR_PLLRDY_Pos            7                                            /*!<RCC CR: PLLRDY Position */
#define RCC_CR_PLLRDY_Msk            (0x1UL << RCC_CR_PLLRDY_Pos)                 /*!<RCC CR: PLLRDY Mask */

#define RCC_CR_CSMON_Pos             8                                            /*!<RCC CR: CSMON Position */
#define RCC_CR_CSMON_Msk             (0x1UL << RCC_CR_CSMON_Pos)                  /*!<RCC CR: CSMON Mask */

#define RCC_CR_Msk_ALL               (RCC_CR_SW_Msk                |\
                                      RCC_CR_SWS_Msk               |\
                                      RCC_CR_HSEON_Msk             |\
                                      RCC_CR_HSERDY_Msk            |\
                                      RCC_CR_PLLON_Msk             |\
                                      RCC_CR_PLLRDY_Msk            |\
                                      RCC_CR_CSMON_Msk             )

#define RCC_CFGR_HPRE_Pos            0                                            /*!<RCC CFGR: HPRE Position */
#define RCC_CFGR_HPRE_Msk            (0x7UL /*<< RCC_CFGR_HPRE_Pos*/)             /*!<RCC CFGR: HPRE Mask */

#define RCC_CFGR_PPRE_Pos            3                                            /*!<RCC CFGR: PPRE Position */
#define RCC_CFGR_PPRE_Msk            (0x7UL << RCC_CFGR_PPRE_Pos)                 /*!<RCC CFGR: PPRE Mask */

#define RCC_CFGR_PLLK_Pos            9                                            /*!<RCC CFGR: PLLK Position */
#define RCC_CFGR_PLLK_Msk            (0x7UL << RCC_CFGR_PLLK_Pos)                 /*!<RCC CFGR: PLLK Mask */

#define RCC_CFGR_PLLF_Pos            12                                           /*!<RCC CFGR: PLLF Position */
#define RCC_CFGR_PLLF_Msk            (0x3FUL << RCC_CFGR_PLLF_Pos)                /*!<RCC CFGR: PLLF Mask */

#define RCC_CFGR_PLLSRC_Pos          18                                           /*!<RCC CFGR: PLLSRC Position */
#define RCC_CFGR_PLLSRC_Msk          (0x1UL << RCC_CFGR_PLLSRC_Pos)               /*!<RCC CFGR: PLLSRC Mask */

#define RCC_CFGR_PLLXTPRE_Pos        19                                           /*!<RCC CFGR: PLLXTPRE Position */
#define RCC_CFGR_PLLXTPRE_Msk        (0x1UL << RCC_CFGR_PLLXTPRE_Pos)             /*!<RCC CFGR: PLLXTPRE Mask */

#define RCC_CFGR_HSE16M_Pos          20                                           /*!<RCC CFGR: HSE16M Position */
#define RCC_CFGR_HSE16M_Msk          (0x1UL << RCC_CFGR_HSE16M_Pos)               /*!<RCC CFGR: HSE16M Mask */

#define RCC_CFGR_Msk_ALL             (RCC_CFGR_HPRE_Msk            |\
                                      RCC_CFGR_PPRE_Msk            |\
                                      RCC_CFGR_PLLK_Msk            |\
                                      RCC_CFGR_PLLF_Msk            |\
                                      RCC_CFGR_PLLSRC_Msk          |\
                                      RCC_CFGR_PLLXTPRE_Msk        |\
                                      RCC_CFGR_HSE16M_Msk          )

#define RCC_CIENR_HSERDYIE_Pos       3                                            /*!<RCC CIENR: HSERDYIE Position */
#define RCC_CIENR_HSERDYIE_Msk       (0x1UL << RCC_CIENR_HSERDYIE_Pos)            /*!<RCC CIENR: HSERDYIE Mask */

#define RCC_CIENR_PLLRDYIE_Pos       4                                            /*!<RCC CIENR: PLLRDYIE Position */
#define RCC_CIENR_PLLRDYIE_Msk       (0x1UL << RCC_CIENR_PLLRDYIE_Pos)            /*!<RCC CIENR: PLLRDYIE Mask */

#define RCC_CIENR_Msk_ALL            (RCC_CIENR_HSERDYIE_Msk       |\
                                      RCC_CIENR_PLLRDYIE_Msk       )

#define RCC_CISTR_HSERDYIF_Pos       3                                            /*!<RCC CISTR: HSERDYIF Position */
#define RCC_CISTR_HSERDYIF_Msk       (0x1UL << RCC_CISTR_HSERDYIF_Pos)            /*!<RCC CISTR: HSERDYIF Mask */

#define RCC_CISTR_PLLRDYIF_Pos       4                                            /*!<RCC CISTR: PLLRDYIF Position */
#define RCC_CISTR_PLLRDYIF_Msk       (0x1UL << RCC_CISTR_PLLRDYIF_Pos)            /*!<RCC CISTR: PLLRDYIF Mask */

#define RCC_CISTR_CSMHSEF_Pos        6                                            /*!<RCC CISTR: CSMHSEF Position */
#define RCC_CISTR_CSMHSEF_Msk        (0x1UL << RCC_CISTR_CSMHSEF_Pos)             /*!<RCC CISTR: CSMHSEF Mask */

#define RCC_CISTR_CSMPLLF_Pos        7                                            /*!<RCC CISTR: CSMPLLF Position */
#define RCC_CISTR_CSMPLLF_Msk        (0x1UL << RCC_CISTR_CSMPLLF_Pos)             /*!<RCC CISTR: CSMPLLF Mask */

#define RCC_CISTR_Msk_ALL            (RCC_CISTR_HSERDYIF_Msk       |\
                                      RCC_CISTR_PLLRDYIF_Msk       |\
                                      RCC_CISTR_CSMHSEF_Msk        |\
                                      RCC_CISTR_CSMPLLF_Msk        )

#define RCC_CICLR_HSERDYC_Pos        3                                            /*!<RCC CICLR: HSERDYC Position */
#define RCC_CICLR_HSERDYC_Msk        (0x1UL << RCC_CICLR_HSERDYC_Pos)             /*!<RCC CICLR: HSERDYC Mask */

#define RCC_CICLR_PLLRDYC_Pos        4                                            /*!<RCC CICLR: PLLRDYC Position */
#define RCC_CICLR_PLLRDYC_Msk        (0x1UL << RCC_CICLR_PLLRDYC_Pos)             /*!<RCC CICLR: PLLRDYC Mask */

#define RCC_CICLR_CSMC_Pos           7                                            /*!<RCC CICLR: CSMC Position */
#define RCC_CICLR_CSMC_Msk           (0x1UL << RCC_CICLR_CSMC_Pos)                /*!<RCC CICLR: CSMC Mask */

#define RCC_CICLR_Msk_ALL            (RCC_CICLR_HSERDYC_Msk        |\
                                      RCC_CICLR_PLLRDYC_Msk        |\
                                      RCC_CICLR_CSMC_Msk           )

#define RCC_AHBRSTR_GPIORST_Pos      0                                            /*!<RCC AHBRSTR: GPIORST Position */
#define RCC_AHBRSTR_GPIORST_Msk      (0x1UL /*<< RCC_AHBRSTR_GPIORST_Pos*/)       /*!<RCC AHBRSTR: GPIORST Mask */

#define RCC_AHBRSTR_MCMRST_Pos       1                                            /*!<RCC AHBRSTR: MCMRST Position */
#define RCC_AHBRSTR_MCMRST_Msk       (0x1UL << RCC_AHBRSTR_MCMRST_Pos)            /*!<RCC AHBRSTR: MCMRST Mask */

#define RCC_AHBRSTR_SYSCFGRST_Pos    2                                            /*!<RCC AHBRSTR: SYSCFGRST Position */
#define RCC_AHBRSTR_SYSCFGRST_Msk    (0x1UL << RCC_AHBRSTR_SYSCFGRST_Pos)         /*!<RCC AHBRSTR: SYSCFGRST Mask */

#define RCC_AHBRSTR_CRCRST_Pos       3                                            /*!<RCC AHBRSTR: CRCRST Position */
#define RCC_AHBRSTR_CRCRST_Msk       (0x1UL << RCC_AHBRSTR_CRCRST_Pos)            /*!<RCC AHBRSTR: CRCRST Mask */

#define RCC_AHBRSTR_MACPRST_Pos      4                                            /*!<RCC AHBRSTR: MACPRST Position */
#define RCC_AHBRSTR_MACPRST_Msk      (0x1UL << RCC_AHBRSTR_MACPRST_Pos)           /*!<RCC AHBRSTR: MACPRST Mask */

#define RCC_AHBRSTR_Msk_ALL          (RCC_AHBRSTR_GPIORST_Msk      |\
                                      RCC_AHBRSTR_MCMRST_Msk       |\
                                      RCC_AHBRSTR_SYSCFGRST_Msk    |\
                                      RCC_AHBRSTR_CRCRST_Msk       |\
                                      RCC_AHBRSTR_MACPRST_Msk      )

#define RCC_APB0RSTR_TIM7RST_Pos     0                                            /*!<RCC APB0RSTR: TIM7RST Position */
#define RCC_APB0RSTR_TIM7RST_Msk     (0x1UL /*<< RCC_APB0RSTR_TIM7RST_Pos*/)      /*!<RCC APB0RSTR: TIM7RST Mask */

#define RCC_APB0RSTR_TIM8RST_Pos     1                                            /*!<RCC APB0RSTR: TIM8RST Position */
#define RCC_APB0RSTR_TIM8RST_Msk     (0x1UL << RCC_APB0RSTR_TIM8RST_Pos)          /*!<RCC APB0RSTR: TIM8RST Mask */

#define RCC_APB0RSTR_QEIRST_Pos      2                                            /*!<RCC APB0RSTR: QEIRST Position */
#define RCC_APB0RSTR_QEIRST_Msk      (0x1UL << RCC_APB0RSTR_QEIRST_Pos)           /*!<RCC APB0RSTR: QEIRST Mask */

#define RCC_APB0RSTR_UART0RST_Pos    3                                            /*!<RCC APB0RSTR: UART0RST Position */
#define RCC_APB0RSTR_UART0RST_Msk    (0x1UL << RCC_APB0RSTR_UART0RST_Pos)         /*!<RCC APB0RSTR: UART0RST Mask */

#define RCC_APB0RSTR_UART1RST_Pos    4                                            /*!<RCC APB0RSTR: UART1RST Position */
#define RCC_APB0RSTR_UART1RST_Msk    (0x1UL << RCC_APB0RSTR_UART1RST_Pos)         /*!<RCC APB0RSTR: UART1RST Mask */

#define RCC_APB0RSTR_UART2RST_Pos    5                                            /*!<RCC APB0RSTR: UART2RST Position */
#define RCC_APB0RSTR_UART2RST_Msk    (0x1UL << RCC_APB0RSTR_UART2RST_Pos)         /*!<RCC APB0RSTR: UART2RST Mask */

#define RCC_APB0RSTR_SPI0RST_Pos     6                                            /*!<RCC APB0RSTR: SPI0RST Position */
#define RCC_APB0RSTR_SPI0RST_Msk     (0x1UL << RCC_APB0RSTR_SPI0RST_Pos)          /*!<RCC APB0RSTR: SPI0RST Mask */

#define RCC_APB0RSTR_TWI0RST_Pos     7                                            /*!<RCC APB0RSTR: TWI0RST Position */
#define RCC_APB0RSTR_TWI0RST_Msk     (0x1UL << RCC_APB0RSTR_TWI0RST_Pos)          /*!<RCC APB0RSTR: TWI0RST Mask */

#define RCC_APB0RSTR_WWDTRST_Pos     8                                            /*!<RCC APB0RSTR: WWDTRST Position */
#define RCC_APB0RSTR_WWDTRST_Msk     (0x1UL << RCC_APB0RSTR_WWDTRST_Pos)          /*!<RCC APB0RSTR: WWDTRST Mask */

#define RCC_APB0RSTR_AMOCRST_Pos     9                                            /*!<RCC APB0RSTR: AMOCRST Position */
#define RCC_APB0RSTR_AMOCRST_Msk     (0x1UL << RCC_APB0RSTR_AMOCRST_Pos)          /*!<RCC APB0RSTR: AMOCRST Mask */

#define RCC_APB0RSTR_PCA0RST_Pos     10                                           /*!<RCC APB0RSTR: PCA0RST Position */
#define RCC_APB0RSTR_PCA0RST_Msk     (0x1UL << RCC_APB0RSTR_PCA0RST_Pos)          /*!<RCC APB0RSTR: PCA0RST Mask */

#define RCC_APB0RSTR_PCA1RST_Pos     11                                           /*!<RCC APB0RSTR: PCA1RST Position */
#define RCC_APB0RSTR_PCA1RST_Msk     (0x1UL << RCC_APB0RSTR_PCA1RST_Pos)          /*!<RCC APB0RSTR: PCA1RST Mask */

#define RCC_APB0RSTR_ADCRST_Pos      12                                           /*!<RCC APB0RSTR: ADCRST Position */
#define RCC_APB0RSTR_ADCRST_Msk      (0x1UL << RCC_APB0RSTR_ADCRST_Pos)           /*!<RCC APB0RSTR: ADCRST Mask */

#define RCC_APB0RSTR_CAN0RST_Pos     13                                           /*!<RCC APB0RSTR: CAN0RST Position */
#define RCC_APB0RSTR_CAN0RST_Msk     (0x1UL << RCC_APB0RSTR_CAN0RST_Pos)          /*!<RCC APB0RSTR: CAN0RST Mask */

#define RCC_APB0RSTR_FIFO0RST_Pos    15                                           /*!<RCC APB0RSTR: FIFO0RST Position */
#define RCC_APB0RSTR_FIFO0RST_Msk    (0x1UL << RCC_APB0RSTR_FIFO0RST_Pos)         /*!<RCC APB0RSTR: FIFO0RST Mask */

#define RCC_APB0RSTR_FIFO1RST_Pos    16                                           /*!<RCC APB0RSTR: FIFO1RST Position */
#define RCC_APB0RSTR_FIFO1RST_Msk    (0x1UL << RCC_APB0RSTR_FIFO1RST_Pos)         /*!<RCC APB0RSTR: FIFO1RST Mask */

#define RCC_APB0RSTR_FIFO2RST_Pos    17                                           /*!<RCC APB0RSTR: FIFO2RST Position */
#define RCC_APB0RSTR_FIFO2RST_Msk    (0x1UL << RCC_APB0RSTR_FIFO2RST_Pos)         /*!<RCC APB0RSTR: FIFO2RST Mask */

#define RCC_APB0RSTR_Msk_ALL         (RCC_APB0RSTR_TIM7RST_Msk     |\
                                      RCC_APB0RSTR_TIM8RST_Msk     |\
                                      RCC_APB0RSTR_QEIRST_Msk      |\
                                      RCC_APB0RSTR_UART0RST_Msk    |\
                                      RCC_APB0RSTR_UART1RST_Msk    |\
                                      RCC_APB0RSTR_UART2RST_Msk    |\
                                      RCC_APB0RSTR_SPI0RST_Msk     |\
                                      RCC_APB0RSTR_TWI0RST_Msk     |\
                                      RCC_APB0RSTR_WWDTRST_Msk     |\
                                      RCC_APB0RSTR_AMOCRST_Msk     |\
                                      RCC_APB0RSTR_PCA0RST_Msk     |\
                                      RCC_APB0RSTR_PCA1RST_Msk     |\
                                      RCC_APB0RSTR_ADCRST_Msk      |\
                                      RCC_APB0RSTR_CAN0RST_Msk     |\
                                      RCC_APB0RSTR_FIFO0RST_Msk    |\
                                      RCC_APB0RSTR_FIFO1RST_Msk    |\
                                      RCC_APB0RSTR_FIFO2RST_Msk    )

#define RCC_AHBENR_GPIOEN_Pos        0                                            /*!<RCC AHBENR: GPIOEN Position */
#define RCC_AHBENR_GPIOEN_Msk        (0x1UL /*<< RCC_AHBENR_GPIOEN_Pos*/)         /*!<RCC AHBENR: GPIOEN Mask */

#define RCC_AHBENR_MCMEN_Pos         1                                            /*!<RCC AHBENR: MCMEN Position */
#define RCC_AHBENR_MCMEN_Msk         (0x1UL << RCC_AHBENR_MCMEN_Pos)              /*!<RCC AHBENR: MCMEN Mask */

#define RCC_AHBENR_SYSCFGEN_Pos      2                                            /*!<RCC AHBENR: SYSCFGEN Position */
#define RCC_AHBENR_SYSCFGEN_Msk      (0x1UL << RCC_AHBENR_SYSCFGEN_Pos)           /*!<RCC AHBENR: SYSCFGEN Mask */

#define RCC_AHBENR_CRCEN_Pos         3                                            /*!<RCC AHBENR: CRCEN Position */
#define RCC_AHBENR_CRCEN_Msk         (0x1UL << RCC_AHBENR_CRCEN_Pos)              /*!<RCC AHBENR: CRCEN Mask */

#define RCC_AHBENR_MACPEN_Pos        4                                            /*!<RCC AHBENR: MACPEN Position */
#define RCC_AHBENR_MACPEN_Msk        (0x1UL << RCC_AHBENR_MACPEN_Pos)             /*!<RCC AHBENR: MACPEN Mask */

#define RCC_AHBENR_Msk_ALL           (RCC_AHBENR_GPIOEN_Msk        |\
                                      RCC_AHBENR_MCMEN_Msk         |\
                                      RCC_AHBENR_SYSCFGEN_Msk      |\
                                      RCC_AHBENR_CRCEN_Msk         |\
                                      RCC_AHBENR_MACPEN_Msk        )

#define RCC_APB0ENR_TIM7EN_Pos       0                                            /*!<RCC APB0ENR: TIM7EN Position */
#define RCC_APB0ENR_TIM7EN_Msk       (0x1UL /*<< RCC_APB0ENR_TIM7EN_Pos*/)        /*!<RCC APB0ENR: TIM7EN Mask */

#define RCC_APB0ENR_TIM8EN_Pos       1                                            /*!<RCC APB0ENR: TIM8EN Position */
#define RCC_APB0ENR_TIM8EN_Msk       (0x1UL << RCC_APB0ENR_TIM8EN_Pos)            /*!<RCC APB0ENR: TIM8EN Mask */

#define RCC_APB0ENR_QEIEN_Pos        2                                            /*!<RCC APB0ENR: QEIEN Position */
#define RCC_APB0ENR_QEIEN_Msk        (0x1UL << RCC_APB0ENR_QEIEN_Pos)             /*!<RCC APB0ENR: QEIEN Mask */

#define RCC_APB0ENR_UART0EN_Pos      3                                            /*!<RCC APB0ENR: UART0EN Position */
#define RCC_APB0ENR_UART0EN_Msk      (0x1UL << RCC_APB0ENR_UART0EN_Pos)           /*!<RCC APB0ENR: UART0EN Mask */

#define RCC_APB0ENR_UART1EN_Pos      4                                            /*!<RCC APB0ENR: UART1EN Position */
#define RCC_APB0ENR_UART1EN_Msk      (0x1UL << RCC_APB0ENR_UART1EN_Pos)           /*!<RCC APB0ENR: UART1EN Mask */

#define RCC_APB0ENR_UART2EN_Pos      5                                            /*!<RCC APB0ENR: UART2EN Position */
#define RCC_APB0ENR_UART2EN_Msk      (0x1UL << RCC_APB0ENR_UART2EN_Pos)           /*!<RCC APB0ENR: UART2EN Mask */

#define RCC_APB0ENR_SPI0EN_Pos       6                                            /*!<RCC APB0ENR: SPI0EN Position */
#define RCC_APB0ENR_SPI0EN_Msk       (0x1UL << RCC_APB0ENR_SPI0EN_Pos)            /*!<RCC APB0ENR: SPI0EN Mask */

#define RCC_APB0ENR_TWI0EN_Pos       7                                            /*!<RCC APB0ENR: TWI0EN Position */
#define RCC_APB0ENR_TWI0EN_Msk       (0x1UL << RCC_APB0ENR_TWI0EN_Pos)            /*!<RCC APB0ENR: TWI0EN Mask */

#define RCC_APB0ENR_WWDTEN_Pos       8                                            /*!<RCC APB0ENR: WWDTEN Position */
#define RCC_APB0ENR_WWDTEN_Msk       (0x1UL << RCC_APB0ENR_WWDTEN_Pos)            /*!<RCC APB0ENR: WWDTEN Mask */

#define RCC_APB0ENR_AMOCEN_Pos       9                                            /*!<RCC APB0ENR: AMOCEN Position */
#define RCC_APB0ENR_AMOCEN_Msk       (0x1UL << RCC_APB0ENR_AMOCEN_Pos)            /*!<RCC APB0ENR: AMOCEN Mask */

#define RCC_APB0ENR_PCA0EN_Pos       10                                           /*!<RCC APB0ENR: PCA0EN Position */
#define RCC_APB0ENR_PCA0EN_Msk       (0x1UL << RCC_APB0ENR_PCA0EN_Pos)            /*!<RCC APB0ENR: PCA0EN Mask */

#define RCC_APB0ENR_PCA1EN_Pos       11                                           /*!<RCC APB0ENR: PCA1EN Position */
#define RCC_APB0ENR_PCA1EN_Msk       (0x1UL << RCC_APB0ENR_PCA1EN_Pos)            /*!<RCC APB0ENR: PCA1EN Mask */

#define RCC_APB0ENR_ADCEN_Pos        12                                           /*!<RCC APB0ENR: ADCEN Position */
#define RCC_APB0ENR_ADCEN_Msk        (0x1UL << RCC_APB0ENR_ADCEN_Pos)             /*!<RCC APB0ENR: ADCEN Mask */

#define RCC_APB0ENR_CAN0EN_Pos       13                                           /*!<RCC APB0ENR: CAN0EN Position */
#define RCC_APB0ENR_CAN0EN_Msk       (0x1UL << RCC_APB0ENR_CAN0EN_Pos)            /*!<RCC APB0ENR: CAN0EN Mask */

#define RCC_APB0ENR_FIFO0EN_Pos      15                                           /*!<RCC APB0ENR: FIFO0EN Position */
#define RCC_APB0ENR_FIFO0EN_Msk      (0x1UL << RCC_APB0ENR_FIFO0EN_Pos)           /*!<RCC APB0ENR: FIFO0EN Mask */

#define RCC_APB0ENR_FIFO1EN_Pos      16                                           /*!<RCC APB0ENR: FIFO1EN Position */
#define RCC_APB0ENR_FIFO1EN_Msk      (0x1UL << RCC_APB0ENR_FIFO1EN_Pos)           /*!<RCC APB0ENR: FIFO1EN Mask */

#define RCC_APB0ENR_FIFO2EN_Pos      17                                           /*!<RCC APB0ENR: FIFO2EN Position */
#define RCC_APB0ENR_FIFO2EN_Msk      (0x1UL << RCC_APB0ENR_FIFO2EN_Pos)           /*!<RCC APB0ENR: FIFO2EN Mask */

#define RCC_APB0ENR_Msk_ALL          (RCC_APB0ENR_TIM7EN_Msk       |\
                                      RCC_APB0ENR_TIM8EN_Msk       |\
                                      RCC_APB0ENR_QEIEN_Msk        |\
                                      RCC_APB0ENR_UART0EN_Msk      |\
                                      RCC_APB0ENR_UART1EN_Msk      |\
                                      RCC_APB0ENR_UART2EN_Msk      |\
                                      RCC_APB0ENR_SPI0EN_Msk       |\
                                      RCC_APB0ENR_TWI0EN_Msk       |\
                                      RCC_APB0ENR_WWDTEN_Msk       |\
                                      RCC_APB0ENR_AMOCEN_Msk       |\
                                      RCC_APB0ENR_PCA0EN_Msk       |\
                                      RCC_APB0ENR_PCA1EN_Msk       |\
                                      RCC_APB0ENR_ADCEN_Msk        |\
                                      RCC_APB0ENR_CAN0EN_Msk       |\
                                      RCC_APB0ENR_FIFO0EN_Msk      |\
                                      RCC_APB0ENR_FIFO1EN_Msk      |\
                                      RCC_APB0ENR_FIFO2EN_Msk      )

#define RCC_RSTSTR_PINRSTF_Pos       0                                            /*!<RCC RSTSTR: PINRSTF Position */
#define RCC_RSTSTR_PINRSTF_Msk       (0x1UL /*<< RCC_RSTSTR_PINRSTF_Pos*/)        /*!<RCC RSTSTR: PINRSTF Mask */

#define RCC_RSTSTR_LVRSTF_Pos        1                                            /*!<RCC RSTSTR: LVRSTF Position */
#define RCC_RSTSTR_LVRSTF_Msk        (0x1UL << RCC_RSTSTR_LVRSTF_Pos)             /*!<RCC RSTSTR: LVRSTF Mask */

#define RCC_RSTSTR_PORSTF_Pos        2                                            /*!<RCC RSTSTR: PORSTF Position */
#define RCC_RSTSTR_PORSTF_Msk        (0x1UL << RCC_RSTSTR_PORSTF_Pos)             /*!<RCC RSTSTR: PORSTF Mask */

#define RCC_RSTSTR_SWRSTF_Pos        3                                            /*!<RCC RSTSTR: SWRSTF Position */
#define RCC_RSTSTR_SWRSTF_Msk        (0x1UL << RCC_RSTSTR_SWRSTF_Pos)             /*!<RCC RSTSTR: SWRSTF Mask */

#define RCC_RSTSTR_IWDTRSTF_Pos      4                                            /*!<RCC RSTSTR: IWDTRSTF Position */
#define RCC_RSTSTR_IWDTRSTF_Msk      (0x1UL << RCC_RSTSTR_IWDTRSTF_Pos)           /*!<RCC RSTSTR: IWDTRSTF Mask */

#define RCC_RSTSTR_WWDTRSTF_Pos      5                                            /*!<RCC RSTSTR: WWDTRSTF Position */
#define RCC_RSTSTR_WWDTRSTF_Msk      (0x1UL << RCC_RSTSTR_WWDTRSTF_Pos)           /*!<RCC RSTSTR: WWDTRSTF Mask */

#define RCC_RSTSTR_LVRSTF2_Pos       6                                            /*!<RCC RSTSTR: LVRSTF2 Position */
#define RCC_RSTSTR_LVRSTF2_Msk       (0x1UL << RCC_RSTSTR_LVRSTF2_Pos)            /*!<RCC RSTSTR: LVRSTF2 Mask */

#define RCC_RSTSTR_Msk_ALL           (RCC_RSTSTR_PINRSTF_Msk       |\
                                      RCC_RSTSTR_LVRSTF_Msk        |\
                                      RCC_RSTSTR_PORSTF_Msk        |\
                                      RCC_RSTSTR_SWRSTF_Msk        |\
                                      RCC_RSTSTR_IWDTRSTF_Msk      |\
                                      RCC_RSTSTR_WWDTRSTF_Msk      |\
                                      RCC_RSTSTR_LVRSTF2_Msk       )

#define RCC_RSTCLR_PINRSTFC_Pos      0                                            /*!<RCC RSTCLR: PINRSTFC Position */
#define RCC_RSTCLR_PINRSTFC_Msk      (0x1UL /*<< RCC_RSTCLR_PINRSTFC_Pos*/)       /*!<RCC RSTCLR: PINRSTFC Mask */

#define RCC_RSTCLR_LVRSTFC_Pos       1                                            /*!<RCC RSTCLR: LVRSTFC Position */
#define RCC_RSTCLR_LVRSTFC_Msk       (0x1UL << RCC_RSTCLR_LVRSTFC_Pos)            /*!<RCC RSTCLR: LVRSTFC Mask */

#define RCC_RSTCLR_PORSTFC_Pos       2                                            /*!<RCC RSTCLR: PORSTFC Position */
#define RCC_RSTCLR_PORSTFC_Msk       (0x1UL << RCC_RSTCLR_PORSTFC_Pos)            /*!<RCC RSTCLR: PORSTFC Mask */

#define RCC_RSTCLR_SWRSTFC_Pos       3                                            /*!<RCC RSTCLR: SWRSTFC Position */
#define RCC_RSTCLR_SWRSTFC_Msk       (0x1UL << RCC_RSTCLR_SWRSTFC_Pos)            /*!<RCC RSTCLR: SWRSTFC Mask */

#define RCC_RSTCLR_IWDTRSTFC_Pos     4                                            /*!<RCC RSTCLR: IWDTRSTFC Position */
#define RCC_RSTCLR_IWDTRSTFC_Msk     (0x1UL << RCC_RSTCLR_IWDTRSTFC_Pos)          /*!<RCC RSTCLR: IWDTRSTFC Mask */

#define RCC_RSTCLR_WWDTRSTFC_Pos     5                                            /*!<RCC RSTCLR: WWDTRSTFC Position */
#define RCC_RSTCLR_WWDTRSTFC_Msk     (0x1UL << RCC_RSTCLR_WWDTRSTFC_Pos)          /*!<RCC RSTCLR: WWDTRSTFC Mask */

#define RCC_RSTCLR_LVRSTF2C_Pos      6                                            /*!<RCC RSTCLR: LVRSTF2C Position */
#define RCC_RSTCLR_LVRSTF2C_Msk      (0x1UL << RCC_RSTCLR_LVRSTF2C_Pos)           /*!<RCC RSTCLR: LVRSTF2C Mask */

#define RCC_RSTCLR_Msk_ALL           (RCC_RSTCLR_PINRSTFC_Msk      |\
                                      RCC_RSTCLR_LVRSTFC_Msk       |\
                                      RCC_RSTCLR_PORSTFC_Msk       |\
                                      RCC_RSTCLR_SWRSTFC_Msk       |\
                                      RCC_RSTCLR_IWDTRSTFC_Msk     |\
                                      RCC_RSTCLR_WWDTRSTFC_Msk     |\
                                      RCC_RSTCLR_LVRSTF2C_Msk      )

#define RCC_HSICAL_HSITRIM_Pos       0                                            /*!<RCC HSICAL: HSITRIM Position */
#define RCC_HSICAL_HSITRIM_Msk       (0x7UL /*<< RCC_HSICAL_HSITRIM_Pos*/)        /*!<RCC HSICAL: HSITRIM Mask */

#define RCC_HSICAL_HSICAL_Pos        8                                            /*!<RCC HSICAL: HSICAL Position */
#define RCC_HSICAL_HSICAL_Msk        (0xFFUL << RCC_HSICAL_HSICAL_Pos)            /*!<RCC HSICAL: HSICAL Mask */

#define RCC_HSICAL_TRIMREF_Pos       16                                           /*!<RCC HSICAL: TRIMREF Position */
#define RCC_HSICAL_TRIMREF_Msk       (0x1FFFUL << RCC_HSICAL_TRIMREF_Pos)         /*!<RCC HSICAL: TRIMREF Mask */

#define RCC_HSICAL_TRIMRUN_Pos       31                                           /*!<RCC HSICAL: TRIMRUN Position */
#define RCC_HSICAL_TRIMRUN_Msk       (0x1UL << RCC_HSICAL_TRIMRUN_Pos)            /*!<RCC HSICAL: TRIMRUN Mask */

#define RCC_HSICAL_Msk_ALL           (RCC_HSICAL_HSITRIM_Msk       |\
                                      RCC_HSICAL_HSICAL_Msk        |\
                                      RCC_HSICAL_TRIMREF_Msk       |\
                                      RCC_HSICAL_TRIMRUN_Msk       )

#define RCC_RCCLOCK_LOCK_Pos         0                                            /*!<RCC RCCLOCK: LOCK Position */
#define RCC_RCCLOCK_LOCK_Msk         (0xFFFFUL /*<< RCC_RCCLOCK_LOCK_Pos*/)       /*!<RCC RCCLOCK: LOCK Mask */

#define RCC_RCCLOCK_Msk_ALL          (RCC_RCCLOCK_LOCK_Msk        )

#define IWDT_CR_IWDTRLR_Pos          0                                            /*!<IWDT CR: IWDTRLR Position */
#define IWDT_CR_IWDTRLR_Msk          (0xFFFUL /*<< IWDT_CR_IWDTRLR_Pos*/)         /*!<IWDT CR: IWDTRLR Mask */

#define IWDT_CR_IWDTPR_Pos           12                                           /*!<IWDT CR: IWDTPR Position */
#define IWDT_CR_IWDTPR_Msk           (0x7UL << IWDT_CR_IWDTPR_Pos)                /*!<IWDT CR: IWDTPR Mask */

#define IWDT_CR_IWDTON_Pos           15                                           /*!<IWDT CR: IWDTON Position */
#define IWDT_CR_IWDTON_Msk           (0x1UL << IWDT_CR_IWDTON_Pos)                /*!<IWDT CR: IWDTON Mask */

#define IWDT_CR_LOCK_Pos             16                                           /*!<IWDT CR: LOCK Position */
#define IWDT_CR_LOCK_Msk             (0xFFFFUL << IWDT_CR_LOCK_Pos)               /*!<IWDT CR: LOCK Mask */

#define IWDT_CR_Msk_ALL              (IWDT_CR_IWDTRLR_Msk          |\
                                      IWDT_CR_IWDTPR_Msk           |\
                                      IWDT_CR_IWDTON_Msk           |\
                                      IWDT_CR_LOCK_Msk             )

#define IWDT_CLR_IWDTCLR_Pos         0                                            /*!<IWDT CLR: IWDTCLR Position */
#define IWDT_CLR_IWDTCLR_Msk         (0xFFFFUL /*<< IWDT_CLR_IWDTCLR_Pos*/)       /*!<IWDT CLR: IWDTCLR Mask */

#define IWDT_CLR_Msk_ALL             (IWDT_CLR_IWDTCLR_Msk        )

#define WWDT_CR_WWDTRLR_Pos          0                                            /*!<WWDT CR: WWDTRLR Position */
#define WWDT_CR_WWDTRLR_Msk          (0xFFUL /*<< WWDT_CR_WWDTRLR_Pos*/)          /*!<WWDT CR: WWDTRLR Mask */

#define WWDT_CR_WWDTPR_Pos           8                                            /*!<WWDT CR: WWDTPR Position */
#define WWDT_CR_WWDTPR_Msk           (0x7UL << WWDT_CR_WWDTPR_Pos)                /*!<WWDT CR: WWDTPR Mask */

#define WWDT_CR_WWDTIE_Pos           14                                           /*!<WWDT CR: WWDTIE Position */
#define WWDT_CR_WWDTIE_Msk           (0x1UL << WWDT_CR_WWDTIE_Pos)                /*!<WWDT CR: WWDTIE Mask */

#define WWDT_CR_WWDTON_Pos           15                                           /*!<WWDT CR: WWDTON Position */
#define WWDT_CR_WWDTON_Msk           (0x1UL << WWDT_CR_WWDTON_Pos)                /*!<WWDT CR: WWDTON Mask */

#define WWDT_CR_LOCK_Pos             16                                           /*!<WWDT CR: LOCK Position */
#define WWDT_CR_LOCK_Msk             (0xFFFFUL << WWDT_CR_LOCK_Pos)               /*!<WWDT CR: LOCK Mask */

#define WWDT_CR_Msk_ALL              (WWDT_CR_WWDTRLR_Msk          |\
                                      WWDT_CR_WWDTPR_Msk           |\
                                      WWDT_CR_WWDTIE_Msk           |\
                                      WWDT_CR_WWDTON_Msk           |\
                                      WWDT_CR_LOCK_Msk             )

#define WWDT_SR_TCNT_Pos             0                                            /*!<WWDT SR: TCNT Position */
#define WWDT_SR_TCNT_Msk             (0xFFUL /*<< WWDT_SR_TCNT_Pos*/)             /*!<WWDT SR: TCNT Mask */

#define WWDT_SR_WWDTIF_Pos           15                                           /*!<WWDT SR: WWDTIF Position */
#define WWDT_SR_WWDTIF_Msk           (0x1UL << WWDT_SR_WWDTIF_Pos)                /*!<WWDT SR: WWDTIF Mask */

#define WWDT_SR_Msk_ALL              (WWDT_SR_TCNT_Msk             |\
                                      WWDT_SR_WWDTIF_Msk           )

#define WWDT_CLR_WWDTCLR_Pos         0                                            /*!<WWDT CLR: WWDTCLR Position */
#define WWDT_CLR_WWDTCLR_Msk         (0xFFFFUL /*<< WWDT_CLR_WWDTCLR_Pos*/)       /*!<WWDT CLR: WWDTCLR Mask */

#define WWDT_CLR_Msk_ALL             (WWDT_CLR_WWDTCLR_Msk        )

#define WWDT_WTR_WWDTWTR_Pos         0                                            /*!<WWDT WTR: WWDTWTR Position */
#define WWDT_WTR_WWDTWTR_Msk         (0xFFUL /*<< WWDT_WTR_WWDTWTR_Pos*/)         /*!<WWDT WTR: WWDTWTR Mask */

#define WWDT_WTR_LOCK_Pos            16                                           /*!<WWDT WTR: LOCK Position */
#define WWDT_WTR_LOCK_Msk            (0xFFFFUL << WWDT_WTR_LOCK_Pos)              /*!<WWDT WTR: LOCK Mask */

#define WWDT_WTR_Msk_ALL             (WWDT_WTR_WWDTWTR_Msk         |\
                                      WWDT_WTR_LOCK_Msk            )

#define CRC_CR_RELOAD_Pos            0                                            /*!<CRC CR: RELOAD Position */
#define CRC_CR_RELOAD_Msk            (0x1UL /*<< CRC_CR_RELOAD_Pos*/)             /*!<CRC CR: RELOAD Mask */

#define CRC_CR_MODE_Pos              8                                            /*!<CRC CR: MODE Position */
#define CRC_CR_MODE_Msk              (0x3UL << CRC_CR_MODE_Pos)                   /*!<CRC CR: MODE Mask */

#define CRC_CR_COMPLW_Pos            10                                           /*!<CRC CR: COMPLW Position */
#define CRC_CR_COMPLW_Msk            (0x1UL << CRC_CR_COMPLW_Pos)                 /*!<CRC CR: COMPLW Mask */

#define CRC_CR_RBITW_Pos             11                                           /*!<CRC CR: RBITW Position */
#define CRC_CR_RBITW_Msk             (0x1UL << CRC_CR_RBITW_Pos)                  /*!<CRC CR: RBITW Mask */

#define CRC_CR_RBYTEW_Pos            12                                           /*!<CRC CR: RBYTEW Position */
#define CRC_CR_RBYTEW_Msk            (0x1UL << CRC_CR_RBYTEW_Pos)                 /*!<CRC CR: RBYTEW Mask */

#define CRC_CR_COMPLR_Pos            13                                           /*!<CRC CR: COMPLR Position */
#define CRC_CR_COMPLR_Msk            (0x1UL << CRC_CR_COMPLR_Pos)                 /*!<CRC CR: COMPLR Mask */

#define CRC_CR_RBITR_Pos             14                                           /*!<CRC CR: RBITR Position */
#define CRC_CR_RBITR_Msk             (0x1UL << CRC_CR_RBITR_Pos)                  /*!<CRC CR: RBITR Mask */

#define CRC_CR_RBYTER_Pos            15                                           /*!<CRC CR: RBYTER Position */
#define CRC_CR_RBYTER_Msk            (0x1UL << CRC_CR_RBYTER_Pos)                 /*!<CRC CR: RBYTER Mask */

#define CRC_CR_Msk_ALL               (CRC_CR_RELOAD_Msk            |\
                                      CRC_CR_MODE_Msk              |\
                                      CRC_CR_COMPLW_Msk            |\
                                      CRC_CR_RBITW_Msk             |\
                                      CRC_CR_RBYTEW_Msk            |\
                                      CRC_CR_COMPLR_Msk            |\
                                      CRC_CR_RBITR_Msk             |\
                                      CRC_CR_RBYTER_Msk            )

#define RAMBIST_CFG_BLKSZ_Pos        0                                            /*!<RAMBIST CFG: BLKSZ Position */
#define RAMBIST_CFG_BLKSZ_Msk        (0x7UL /*<< RAMBIST_CFG_BLKSZ_Pos*/)         /*!<RAMBIST CFG: BLKSZ Mask */

#define RAMBIST_CFG_SEL_Pos          15                                           /*!<RAMBIST CFG: SEL Position */
#define RAMBIST_CFG_SEL_Msk          (0x1UL << RAMBIST_CFG_SEL_Pos)               /*!<RAMBIST CFG: SEL Mask */

#define RAMBIST_CFG_Msk_ALL          (RAMBIST_CFG_BLKSZ_Msk        |\
                                      RAMBIST_CFG_SEL_Msk          )

#define RAMBIST_CSR_RUN_Pos          0                                            /*!<RAMBIST CSR: RUN Position */
#define RAMBIST_CSR_RUN_Msk          (0xFFFFUL /*<< RAMBIST_CSR_RUN_Pos*/)        /*!<RAMBIST CSR: RUN Mask */

#define RAMBIST_CSR_MOD_Pos          16                                           /*!<RAMBIST CSR: MOD Position */
#define RAMBIST_CSR_MOD_Msk          (0x1UL << RAMBIST_CSR_MOD_Pos)               /*!<RAMBIST CSR: MOD Mask */

#define RAMBIST_CSR_BSY_Pos          17                                           /*!<RAMBIST CSR: BSY Position */
#define RAMBIST_CSR_BSY_Msk          (0x1UL << RAMBIST_CSR_BSY_Pos)               /*!<RAMBIST CSR: BSY Mask */

#define RAMBIST_CSR_ERR_Pos          18                                           /*!<RAMBIST CSR: ERR Position */
#define RAMBIST_CSR_ERR_Msk          (0x1UL << RAMBIST_CSR_ERR_Pos)               /*!<RAMBIST CSR: ERR Mask */

#define RAMBIST_CSR_Msk_ALL          (RAMBIST_CSR_RUN_Msk          |\
                                      RAMBIST_CSR_MOD_Msk          |\
                                      RAMBIST_CSR_BSY_Msk          |\
                                      RAMBIST_CSR_ERR_Msk          )

#define GPIOA_MODER_MODER0_Pos       0                                            /*!<GPIOA MODER: MODER0 Position */
#define GPIOA_MODER_MODER0_Msk       (0x1UL /*<< GPIOA_MODER_MODER0_Pos*/)        /*!<GPIOA MODER: MODER0 Mask */

#define GPIOA_MODER_MODER1_Pos       1                                            /*!<GPIOA MODER: MODER1 Position */
#define GPIOA_MODER_MODER1_Msk       (0x1UL << GPIOA_MODER_MODER1_Pos)            /*!<GPIOA MODER: MODER1 Mask */

#define GPIOA_MODER_MODER2_Pos       2                                            /*!<GPIOA MODER: MODER2 Position */
#define GPIOA_MODER_MODER2_Msk       (0x1UL << GPIOA_MODER_MODER2_Pos)            /*!<GPIOA MODER: MODER2 Mask */

#define GPIOA_MODER_MODER3_Pos       3                                            /*!<GPIOA MODER: MODER3 Position */
#define GPIOA_MODER_MODER3_Msk       (0x1UL << GPIOA_MODER_MODER3_Pos)            /*!<GPIOA MODER: MODER3 Mask */

#define GPIOA_MODER_MODER4_Pos       4                                            /*!<GPIOA MODER: MODER4 Position */
#define GPIOA_MODER_MODER4_Msk       (0x1UL << GPIOA_MODER_MODER4_Pos)            /*!<GPIOA MODER: MODER4 Mask */

#define GPIOA_MODER_MODER5_Pos       5                                            /*!<GPIOA MODER: MODER5 Position */
#define GPIOA_MODER_MODER5_Msk       (0x1UL << GPIOA_MODER_MODER5_Pos)            /*!<GPIOA MODER: MODER5 Mask */

#define GPIOA_MODER_MODER6_Pos       6                                            /*!<GPIOA MODER: MODER6 Position */
#define GPIOA_MODER_MODER6_Msk       (0x1UL << GPIOA_MODER_MODER6_Pos)            /*!<GPIOA MODER: MODER6 Mask */

#define GPIOA_MODER_MODER7_Pos       7                                            /*!<GPIOA MODER: MODER7 Position */
#define GPIOA_MODER_MODER7_Msk       (0x1UL << GPIOA_MODER_MODER7_Pos)            /*!<GPIOA MODER: MODER7 Mask */

#define GPIOA_MODER_MODER8_Pos       8                                            /*!<GPIOA MODER: MODER8 Position */
#define GPIOA_MODER_MODER8_Msk       (0x1UL << GPIOA_MODER_MODER8_Pos)            /*!<GPIOA MODER: MODER8 Mask */

#define GPIOA_MODER_MODER9_Pos       9                                            /*!<GPIOA MODER: MODER9 Position */
#define GPIOA_MODER_MODER9_Msk       (0x1UL << GPIOA_MODER_MODER9_Pos)            /*!<GPIOA MODER: MODER9 Mask */

#define GPIOA_MODER_MODER10_Pos      10                                           /*!<GPIOA MODER: MODER10 Position */
#define GPIOA_MODER_MODER10_Msk      (0x1UL << GPIOA_MODER_MODER10_Pos)           /*!<GPIOA MODER: MODER10 Mask */

#define GPIOA_MODER_MODER11_Pos      11                                           /*!<GPIOA MODER: MODER11 Position */
#define GPIOA_MODER_MODER11_Msk      (0x1UL << GPIOA_MODER_MODER11_Pos)           /*!<GPIOA MODER: MODER11 Mask */

#define GPIOA_MODER_MODER12_Pos      12                                           /*!<GPIOA MODER: MODER12 Position */
#define GPIOA_MODER_MODER12_Msk      (0x1UL << GPIOA_MODER_MODER12_Pos)           /*!<GPIOA MODER: MODER12 Mask */

#define GPIOA_MODER_MODER13_Pos      13                                           /*!<GPIOA MODER: MODER13 Position */
#define GPIOA_MODER_MODER13_Msk      (0x1UL << GPIOA_MODER_MODER13_Pos)           /*!<GPIOA MODER: MODER13 Mask */

#define GPIOA_MODER_MODER14_Pos      14                                           /*!<GPIOA MODER: MODER14 Position */
#define GPIOA_MODER_MODER14_Msk      (0x1UL << GPIOA_MODER_MODER14_Pos)           /*!<GPIOA MODER: MODER14 Mask */

#define GPIOA_MODER_MODER15_Pos      15                                           /*!<GPIOA MODER: MODER15 Position */
#define GPIOA_MODER_MODER15_Msk      (0x1UL << GPIOA_MODER_MODER15_Pos)           /*!<GPIOA MODER: MODER15 Mask */

#define GPIOA_MODER_Msk_ALL          (GPIOA_MODER_MODER0_Msk       |\
                                      GPIOA_MODER_MODER1_Msk       |\
                                      GPIOA_MODER_MODER2_Msk       |\
                                      GPIOA_MODER_MODER3_Msk       |\
                                      GPIOA_MODER_MODER4_Msk       |\
                                      GPIOA_MODER_MODER5_Msk       |\
                                      GPIOA_MODER_MODER6_Msk       |\
                                      GPIOA_MODER_MODER7_Msk       |\
                                      GPIOA_MODER_MODER8_Msk       |\
                                      GPIOA_MODER_MODER9_Msk       |\
                                      GPIOA_MODER_MODER10_Msk      |\
                                      GPIOA_MODER_MODER11_Msk      |\
                                      GPIOA_MODER_MODER12_Msk      |\
                                      GPIOA_MODER_MODER13_Msk      |\
                                      GPIOA_MODER_MODER14_Msk      |\
                                      GPIOA_MODER_MODER15_Msk      )

#define GPIOA_IDR_IDR_Pos            0                                            /*!<GPIOA IDR: IDR Position */
#define GPIOA_IDR_IDR_Msk            (0xFFFFUL /*<< GPIOA_IDR_IDR_Pos*/)          /*!<GPIOA IDR: IDR Mask */

#define GPIOA_IDR_Msk_ALL            (GPIOA_IDR_IDR_Msk           )

#define GPIOA_ODR_ODR_Pos            0                                            /*!<GPIOA ODR: ODR Position */
#define GPIOA_ODR_ODR_Msk            (0xFFFFUL /*<< GPIOA_ODR_ODR_Pos*/)          /*!<GPIOA ODR: ODR Mask */

#define GPIOA_ODR_Msk_ALL            (GPIOA_ODR_ODR_Msk           )

#define GPIOA_BSRR_BS_Pos            0                                            /*!<GPIOA BSRR: BS Position */
#define GPIOA_BSRR_BS_Msk            (0xFFFFUL /*<< GPIOA_BSRR_BS_Pos*/)          /*!<GPIOA BSRR: BS Mask */

#define GPIOA_BSRR_BR_Pos            16                                           /*!<GPIOA BSRR: BR Position */
#define GPIOA_BSRR_BR_Msk            (0xFFFFUL << GPIOA_BSRR_BR_Pos)              /*!<GPIOA BSRR: BR Mask */

#define GPIOA_BSRR_Msk_ALL           (GPIOA_BSRR_BS_Msk            |\
                                      GPIOA_BSRR_BR_Msk            )

#define GPIOA_LCKR_LCK0_Pos          0                                            /*!<GPIOA LCKR: LCK0 Position */
#define GPIOA_LCKR_LCK0_Msk          (0x1UL /*<< GPIOA_LCKR_LCK0_Pos*/)           /*!<GPIOA LCKR: LCK0 Mask */

#define GPIOA_LCKR_LCK1_Pos          1                                            /*!<GPIOA LCKR: LCK1 Position */
#define GPIOA_LCKR_LCK1_Msk          (0x1UL << GPIOA_LCKR_LCK1_Pos)               /*!<GPIOA LCKR: LCK1 Mask */

#define GPIOA_LCKR_LCK2_Pos          2                                            /*!<GPIOA LCKR: LCK2 Position */
#define GPIOA_LCKR_LCK2_Msk          (0x1UL << GPIOA_LCKR_LCK2_Pos)               /*!<GPIOA LCKR: LCK2 Mask */

#define GPIOA_LCKR_LCK3_Pos          3                                            /*!<GPIOA LCKR: LCK3 Position */
#define GPIOA_LCKR_LCK3_Msk          (0x1UL << GPIOA_LCKR_LCK3_Pos)               /*!<GPIOA LCKR: LCK3 Mask */

#define GPIOA_LCKR_LCK4_Pos          4                                            /*!<GPIOA LCKR: LCK4 Position */
#define GPIOA_LCKR_LCK4_Msk          (0x1UL << GPIOA_LCKR_LCK4_Pos)               /*!<GPIOA LCKR: LCK4 Mask */

#define GPIOA_LCKR_LCK5_Pos          5                                            /*!<GPIOA LCKR: LCK5 Position */
#define GPIOA_LCKR_LCK5_Msk          (0x1UL << GPIOA_LCKR_LCK5_Pos)               /*!<GPIOA LCKR: LCK5 Mask */

#define GPIOA_LCKR_LCK6_Pos          6                                            /*!<GPIOA LCKR: LCK6 Position */
#define GPIOA_LCKR_LCK6_Msk          (0x1UL << GPIOA_LCKR_LCK6_Pos)               /*!<GPIOA LCKR: LCK6 Mask */

#define GPIOA_LCKR_LCK7_Pos          7                                            /*!<GPIOA LCKR: LCK7 Position */
#define GPIOA_LCKR_LCK7_Msk          (0x1UL << GPIOA_LCKR_LCK7_Pos)               /*!<GPIOA LCKR: LCK7 Mask */

#define GPIOA_LCKR_LCK8_Pos          8                                            /*!<GPIOA LCKR: LCK8 Position */
#define GPIOA_LCKR_LCK8_Msk          (0x1UL << GPIOA_LCKR_LCK8_Pos)               /*!<GPIOA LCKR: LCK8 Mask */

#define GPIOA_LCKR_LCK9_Pos          9                                            /*!<GPIOA LCKR: LCK9 Position */
#define GPIOA_LCKR_LCK9_Msk          (0x1UL << GPIOA_LCKR_LCK9_Pos)               /*!<GPIOA LCKR: LCK9 Mask */

#define GPIOA_LCKR_LCK10_Pos         10                                           /*!<GPIOA LCKR: LCK10 Position */
#define GPIOA_LCKR_LCK10_Msk         (0x1UL << GPIOA_LCKR_LCK10_Pos)              /*!<GPIOA LCKR: LCK10 Mask */

#define GPIOA_LCKR_LCK11_Pos         11                                           /*!<GPIOA LCKR: LCK11 Position */
#define GPIOA_LCKR_LCK11_Msk         (0x1UL << GPIOA_LCKR_LCK11_Pos)              /*!<GPIOA LCKR: LCK11 Mask */

#define GPIOA_LCKR_LCK12_Pos         12                                           /*!<GPIOA LCKR: LCK12 Position */
#define GPIOA_LCKR_LCK12_Msk         (0x1UL << GPIOA_LCKR_LCK12_Pos)              /*!<GPIOA LCKR: LCK12 Mask */

#define GPIOA_LCKR_LCK13_Pos         13                                           /*!<GPIOA LCKR: LCK13 Position */
#define GPIOA_LCKR_LCK13_Msk         (0x1UL << GPIOA_LCKR_LCK13_Pos)              /*!<GPIOA LCKR: LCK13 Mask */

#define GPIOA_LCKR_LCK14_Pos         14                                           /*!<GPIOA LCKR: LCK14 Position */
#define GPIOA_LCKR_LCK14_Msk         (0x1UL << GPIOA_LCKR_LCK14_Pos)              /*!<GPIOA LCKR: LCK14 Mask */

#define GPIOA_LCKR_LCK15_Pos         15                                           /*!<GPIOA LCKR: LCK15 Position */
#define GPIOA_LCKR_LCK15_Msk         (0x1UL << GPIOA_LCKR_LCK15_Pos)              /*!<GPIOA LCKR: LCK15 Mask */

#define GPIOA_LCKR_LOCK_Pos          16                                           /*!<GPIOA LCKR: LOCK Position */
#define GPIOA_LCKR_LOCK_Msk          (0xFFFFUL << GPIOA_LCKR_LOCK_Pos)            /*!<GPIOA LCKR: LOCK Mask */

#define GPIOA_LCKR_Msk_ALL           (GPIOA_LCKR_LCK0_Msk          |\
                                      GPIOA_LCKR_LCK1_Msk          |\
                                      GPIOA_LCKR_LCK2_Msk          |\
                                      GPIOA_LCKR_LCK3_Msk          |\
                                      GPIOA_LCKR_LCK4_Msk          |\
                                      GPIOA_LCKR_LCK5_Msk          |\
                                      GPIOA_LCKR_LCK6_Msk          |\
                                      GPIOA_LCKR_LCK7_Msk          |\
                                      GPIOA_LCKR_LCK8_Msk          |\
                                      GPIOA_LCKR_LCK9_Msk          |\
                                      GPIOA_LCKR_LCK10_Msk         |\
                                      GPIOA_LCKR_LCK11_Msk         |\
                                      GPIOA_LCKR_LCK12_Msk         |\
                                      GPIOA_LCKR_LCK13_Msk         |\
                                      GPIOA_LCKR_LCK14_Msk         |\
                                      GPIOA_LCKR_LCK15_Msk         |\
                                      GPIOA_LCKR_LOCK_Msk          )

#define GPIOA_IE_IE0_Pos             0                                            /*!<GPIOA IE: IE0 Position */
#define GPIOA_IE_IE0_Msk             (0x1UL /*<< GPIOA_IE_IE0_Pos*/)              /*!<GPIOA IE: IE0 Mask */

#define GPIOA_IE_IE1_Pos             1                                            /*!<GPIOA IE: IE1 Position */
#define GPIOA_IE_IE1_Msk             (0x1UL << GPIOA_IE_IE1_Pos)                  /*!<GPIOA IE: IE1 Mask */

#define GPIOA_IE_IE2_Pos             2                                            /*!<GPIOA IE: IE2 Position */
#define GPIOA_IE_IE2_Msk             (0x1UL << GPIOA_IE_IE2_Pos)                  /*!<GPIOA IE: IE2 Mask */

#define GPIOA_IE_IE3_Pos             3                                            /*!<GPIOA IE: IE3 Position */
#define GPIOA_IE_IE3_Msk             (0x1UL << GPIOA_IE_IE3_Pos)                  /*!<GPIOA IE: IE3 Mask */

#define GPIOA_IE_IE4_Pos             4                                            /*!<GPIOA IE: IE4 Position */
#define GPIOA_IE_IE4_Msk             (0x1UL << GPIOA_IE_IE4_Pos)                  /*!<GPIOA IE: IE4 Mask */

#define GPIOA_IE_IE5_Pos             5                                            /*!<GPIOA IE: IE5 Position */
#define GPIOA_IE_IE5_Msk             (0x1UL << GPIOA_IE_IE5_Pos)                  /*!<GPIOA IE: IE5 Mask */

#define GPIOA_IE_IE6_Pos             6                                            /*!<GPIOA IE: IE6 Position */
#define GPIOA_IE_IE6_Msk             (0x1UL << GPIOA_IE_IE6_Pos)                  /*!<GPIOA IE: IE6 Mask */

#define GPIOA_IE_IE7_Pos             7                                            /*!<GPIOA IE: IE7 Position */
#define GPIOA_IE_IE7_Msk             (0x1UL << GPIOA_IE_IE7_Pos)                  /*!<GPIOA IE: IE7 Mask */

#define GPIOA_IE_IE8_Pos             8                                            /*!<GPIOA IE: IE8 Position */
#define GPIOA_IE_IE8_Msk             (0x1UL << GPIOA_IE_IE8_Pos)                  /*!<GPIOA IE: IE8 Mask */

#define GPIOA_IE_IE9_Pos             9                                            /*!<GPIOA IE: IE9 Position */
#define GPIOA_IE_IE9_Msk             (0x1UL << GPIOA_IE_IE9_Pos)                  /*!<GPIOA IE: IE9 Mask */

#define GPIOA_IE_IE10_Pos            10                                           /*!<GPIOA IE: IE10 Position */
#define GPIOA_IE_IE10_Msk            (0x1UL << GPIOA_IE_IE10_Pos)                 /*!<GPIOA IE: IE10 Mask */

#define GPIOA_IE_IE11_Pos            11                                           /*!<GPIOA IE: IE11 Position */
#define GPIOA_IE_IE11_Msk            (0x1UL << GPIOA_IE_IE11_Pos)                 /*!<GPIOA IE: IE11 Mask */

#define GPIOA_IE_IE12_Pos            12                                           /*!<GPIOA IE: IE12 Position */
#define GPIOA_IE_IE12_Msk            (0x1UL << GPIOA_IE_IE12_Pos)                 /*!<GPIOA IE: IE12 Mask */

#define GPIOA_IE_IE13_Pos            13                                           /*!<GPIOA IE: IE13 Position */
#define GPIOA_IE_IE13_Msk            (0x1UL << GPIOA_IE_IE13_Pos)                 /*!<GPIOA IE: IE13 Mask */

#define GPIOA_IE_IE14_Pos            14                                           /*!<GPIOA IE: IE14 Position */
#define GPIOA_IE_IE14_Msk            (0x1UL << GPIOA_IE_IE14_Pos)                 /*!<GPIOA IE: IE14 Mask */

#define GPIOA_IE_IE15_Pos            15                                           /*!<GPIOA IE: IE15 Position */
#define GPIOA_IE_IE15_Msk            (0x1UL << GPIOA_IE_IE15_Pos)                 /*!<GPIOA IE: IE15 Mask */

#define GPIOA_IE_Msk_ALL             (GPIOA_IE_IE0_Msk             |\
                                      GPIOA_IE_IE1_Msk             |\
                                      GPIOA_IE_IE2_Msk             |\
                                      GPIOA_IE_IE3_Msk             |\
                                      GPIOA_IE_IE4_Msk             |\
                                      GPIOA_IE_IE5_Msk             |\
                                      GPIOA_IE_IE6_Msk             |\
                                      GPIOA_IE_IE7_Msk             |\
                                      GPIOA_IE_IE8_Msk             |\
                                      GPIOA_IE_IE9_Msk             |\
                                      GPIOA_IE_IE10_Msk            |\
                                      GPIOA_IE_IE11_Msk            |\
                                      GPIOA_IE_IE12_Msk            |\
                                      GPIOA_IE_IE13_Msk            |\
                                      GPIOA_IE_IE14_Msk            |\
                                      GPIOA_IE_IE15_Msk            )

#define GPIOA_OTYPER_OT0_Pos         0                                            /*!<GPIOA OTYPER: OT0 Position */
#define GPIOA_OTYPER_OT0_Msk         (0x1UL /*<< GPIOA_OTYPER_OT0_Pos*/)          /*!<GPIOA OTYPER: OT0 Mask */

#define GPIOA_OTYPER_OT2_Pos         2                                            /*!<GPIOA OTYPER: OT2 Position */
#define GPIOA_OTYPER_OT2_Msk         (0x1UL << GPIOA_OTYPER_OT2_Pos)              /*!<GPIOA OTYPER: OT2 Mask */

#define GPIOA_OTYPER_OT13_Pos        13                                           /*!<GPIOA OTYPER: OT13 Position */
#define GPIOA_OTYPER_OT13_Msk        (0x1UL << GPIOA_OTYPER_OT13_Pos)             /*!<GPIOA OTYPER: OT13 Mask */

#define GPIOA_OTYPER_OT14_Pos        14                                           /*!<GPIOA OTYPER: OT14 Position */
#define GPIOA_OTYPER_OT14_Msk        (0x1UL << GPIOA_OTYPER_OT14_Pos)             /*!<GPIOA OTYPER: OT14 Mask */

#define GPIOA_OTYPER_Msk_ALL         (GPIOA_OTYPER_OT0_Msk         |\
                                      GPIOA_OTYPER_OT2_Msk         |\
                                      GPIOA_OTYPER_OT13_Msk        |\
                                      GPIOA_OTYPER_OT14_Msk        )

#define GPIOA_PUPDR_PHDR0_Pos        0                                            /*!<GPIOA PUPDR: PHDR0 Position */
#define GPIOA_PUPDR_PHDR0_Msk        (0x1UL /*<< GPIOA_PUPDR_PHDR0_Pos*/)         /*!<GPIOA PUPDR: PHDR0 Mask */

#define GPIOA_PUPDR_PHDR1_Pos        2                                            /*!<GPIOA PUPDR: PHDR1 Position */
#define GPIOA_PUPDR_PHDR1_Msk        (0x1UL << GPIOA_PUPDR_PHDR1_Pos)             /*!<GPIOA PUPDR: PHDR1 Mask */

#define GPIOA_PUPDR_PHDR2_Pos        4                                            /*!<GPIOA PUPDR: PHDR2 Position */
#define GPIOA_PUPDR_PHDR2_Msk        (0x1UL << GPIOA_PUPDR_PHDR2_Pos)             /*!<GPIOA PUPDR: PHDR2 Mask */

#define GPIOA_PUPDR_PHDR3_Pos        6                                            /*!<GPIOA PUPDR: PHDR3 Position */
#define GPIOA_PUPDR_PHDR3_Msk        (0x1UL << GPIOA_PUPDR_PHDR3_Pos)             /*!<GPIOA PUPDR: PHDR3 Mask */

#define GPIOA_PUPDR_PHDR4_Pos        8                                            /*!<GPIOA PUPDR: PHDR4 Position */
#define GPIOA_PUPDR_PHDR4_Msk        (0x1UL << GPIOA_PUPDR_PHDR4_Pos)             /*!<GPIOA PUPDR: PHDR4 Mask */

#define GPIOA_PUPDR_PHDR5_Pos        10                                           /*!<GPIOA PUPDR: PHDR5 Position */
#define GPIOA_PUPDR_PHDR5_Msk        (0x1UL << GPIOA_PUPDR_PHDR5_Pos)             /*!<GPIOA PUPDR: PHDR5 Mask */

#define GPIOA_PUPDR_PHDR6_Pos        12                                           /*!<GPIOA PUPDR: PHDR6 Position */
#define GPIOA_PUPDR_PHDR6_Msk        (0x1UL << GPIOA_PUPDR_PHDR6_Pos)             /*!<GPIOA PUPDR: PHDR6 Mask */

#define GPIOA_PUPDR_PHDR7_Pos        14                                           /*!<GPIOA PUPDR: PHDR7 Position */
#define GPIOA_PUPDR_PHDR7_Msk        (0x1UL << GPIOA_PUPDR_PHDR7_Pos)             /*!<GPIOA PUPDR: PHDR7 Mask */

#define GPIOA_PUPDR_PHDR8_Pos        16                                           /*!<GPIOA PUPDR: PHDR8 Position */
#define GPIOA_PUPDR_PHDR8_Msk        (0x1UL << GPIOA_PUPDR_PHDR8_Pos)             /*!<GPIOA PUPDR: PHDR8 Mask */

#define GPIOA_PUPDR_PHDR9_Pos        18                                           /*!<GPIOA PUPDR: PHDR9 Position */
#define GPIOA_PUPDR_PHDR9_Msk        (0x1UL << GPIOA_PUPDR_PHDR9_Pos)             /*!<GPIOA PUPDR: PHDR9 Mask */

#define GPIOA_PUPDR_PHDR10_Pos       20                                           /*!<GPIOA PUPDR: PHDR10 Position */
#define GPIOA_PUPDR_PHDR10_Msk       (0x1UL << GPIOA_PUPDR_PHDR10_Pos)            /*!<GPIOA PUPDR: PHDR10 Mask */

#define GPIOA_PUPDR_PHDR11_Pos       22                                           /*!<GPIOA PUPDR: PHDR11 Position */
#define GPIOA_PUPDR_PHDR11_Msk       (0x1UL << GPIOA_PUPDR_PHDR11_Pos)            /*!<GPIOA PUPDR: PHDR11 Mask */

#define GPIOA_PUPDR_PHDR12_Pos       24                                           /*!<GPIOA PUPDR: PHDR12 Position */
#define GPIOA_PUPDR_PHDR12_Msk       (0x1UL << GPIOA_PUPDR_PHDR12_Pos)            /*!<GPIOA PUPDR: PHDR12 Mask */

#define GPIOA_PUPDR_PHDR13_Pos       26                                           /*!<GPIOA PUPDR: PHDR13 Position */
#define GPIOA_PUPDR_PHDR13_Msk       (0x1UL << GPIOA_PUPDR_PHDR13_Pos)            /*!<GPIOA PUPDR: PHDR13 Mask */

#define GPIOA_PUPDR_PHDR14_Pos       28                                           /*!<GPIOA PUPDR: PHDR14 Position */
#define GPIOA_PUPDR_PHDR14_Msk       (0x1UL << GPIOA_PUPDR_PHDR14_Pos)            /*!<GPIOA PUPDR: PHDR14 Mask */

#define GPIOA_PUPDR_PHDR15_Pos       30                                           /*!<GPIOA PUPDR: PHDR15 Position */
#define GPIOA_PUPDR_PHDR15_Msk       (0x1UL << GPIOA_PUPDR_PHDR15_Pos)            /*!<GPIOA PUPDR: PHDR15 Mask */

#define GPIOA_PUPDR_Msk_ALL          (GPIOA_PUPDR_PHDR0_Msk        |\
                                      GPIOA_PUPDR_PHDR1_Msk        |\
                                      GPIOA_PUPDR_PHDR2_Msk        |\
                                      GPIOA_PUPDR_PHDR3_Msk        |\
                                      GPIOA_PUPDR_PHDR4_Msk        |\
                                      GPIOA_PUPDR_PHDR5_Msk        |\
                                      GPIOA_PUPDR_PHDR6_Msk        |\
                                      GPIOA_PUPDR_PHDR7_Msk        |\
                                      GPIOA_PUPDR_PHDR8_Msk        |\
                                      GPIOA_PUPDR_PHDR9_Msk        |\
                                      GPIOA_PUPDR_PHDR10_Msk       |\
                                      GPIOA_PUPDR_PHDR11_Msk       |\
                                      GPIOA_PUPDR_PHDR12_Msk       |\
                                      GPIOA_PUPDR_PHDR13_Msk       |\
                                      GPIOA_PUPDR_PHDR14_Msk       |\
                                      GPIOA_PUPDR_PHDR15_Msk       )

#define GPIOA_TTLEN_TTLEN0_Pos       0                                            /*!<GPIOA TTLEN: TTLEN0 Position */
#define GPIOA_TTLEN_TTLEN0_Msk       (0x1UL /*<< GPIOA_TTLEN_TTLEN0_Pos*/)        /*!<GPIOA TTLEN: TTLEN0 Mask */

#define GPIOA_TTLEN_TTLEN1_Pos       1                                            /*!<GPIOA TTLEN: TTLEN1 Position */
#define GPIOA_TTLEN_TTLEN1_Msk       (0x1UL << GPIOA_TTLEN_TTLEN1_Pos)            /*!<GPIOA TTLEN: TTLEN1 Mask */

#define GPIOA_TTLEN_TTLEN2_Pos       2                                            /*!<GPIOA TTLEN: TTLEN2 Position */
#define GPIOA_TTLEN_TTLEN2_Msk       (0x1UL << GPIOA_TTLEN_TTLEN2_Pos)            /*!<GPIOA TTLEN: TTLEN2 Mask */

#define GPIOA_TTLEN_TTLEN6_Pos       6                                            /*!<GPIOA TTLEN: TTLEN6 Position */
#define GPIOA_TTLEN_TTLEN6_Msk       (0x1UL << GPIOA_TTLEN_TTLEN6_Pos)            /*!<GPIOA TTLEN: TTLEN6 Mask */

#define GPIOA_TTLEN_TTLEN9_Pos       9                                            /*!<GPIOA TTLEN: TTLEN9 Position */
#define GPIOA_TTLEN_TTLEN9_Msk       (0x1UL << GPIOA_TTLEN_TTLEN9_Pos)            /*!<GPIOA TTLEN: TTLEN9 Mask */

#define GPIOA_TTLEN_TTLEN11_Pos      11                                           /*!<GPIOA TTLEN: TTLEN11 Position */
#define GPIOA_TTLEN_TTLEN11_Msk      (0x1UL << GPIOA_TTLEN_TTLEN11_Pos)           /*!<GPIOA TTLEN: TTLEN11 Mask */

#define GPIOA_TTLEN_TTLEN12_Pos      12                                           /*!<GPIOA TTLEN: TTLEN12 Position */
#define GPIOA_TTLEN_TTLEN12_Msk      (0x1UL << GPIOA_TTLEN_TTLEN12_Pos)           /*!<GPIOA TTLEN: TTLEN12 Mask */

#define GPIOA_TTLEN_TTLEN13_Pos      13                                           /*!<GPIOA TTLEN: TTLEN13 Position */
#define GPIOA_TTLEN_TTLEN13_Msk      (0x1UL << GPIOA_TTLEN_TTLEN13_Pos)           /*!<GPIOA TTLEN: TTLEN13 Mask */

#define GPIOA_TTLEN_TTLEN14_Pos      14                                           /*!<GPIOA TTLEN: TTLEN14 Position */
#define GPIOA_TTLEN_TTLEN14_Msk      (0x1UL << GPIOA_TTLEN_TTLEN14_Pos)           /*!<GPIOA TTLEN: TTLEN14 Mask */

#define GPIOA_TTLEN_Msk_ALL          (GPIOA_TTLEN_TTLEN0_Msk       |\
                                      GPIOA_TTLEN_TTLEN1_Msk       |\
                                      GPIOA_TTLEN_TTLEN2_Msk       |\
                                      GPIOA_TTLEN_TTLEN6_Msk       |\
                                      GPIOA_TTLEN_TTLEN9_Msk       |\
                                      GPIOA_TTLEN_TTLEN11_Msk      |\
                                      GPIOA_TTLEN_TTLEN12_Msk      |\
                                      GPIOA_TTLEN_TTLEN13_Msk      |\
                                      GPIOA_TTLEN_TTLEN14_Msk      )

#define GPIOA_AFRL_AFR0_Pos          0                                            /*!<GPIOA AFRL: AFR0 Position */
#define GPIOA_AFRL_AFR0_Msk          (0x7UL /*<< GPIOA_AFRL_AFR0_Pos*/)           /*!<GPIOA AFRL: AFR0 Mask */

#define GPIOA_AFRL_AFR1_Pos          4                                            /*!<GPIOA AFRL: AFR1 Position */
#define GPIOA_AFRL_AFR1_Msk          (0x7UL << GPIOA_AFRL_AFR1_Pos)               /*!<GPIOA AFRL: AFR1 Mask */

#define GPIOA_AFRL_AFR2_Pos          8                                            /*!<GPIOA AFRL: AFR2 Position */
#define GPIOA_AFRL_AFR2_Msk          (0x7UL << GPIOA_AFRL_AFR2_Pos)               /*!<GPIOA AFRL: AFR2 Mask */

#define GPIOA_AFRL_AFR3_Pos          12                                           /*!<GPIOA AFRL: AFR3 Position */
#define GPIOA_AFRL_AFR3_Msk          (0x7UL << GPIOA_AFRL_AFR3_Pos)               /*!<GPIOA AFRL: AFR3 Mask */

#define GPIOA_AFRL_AFR4_Pos          16                                           /*!<GPIOA AFRL: AFR4 Position */
#define GPIOA_AFRL_AFR4_Msk          (0x7UL << GPIOA_AFRL_AFR4_Pos)               /*!<GPIOA AFRL: AFR4 Mask */

#define GPIOA_AFRL_AFR5_Pos          20                                           /*!<GPIOA AFRL: AFR5 Position */
#define GPIOA_AFRL_AFR5_Msk          (0x7UL << GPIOA_AFRL_AFR5_Pos)               /*!<GPIOA AFRL: AFR5 Mask */

#define GPIOA_AFRL_AFR6_Pos          24                                           /*!<GPIOA AFRL: AFR6 Position */
#define GPIOA_AFRL_AFR6_Msk          (0x7UL << GPIOA_AFRL_AFR6_Pos)               /*!<GPIOA AFRL: AFR6 Mask */

#define GPIOA_AFRL_AFR7_Pos          28                                           /*!<GPIOA AFRL: AFR7 Position */
#define GPIOA_AFRL_AFR7_Msk          (0x7UL << GPIOA_AFRL_AFR7_Pos)               /*!<GPIOA AFRL: AFR7 Mask */

#define GPIOA_AFRL_Msk_ALL           (GPIOA_AFRL_AFR0_Msk          |\
                                      GPIOA_AFRL_AFR1_Msk          |\
                                      GPIOA_AFRL_AFR2_Msk          |\
                                      GPIOA_AFRL_AFR3_Msk          |\
                                      GPIOA_AFRL_AFR4_Msk          |\
                                      GPIOA_AFRL_AFR5_Msk          |\
                                      GPIOA_AFRL_AFR6_Msk          |\
                                      GPIOA_AFRL_AFR7_Msk          )

#define GPIOA_AFRH_AFR8_Pos          0                                            /*!<GPIOA AFRH: AFR8 Position */
#define GPIOA_AFRH_AFR8_Msk          (0x7UL /*<< GPIOA_AFRH_AFR8_Pos*/)           /*!<GPIOA AFRH: AFR8 Mask */

#define GPIOA_AFRH_AFR9_Pos          4                                            /*!<GPIOA AFRH: AFR9 Position */
#define GPIOA_AFRH_AFR9_Msk          (0x7UL << GPIOA_AFRH_AFR9_Pos)               /*!<GPIOA AFRH: AFR9 Mask */

#define GPIOA_AFRH_AFR10_Pos         8                                            /*!<GPIOA AFRH: AFR10 Position */
#define GPIOA_AFRH_AFR10_Msk         (0x7UL << GPIOA_AFRH_AFR10_Pos)              /*!<GPIOA AFRH: AFR10 Mask */

#define GPIOA_AFRH_AFR11_Pos         12                                           /*!<GPIOA AFRH: AFR11 Position */
#define GPIOA_AFRH_AFR11_Msk         (0x7UL << GPIOA_AFRH_AFR11_Pos)              /*!<GPIOA AFRH: AFR11 Mask */

#define GPIOA_AFRH_AFR12_Pos         16                                           /*!<GPIOA AFRH: AFR12 Position */
#define GPIOA_AFRH_AFR12_Msk         (0x7UL << GPIOA_AFRH_AFR12_Pos)              /*!<GPIOA AFRH: AFR12 Mask */

#define GPIOA_AFRH_AFR13_Pos         20                                           /*!<GPIOA AFRH: AFR13 Position */
#define GPIOA_AFRH_AFR13_Msk         (0x7UL << GPIOA_AFRH_AFR13_Pos)              /*!<GPIOA AFRH: AFR13 Mask */

#define GPIOA_AFRH_AFR14_Pos         24                                           /*!<GPIOA AFRH: AFR14 Position */
#define GPIOA_AFRH_AFR14_Msk         (0x7UL << GPIOA_AFRH_AFR14_Pos)              /*!<GPIOA AFRH: AFR14 Mask */

#define GPIOA_AFRH_AFR15_Pos         28                                           /*!<GPIOA AFRH: AFR15 Position */
#define GPIOA_AFRH_AFR15_Msk         (0x7UL << GPIOA_AFRH_AFR15_Pos)              /*!<GPIOA AFRH: AFR15 Mask */

#define GPIOA_AFRH_Msk_ALL           (GPIOA_AFRH_AFR8_Msk          |\
                                      GPIOA_AFRH_AFR9_Msk          |\
                                      GPIOA_AFRH_AFR10_Msk         |\
                                      GPIOA_AFRH_AFR11_Msk         |\
                                      GPIOA_AFRH_AFR12_Msk         |\
                                      GPIOA_AFRH_AFR13_Msk         |\
                                      GPIOA_AFRH_AFR14_Msk         |\
                                      GPIOA_AFRH_AFR15_Msk         )

#define GPIOB_MODER_MODER0_Pos       0                                            /*!<GPIOB MODER: MODER0 Position */
#define GPIOB_MODER_MODER0_Msk       (0x1UL /*<< GPIOB_MODER_MODER0_Pos*/)        /*!<GPIOB MODER: MODER0 Mask */

#define GPIOB_MODER_MODER1_Pos       1                                            /*!<GPIOB MODER: MODER1 Position */
#define GPIOB_MODER_MODER1_Msk       (0x1UL << GPIOB_MODER_MODER1_Pos)            /*!<GPIOB MODER: MODER1 Mask */

#define GPIOB_MODER_MODER2_Pos       2                                            /*!<GPIOB MODER: MODER2 Position */
#define GPIOB_MODER_MODER2_Msk       (0x1UL << GPIOB_MODER_MODER2_Pos)            /*!<GPIOB MODER: MODER2 Mask */

#define GPIOB_MODER_MODER3_Pos       3                                            /*!<GPIOB MODER: MODER3 Position */
#define GPIOB_MODER_MODER3_Msk       (0x1UL << GPIOB_MODER_MODER3_Pos)            /*!<GPIOB MODER: MODER3 Mask */

#define GPIOB_MODER_MODER4_Pos       4                                            /*!<GPIOB MODER: MODER4 Position */
#define GPIOB_MODER_MODER4_Msk       (0x1UL << GPIOB_MODER_MODER4_Pos)            /*!<GPIOB MODER: MODER4 Mask */

#define GPIOB_MODER_MODER5_Pos       5                                            /*!<GPIOB MODER: MODER5 Position */
#define GPIOB_MODER_MODER5_Msk       (0x1UL << GPIOB_MODER_MODER5_Pos)            /*!<GPIOB MODER: MODER5 Mask */

#define GPIOB_MODER_MODER6_Pos       6                                            /*!<GPIOB MODER: MODER6 Position */
#define GPIOB_MODER_MODER6_Msk       (0x1UL << GPIOB_MODER_MODER6_Pos)            /*!<GPIOB MODER: MODER6 Mask */

#define GPIOB_MODER_MODER7_Pos       7                                            /*!<GPIOB MODER: MODER7 Position */
#define GPIOB_MODER_MODER7_Msk       (0x1UL << GPIOB_MODER_MODER7_Pos)            /*!<GPIOB MODER: MODER7 Mask */

#define GPIOB_MODER_MODER8_Pos       8                                            /*!<GPIOB MODER: MODER8 Position */
#define GPIOB_MODER_MODER8_Msk       (0x1UL << GPIOB_MODER_MODER8_Pos)            /*!<GPIOB MODER: MODER8 Mask */

#define GPIOB_MODER_MODER9_Pos       9                                            /*!<GPIOB MODER: MODER9 Position */
#define GPIOB_MODER_MODER9_Msk       (0x1UL << GPIOB_MODER_MODER9_Pos)            /*!<GPIOB MODER: MODER9 Mask */

#define GPIOB_MODER_MODER10_Pos      10                                           /*!<GPIOB MODER: MODER10 Position */
#define GPIOB_MODER_MODER10_Msk      (0x1UL << GPIOB_MODER_MODER10_Pos)           /*!<GPIOB MODER: MODER10 Mask */

#define GPIOB_MODER_MODER11_Pos      11                                           /*!<GPIOB MODER: MODER11 Position */
#define GPIOB_MODER_MODER11_Msk      (0x1UL << GPIOB_MODER_MODER11_Pos)           /*!<GPIOB MODER: MODER11 Mask */

#define GPIOB_MODER_MODER12_Pos      12                                           /*!<GPIOB MODER: MODER12 Position */
#define GPIOB_MODER_MODER12_Msk      (0x1UL << GPIOB_MODER_MODER12_Pos)           /*!<GPIOB MODER: MODER12 Mask */

#define GPIOB_MODER_MODER13_Pos      13                                           /*!<GPIOB MODER: MODER13 Position */
#define GPIOB_MODER_MODER13_Msk      (0x1UL << GPIOB_MODER_MODER13_Pos)           /*!<GPIOB MODER: MODER13 Mask */

#define GPIOB_MODER_MODER14_Pos      14                                           /*!<GPIOB MODER: MODER14 Position */
#define GPIOB_MODER_MODER14_Msk      (0x1UL << GPIOB_MODER_MODER14_Pos)           /*!<GPIOB MODER: MODER14 Mask */

#define GPIOB_MODER_MODER15_Pos      15                                           /*!<GPIOB MODER: MODER15 Position */
#define GPIOB_MODER_MODER15_Msk      (0x1UL << GPIOB_MODER_MODER15_Pos)           /*!<GPIOB MODER: MODER15 Mask */

#define GPIOB_MODER_Msk_ALL          (GPIOB_MODER_MODER0_Msk       |\
                                      GPIOB_MODER_MODER1_Msk       |\
                                      GPIOB_MODER_MODER2_Msk       |\
                                      GPIOB_MODER_MODER3_Msk       |\
                                      GPIOB_MODER_MODER4_Msk       |\
                                      GPIOB_MODER_MODER5_Msk       |\
                                      GPIOB_MODER_MODER6_Msk       |\
                                      GPIOB_MODER_MODER7_Msk       |\
                                      GPIOB_MODER_MODER8_Msk       |\
                                      GPIOB_MODER_MODER9_Msk       |\
                                      GPIOB_MODER_MODER10_Msk      |\
                                      GPIOB_MODER_MODER11_Msk      |\
                                      GPIOB_MODER_MODER12_Msk      |\
                                      GPIOB_MODER_MODER13_Msk      |\
                                      GPIOB_MODER_MODER14_Msk      |\
                                      GPIOB_MODER_MODER15_Msk      )

#define GPIOB_IDR_IDR_Pos            0                                            /*!<GPIOB IDR: IDR Position */
#define GPIOB_IDR_IDR_Msk            (0xFFFFUL /*<< GPIOB_IDR_IDR_Pos*/)          /*!<GPIOB IDR: IDR Mask */

#define GPIOB_IDR_Msk_ALL            (GPIOB_IDR_IDR_Msk           )

#define GPIOB_ODR_ODR_Pos            0                                            /*!<GPIOB ODR: ODR Position */
#define GPIOB_ODR_ODR_Msk            (0xFFFFUL /*<< GPIOB_ODR_ODR_Pos*/)          /*!<GPIOB ODR: ODR Mask */

#define GPIOB_ODR_Msk_ALL            (GPIOB_ODR_ODR_Msk           )

#define GPIOB_BSRR_BS_Pos            0                                            /*!<GPIOB BSRR: BS Position */
#define GPIOB_BSRR_BS_Msk            (0xFFFFUL /*<< GPIOB_BSRR_BS_Pos*/)          /*!<GPIOB BSRR: BS Mask */

#define GPIOB_BSRR_BR_Pos            16                                           /*!<GPIOB BSRR: BR Position */
#define GPIOB_BSRR_BR_Msk            (0xFFFFUL << GPIOB_BSRR_BR_Pos)              /*!<GPIOB BSRR: BR Mask */

#define GPIOB_BSRR_Msk_ALL           (GPIOB_BSRR_BS_Msk            |\
                                      GPIOB_BSRR_BR_Msk            )

#define GPIOB_LCKR_LCK0_Pos          0                                            /*!<GPIOB LCKR: LCK0 Position */
#define GPIOB_LCKR_LCK0_Msk          (0x1UL /*<< GPIOB_LCKR_LCK0_Pos*/)           /*!<GPIOB LCKR: LCK0 Mask */

#define GPIOB_LCKR_LCK1_Pos          1                                            /*!<GPIOB LCKR: LCK1 Position */
#define GPIOB_LCKR_LCK1_Msk          (0x1UL << GPIOB_LCKR_LCK1_Pos)               /*!<GPIOB LCKR: LCK1 Mask */

#define GPIOB_LCKR_LCK2_Pos          2                                            /*!<GPIOB LCKR: LCK2 Position */
#define GPIOB_LCKR_LCK2_Msk          (0x1UL << GPIOB_LCKR_LCK2_Pos)               /*!<GPIOB LCKR: LCK2 Mask */

#define GPIOB_LCKR_LCK3_Pos          3                                            /*!<GPIOB LCKR: LCK3 Position */
#define GPIOB_LCKR_LCK3_Msk          (0x1UL << GPIOB_LCKR_LCK3_Pos)               /*!<GPIOB LCKR: LCK3 Mask */

#define GPIOB_LCKR_LCK4_Pos          4                                            /*!<GPIOB LCKR: LCK4 Position */
#define GPIOB_LCKR_LCK4_Msk          (0x1UL << GPIOB_LCKR_LCK4_Pos)               /*!<GPIOB LCKR: LCK4 Mask */

#define GPIOB_LCKR_LCK5_Pos          5                                            /*!<GPIOB LCKR: LCK5 Position */
#define GPIOB_LCKR_LCK5_Msk          (0x1UL << GPIOB_LCKR_LCK5_Pos)               /*!<GPIOB LCKR: LCK5 Mask */

#define GPIOB_LCKR_LCK6_Pos          6                                            /*!<GPIOB LCKR: LCK6 Position */
#define GPIOB_LCKR_LCK6_Msk          (0x1UL << GPIOB_LCKR_LCK6_Pos)               /*!<GPIOB LCKR: LCK6 Mask */

#define GPIOB_LCKR_LCK7_Pos          7                                            /*!<GPIOB LCKR: LCK7 Position */
#define GPIOB_LCKR_LCK7_Msk          (0x1UL << GPIOB_LCKR_LCK7_Pos)               /*!<GPIOB LCKR: LCK7 Mask */

#define GPIOB_LCKR_LCK8_Pos          8                                            /*!<GPIOB LCKR: LCK8 Position */
#define GPIOB_LCKR_LCK8_Msk          (0x1UL << GPIOB_LCKR_LCK8_Pos)               /*!<GPIOB LCKR: LCK8 Mask */

#define GPIOB_LCKR_LCK9_Pos          9                                            /*!<GPIOB LCKR: LCK9 Position */
#define GPIOB_LCKR_LCK9_Msk          (0x1UL << GPIOB_LCKR_LCK9_Pos)               /*!<GPIOB LCKR: LCK9 Mask */

#define GPIOB_LCKR_LCK10_Pos         10                                           /*!<GPIOB LCKR: LCK10 Position */
#define GPIOB_LCKR_LCK10_Msk         (0x1UL << GPIOB_LCKR_LCK10_Pos)              /*!<GPIOB LCKR: LCK10 Mask */

#define GPIOB_LCKR_LCK11_Pos         11                                           /*!<GPIOB LCKR: LCK11 Position */
#define GPIOB_LCKR_LCK11_Msk         (0x1UL << GPIOB_LCKR_LCK11_Pos)              /*!<GPIOB LCKR: LCK11 Mask */

#define GPIOB_LCKR_LCK12_Pos         12                                           /*!<GPIOB LCKR: LCK12 Position */
#define GPIOB_LCKR_LCK12_Msk         (0x1UL << GPIOB_LCKR_LCK12_Pos)              /*!<GPIOB LCKR: LCK12 Mask */

#define GPIOB_LCKR_LCK13_Pos         13                                           /*!<GPIOB LCKR: LCK13 Position */
#define GPIOB_LCKR_LCK13_Msk         (0x1UL << GPIOB_LCKR_LCK13_Pos)              /*!<GPIOB LCKR: LCK13 Mask */

#define GPIOB_LCKR_LCK14_Pos         14                                           /*!<GPIOB LCKR: LCK14 Position */
#define GPIOB_LCKR_LCK14_Msk         (0x1UL << GPIOB_LCKR_LCK14_Pos)              /*!<GPIOB LCKR: LCK14 Mask */

#define GPIOB_LCKR_LCK15_Pos         15                                           /*!<GPIOB LCKR: LCK15 Position */
#define GPIOB_LCKR_LCK15_Msk         (0x1UL << GPIOB_LCKR_LCK15_Pos)              /*!<GPIOB LCKR: LCK15 Mask */

#define GPIOB_LCKR_LOCK_Pos          16                                           /*!<GPIOB LCKR: LOCK Position */
#define GPIOB_LCKR_LOCK_Msk          (0xFFFFUL << GPIOB_LCKR_LOCK_Pos)            /*!<GPIOB LCKR: LOCK Mask */

#define GPIOB_LCKR_Msk_ALL           (GPIOB_LCKR_LCK0_Msk          |\
                                      GPIOB_LCKR_LCK1_Msk          |\
                                      GPIOB_LCKR_LCK2_Msk          |\
                                      GPIOB_LCKR_LCK3_Msk          |\
                                      GPIOB_LCKR_LCK4_Msk          |\
                                      GPIOB_LCKR_LCK5_Msk          |\
                                      GPIOB_LCKR_LCK6_Msk          |\
                                      GPIOB_LCKR_LCK7_Msk          |\
                                      GPIOB_LCKR_LCK8_Msk          |\
                                      GPIOB_LCKR_LCK9_Msk          |\
                                      GPIOB_LCKR_LCK10_Msk         |\
                                      GPIOB_LCKR_LCK11_Msk         |\
                                      GPIOB_LCKR_LCK12_Msk         |\
                                      GPIOB_LCKR_LCK13_Msk         |\
                                      GPIOB_LCKR_LCK14_Msk         |\
                                      GPIOB_LCKR_LCK15_Msk         |\
                                      GPIOB_LCKR_LOCK_Msk          )

#define GPIOB_IE_IE0_Pos             0                                            /*!<GPIOB IE: IE0 Position */
#define GPIOB_IE_IE0_Msk             (0x1UL /*<< GPIOB_IE_IE0_Pos*/)              /*!<GPIOB IE: IE0 Mask */

#define GPIOB_IE_IE1_Pos             1                                            /*!<GPIOB IE: IE1 Position */
#define GPIOB_IE_IE1_Msk             (0x1UL << GPIOB_IE_IE1_Pos)                  /*!<GPIOB IE: IE1 Mask */

#define GPIOB_IE_IE2_Pos             2                                            /*!<GPIOB IE: IE2 Position */
#define GPIOB_IE_IE2_Msk             (0x1UL << GPIOB_IE_IE2_Pos)                  /*!<GPIOB IE: IE2 Mask */

#define GPIOB_IE_IE3_Pos             3                                            /*!<GPIOB IE: IE3 Position */
#define GPIOB_IE_IE3_Msk             (0x1UL << GPIOB_IE_IE3_Pos)                  /*!<GPIOB IE: IE3 Mask */

#define GPIOB_IE_IE4_Pos             4                                            /*!<GPIOB IE: IE4 Position */
#define GPIOB_IE_IE4_Msk             (0x1UL << GPIOB_IE_IE4_Pos)                  /*!<GPIOB IE: IE4 Mask */

#define GPIOB_IE_IE5_Pos             5                                            /*!<GPIOB IE: IE5 Position */
#define GPIOB_IE_IE5_Msk             (0x1UL << GPIOB_IE_IE5_Pos)                  /*!<GPIOB IE: IE5 Mask */

#define GPIOB_IE_IE6_Pos             6                                            /*!<GPIOB IE: IE6 Position */
#define GPIOB_IE_IE6_Msk             (0x1UL << GPIOB_IE_IE6_Pos)                  /*!<GPIOB IE: IE6 Mask */

#define GPIOB_IE_IE7_Pos             7                                            /*!<GPIOB IE: IE7 Position */
#define GPIOB_IE_IE7_Msk             (0x1UL << GPIOB_IE_IE7_Pos)                  /*!<GPIOB IE: IE7 Mask */

#define GPIOB_IE_IE8_Pos             8                                            /*!<GPIOB IE: IE8 Position */
#define GPIOB_IE_IE8_Msk             (0x1UL << GPIOB_IE_IE8_Pos)                  /*!<GPIOB IE: IE8 Mask */

#define GPIOB_IE_IE9_Pos             9                                            /*!<GPIOB IE: IE9 Position */
#define GPIOB_IE_IE9_Msk             (0x1UL << GPIOB_IE_IE9_Pos)                  /*!<GPIOB IE: IE9 Mask */

#define GPIOB_IE_IE10_Pos            10                                           /*!<GPIOB IE: IE10 Position */
#define GPIOB_IE_IE10_Msk            (0x1UL << GPIOB_IE_IE10_Pos)                 /*!<GPIOB IE: IE10 Mask */

#define GPIOB_IE_IE11_Pos            11                                           /*!<GPIOB IE: IE11 Position */
#define GPIOB_IE_IE11_Msk            (0x1UL << GPIOB_IE_IE11_Pos)                 /*!<GPIOB IE: IE11 Mask */

#define GPIOB_IE_IE12_Pos            12                                           /*!<GPIOB IE: IE12 Position */
#define GPIOB_IE_IE12_Msk            (0x1UL << GPIOB_IE_IE12_Pos)                 /*!<GPIOB IE: IE12 Mask */

#define GPIOB_IE_IE13_Pos            13                                           /*!<GPIOB IE: IE13 Position */
#define GPIOB_IE_IE13_Msk            (0x1UL << GPIOB_IE_IE13_Pos)                 /*!<GPIOB IE: IE13 Mask */

#define GPIOB_IE_IE14_Pos            14                                           /*!<GPIOB IE: IE14 Position */
#define GPIOB_IE_IE14_Msk            (0x1UL << GPIOB_IE_IE14_Pos)                 /*!<GPIOB IE: IE14 Mask */

#define GPIOB_IE_IE15_Pos            15                                           /*!<GPIOB IE: IE15 Position */
#define GPIOB_IE_IE15_Msk            (0x1UL << GPIOB_IE_IE15_Pos)                 /*!<GPIOB IE: IE15 Mask */

#define GPIOB_IE_Msk_ALL             (GPIOB_IE_IE0_Msk             |\
                                      GPIOB_IE_IE1_Msk             |\
                                      GPIOB_IE_IE2_Msk             |\
                                      GPIOB_IE_IE3_Msk             |\
                                      GPIOB_IE_IE4_Msk             |\
                                      GPIOB_IE_IE5_Msk             |\
                                      GPIOB_IE_IE6_Msk             |\
                                      GPIOB_IE_IE7_Msk             |\
                                      GPIOB_IE_IE8_Msk             |\
                                      GPIOB_IE_IE9_Msk             |\
                                      GPIOB_IE_IE10_Msk            |\
                                      GPIOB_IE_IE11_Msk            |\
                                      GPIOB_IE_IE12_Msk            |\
                                      GPIOB_IE_IE13_Msk            |\
                                      GPIOB_IE_IE14_Msk            |\
                                      GPIOB_IE_IE15_Msk            )

#define GPIOB_OTYPER_OT0_Pos         0                                            /*!<GPIOB OTYPER: OT0 Position */
#define GPIOB_OTYPER_OT0_Msk         (0x1UL /*<< GPIOB_OTYPER_OT0_Pos*/)          /*!<GPIOB OTYPER: OT0 Mask */

#define GPIOB_OTYPER_OT2_Pos         2                                            /*!<GPIOB OTYPER: OT2 Position */
#define GPIOB_OTYPER_OT2_Msk         (0x1UL << GPIOB_OTYPER_OT2_Pos)              /*!<GPIOB OTYPER: OT2 Mask */

#define GPIOB_OTYPER_OT13_Pos        13                                           /*!<GPIOB OTYPER: OT13 Position */
#define GPIOB_OTYPER_OT13_Msk        (0x1UL << GPIOB_OTYPER_OT13_Pos)             /*!<GPIOB OTYPER: OT13 Mask */

#define GPIOB_OTYPER_OT14_Pos        14                                           /*!<GPIOB OTYPER: OT14 Position */
#define GPIOB_OTYPER_OT14_Msk        (0x1UL << GPIOB_OTYPER_OT14_Pos)             /*!<GPIOB OTYPER: OT14 Mask */

#define GPIOB_OTYPER_Msk_ALL         (GPIOB_OTYPER_OT0_Msk         |\
                                      GPIOB_OTYPER_OT2_Msk         |\
                                      GPIOB_OTYPER_OT13_Msk        |\
                                      GPIOB_OTYPER_OT14_Msk        )

#define GPIOB_PUPDR_PHDR0_Pos        0                                            /*!<GPIOB PUPDR: PHDR0 Position */
#define GPIOB_PUPDR_PHDR0_Msk        (0x1UL /*<< GPIOB_PUPDR_PHDR0_Pos*/)         /*!<GPIOB PUPDR: PHDR0 Mask */

#define GPIOB_PUPDR_PHDR1_Pos        2                                            /*!<GPIOB PUPDR: PHDR1 Position */
#define GPIOB_PUPDR_PHDR1_Msk        (0x1UL << GPIOB_PUPDR_PHDR1_Pos)             /*!<GPIOB PUPDR: PHDR1 Mask */

#define GPIOB_PUPDR_PHDR2_Pos        4                                            /*!<GPIOB PUPDR: PHDR2 Position */
#define GPIOB_PUPDR_PHDR2_Msk        (0x1UL << GPIOB_PUPDR_PHDR2_Pos)             /*!<GPIOB PUPDR: PHDR2 Mask */

#define GPIOB_PUPDR_PHDR3_Pos        6                                            /*!<GPIOB PUPDR: PHDR3 Position */
#define GPIOB_PUPDR_PHDR3_Msk        (0x1UL << GPIOB_PUPDR_PHDR3_Pos)             /*!<GPIOB PUPDR: PHDR3 Mask */

#define GPIOB_PUPDR_PHDR4_Pos        8                                            /*!<GPIOB PUPDR: PHDR4 Position */
#define GPIOB_PUPDR_PHDR4_Msk        (0x1UL << GPIOB_PUPDR_PHDR4_Pos)             /*!<GPIOB PUPDR: PHDR4 Mask */

#define GPIOB_PUPDR_PHDR5_Pos        10                                           /*!<GPIOB PUPDR: PHDR5 Position */
#define GPIOB_PUPDR_PHDR5_Msk        (0x1UL << GPIOB_PUPDR_PHDR5_Pos)             /*!<GPIOB PUPDR: PHDR5 Mask */

#define GPIOB_PUPDR_PHDR6_Pos        12                                           /*!<GPIOB PUPDR: PHDR6 Position */
#define GPIOB_PUPDR_PHDR6_Msk        (0x1UL << GPIOB_PUPDR_PHDR6_Pos)             /*!<GPIOB PUPDR: PHDR6 Mask */

#define GPIOB_PUPDR_PHDR7_Pos        14                                           /*!<GPIOB PUPDR: PHDR7 Position */
#define GPIOB_PUPDR_PHDR7_Msk        (0x1UL << GPIOB_PUPDR_PHDR7_Pos)             /*!<GPIOB PUPDR: PHDR7 Mask */

#define GPIOB_PUPDR_PHDR8_Pos        16                                           /*!<GPIOB PUPDR: PHDR8 Position */
#define GPIOB_PUPDR_PHDR8_Msk        (0x1UL << GPIOB_PUPDR_PHDR8_Pos)             /*!<GPIOB PUPDR: PHDR8 Mask */

#define GPIOB_PUPDR_PHDR9_Pos        18                                           /*!<GPIOB PUPDR: PHDR9 Position */
#define GPIOB_PUPDR_PHDR9_Msk        (0x1UL << GPIOB_PUPDR_PHDR9_Pos)             /*!<GPIOB PUPDR: PHDR9 Mask */

#define GPIOB_PUPDR_PHDR10_Pos       20                                           /*!<GPIOB PUPDR: PHDR10 Position */
#define GPIOB_PUPDR_PHDR10_Msk       (0x1UL << GPIOB_PUPDR_PHDR10_Pos)            /*!<GPIOB PUPDR: PHDR10 Mask */

#define GPIOB_PUPDR_PHDR11_Pos       22                                           /*!<GPIOB PUPDR: PHDR11 Position */
#define GPIOB_PUPDR_PHDR11_Msk       (0x1UL << GPIOB_PUPDR_PHDR11_Pos)            /*!<GPIOB PUPDR: PHDR11 Mask */

#define GPIOB_PUPDR_PHDR12_Pos       24                                           /*!<GPIOB PUPDR: PHDR12 Position */
#define GPIOB_PUPDR_PHDR12_Msk       (0x1UL << GPIOB_PUPDR_PHDR12_Pos)            /*!<GPIOB PUPDR: PHDR12 Mask */

#define GPIOB_PUPDR_PHDR13_Pos       26                                           /*!<GPIOB PUPDR: PHDR13 Position */
#define GPIOB_PUPDR_PHDR13_Msk       (0x1UL << GPIOB_PUPDR_PHDR13_Pos)            /*!<GPIOB PUPDR: PHDR13 Mask */

#define GPIOB_PUPDR_PHDR14_Pos       28                                           /*!<GPIOB PUPDR: PHDR14 Position */
#define GPIOB_PUPDR_PHDR14_Msk       (0x1UL << GPIOB_PUPDR_PHDR14_Pos)            /*!<GPIOB PUPDR: PHDR14 Mask */

#define GPIOB_PUPDR_PHDR15_Pos       30                                           /*!<GPIOB PUPDR: PHDR15 Position */
#define GPIOB_PUPDR_PHDR15_Msk       (0x1UL << GPIOB_PUPDR_PHDR15_Pos)            /*!<GPIOB PUPDR: PHDR15 Mask */

#define GPIOB_PUPDR_Msk_ALL          (GPIOB_PUPDR_PHDR0_Msk        |\
                                      GPIOB_PUPDR_PHDR1_Msk        |\
                                      GPIOB_PUPDR_PHDR2_Msk        |\
                                      GPIOB_PUPDR_PHDR3_Msk        |\
                                      GPIOB_PUPDR_PHDR4_Msk        |\
                                      GPIOB_PUPDR_PHDR5_Msk        |\
                                      GPIOB_PUPDR_PHDR6_Msk        |\
                                      GPIOB_PUPDR_PHDR7_Msk        |\
                                      GPIOB_PUPDR_PHDR8_Msk        |\
                                      GPIOB_PUPDR_PHDR9_Msk        |\
                                      GPIOB_PUPDR_PHDR10_Msk       |\
                                      GPIOB_PUPDR_PHDR11_Msk       |\
                                      GPIOB_PUPDR_PHDR12_Msk       |\
                                      GPIOB_PUPDR_PHDR13_Msk       |\
                                      GPIOB_PUPDR_PHDR14_Msk       |\
                                      GPIOB_PUPDR_PHDR15_Msk       )

#define GPIOB_TTLEN_TTLEN0_Pos       0                                            /*!<GPIOB TTLEN: TTLEN0 Position */
#define GPIOB_TTLEN_TTLEN0_Msk       (0x1UL /*<< GPIOB_TTLEN_TTLEN0_Pos*/)        /*!<GPIOB TTLEN: TTLEN0 Mask */

#define GPIOB_TTLEN_TTLEN1_Pos       1                                            /*!<GPIOB TTLEN: TTLEN1 Position */
#define GPIOB_TTLEN_TTLEN1_Msk       (0x1UL << GPIOB_TTLEN_TTLEN1_Pos)            /*!<GPIOB TTLEN: TTLEN1 Mask */

#define GPIOB_TTLEN_TTLEN2_Pos       2                                            /*!<GPIOB TTLEN: TTLEN2 Position */
#define GPIOB_TTLEN_TTLEN2_Msk       (0x1UL << GPIOB_TTLEN_TTLEN2_Pos)            /*!<GPIOB TTLEN: TTLEN2 Mask */

#define GPIOB_TTLEN_TTLEN6_Pos       6                                            /*!<GPIOB TTLEN: TTLEN6 Position */
#define GPIOB_TTLEN_TTLEN6_Msk       (0x1UL << GPIOB_TTLEN_TTLEN6_Pos)            /*!<GPIOB TTLEN: TTLEN6 Mask */

#define GPIOB_TTLEN_TTLEN9_Pos       9                                            /*!<GPIOB TTLEN: TTLEN9 Position */
#define GPIOB_TTLEN_TTLEN9_Msk       (0x1UL << GPIOB_TTLEN_TTLEN9_Pos)            /*!<GPIOB TTLEN: TTLEN9 Mask */

#define GPIOB_TTLEN_TTLEN11_Pos      11                                           /*!<GPIOB TTLEN: TTLEN11 Position */
#define GPIOB_TTLEN_TTLEN11_Msk      (0x1UL << GPIOB_TTLEN_TTLEN11_Pos)           /*!<GPIOB TTLEN: TTLEN11 Mask */

#define GPIOB_TTLEN_TTLEN12_Pos      12                                           /*!<GPIOB TTLEN: TTLEN12 Position */
#define GPIOB_TTLEN_TTLEN12_Msk      (0x1UL << GPIOB_TTLEN_TTLEN12_Pos)           /*!<GPIOB TTLEN: TTLEN12 Mask */

#define GPIOB_TTLEN_TTLEN13_Pos      13                                           /*!<GPIOB TTLEN: TTLEN13 Position */
#define GPIOB_TTLEN_TTLEN13_Msk      (0x1UL << GPIOB_TTLEN_TTLEN13_Pos)           /*!<GPIOB TTLEN: TTLEN13 Mask */

#define GPIOB_TTLEN_TTLEN14_Pos      14                                           /*!<GPIOB TTLEN: TTLEN14 Position */
#define GPIOB_TTLEN_TTLEN14_Msk      (0x1UL << GPIOB_TTLEN_TTLEN14_Pos)           /*!<GPIOB TTLEN: TTLEN14 Mask */

#define GPIOB_TTLEN_Msk_ALL          (GPIOB_TTLEN_TTLEN0_Msk       |\
                                      GPIOB_TTLEN_TTLEN1_Msk       |\
                                      GPIOB_TTLEN_TTLEN2_Msk       |\
                                      GPIOB_TTLEN_TTLEN6_Msk       |\
                                      GPIOB_TTLEN_TTLEN9_Msk       |\
                                      GPIOB_TTLEN_TTLEN11_Msk      |\
                                      GPIOB_TTLEN_TTLEN12_Msk      |\
                                      GPIOB_TTLEN_TTLEN13_Msk      |\
                                      GPIOB_TTLEN_TTLEN14_Msk      )

#define GPIOB_AFRL_AFR0_Pos          0                                            /*!<GPIOB AFRL: AFR0 Position */
#define GPIOB_AFRL_AFR0_Msk          (0x7UL /*<< GPIOB_AFRL_AFR0_Pos*/)           /*!<GPIOB AFRL: AFR0 Mask */

#define GPIOB_AFRL_AFR1_Pos          4                                            /*!<GPIOB AFRL: AFR1 Position */
#define GPIOB_AFRL_AFR1_Msk          (0x7UL << GPIOB_AFRL_AFR1_Pos)               /*!<GPIOB AFRL: AFR1 Mask */

#define GPIOB_AFRL_AFR2_Pos          8                                            /*!<GPIOB AFRL: AFR2 Position */
#define GPIOB_AFRL_AFR2_Msk          (0x7UL << GPIOB_AFRL_AFR2_Pos)               /*!<GPIOB AFRL: AFR2 Mask */

#define GPIOB_AFRL_AFR3_Pos          12                                           /*!<GPIOB AFRL: AFR3 Position */
#define GPIOB_AFRL_AFR3_Msk          (0x7UL << GPIOB_AFRL_AFR3_Pos)               /*!<GPIOB AFRL: AFR3 Mask */

#define GPIOB_AFRL_AFR4_Pos          16                                           /*!<GPIOB AFRL: AFR4 Position */
#define GPIOB_AFRL_AFR4_Msk          (0x7UL << GPIOB_AFRL_AFR4_Pos)               /*!<GPIOB AFRL: AFR4 Mask */

#define GPIOB_AFRL_AFR5_Pos          20                                           /*!<GPIOB AFRL: AFR5 Position */
#define GPIOB_AFRL_AFR5_Msk          (0x7UL << GPIOB_AFRL_AFR5_Pos)               /*!<GPIOB AFRL: AFR5 Mask */

#define GPIOB_AFRL_AFR6_Pos          24                                           /*!<GPIOB AFRL: AFR6 Position */
#define GPIOB_AFRL_AFR6_Msk          (0x7UL << GPIOB_AFRL_AFR6_Pos)               /*!<GPIOB AFRL: AFR6 Mask */

#define GPIOB_AFRL_AFR7_Pos          28                                           /*!<GPIOB AFRL: AFR7 Position */
#define GPIOB_AFRL_AFR7_Msk          (0x7UL << GPIOB_AFRL_AFR7_Pos)               /*!<GPIOB AFRL: AFR7 Mask */

#define GPIOB_AFRL_Msk_ALL           (GPIOB_AFRL_AFR0_Msk          |\
                                      GPIOB_AFRL_AFR1_Msk          |\
                                      GPIOB_AFRL_AFR2_Msk          |\
                                      GPIOB_AFRL_AFR3_Msk          |\
                                      GPIOB_AFRL_AFR4_Msk          |\
                                      GPIOB_AFRL_AFR5_Msk          |\
                                      GPIOB_AFRL_AFR6_Msk          |\
                                      GPIOB_AFRL_AFR7_Msk          )

#define GPIOB_AFRH_AFR8_Pos          0                                            /*!<GPIOB AFRH: AFR8 Position */
#define GPIOB_AFRH_AFR8_Msk          (0x7UL /*<< GPIOB_AFRH_AFR8_Pos*/)           /*!<GPIOB AFRH: AFR8 Mask */

#define GPIOB_AFRH_AFR9_Pos          4                                            /*!<GPIOB AFRH: AFR9 Position */
#define GPIOB_AFRH_AFR9_Msk          (0x7UL << GPIOB_AFRH_AFR9_Pos)               /*!<GPIOB AFRH: AFR9 Mask */

#define GPIOB_AFRH_AFR10_Pos         8                                            /*!<GPIOB AFRH: AFR10 Position */
#define GPIOB_AFRH_AFR10_Msk         (0x7UL << GPIOB_AFRH_AFR10_Pos)              /*!<GPIOB AFRH: AFR10 Mask */

#define GPIOB_AFRH_AFR11_Pos         12                                           /*!<GPIOB AFRH: AFR11 Position */
#define GPIOB_AFRH_AFR11_Msk         (0x7UL << GPIOB_AFRH_AFR11_Pos)              /*!<GPIOB AFRH: AFR11 Mask */

#define GPIOB_AFRH_AFR12_Pos         16                                           /*!<GPIOB AFRH: AFR12 Position */
#define GPIOB_AFRH_AFR12_Msk         (0x7UL << GPIOB_AFRH_AFR12_Pos)              /*!<GPIOB AFRH: AFR12 Mask */

#define GPIOB_AFRH_AFR13_Pos         20                                           /*!<GPIOB AFRH: AFR13 Position */
#define GPIOB_AFRH_AFR13_Msk         (0x7UL << GPIOB_AFRH_AFR13_Pos)              /*!<GPIOB AFRH: AFR13 Mask */

#define GPIOB_AFRH_AFR14_Pos         24                                           /*!<GPIOB AFRH: AFR14 Position */
#define GPIOB_AFRH_AFR14_Msk         (0x7UL << GPIOB_AFRH_AFR14_Pos)              /*!<GPIOB AFRH: AFR14 Mask */

#define GPIOB_AFRH_AFR15_Pos         28                                           /*!<GPIOB AFRH: AFR15 Position */
#define GPIOB_AFRH_AFR15_Msk         (0x7UL << GPIOB_AFRH_AFR15_Pos)              /*!<GPIOB AFRH: AFR15 Mask */

#define GPIOB_AFRH_Msk_ALL           (GPIOB_AFRH_AFR8_Msk          |\
                                      GPIOB_AFRH_AFR9_Msk          |\
                                      GPIOB_AFRH_AFR10_Msk         |\
                                      GPIOB_AFRH_AFR11_Msk         |\
                                      GPIOB_AFRH_AFR12_Msk         |\
                                      GPIOB_AFRH_AFR13_Msk         |\
                                      GPIOB_AFRH_AFR14_Msk         |\
                                      GPIOB_AFRH_AFR15_Msk         )

#define GPIOC_MODER_MODER0_Pos       0                                            /*!<GPIOC MODER: MODER0 Position */
#define GPIOC_MODER_MODER0_Msk       (0x1UL /*<< GPIOC_MODER_MODER0_Pos*/)        /*!<GPIOC MODER: MODER0 Mask */

#define GPIOC_MODER_MODER1_Pos       1                                            /*!<GPIOC MODER: MODER1 Position */
#define GPIOC_MODER_MODER1_Msk       (0x1UL << GPIOC_MODER_MODER1_Pos)            /*!<GPIOC MODER: MODER1 Mask */

#define GPIOC_MODER_MODER2_Pos       2                                            /*!<GPIOC MODER: MODER2 Position */
#define GPIOC_MODER_MODER2_Msk       (0x1UL << GPIOC_MODER_MODER2_Pos)            /*!<GPIOC MODER: MODER2 Mask */

#define GPIOC_MODER_MODER3_Pos       3                                            /*!<GPIOC MODER: MODER3 Position */
#define GPIOC_MODER_MODER3_Msk       (0x1UL << GPIOC_MODER_MODER3_Pos)            /*!<GPIOC MODER: MODER3 Mask */

#define GPIOC_MODER_MODER4_Pos       4                                            /*!<GPIOC MODER: MODER4 Position */
#define GPIOC_MODER_MODER4_Msk       (0x1UL << GPIOC_MODER_MODER4_Pos)            /*!<GPIOC MODER: MODER4 Mask */

#define GPIOC_MODER_MODER5_Pos       5                                            /*!<GPIOC MODER: MODER5 Position */
#define GPIOC_MODER_MODER5_Msk       (0x1UL << GPIOC_MODER_MODER5_Pos)            /*!<GPIOC MODER: MODER5 Mask */

#define GPIOC_MODER_MODER6_Pos       6                                            /*!<GPIOC MODER: MODER6 Position */
#define GPIOC_MODER_MODER6_Msk       (0x1UL << GPIOC_MODER_MODER6_Pos)            /*!<GPIOC MODER: MODER6 Mask */

#define GPIOC_MODER_MODER7_Pos       7                                            /*!<GPIOC MODER: MODER7 Position */
#define GPIOC_MODER_MODER7_Msk       (0x1UL << GPIOC_MODER_MODER7_Pos)            /*!<GPIOC MODER: MODER7 Mask */

#define GPIOC_MODER_MODER8_Pos       8                                            /*!<GPIOC MODER: MODER8 Position */
#define GPIOC_MODER_MODER8_Msk       (0x1UL << GPIOC_MODER_MODER8_Pos)            /*!<GPIOC MODER: MODER8 Mask */

#define GPIOC_MODER_MODER9_Pos       9                                            /*!<GPIOC MODER: MODER9 Position */
#define GPIOC_MODER_MODER9_Msk       (0x1UL << GPIOC_MODER_MODER9_Pos)            /*!<GPIOC MODER: MODER9 Mask */

#define GPIOC_MODER_MODER10_Pos      10                                           /*!<GPIOC MODER: MODER10 Position */
#define GPIOC_MODER_MODER10_Msk      (0x1UL << GPIOC_MODER_MODER10_Pos)           /*!<GPIOC MODER: MODER10 Mask */

#define GPIOC_MODER_MODER11_Pos      11                                           /*!<GPIOC MODER: MODER11 Position */
#define GPIOC_MODER_MODER11_Msk      (0x1UL << GPIOC_MODER_MODER11_Pos)           /*!<GPIOC MODER: MODER11 Mask */

#define GPIOC_MODER_MODER12_Pos      12                                           /*!<GPIOC MODER: MODER12 Position */
#define GPIOC_MODER_MODER12_Msk      (0x1UL << GPIOC_MODER_MODER12_Pos)           /*!<GPIOC MODER: MODER12 Mask */

#define GPIOC_MODER_MODER13_Pos      13                                           /*!<GPIOC MODER: MODER13 Position */
#define GPIOC_MODER_MODER13_Msk      (0x1UL << GPIOC_MODER_MODER13_Pos)           /*!<GPIOC MODER: MODER13 Mask */

#define GPIOC_MODER_MODER14_Pos      14                                           /*!<GPIOC MODER: MODER14 Position */
#define GPIOC_MODER_MODER14_Msk      (0x1UL << GPIOC_MODER_MODER14_Pos)           /*!<GPIOC MODER: MODER14 Mask */

#define GPIOC_MODER_MODER15_Pos      15                                           /*!<GPIOC MODER: MODER15 Position */
#define GPIOC_MODER_MODER15_Msk      (0x1UL << GPIOC_MODER_MODER15_Pos)           /*!<GPIOC MODER: MODER15 Mask */

#define GPIOC_MODER_Msk_ALL          (GPIOC_MODER_MODER0_Msk       |\
                                      GPIOC_MODER_MODER1_Msk       |\
                                      GPIOC_MODER_MODER2_Msk       |\
                                      GPIOC_MODER_MODER3_Msk       |\
                                      GPIOC_MODER_MODER4_Msk       |\
                                      GPIOC_MODER_MODER5_Msk       |\
                                      GPIOC_MODER_MODER6_Msk       |\
                                      GPIOC_MODER_MODER7_Msk       |\
                                      GPIOC_MODER_MODER8_Msk       |\
                                      GPIOC_MODER_MODER9_Msk       |\
                                      GPIOC_MODER_MODER10_Msk      |\
                                      GPIOC_MODER_MODER11_Msk      |\
                                      GPIOC_MODER_MODER12_Msk      |\
                                      GPIOC_MODER_MODER13_Msk      |\
                                      GPIOC_MODER_MODER14_Msk      |\
                                      GPIOC_MODER_MODER15_Msk      )

#define GPIOC_IDR_IDR_Pos            0                                            /*!<GPIOC IDR: IDR Position */
#define GPIOC_IDR_IDR_Msk            (0xFFFFUL /*<< GPIOC_IDR_IDR_Pos*/)          /*!<GPIOC IDR: IDR Mask */

#define GPIOC_IDR_Msk_ALL            (GPIOC_IDR_IDR_Msk           )

#define GPIOC_ODR_ODR_Pos            0                                            /*!<GPIOC ODR: ODR Position */
#define GPIOC_ODR_ODR_Msk            (0xFFFFUL /*<< GPIOC_ODR_ODR_Pos*/)          /*!<GPIOC ODR: ODR Mask */

#define GPIOC_ODR_Msk_ALL            (GPIOC_ODR_ODR_Msk           )

#define GPIOC_BSRR_BS_Pos            0                                            /*!<GPIOC BSRR: BS Position */
#define GPIOC_BSRR_BS_Msk            (0xFFFFUL /*<< GPIOC_BSRR_BS_Pos*/)          /*!<GPIOC BSRR: BS Mask */

#define GPIOC_BSRR_BR_Pos            16                                           /*!<GPIOC BSRR: BR Position */
#define GPIOC_BSRR_BR_Msk            (0xFFFFUL << GPIOC_BSRR_BR_Pos)              /*!<GPIOC BSRR: BR Mask */

#define GPIOC_BSRR_Msk_ALL           (GPIOC_BSRR_BS_Msk            |\
                                      GPIOC_BSRR_BR_Msk            )

#define GPIOC_LCKR_LCK0_Pos          0                                            /*!<GPIOC LCKR: LCK0 Position */
#define GPIOC_LCKR_LCK0_Msk          (0x1UL /*<< GPIOC_LCKR_LCK0_Pos*/)           /*!<GPIOC LCKR: LCK0 Mask */

#define GPIOC_LCKR_LCK1_Pos          1                                            /*!<GPIOC LCKR: LCK1 Position */
#define GPIOC_LCKR_LCK1_Msk          (0x1UL << GPIOC_LCKR_LCK1_Pos)               /*!<GPIOC LCKR: LCK1 Mask */

#define GPIOC_LCKR_LCK2_Pos          2                                            /*!<GPIOC LCKR: LCK2 Position */
#define GPIOC_LCKR_LCK2_Msk          (0x1UL << GPIOC_LCKR_LCK2_Pos)               /*!<GPIOC LCKR: LCK2 Mask */

#define GPIOC_LCKR_LCK3_Pos          3                                            /*!<GPIOC LCKR: LCK3 Position */
#define GPIOC_LCKR_LCK3_Msk          (0x1UL << GPIOC_LCKR_LCK3_Pos)               /*!<GPIOC LCKR: LCK3 Mask */

#define GPIOC_LCKR_LCK4_Pos          4                                            /*!<GPIOC LCKR: LCK4 Position */
#define GPIOC_LCKR_LCK4_Msk          (0x1UL << GPIOC_LCKR_LCK4_Pos)               /*!<GPIOC LCKR: LCK4 Mask */

#define GPIOC_LCKR_LCK5_Pos          5                                            /*!<GPIOC LCKR: LCK5 Position */
#define GPIOC_LCKR_LCK5_Msk          (0x1UL << GPIOC_LCKR_LCK5_Pos)               /*!<GPIOC LCKR: LCK5 Mask */

#define GPIOC_LCKR_LCK6_Pos          6                                            /*!<GPIOC LCKR: LCK6 Position */
#define GPIOC_LCKR_LCK6_Msk          (0x1UL << GPIOC_LCKR_LCK6_Pos)               /*!<GPIOC LCKR: LCK6 Mask */

#define GPIOC_LCKR_LCK7_Pos          7                                            /*!<GPIOC LCKR: LCK7 Position */
#define GPIOC_LCKR_LCK7_Msk          (0x1UL << GPIOC_LCKR_LCK7_Pos)               /*!<GPIOC LCKR: LCK7 Mask */

#define GPIOC_LCKR_LCK8_Pos          8                                            /*!<GPIOC LCKR: LCK8 Position */
#define GPIOC_LCKR_LCK8_Msk          (0x1UL << GPIOC_LCKR_LCK8_Pos)               /*!<GPIOC LCKR: LCK8 Mask */

#define GPIOC_LCKR_LCK9_Pos          9                                            /*!<GPIOC LCKR: LCK9 Position */
#define GPIOC_LCKR_LCK9_Msk          (0x1UL << GPIOC_LCKR_LCK9_Pos)               /*!<GPIOC LCKR: LCK9 Mask */

#define GPIOC_LCKR_LCK10_Pos         10                                           /*!<GPIOC LCKR: LCK10 Position */
#define GPIOC_LCKR_LCK10_Msk         (0x1UL << GPIOC_LCKR_LCK10_Pos)              /*!<GPIOC LCKR: LCK10 Mask */

#define GPIOC_LCKR_LCK11_Pos         11                                           /*!<GPIOC LCKR: LCK11 Position */
#define GPIOC_LCKR_LCK11_Msk         (0x1UL << GPIOC_LCKR_LCK11_Pos)              /*!<GPIOC LCKR: LCK11 Mask */

#define GPIOC_LCKR_LCK12_Pos         12                                           /*!<GPIOC LCKR: LCK12 Position */
#define GPIOC_LCKR_LCK12_Msk         (0x1UL << GPIOC_LCKR_LCK12_Pos)              /*!<GPIOC LCKR: LCK12 Mask */

#define GPIOC_LCKR_LCK13_Pos         13                                           /*!<GPIOC LCKR: LCK13 Position */
#define GPIOC_LCKR_LCK13_Msk         (0x1UL << GPIOC_LCKR_LCK13_Pos)              /*!<GPIOC LCKR: LCK13 Mask */

#define GPIOC_LCKR_LCK14_Pos         14                                           /*!<GPIOC LCKR: LCK14 Position */
#define GPIOC_LCKR_LCK14_Msk         (0x1UL << GPIOC_LCKR_LCK14_Pos)              /*!<GPIOC LCKR: LCK14 Mask */

#define GPIOC_LCKR_LCK15_Pos         15                                           /*!<GPIOC LCKR: LCK15 Position */
#define GPIOC_LCKR_LCK15_Msk         (0x1UL << GPIOC_LCKR_LCK15_Pos)              /*!<GPIOC LCKR: LCK15 Mask */

#define GPIOC_LCKR_LOCK_Pos          16                                           /*!<GPIOC LCKR: LOCK Position */
#define GPIOC_LCKR_LOCK_Msk          (0xFFFFUL << GPIOC_LCKR_LOCK_Pos)            /*!<GPIOC LCKR: LOCK Mask */

#define GPIOC_LCKR_Msk_ALL           (GPIOC_LCKR_LCK0_Msk          |\
                                      GPIOC_LCKR_LCK1_Msk          |\
                                      GPIOC_LCKR_LCK2_Msk          |\
                                      GPIOC_LCKR_LCK3_Msk          |\
                                      GPIOC_LCKR_LCK4_Msk          |\
                                      GPIOC_LCKR_LCK5_Msk          |\
                                      GPIOC_LCKR_LCK6_Msk          |\
                                      GPIOC_LCKR_LCK7_Msk          |\
                                      GPIOC_LCKR_LCK8_Msk          |\
                                      GPIOC_LCKR_LCK9_Msk          |\
                                      GPIOC_LCKR_LCK10_Msk         |\
                                      GPIOC_LCKR_LCK11_Msk         |\
                                      GPIOC_LCKR_LCK12_Msk         |\
                                      GPIOC_LCKR_LCK13_Msk         |\
                                      GPIOC_LCKR_LCK14_Msk         |\
                                      GPIOC_LCKR_LCK15_Msk         |\
                                      GPIOC_LCKR_LOCK_Msk          )

#define GPIOC_IE_IE0_Pos             0                                            /*!<GPIOC IE: IE0 Position */
#define GPIOC_IE_IE0_Msk             (0x1UL /*<< GPIOC_IE_IE0_Pos*/)              /*!<GPIOC IE: IE0 Mask */

#define GPIOC_IE_IE1_Pos             1                                            /*!<GPIOC IE: IE1 Position */
#define GPIOC_IE_IE1_Msk             (0x1UL << GPIOC_IE_IE1_Pos)                  /*!<GPIOC IE: IE1 Mask */

#define GPIOC_IE_IE2_Pos             2                                            /*!<GPIOC IE: IE2 Position */
#define GPIOC_IE_IE2_Msk             (0x1UL << GPIOC_IE_IE2_Pos)                  /*!<GPIOC IE: IE2 Mask */

#define GPIOC_IE_IE3_Pos             3                                            /*!<GPIOC IE: IE3 Position */
#define GPIOC_IE_IE3_Msk             (0x1UL << GPIOC_IE_IE3_Pos)                  /*!<GPIOC IE: IE3 Mask */

#define GPIOC_IE_IE4_Pos             4                                            /*!<GPIOC IE: IE4 Position */
#define GPIOC_IE_IE4_Msk             (0x1UL << GPIOC_IE_IE4_Pos)                  /*!<GPIOC IE: IE4 Mask */

#define GPIOC_IE_IE5_Pos             5                                            /*!<GPIOC IE: IE5 Position */
#define GPIOC_IE_IE5_Msk             (0x1UL << GPIOC_IE_IE5_Pos)                  /*!<GPIOC IE: IE5 Mask */

#define GPIOC_IE_IE6_Pos             6                                            /*!<GPIOC IE: IE6 Position */
#define GPIOC_IE_IE6_Msk             (0x1UL << GPIOC_IE_IE6_Pos)                  /*!<GPIOC IE: IE6 Mask */

#define GPIOC_IE_IE7_Pos             7                                            /*!<GPIOC IE: IE7 Position */
#define GPIOC_IE_IE7_Msk             (0x1UL << GPIOC_IE_IE7_Pos)                  /*!<GPIOC IE: IE7 Mask */

#define GPIOC_IE_IE8_Pos             8                                            /*!<GPIOC IE: IE8 Position */
#define GPIOC_IE_IE8_Msk             (0x1UL << GPIOC_IE_IE8_Pos)                  /*!<GPIOC IE: IE8 Mask */

#define GPIOC_IE_IE9_Pos             9                                            /*!<GPIOC IE: IE9 Position */
#define GPIOC_IE_IE9_Msk             (0x1UL << GPIOC_IE_IE9_Pos)                  /*!<GPIOC IE: IE9 Mask */

#define GPIOC_IE_IE10_Pos            10                                           /*!<GPIOC IE: IE10 Position */
#define GPIOC_IE_IE10_Msk            (0x1UL << GPIOC_IE_IE10_Pos)                 /*!<GPIOC IE: IE10 Mask */

#define GPIOC_IE_IE11_Pos            11                                           /*!<GPIOC IE: IE11 Position */
#define GPIOC_IE_IE11_Msk            (0x1UL << GPIOC_IE_IE11_Pos)                 /*!<GPIOC IE: IE11 Mask */

#define GPIOC_IE_IE12_Pos            12                                           /*!<GPIOC IE: IE12 Position */
#define GPIOC_IE_IE12_Msk            (0x1UL << GPIOC_IE_IE12_Pos)                 /*!<GPIOC IE: IE12 Mask */

#define GPIOC_IE_IE13_Pos            13                                           /*!<GPIOC IE: IE13 Position */
#define GPIOC_IE_IE13_Msk            (0x1UL << GPIOC_IE_IE13_Pos)                 /*!<GPIOC IE: IE13 Mask */

#define GPIOC_IE_IE14_Pos            14                                           /*!<GPIOC IE: IE14 Position */
#define GPIOC_IE_IE14_Msk            (0x1UL << GPIOC_IE_IE14_Pos)                 /*!<GPIOC IE: IE14 Mask */

#define GPIOC_IE_IE15_Pos            15                                           /*!<GPIOC IE: IE15 Position */
#define GPIOC_IE_IE15_Msk            (0x1UL << GPIOC_IE_IE15_Pos)                 /*!<GPIOC IE: IE15 Mask */

#define GPIOC_IE_Msk_ALL             (GPIOC_IE_IE0_Msk             |\
                                      GPIOC_IE_IE1_Msk             |\
                                      GPIOC_IE_IE2_Msk             |\
                                      GPIOC_IE_IE3_Msk             |\
                                      GPIOC_IE_IE4_Msk             |\
                                      GPIOC_IE_IE5_Msk             |\
                                      GPIOC_IE_IE6_Msk             |\
                                      GPIOC_IE_IE7_Msk             |\
                                      GPIOC_IE_IE8_Msk             |\
                                      GPIOC_IE_IE9_Msk             |\
                                      GPIOC_IE_IE10_Msk            |\
                                      GPIOC_IE_IE11_Msk            |\
                                      GPIOC_IE_IE12_Msk            |\
                                      GPIOC_IE_IE13_Msk            |\
                                      GPIOC_IE_IE14_Msk            |\
                                      GPIOC_IE_IE15_Msk            )

#define GPIOC_OTYPER_OT0_Pos         0                                            /*!<GPIOC OTYPER: OT0 Position */
#define GPIOC_OTYPER_OT0_Msk         (0x1UL /*<< GPIOC_OTYPER_OT0_Pos*/)          /*!<GPIOC OTYPER: OT0 Mask */

#define GPIOC_OTYPER_OT2_Pos         2                                            /*!<GPIOC OTYPER: OT2 Position */
#define GPIOC_OTYPER_OT2_Msk         (0x1UL << GPIOC_OTYPER_OT2_Pos)              /*!<GPIOC OTYPER: OT2 Mask */

#define GPIOC_OTYPER_OT13_Pos        13                                           /*!<GPIOC OTYPER: OT13 Position */
#define GPIOC_OTYPER_OT13_Msk        (0x1UL << GPIOC_OTYPER_OT13_Pos)             /*!<GPIOC OTYPER: OT13 Mask */

#define GPIOC_OTYPER_OT14_Pos        14                                           /*!<GPIOC OTYPER: OT14 Position */
#define GPIOC_OTYPER_OT14_Msk        (0x1UL << GPIOC_OTYPER_OT14_Pos)             /*!<GPIOC OTYPER: OT14 Mask */

#define GPIOC_OTYPER_Msk_ALL         (GPIOC_OTYPER_OT0_Msk         |\
                                      GPIOC_OTYPER_OT2_Msk         |\
                                      GPIOC_OTYPER_OT13_Msk        |\
                                      GPIOC_OTYPER_OT14_Msk        )

#define GPIOC_PUPDR_PHDR0_Pos        0                                            /*!<GPIOC PUPDR: PHDR0 Position */
#define GPIOC_PUPDR_PHDR0_Msk        (0x1UL /*<< GPIOC_PUPDR_PHDR0_Pos*/)         /*!<GPIOC PUPDR: PHDR0 Mask */

#define GPIOC_PUPDR_PHDR1_Pos        2                                            /*!<GPIOC PUPDR: PHDR1 Position */
#define GPIOC_PUPDR_PHDR1_Msk        (0x1UL << GPIOC_PUPDR_PHDR1_Pos)             /*!<GPIOC PUPDR: PHDR1 Mask */

#define GPIOC_PUPDR_PHDR2_Pos        4                                            /*!<GPIOC PUPDR: PHDR2 Position */
#define GPIOC_PUPDR_PHDR2_Msk        (0x1UL << GPIOC_PUPDR_PHDR2_Pos)             /*!<GPIOC PUPDR: PHDR2 Mask */

#define GPIOC_PUPDR_PHDR3_Pos        6                                            /*!<GPIOC PUPDR: PHDR3 Position */
#define GPIOC_PUPDR_PHDR3_Msk        (0x1UL << GPIOC_PUPDR_PHDR3_Pos)             /*!<GPIOC PUPDR: PHDR3 Mask */

#define GPIOC_PUPDR_PHDR4_Pos        8                                            /*!<GPIOC PUPDR: PHDR4 Position */
#define GPIOC_PUPDR_PHDR4_Msk        (0x1UL << GPIOC_PUPDR_PHDR4_Pos)             /*!<GPIOC PUPDR: PHDR4 Mask */

#define GPIOC_PUPDR_PHDR5_Pos        10                                           /*!<GPIOC PUPDR: PHDR5 Position */
#define GPIOC_PUPDR_PHDR5_Msk        (0x1UL << GPIOC_PUPDR_PHDR5_Pos)             /*!<GPIOC PUPDR: PHDR5 Mask */

#define GPIOC_PUPDR_PHDR6_Pos        12                                           /*!<GPIOC PUPDR: PHDR6 Position */
#define GPIOC_PUPDR_PHDR6_Msk        (0x1UL << GPIOC_PUPDR_PHDR6_Pos)             /*!<GPIOC PUPDR: PHDR6 Mask */

#define GPIOC_PUPDR_PHDR7_Pos        14                                           /*!<GPIOC PUPDR: PHDR7 Position */
#define GPIOC_PUPDR_PHDR7_Msk        (0x1UL << GPIOC_PUPDR_PHDR7_Pos)             /*!<GPIOC PUPDR: PHDR7 Mask */

#define GPIOC_PUPDR_PHDR8_Pos        16                                           /*!<GPIOC PUPDR: PHDR8 Position */
#define GPIOC_PUPDR_PHDR8_Msk        (0x1UL << GPIOC_PUPDR_PHDR8_Pos)             /*!<GPIOC PUPDR: PHDR8 Mask */

#define GPIOC_PUPDR_PHDR9_Pos        18                                           /*!<GPIOC PUPDR: PHDR9 Position */
#define GPIOC_PUPDR_PHDR9_Msk        (0x1UL << GPIOC_PUPDR_PHDR9_Pos)             /*!<GPIOC PUPDR: PHDR9 Mask */

#define GPIOC_PUPDR_PHDR10_Pos       20                                           /*!<GPIOC PUPDR: PHDR10 Position */
#define GPIOC_PUPDR_PHDR10_Msk       (0x1UL << GPIOC_PUPDR_PHDR10_Pos)            /*!<GPIOC PUPDR: PHDR10 Mask */

#define GPIOC_PUPDR_PHDR11_Pos       22                                           /*!<GPIOC PUPDR: PHDR11 Position */
#define GPIOC_PUPDR_PHDR11_Msk       (0x1UL << GPIOC_PUPDR_PHDR11_Pos)            /*!<GPIOC PUPDR: PHDR11 Mask */

#define GPIOC_PUPDR_PHDR12_Pos       24                                           /*!<GPIOC PUPDR: PHDR12 Position */
#define GPIOC_PUPDR_PHDR12_Msk       (0x1UL << GPIOC_PUPDR_PHDR12_Pos)            /*!<GPIOC PUPDR: PHDR12 Mask */

#define GPIOC_PUPDR_PHDR13_Pos       26                                           /*!<GPIOC PUPDR: PHDR13 Position */
#define GPIOC_PUPDR_PHDR13_Msk       (0x1UL << GPIOC_PUPDR_PHDR13_Pos)            /*!<GPIOC PUPDR: PHDR13 Mask */

#define GPIOC_PUPDR_PHDR14_Pos       28                                           /*!<GPIOC PUPDR: PHDR14 Position */
#define GPIOC_PUPDR_PHDR14_Msk       (0x1UL << GPIOC_PUPDR_PHDR14_Pos)            /*!<GPIOC PUPDR: PHDR14 Mask */

#define GPIOC_PUPDR_PHDR15_Pos       30                                           /*!<GPIOC PUPDR: PHDR15 Position */
#define GPIOC_PUPDR_PHDR15_Msk       (0x1UL << GPIOC_PUPDR_PHDR15_Pos)            /*!<GPIOC PUPDR: PHDR15 Mask */

#define GPIOC_PUPDR_Msk_ALL          (GPIOC_PUPDR_PHDR0_Msk        |\
                                      GPIOC_PUPDR_PHDR1_Msk        |\
                                      GPIOC_PUPDR_PHDR2_Msk        |\
                                      GPIOC_PUPDR_PHDR3_Msk        |\
                                      GPIOC_PUPDR_PHDR4_Msk        |\
                                      GPIOC_PUPDR_PHDR5_Msk        |\
                                      GPIOC_PUPDR_PHDR6_Msk        |\
                                      GPIOC_PUPDR_PHDR7_Msk        |\
                                      GPIOC_PUPDR_PHDR8_Msk        |\
                                      GPIOC_PUPDR_PHDR9_Msk        |\
                                      GPIOC_PUPDR_PHDR10_Msk       |\
                                      GPIOC_PUPDR_PHDR11_Msk       |\
                                      GPIOC_PUPDR_PHDR12_Msk       |\
                                      GPIOC_PUPDR_PHDR13_Msk       |\
                                      GPIOC_PUPDR_PHDR14_Msk       |\
                                      GPIOC_PUPDR_PHDR15_Msk       )

#define GPIOC_TTLEN_TTLEN0_Pos       0                                            /*!<GPIOC TTLEN: TTLEN0 Position */
#define GPIOC_TTLEN_TTLEN0_Msk       (0x1UL /*<< GPIOC_TTLEN_TTLEN0_Pos*/)        /*!<GPIOC TTLEN: TTLEN0 Mask */

#define GPIOC_TTLEN_TTLEN1_Pos       1                                            /*!<GPIOC TTLEN: TTLEN1 Position */
#define GPIOC_TTLEN_TTLEN1_Msk       (0x1UL << GPIOC_TTLEN_TTLEN1_Pos)            /*!<GPIOC TTLEN: TTLEN1 Mask */

#define GPIOC_TTLEN_TTLEN2_Pos       2                                            /*!<GPIOC TTLEN: TTLEN2 Position */
#define GPIOC_TTLEN_TTLEN2_Msk       (0x1UL << GPIOC_TTLEN_TTLEN2_Pos)            /*!<GPIOC TTLEN: TTLEN2 Mask */

#define GPIOC_TTLEN_TTLEN6_Pos       6                                            /*!<GPIOC TTLEN: TTLEN6 Position */
#define GPIOC_TTLEN_TTLEN6_Msk       (0x1UL << GPIOC_TTLEN_TTLEN6_Pos)            /*!<GPIOC TTLEN: TTLEN6 Mask */

#define GPIOC_TTLEN_TTLEN9_Pos       9                                            /*!<GPIOC TTLEN: TTLEN9 Position */
#define GPIOC_TTLEN_TTLEN9_Msk       (0x1UL << GPIOC_TTLEN_TTLEN9_Pos)            /*!<GPIOC TTLEN: TTLEN9 Mask */

#define GPIOC_TTLEN_TTLEN11_Pos      11                                           /*!<GPIOC TTLEN: TTLEN11 Position */
#define GPIOC_TTLEN_TTLEN11_Msk      (0x1UL << GPIOC_TTLEN_TTLEN11_Pos)           /*!<GPIOC TTLEN: TTLEN11 Mask */

#define GPIOC_TTLEN_TTLEN12_Pos      12                                           /*!<GPIOC TTLEN: TTLEN12 Position */
#define GPIOC_TTLEN_TTLEN12_Msk      (0x1UL << GPIOC_TTLEN_TTLEN12_Pos)           /*!<GPIOC TTLEN: TTLEN12 Mask */

#define GPIOC_TTLEN_TTLEN13_Pos      13                                           /*!<GPIOC TTLEN: TTLEN13 Position */
#define GPIOC_TTLEN_TTLEN13_Msk      (0x1UL << GPIOC_TTLEN_TTLEN13_Pos)           /*!<GPIOC TTLEN: TTLEN13 Mask */

#define GPIOC_TTLEN_TTLEN14_Pos      14                                           /*!<GPIOC TTLEN: TTLEN14 Position */
#define GPIOC_TTLEN_TTLEN14_Msk      (0x1UL << GPIOC_TTLEN_TTLEN14_Pos)           /*!<GPIOC TTLEN: TTLEN14 Mask */

#define GPIOC_TTLEN_Msk_ALL          (GPIOC_TTLEN_TTLEN0_Msk       |\
                                      GPIOC_TTLEN_TTLEN1_Msk       |\
                                      GPIOC_TTLEN_TTLEN2_Msk       |\
                                      GPIOC_TTLEN_TTLEN6_Msk       |\
                                      GPIOC_TTLEN_TTLEN9_Msk       |\
                                      GPIOC_TTLEN_TTLEN11_Msk      |\
                                      GPIOC_TTLEN_TTLEN12_Msk      |\
                                      GPIOC_TTLEN_TTLEN13_Msk      |\
                                      GPIOC_TTLEN_TTLEN14_Msk      )

#define GPIOC_AFRL_AFR0_Pos          0                                            /*!<GPIOC AFRL: AFR0 Position */
#define GPIOC_AFRL_AFR0_Msk          (0x7UL /*<< GPIOC_AFRL_AFR0_Pos*/)           /*!<GPIOC AFRL: AFR0 Mask */

#define GPIOC_AFRL_AFR1_Pos          4                                            /*!<GPIOC AFRL: AFR1 Position */
#define GPIOC_AFRL_AFR1_Msk          (0x7UL << GPIOC_AFRL_AFR1_Pos)               /*!<GPIOC AFRL: AFR1 Mask */

#define GPIOC_AFRL_AFR2_Pos          8                                            /*!<GPIOC AFRL: AFR2 Position */
#define GPIOC_AFRL_AFR2_Msk          (0x7UL << GPIOC_AFRL_AFR2_Pos)               /*!<GPIOC AFRL: AFR2 Mask */

#define GPIOC_AFRL_AFR3_Pos          12                                           /*!<GPIOC AFRL: AFR3 Position */
#define GPIOC_AFRL_AFR3_Msk          (0x7UL << GPIOC_AFRL_AFR3_Pos)               /*!<GPIOC AFRL: AFR3 Mask */

#define GPIOC_AFRL_AFR4_Pos          16                                           /*!<GPIOC AFRL: AFR4 Position */
#define GPIOC_AFRL_AFR4_Msk          (0x7UL << GPIOC_AFRL_AFR4_Pos)               /*!<GPIOC AFRL: AFR4 Mask */

#define GPIOC_AFRL_AFR5_Pos          20                                           /*!<GPIOC AFRL: AFR5 Position */
#define GPIOC_AFRL_AFR5_Msk          (0x7UL << GPIOC_AFRL_AFR5_Pos)               /*!<GPIOC AFRL: AFR5 Mask */

#define GPIOC_AFRL_AFR6_Pos          24                                           /*!<GPIOC AFRL: AFR6 Position */
#define GPIOC_AFRL_AFR6_Msk          (0x7UL << GPIOC_AFRL_AFR6_Pos)               /*!<GPIOC AFRL: AFR6 Mask */

#define GPIOC_AFRL_AFR7_Pos          28                                           /*!<GPIOC AFRL: AFR7 Position */
#define GPIOC_AFRL_AFR7_Msk          (0x7UL << GPIOC_AFRL_AFR7_Pos)               /*!<GPIOC AFRL: AFR7 Mask */

#define GPIOC_AFRL_Msk_ALL           (GPIOC_AFRL_AFR0_Msk          |\
                                      GPIOC_AFRL_AFR1_Msk          |\
                                      GPIOC_AFRL_AFR2_Msk          |\
                                      GPIOC_AFRL_AFR3_Msk          |\
                                      GPIOC_AFRL_AFR4_Msk          |\
                                      GPIOC_AFRL_AFR5_Msk          |\
                                      GPIOC_AFRL_AFR6_Msk          |\
                                      GPIOC_AFRL_AFR7_Msk          )

#define GPIOC_AFRH_AFR8_Pos          0                                            /*!<GPIOC AFRH: AFR8 Position */
#define GPIOC_AFRH_AFR8_Msk          (0x7UL /*<< GPIOC_AFRH_AFR8_Pos*/)           /*!<GPIOC AFRH: AFR8 Mask */

#define GPIOC_AFRH_AFR9_Pos          4                                            /*!<GPIOC AFRH: AFR9 Position */
#define GPIOC_AFRH_AFR9_Msk          (0x7UL << GPIOC_AFRH_AFR9_Pos)               /*!<GPIOC AFRH: AFR9 Mask */

#define GPIOC_AFRH_AFR10_Pos         8                                            /*!<GPIOC AFRH: AFR10 Position */
#define GPIOC_AFRH_AFR10_Msk         (0x7UL << GPIOC_AFRH_AFR10_Pos)              /*!<GPIOC AFRH: AFR10 Mask */

#define GPIOC_AFRH_AFR11_Pos         12                                           /*!<GPIOC AFRH: AFR11 Position */
#define GPIOC_AFRH_AFR11_Msk         (0x7UL << GPIOC_AFRH_AFR11_Pos)              /*!<GPIOC AFRH: AFR11 Mask */

#define GPIOC_AFRH_AFR12_Pos         16                                           /*!<GPIOC AFRH: AFR12 Position */
#define GPIOC_AFRH_AFR12_Msk         (0x7UL << GPIOC_AFRH_AFR12_Pos)              /*!<GPIOC AFRH: AFR12 Mask */

#define GPIOC_AFRH_AFR13_Pos         20                                           /*!<GPIOC AFRH: AFR13 Position */
#define GPIOC_AFRH_AFR13_Msk         (0x7UL << GPIOC_AFRH_AFR13_Pos)              /*!<GPIOC AFRH: AFR13 Mask */

#define GPIOC_AFRH_AFR14_Pos         24                                           /*!<GPIOC AFRH: AFR14 Position */
#define GPIOC_AFRH_AFR14_Msk         (0x7UL << GPIOC_AFRH_AFR14_Pos)              /*!<GPIOC AFRH: AFR14 Mask */

#define GPIOC_AFRH_AFR15_Pos         28                                           /*!<GPIOC AFRH: AFR15 Position */
#define GPIOC_AFRH_AFR15_Msk         (0x7UL << GPIOC_AFRH_AFR15_Pos)              /*!<GPIOC AFRH: AFR15 Mask */

#define GPIOC_AFRH_Msk_ALL           (GPIOC_AFRH_AFR8_Msk          |\
                                      GPIOC_AFRH_AFR9_Msk          |\
                                      GPIOC_AFRH_AFR10_Msk         |\
                                      GPIOC_AFRH_AFR11_Msk         |\
                                      GPIOC_AFRH_AFR12_Msk         |\
                                      GPIOC_AFRH_AFR13_Msk         |\
                                      GPIOC_AFRH_AFR14_Msk         |\
                                      GPIOC_AFRH_AFR15_Msk         )

#define EXTI_IMR_IMR_Pos             0                                            /*!<EXTI IMR: IMR Position */
#define EXTI_IMR_IMR_Msk             (0xFFUL /*<< EXTI_IMR_IMR_Pos*/)             /*!<EXTI IMR: IMR Mask */

#define EXTI_IMR_Msk_ALL             (EXTI_IMR_IMR_Msk            )

#define EXTI_EMR_EMR_Pos             0                                            /*!<EXTI EMR: EMR Position */
#define EXTI_EMR_EMR_Msk             (0xFFUL /*<< EXTI_EMR_EMR_Pos*/)             /*!<EXTI EMR: EMR Mask */

#define EXTI_EMR_Msk_ALL             (EXTI_EMR_EMR_Msk            )

#define EXTI_TMSR_TMR_Pos            0                                            /*!<EXTI TMSR: TMR Position */
#define EXTI_TMSR_TMR_Msk            (0xFFUL /*<< EXTI_TMSR_TMR_Pos*/)            /*!<EXTI TMSR: TMR Mask */

#define EXTI_TMSR_Msk_ALL            (EXTI_TMSR_TMR_Msk           )

#define EXTI_RTSR_RTR_Pos            0                                            /*!<EXTI RTSR: RTR Position */
#define EXTI_RTSR_RTR_Msk            (0xFFUL /*<< EXTI_RTSR_RTR_Pos*/)            /*!<EXTI RTSR: RTR Mask */

#define EXTI_RTSR_Msk_ALL            (EXTI_RTSR_RTR_Msk           )

#define EXTI_FTSR_FTR_Pos            0                                            /*!<EXTI FTSR: FTR Position */
#define EXTI_FTSR_FTR_Msk            (0xFFUL /*<< EXTI_FTSR_FTR_Pos*/)            /*!<EXTI FTSR: FTR Mask */

#define EXTI_FTSR_Msk_ALL            (EXTI_FTSR_FTR_Msk           )

#define EXTI_SWIER_SWIER_Pos         0                                            /*!<EXTI SWIER: SWIER Position */
#define EXTI_SWIER_SWIER_Msk         (0xFFUL /*<< EXTI_SWIER_SWIER_Pos*/)         /*!<EXTI SWIER: SWIER Mask */

#define EXTI_SWIER_Msk_ALL           (EXTI_SWIER_SWIER_Msk        )

#define EXTI_PR_PR_Pos               0                                            /*!<EXTI PR: PR Position */
#define EXTI_PR_PR_Msk               (0xFFUL /*<< EXTI_PR_PR_Pos*/)               /*!<EXTI PR: PR Mask */

#define EXTI_PR_PRC_Pos              16                                           /*!<EXTI PR: PRC Position */
#define EXTI_PR_PRC_Msk              (0xFFUL << EXTI_PR_PRC_Pos)                  /*!<EXTI PR: PRC Mask */

#define EXTI_PR_Msk_ALL              (EXTI_PR_PR_Msk               |\
                                      EXTI_PR_PRC_Msk              )

#define EXTI_CFG_EXTI0_EN_Pos        0                                            /*!<EXTI CFG: EXTI0_EN Position */
#define EXTI_CFG_EXTI0_EN_Msk        (0x1UL /*<< EXTI_CFG_EXTI0_EN_Pos*/)         /*!<EXTI CFG: EXTI0_EN Mask */

#define EXTI_CFG_EXTI1_EN_Pos        1                                            /*!<EXTI CFG: EXTI1_EN Position */
#define EXTI_CFG_EXTI1_EN_Msk        (0x1UL << EXTI_CFG_EXTI1_EN_Pos)             /*!<EXTI CFG: EXTI1_EN Mask */

#define EXTI_CFG_EXTI2_EN_Pos        2                                            /*!<EXTI CFG: EXTI2_EN Position */
#define EXTI_CFG_EXTI2_EN_Msk        (0x1UL << EXTI_CFG_EXTI2_EN_Pos)             /*!<EXTI CFG: EXTI2_EN Mask */

#define EXTI_CFG_EXTI3_EN_Pos        3                                            /*!<EXTI CFG: EXTI3_EN Position */
#define EXTI_CFG_EXTI3_EN_Msk        (0x1UL << EXTI_CFG_EXTI3_EN_Pos)             /*!<EXTI CFG: EXTI3_EN Mask */

#define EXTI_CFG_EXTI4_EN_Pos        4                                            /*!<EXTI CFG: EXTI4_EN Position */
#define EXTI_CFG_EXTI4_EN_Msk        (0x1UL << EXTI_CFG_EXTI4_EN_Pos)             /*!<EXTI CFG: EXTI4_EN Mask */

#define EXTI_CFG_EXTI5_EN_Pos        5                                            /*!<EXTI CFG: EXTI5_EN Position */
#define EXTI_CFG_EXTI5_EN_Msk        (0x1UL << EXTI_CFG_EXTI5_EN_Pos)             /*!<EXTI CFG: EXTI5_EN Mask */

#define EXTI_CFG_EXTI6_EN_Pos        6                                            /*!<EXTI CFG: EXTI6_EN Position */
#define EXTI_CFG_EXTI6_EN_Msk        (0x1UL << EXTI_CFG_EXTI6_EN_Pos)             /*!<EXTI CFG: EXTI6_EN Mask */

#define EXTI_CFG_EXTI7_EN_Pos        7                                            /*!<EXTI CFG: EXTI7_EN Position */
#define EXTI_CFG_EXTI7_EN_Msk        (0x1UL << EXTI_CFG_EXTI7_EN_Pos)             /*!<EXTI CFG: EXTI7_EN Mask */

#define EXTI_CFG_Msk_ALL             (EXTI_CFG_EXTI0_EN_Msk        |\
                                      EXTI_CFG_EXTI1_EN_Msk        |\
                                      EXTI_CFG_EXTI2_EN_Msk        |\
                                      EXTI_CFG_EXTI3_EN_Msk        |\
                                      EXTI_CFG_EXTI4_EN_Msk        |\
                                      EXTI_CFG_EXTI5_EN_Msk        |\
                                      EXTI_CFG_EXTI6_EN_Msk        |\
                                      EXTI_CFG_EXTI7_EN_Msk        )

#define EXTI_SAMP_SN0_Pos            0                                            /*!<EXTI SAMP: SN0 Position */
#define EXTI_SAMP_SN0_Msk            (0x3UL /*<< EXTI_SAMP_SN0_Pos*/)             /*!<EXTI SAMP: SN0 Mask */

#define EXTI_SAMP_PS0_Pos            2                                            /*!<EXTI SAMP: PS0 Position */
#define EXTI_SAMP_PS0_Msk            (0x3UL << EXTI_SAMP_PS0_Pos)                 /*!<EXTI SAMP: PS0 Mask */

#define EXTI_SAMP_SN1_Pos            4                                            /*!<EXTI SAMP: SN1 Position */
#define EXTI_SAMP_SN1_Msk            (0x3UL << EXTI_SAMP_SN1_Pos)                 /*!<EXTI SAMP: SN1 Mask */

#define EXTI_SAMP_PS1_Pos            6                                            /*!<EXTI SAMP: PS1 Position */
#define EXTI_SAMP_PS1_Msk            (0x3UL << EXTI_SAMP_PS1_Pos)                 /*!<EXTI SAMP: PS1 Mask */

#define EXTI_SAMP_SN2_Pos            8                                            /*!<EXTI SAMP: SN2 Position */
#define EXTI_SAMP_SN2_Msk            (0x3UL << EXTI_SAMP_SN2_Pos)                 /*!<EXTI SAMP: SN2 Mask */

#define EXTI_SAMP_PS2_Pos            10                                           /*!<EXTI SAMP: PS2 Position */
#define EXTI_SAMP_PS2_Msk            (0x3UL << EXTI_SAMP_PS2_Pos)                 /*!<EXTI SAMP: PS2 Mask */

#define EXTI_SAMP_SN3_Pos            12                                           /*!<EXTI SAMP: SN3 Position */
#define EXTI_SAMP_SN3_Msk            (0x3UL << EXTI_SAMP_SN3_Pos)                 /*!<EXTI SAMP: SN3 Mask */

#define EXTI_SAMP_PS3_Pos            14                                           /*!<EXTI SAMP: PS3 Position */
#define EXTI_SAMP_PS3_Msk            (0x3UL << EXTI_SAMP_PS3_Pos)                 /*!<EXTI SAMP: PS3 Mask */

#define EXTI_SAMP_SN4_Pos            16                                           /*!<EXTI SAMP: SN4 Position */
#define EXTI_SAMP_SN4_Msk            (0x3UL << EXTI_SAMP_SN4_Pos)                 /*!<EXTI SAMP: SN4 Mask */

#define EXTI_SAMP_PS4_Pos            18                                           /*!<EXTI SAMP: PS4 Position */
#define EXTI_SAMP_PS4_Msk            (0x3UL << EXTI_SAMP_PS4_Pos)                 /*!<EXTI SAMP: PS4 Mask */

#define EXTI_SAMP_SN5_Pos            20                                           /*!<EXTI SAMP: SN5 Position */
#define EXTI_SAMP_SN5_Msk            (0x3UL << EXTI_SAMP_SN5_Pos)                 /*!<EXTI SAMP: SN5 Mask */

#define EXTI_SAMP_PS5_Pos            22                                           /*!<EXTI SAMP: PS5 Position */
#define EXTI_SAMP_PS5_Msk            (0x3UL << EXTI_SAMP_PS5_Pos)                 /*!<EXTI SAMP: PS5 Mask */

#define EXTI_SAMP_SN6_Pos            24                                           /*!<EXTI SAMP: SN6 Position */
#define EXTI_SAMP_SN6_Msk            (0x3UL << EXTI_SAMP_SN6_Pos)                 /*!<EXTI SAMP: SN6 Mask */

#define EXTI_SAMP_PS6_Pos            26                                           /*!<EXTI SAMP: PS6 Position */
#define EXTI_SAMP_PS6_Msk            (0x3UL << EXTI_SAMP_PS6_Pos)                 /*!<EXTI SAMP: PS6 Mask */

#define EXTI_SAMP_SN7_Pos            28                                           /*!<EXTI SAMP: SN7 Position */
#define EXTI_SAMP_SN7_Msk            (0x3UL << EXTI_SAMP_SN7_Pos)                 /*!<EXTI SAMP: SN7 Mask */

#define EXTI_SAMP_PS7_Pos            30                                           /*!<EXTI SAMP: PS7 Position */
#define EXTI_SAMP_PS7_Msk            (0x3UL << EXTI_SAMP_PS7_Pos)                 /*!<EXTI SAMP: PS7 Mask */

#define EXTI_SAMP_Msk_ALL            (EXTI_SAMP_SN0_Msk            |\
                                      EXTI_SAMP_PS0_Msk            |\
                                      EXTI_SAMP_SN1_Msk            |\
                                      EXTI_SAMP_PS1_Msk            |\
                                      EXTI_SAMP_SN2_Msk            |\
                                      EXTI_SAMP_PS2_Msk            |\
                                      EXTI_SAMP_SN3_Msk            |\
                                      EXTI_SAMP_PS3_Msk            |\
                                      EXTI_SAMP_SN4_Msk            |\
                                      EXTI_SAMP_PS4_Msk            |\
                                      EXTI_SAMP_SN5_Msk            |\
                                      EXTI_SAMP_PS5_Msk            |\
                                      EXTI_SAMP_SN6_Msk            |\
                                      EXTI_SAMP_PS6_Msk            |\
                                      EXTI_SAMP_SN7_Msk            |\
                                      EXTI_SAMP_PS7_Msk            )

#define MCM_PWMOE_PWMOE_Pos          0                                            /*!<MCM PWMOE: PWMOE Position */
#define MCM_PWMOE_PWMOE_Msk          (0x1UL /*<< MCM_PWMOE_PWMOE_Pos*/)           /*!<MCM PWMOE: PWMOE Mask */

#define MCM_PWMOE_Msk_ALL            (MCM_PWMOE_PWMOE_Msk         )

#define MCM_PWMCON1_PWM0S_Pos        0                                            /*!<MCM PWMCON1: PWM0S Position */
#define MCM_PWMCON1_PWM0S_Msk        (0x1UL /*<< MCM_PWMCON1_PWM0S_Pos*/)         /*!<MCM PWMCON1: PWM0S Mask */

#define MCM_PWMCON1_PWM1S_Pos        1                                            /*!<MCM PWMCON1: PWM1S Position */
#define MCM_PWMCON1_PWM1S_Msk        (0x1UL << MCM_PWMCON1_PWM1S_Pos)             /*!<MCM PWMCON1: PWM1S Mask */

#define MCM_PWMCON1_PWM2S_Pos        2                                            /*!<MCM PWMCON1: PWM2S Position */
#define MCM_PWMCON1_PWM2S_Msk        (0x1UL << MCM_PWMCON1_PWM2S_Pos)             /*!<MCM PWMCON1: PWM2S Mask */

#define MCM_PWMCON1_PWM01S_Pos       3                                            /*!<MCM PWMCON1: PWM01S Position */
#define MCM_PWMCON1_PWM01S_Msk       (0x1UL << MCM_PWMCON1_PWM01S_Pos)            /*!<MCM PWMCON1: PWM01S Mask */

#define MCM_PWMCON1_PWM11S_Pos       4                                            /*!<MCM PWMCON1: PWM11S Position */
#define MCM_PWMCON1_PWM11S_Msk       (0x1UL << MCM_PWMCON1_PWM11S_Pos)            /*!<MCM PWMCON1: PWM11S Mask */

#define MCM_PWMCON1_PWM21S_Pos       5                                            /*!<MCM PWMCON1: PWM21S Position */
#define MCM_PWMCON1_PWM21S_Msk       (0x1UL << MCM_PWMCON1_PWM21S_Pos)            /*!<MCM PWMCON1: PWM21S Mask */

#define MCM_PWMCON1_PDCON0_Pos       6                                            /*!<MCM PWMCON1: PDCON0 Position */
#define MCM_PWMCON1_PDCON0_Msk       (0x1UL << MCM_PWMCON1_PDCON0_Pos)            /*!<MCM PWMCON1: PDCON0 Mask */

#define MCM_PWMCON1_PDCON1_Pos       7                                            /*!<MCM PWMCON1: PDCON1 Position */
#define MCM_PWMCON1_PDCON1_Msk       (0x1UL << MCM_PWMCON1_PDCON1_Pos)            /*!<MCM PWMCON1: PDCON1 Mask */

#define MCM_PWMCON1_PDCON2_Pos       8                                            /*!<MCM PWMCON1: PDCON2 Position */
#define MCM_PWMCON1_PDCON2_Msk       (0x1UL << MCM_PWMCON1_PDCON2_Pos)            /*!<MCM PWMCON1: PDCON2 Mask */

#define MCM_PWMCON1_PWMSYM_Pos       9                                            /*!<MCM PWMCON1: PWMSYM Position */
#define MCM_PWMCON1_PWMSYM_Msk       (0x1UL << MCM_PWMCON1_PWMSYM_Pos)            /*!<MCM PWMCON1: PWMSYM Mask */

#define MCM_PWMCON1_PTMOD_Pos        10                                           /*!<MCM PWMCON1: PTMOD Position */
#define MCM_PWMCON1_PTMOD_Msk        (0x3UL << MCM_PWMCON1_PTMOD_Pos)             /*!<MCM PWMCON1: PTMOD Mask */

#define MCM_PWMCON1_POSTPS_Pos       12                                           /*!<MCM PWMCON1: POSTPS Position */
#define MCM_PWMCON1_POSTPS_Msk       (0x7UL << MCM_PWMCON1_POSTPS_Pos)            /*!<MCM PWMCON1: POSTPS Mask */

#define MCM_PWMCON1_POUTMOD_Pos      15                                           /*!<MCM PWMCON1: POUTMOD Position */
#define MCM_PWMCON1_POUTMOD_Msk      (0x1UL << MCM_PWMCON1_POUTMOD_Pos)           /*!<MCM PWMCON1: POUTMOD Mask */

#define MCM_PWMCON1_Msk_ALL          (MCM_PWMCON1_PWM0S_Msk        |\
                                      MCM_PWMCON1_PWM1S_Msk        |\
                                      MCM_PWMCON1_PWM2S_Msk        |\
                                      MCM_PWMCON1_PWM01S_Msk       |\
                                      MCM_PWMCON1_PWM11S_Msk       |\
                                      MCM_PWMCON1_PWM21S_Msk       |\
                                      MCM_PWMCON1_PDCON0_Msk       |\
                                      MCM_PWMCON1_PDCON1_Msk       |\
                                      MCM_PWMCON1_PDCON2_Msk       |\
                                      MCM_PWMCON1_PWMSYM_Msk       |\
                                      MCM_PWMCON1_PTMOD_Msk        |\
                                      MCM_PWMCON1_POSTPS_Msk       |\
                                      MCM_PWMCON1_POUTMOD_Msk      )

#define MCM_PWMCON2_CMP1_Pos         0                                            /*!<MCM PWMCON2: CMP1 Position */
#define MCM_PWMCON2_CMP1_Msk         (0x3UL /*<< MCM_PWMCON2_CMP1_Pos*/)          /*!<MCM PWMCON2: CMP1 Mask */

#define MCM_PWMCON2_CMP2_Pos         2                                            /*!<MCM PWMCON2: CMP2 Position */
#define MCM_PWMCON2_CMP2_Msk         (0x3UL << MCM_PWMCON2_CMP2_Pos)              /*!<MCM PWMCON2: CMP2 Mask */

#define MCM_PWMCON2_CMP3_Pos         4                                            /*!<MCM PWMCON2: CMP3 Position */
#define MCM_PWMCON2_CMP3_Msk         (0x3UL << MCM_PWMCON2_CMP3_Pos)              /*!<MCM PWMCON2: CMP3 Mask */

#define MCM_PWMCON2_CMP4_Pos         6                                            /*!<MCM PWMCON2: CMP4 Position */
#define MCM_PWMCON2_CMP4_Msk         (0x3UL << MCM_PWMCON2_CMP4_Pos)              /*!<MCM PWMCON2: CMP4 Mask */

#define MCM_PWMCON2_OSYNC_Pos        8                                            /*!<MCM PWMCON2: OSYNC Position */
#define MCM_PWMCON2_OSYNC_Msk        (0x1UL << MCM_PWMCON2_OSYNC_Pos)             /*!<MCM PWMCON2: OSYNC Mask */

#define MCM_PWMCON2_DILDEN_Pos       9                                            /*!<MCM PWMCON2: DILDEN Position */
#define MCM_PWMCON2_DILDEN_Msk       (0x1UL << MCM_PWMCON2_DILDEN_Pos)            /*!<MCM PWMCON2: DILDEN Mask */

#define MCM_PWMCON2_CILDEN_Pos       10                                           /*!<MCM PWMCON2: CILDEN Position */
#define MCM_PWMCON2_CILDEN_Msk       (0x1UL << MCM_PWMCON2_CILDEN_Pos)            /*!<MCM PWMCON2: CILDEN Mask */

#define MCM_PWMCON2_ZDLDEN_Pos       11                                           /*!<MCM PWMCON2: ZDLDEN Position */
#define MCM_PWMCON2_ZDLDEN_Msk       (0x1UL << MCM_PWMCON2_ZDLDEN_Pos)            /*!<MCM PWMCON2: ZDLDEN Mask */

#define MCM_PWMCON2_PDLDEN_Pos       12                                           /*!<MCM PWMCON2: PDLDEN Position */
#define MCM_PWMCON2_PDLDEN_Msk       (0x1UL << MCM_PWMCON2_PDLDEN_Pos)            /*!<MCM PWMCON2: PDLDEN Mask */

#define MCM_PWMCON2_ZCMLDEN_Pos      13                                           /*!<MCM PWMCON2: ZCMLDEN Position */
#define MCM_PWMCON2_ZCMLDEN_Msk      (0x1UL << MCM_PWMCON2_ZCMLDEN_Pos)           /*!<MCM PWMCON2: ZCMLDEN Mask */

#define MCM_PWMCON2_PCMLDEN_Pos      14                                           /*!<MCM PWMCON2: PCMLDEN Position */
#define MCM_PWMCON2_PCMLDEN_Msk      (0x1UL << MCM_PWMCON2_PCMLDEN_Pos)           /*!<MCM PWMCON2: PCMLDEN Mask */

#define MCM_PWMCON2_Msk_ALL          (MCM_PWMCON2_CMP1_Msk         |\
                                      MCM_PWMCON2_CMP2_Msk         |\
                                      MCM_PWMCON2_CMP3_Msk         |\
                                      MCM_PWMCON2_CMP4_Msk         |\
                                      MCM_PWMCON2_OSYNC_Msk        |\
                                      MCM_PWMCON2_DILDEN_Msk       |\
                                      MCM_PWMCON2_CILDEN_Msk       |\
                                      MCM_PWMCON2_ZDLDEN_Msk       |\
                                      MCM_PWMCON2_PDLDEN_Msk       |\
                                      MCM_PWMCON2_ZCMLDEN_Msk      |\
                                      MCM_PWMCON2_PCMLDEN_Msk      )

#define MCM_PWMP_PWMP_Pos            0                                            /*!<MCM PWMP: PWMP Position */
#define MCM_PWMP_PWMP_Msk            (0xFFFFUL /*<< MCM_PWMP_PWMP_Pos*/)          /*!<MCM PWMP: PWMP Mask */

#define MCM_PWMP_Msk_ALL             (MCM_PWMP_PWMP_Msk           )

#define MCM_PWMC_PWMC_Pos            0                                            /*!<MCM PWMC: PWMC Position */
#define MCM_PWMC_PWMC_Msk            (0xFFFFUL /*<< MCM_PWMC_PWMC_Pos*/)          /*!<MCM PWMC: PWMC Mask */

#define MCM_PWMC_Msk_ALL             (MCM_PWMC_PWMC_Msk           )

#define MCM_PWMPSQ_PWMPSQ_Pos        0                                            /*!<MCM PWMPSQ: PWMPSQ Position */
#define MCM_PWMPSQ_PWMPSQ_Msk        (0xFFFFUL /*<< MCM_PWMPSQ_PWMPSQ_Pos*/)      /*!<MCM PWMPSQ: PWMPSQ Mask */

#define MCM_PWMPSQ_Msk_ALL           (MCM_PWMPSQ_PWMPSQ_Msk       )

#define MCM_PWM0D_PWM0D_Pos          0                                            /*!<MCM PWM0D: PWM0D Position */
#define MCM_PWM0D_PWM0D_Msk          (0xFFFFUL /*<< MCM_PWM0D_PWM0D_Pos*/)        /*!<MCM PWM0D: PWM0D Mask */

#define MCM_PWM0D_Msk_ALL            (MCM_PWM0D_PWM0D_Msk         )

#define MCM_PWM1D_PWM1D_Pos          0                                            /*!<MCM PWM1D: PWM1D Position */
#define MCM_PWM1D_PWM1D_Msk          (0xFFFFUL /*<< MCM_PWM1D_PWM1D_Pos*/)        /*!<MCM PWM1D: PWM1D Mask */

#define MCM_PWM1D_Msk_ALL            (MCM_PWM1D_PWM1D_Msk         )

#define MCM_PWM2D_PWM2D_Pos          0                                            /*!<MCM PWM2D: PWM2D Position */
#define MCM_PWM2D_PWM2D_Msk          (0xFFFFUL /*<< MCM_PWM2D_PWM2D_Pos*/)        /*!<MCM PWM2D: PWM2D Mask */

#define MCM_PWM2D_Msk_ALL            (MCM_PWM2D_PWM2D_Msk         )

#define MCM_PWM01D_PWM01D_Pos        0                                            /*!<MCM PWM01D: PWM01D Position */
#define MCM_PWM01D_PWM01D_Msk        (0xFFFFUL /*<< MCM_PWM01D_PWM01D_Pos*/)      /*!<MCM PWM01D: PWM01D Mask */

#define MCM_PWM01D_Msk_ALL           (MCM_PWM01D_PWM01D_Msk       )

#define MCM_PWM11D_PWM11D_Pos        0                                            /*!<MCM PWM11D: PWM11D Position */
#define MCM_PWM11D_PWM11D_Msk        (0xFFFFUL /*<< MCM_PWM11D_PWM11D_Pos*/)      /*!<MCM PWM11D: PWM11D Mask */

#define MCM_PWM11D_Msk_ALL           (MCM_PWM11D_PWM11D_Msk       )

#define MCM_PWM21D_PWM21D_Pos        0                                            /*!<MCM PWM21D: PWM21D Position */
#define MCM_PWM21D_PWM21D_Msk        (0xFFFFUL /*<< MCM_PWM21D_PWM21D_Pos*/)      /*!<MCM PWM21D: PWM21D Mask */

#define MCM_PWM21D_Msk_ALL           (MCM_PWM21D_PWM21D_Msk       )

#define MCM_PWMCMP1_PWMCMP1_Pos      0                                            /*!<MCM PWMCMP1: PWMCMP1 Position */
#define MCM_PWMCMP1_PWMCMP1_Msk      (0xFFFFUL /*<< MCM_PWMCMP1_PWMCMP1_Pos*/)    /*!<MCM PWMCMP1: PWMCMP1 Mask */

#define MCM_PWMCMP1_Msk_ALL          (MCM_PWMCMP1_PWMCMP1_Msk     )

#define MCM_PWMCMP2_PWMCMP2_Pos      0                                            /*!<MCM PWMCMP2: PWMCMP2 Position */
#define MCM_PWMCMP2_PWMCMP2_Msk      (0xFFFFUL /*<< MCM_PWMCMP2_PWMCMP2_Pos*/)    /*!<MCM PWMCMP2: PWMCMP2 Mask */

#define MCM_PWMCMP2_Msk_ALL          (MCM_PWMCMP2_PWMCMP2_Msk     )

#define MCM_PWMCMP3_PWMCMP3_Pos      0                                            /*!<MCM PWMCMP3: PWMCMP3 Position */
#define MCM_PWMCMP3_PWMCMP3_Msk      (0xFFFFUL /*<< MCM_PWMCMP3_PWMCMP3_Pos*/)    /*!<MCM PWMCMP3: PWMCMP3 Mask */

#define MCM_PWMCMP3_Msk_ALL          (MCM_PWMCMP3_PWMCMP3_Msk     )

#define MCM_PWMCMP4_PWMCMP4_Pos      0                                            /*!<MCM PWMCMP4: PWMCMP4 Position */
#define MCM_PWMCMP4_PWMCMP4_Msk      (0xFFFFUL /*<< MCM_PWMCMP4_PWMCMP4_Pos*/)    /*!<MCM PWMCMP4: PWMCMP4 Mask */

#define MCM_PWMCMP4_Msk_ALL          (MCM_PWMCMP4_PWMCMP4_Msk     )

#define MCM_PWMDT00_PWMDT00_Pos      0                                            /*!<MCM PWMDT00: PWMDT00 Position */
#define MCM_PWMDT00_PWMDT00_Msk      (0xFFFFUL /*<< MCM_PWMDT00_PWMDT00_Pos*/)    /*!<MCM PWMDT00: PWMDT00 Mask */

#define MCM_PWMDT00_Msk_ALL          (MCM_PWMDT00_PWMDT00_Msk     )

#define MCM_PWMDT01_PWMDT01_Pos      0                                            /*!<MCM PWMDT01: PWMDT01 Position */
#define MCM_PWMDT01_PWMDT01_Msk      (0xFFFFUL /*<< MCM_PWMDT01_PWMDT01_Pos*/)    /*!<MCM PWMDT01: PWMDT01 Mask */

#define MCM_PWMDT01_Msk_ALL          (MCM_PWMDT01_PWMDT01_Msk     )

#define MCM_PWMDT10_PWMDT10_Pos      0                                            /*!<MCM PWMDT10: PWMDT10 Position */
#define MCM_PWMDT10_PWMDT10_Msk      (0xFFFFUL /*<< MCM_PWMDT10_PWMDT10_Pos*/)    /*!<MCM PWMDT10: PWMDT10 Mask */

#define MCM_PWMDT10_Msk_ALL          (MCM_PWMDT10_PWMDT10_Msk     )

#define MCM_PWMDT11_PWMDT11_Pos      0                                            /*!<MCM PWMDT11: PWMDT11 Position */
#define MCM_PWMDT11_PWMDT11_Msk      (0xFFFFUL /*<< MCM_PWMDT11_PWMDT11_Pos*/)    /*!<MCM PWMDT11: PWMDT11 Mask */

#define MCM_PWMDT11_Msk_ALL          (MCM_PWMDT11_PWMDT11_Msk     )

#define MCM_PWMDT20_PWMDT20_Pos      0                                            /*!<MCM PWMDT20: PWMDT20 Position */
#define MCM_PWMDT20_PWMDT20_Msk      (0xFFFFUL /*<< MCM_PWMDT20_PWMDT20_Pos*/)    /*!<MCM PWMDT20: PWMDT20 Mask */

#define MCM_PWMDT20_Msk_ALL          (MCM_PWMDT20_PWMDT20_Msk     )

#define MCM_PWMDT21_PWMDT21_Pos      0                                            /*!<MCM PWMDT21: PWMDT21 Position */
#define MCM_PWMDT21_PWMDT21_Msk      (0xFFFFUL /*<< MCM_PWMDT21_PWMDT21_Pos*/)    /*!<MCM PWMDT21: PWMDT21 Mask */

#define MCM_PWMDT21_Msk_ALL          (MCM_PWMDT21_PWMDT21_Msk     )

#define MCM_PMANUALCON1_PMANUAL0_Pos 0                                            /*!<MCM PMANUALCON1: PMANUAL0 Position */
#define MCM_PMANUALCON1_PMANUAL0_Msk (0x1UL /*<< MCM_PMANUALCON1_PMANUAL0_Pos*/)  /*!<MCM PMANUALCON1: PMANUAL0 Mask */

#define MCM_PMANUALCON1_PMANUAL1_Pos 1                                            /*!<MCM PMANUALCON1: PMANUAL1 Position */
#define MCM_PMANUALCON1_PMANUAL1_Msk (0x1UL << MCM_PMANUALCON1_PMANUAL1_Pos)      /*!<MCM PMANUALCON1: PMANUAL1 Mask */

#define MCM_PMANUALCON1_PMANUAL2_Pos 2                                            /*!<MCM PMANUALCON1: PMANUAL2 Position */
#define MCM_PMANUALCON1_PMANUAL2_Msk (0x1UL << MCM_PMANUALCON1_PMANUAL2_Pos)      /*!<MCM PMANUALCON1: PMANUAL2 Mask */

#define MCM_PMANUALCON1_PMANUAL01_Pos 3                                            /*!<MCM PMANUALCON1: PMANUAL01 Position */
#define MCM_PMANUALCON1_PMANUAL01_Msk (0x1UL << MCM_PMANUALCON1_PMANUAL01_Pos)     /*!<MCM PMANUALCON1: PMANUAL01 Mask */

#define MCM_PMANUALCON1_PMANUAL11_Pos 4                                            /*!<MCM PMANUALCON1: PMANUAL11 Position */
#define MCM_PMANUALCON1_PMANUAL11_Msk (0x1UL << MCM_PMANUALCON1_PMANUAL11_Pos)     /*!<MCM PMANUALCON1: PMANUAL11 Mask */

#define MCM_PMANUALCON1_PMANUAL21_Pos 5                                            /*!<MCM PMANUALCON1: PMANUAL21 Position */
#define MCM_PMANUALCON1_PMANUAL21_Msk (0x1UL << MCM_PMANUALCON1_PMANUAL21_Pos)     /*!<MCM PMANUALCON1: PMANUAL21 Mask */

#define MCM_PMANUALCON1_Msk_ALL      (MCM_PMANUALCON1_PMANUAL0_Msk |\
                                      MCM_PMANUALCON1_PMANUAL1_Msk |\
                                      MCM_PMANUALCON1_PMANUAL2_Msk |\
                                      MCM_PMANUALCON1_PMANUAL01_Msk |\
                                      MCM_PMANUALCON1_PMANUAL11_Msk |\
                                      MCM_PMANUALCON1_PMANUAL21_Msk )

#define MCM_PMANUALCON2_POUT0_Pos    0                                            /*!<MCM PMANUALCON2: POUT0 Position */
#define MCM_PMANUALCON2_POUT0_Msk    (0x1UL /*<< MCM_PMANUALCON2_POUT0_Pos*/)     /*!<MCM PMANUALCON2: POUT0 Mask */

#define MCM_PMANUALCON2_POUT1_Pos    1                                            /*!<MCM PMANUALCON2: POUT1 Position */
#define MCM_PMANUALCON2_POUT1_Msk    (0x1UL << MCM_PMANUALCON2_POUT1_Pos)         /*!<MCM PMANUALCON2: POUT1 Mask */

#define MCM_PMANUALCON2_POUT2_Pos    2                                            /*!<MCM PMANUALCON2: POUT2 Position */
#define MCM_PMANUALCON2_POUT2_Msk    (0x1UL << MCM_PMANUALCON2_POUT2_Pos)         /*!<MCM PMANUALCON2: POUT2 Mask */

#define MCM_PMANUALCON2_POUT01_Pos   3                                            /*!<MCM PMANUALCON2: POUT01 Position */
#define MCM_PMANUALCON2_POUT01_Msk   (0x1UL << MCM_PMANUALCON2_POUT01_Pos)        /*!<MCM PMANUALCON2: POUT01 Mask */

#define MCM_PMANUALCON2_POUT11_Pos   4                                            /*!<MCM PMANUALCON2: POUT11 Position */
#define MCM_PMANUALCON2_POUT11_Msk   (0x1UL << MCM_PMANUALCON2_POUT11_Pos)        /*!<MCM PMANUALCON2: POUT11 Mask */

#define MCM_PMANUALCON2_POUT21_Pos   5                                            /*!<MCM PMANUALCON2: POUT21 Position */
#define MCM_PMANUALCON2_POUT21_Msk   (0x1UL << MCM_PMANUALCON2_POUT21_Pos)        /*!<MCM PMANUALCON2: POUT21 Mask */

#define MCM_PMANUALCON2_Msk_ALL      (MCM_PMANUALCON2_POUT0_Msk    |\
                                      MCM_PMANUALCON2_POUT1_Msk    |\
                                      MCM_PMANUALCON2_POUT2_Msk    |\
                                      MCM_PMANUALCON2_POUT01_Msk   |\
                                      MCM_PMANUALCON2_POUT11_Msk   |\
                                      MCM_PMANUALCON2_POUT21_Msk   )

#define MCM_FLTCON_FLT2STAT_Pos      0                                            /*!<MCM FLTCON: FLT2STAT Position */
#define MCM_FLTCON_FLT2STAT_Msk      (0x1UL /*<< MCM_FLTCON_FLT2STAT_Pos*/)       /*!<MCM FLTCON: FLT2STAT Mask */

#define MCM_FLTCON_FLT2M_Pos         1                                            /*!<MCM FLTCON: FLT2M Position */
#define MCM_FLTCON_FLT2M_Msk         (0x1UL << MCM_FLTCON_FLT2M_Pos)              /*!<MCM FLTCON: FLT2M Mask */

#define MCM_FLTCON_FLT2S_Pos         2                                            /*!<MCM FLTCON: FLT2S Position */
#define MCM_FLTCON_FLT2S_Msk         (0x1UL << MCM_FLTCON_FLT2S_Pos)              /*!<MCM FLTCON: FLT2S Mask */

#define MCM_FLTCON_FLT2EN_Pos        3                                            /*!<MCM FLTCON: FLT2EN Position */
#define MCM_FLTCON_FLT2EN_Msk        (0x1UL << MCM_FLTCON_FLT2EN_Pos)             /*!<MCM FLTCON: FLT2EN Mask */

#define MCM_FLTCON_FLT2DEB_Pos       4                                            /*!<MCM FLTCON: FLT2DEB Position */
#define MCM_FLTCON_FLT2DEB_Msk       (0xFUL << MCM_FLTCON_FLT2DEB_Pos)            /*!<MCM FLTCON: FLT2DEB Mask */

#define MCM_FLTCON_FLT1STAT_Pos      8                                            /*!<MCM FLTCON: FLT1STAT Position */
#define MCM_FLTCON_FLT1STAT_Msk      (0x1UL << MCM_FLTCON_FLT1STAT_Pos)           /*!<MCM FLTCON: FLT1STAT Mask */

#define MCM_FLTCON_FLT1M_Pos         9                                            /*!<MCM FLTCON: FLT1M Position */
#define MCM_FLTCON_FLT1M_Msk         (0x1UL << MCM_FLTCON_FLT1M_Pos)              /*!<MCM FLTCON: FLT1M Mask */

#define MCM_FLTCON_FLT1S_Pos         10                                           /*!<MCM FLTCON: FLT1S Position */
#define MCM_FLTCON_FLT1S_Msk         (0x1UL << MCM_FLTCON_FLT1S_Pos)              /*!<MCM FLTCON: FLT1S Mask */

#define MCM_FLTCON_FLT1EN_Pos        11                                           /*!<MCM FLTCON: FLT1EN Position */
#define MCM_FLTCON_FLT1EN_Msk        (0x1UL << MCM_FLTCON_FLT1EN_Pos)             /*!<MCM FLTCON: FLT1EN Mask */

#define MCM_FLTCON_FLT0STAT_Pos      12                                           /*!<MCM FLTCON: FLT0STAT Position */
#define MCM_FLTCON_FLT0STAT_Msk      (0x1UL << MCM_FLTCON_FLT0STAT_Pos)           /*!<MCM FLTCON: FLT0STAT Mask */

#define MCM_FLTCON_FLT0M_Pos         13                                           /*!<MCM FLTCON: FLT0M Position */
#define MCM_FLTCON_FLT0M_Msk         (0x1UL << MCM_FLTCON_FLT0M_Pos)              /*!<MCM FLTCON: FLT0M Mask */

#define MCM_FLTCON_FLT0S_Pos         14                                           /*!<MCM FLTCON: FLT0S Position */
#define MCM_FLTCON_FLT0S_Msk         (0x1UL << MCM_FLTCON_FLT0S_Pos)              /*!<MCM FLTCON: FLT0S Mask */

#define MCM_FLTCON_FLT0EN_Pos        15                                           /*!<MCM FLTCON: FLT0EN Position */
#define MCM_FLTCON_FLT0EN_Msk        (0x1UL << MCM_FLTCON_FLT0EN_Pos)             /*!<MCM FLTCON: FLT0EN Mask */

#define MCM_FLTCON_FLT2STATC_Pos     16                                           /*!<MCM FLTCON: FLT2STATC Position */
#define MCM_FLTCON_FLT2STATC_Msk     (0x1UL << MCM_FLTCON_FLT2STATC_Pos)          /*!<MCM FLTCON: FLT2STATC Mask */

#define MCM_FLTCON_FLT1STATC_Pos     17                                           /*!<MCM FLTCON: FLT1STATC Position */
#define MCM_FLTCON_FLT1STATC_Msk     (0x1UL << MCM_FLTCON_FLT1STATC_Pos)          /*!<MCM FLTCON: FLT1STATC Mask */

#define MCM_FLTCON_FLT0STATC_Pos     18                                           /*!<MCM FLTCON: FLT0STATC Position */
#define MCM_FLTCON_FLT0STATC_Msk     (0x1UL << MCM_FLTCON_FLT0STATC_Pos)          /*!<MCM FLTCON: FLT0STATC Mask */

#define MCM_FLTCON_FOUT0_Pos         20                                           /*!<MCM FLTCON: FOUT0 Position */
#define MCM_FLTCON_FOUT0_Msk         (0x3UL << MCM_FLTCON_FOUT0_Pos)              /*!<MCM FLTCON: FOUT0 Mask */

#define MCM_FLTCON_FOUT1_Pos         22                                           /*!<MCM FLTCON: FOUT1 Position */
#define MCM_FLTCON_FOUT1_Msk         (0x3UL << MCM_FLTCON_FOUT1_Pos)              /*!<MCM FLTCON: FOUT1 Mask */

#define MCM_FLTCON_Msk_ALL           (MCM_FLTCON_FLT2STAT_Msk      |\
                                      MCM_FLTCON_FLT2M_Msk         |\
                                      MCM_FLTCON_FLT2S_Msk         |\
                                      MCM_FLTCON_FLT2EN_Msk        |\
                                      MCM_FLTCON_FLT2DEB_Msk       |\
                                      MCM_FLTCON_FLT1STAT_Msk      |\
                                      MCM_FLTCON_FLT1M_Msk         |\
                                      MCM_FLTCON_FLT1S_Msk         |\
                                      MCM_FLTCON_FLT1EN_Msk        |\
                                      MCM_FLTCON_FLT0STAT_Msk      |\
                                      MCM_FLTCON_FLT0M_Msk         |\
                                      MCM_FLTCON_FLT0S_Msk         |\
                                      MCM_FLTCON_FLT0EN_Msk        |\
                                      MCM_FLTCON_FLT2STATC_Msk     |\
                                      MCM_FLTCON_FLT1STATC_Msk     |\
                                      MCM_FLTCON_FLT0STATC_Msk     |\
                                      MCM_FLTCON_FOUT0_Msk         |\
                                      MCM_FLTCON_FOUT1_Msk         )

#define MCM_POSCR_OLSG0_Pos          0                                            /*!<MCM POSCR: OLSG0 Position */
#define MCM_POSCR_OLSG0_Msk          (0x1UL /*<< MCM_POSCR_OLSG0_Pos*/)           /*!<MCM POSCR: OLSG0 Mask */

#define MCM_POSCR_OLSG1_Pos          1                                            /*!<MCM POSCR: OLSG1 Position */
#define MCM_POSCR_OLSG1_Msk          (0x1UL << MCM_POSCR_OLSG1_Pos)               /*!<MCM POSCR: OLSG1 Mask */

#define MCM_POSCR_OLSG2_Pos          2                                            /*!<MCM POSCR: OLSG2 Position */
#define MCM_POSCR_OLSG2_Msk          (0x1UL << MCM_POSCR_OLSG2_Pos)               /*!<MCM POSCR: OLSG2 Mask */

#define MCM_POSCR_OLSG01_Pos         3                                            /*!<MCM POSCR: OLSG01 Position */
#define MCM_POSCR_OLSG01_Msk         (0x1UL << MCM_POSCR_OLSG01_Pos)              /*!<MCM POSCR: OLSG01 Mask */

#define MCM_POSCR_OLSG11_Pos         4                                            /*!<MCM POSCR: OLSG11 Position */
#define MCM_POSCR_OLSG11_Msk         (0x1UL << MCM_POSCR_OLSG11_Pos)              /*!<MCM POSCR: OLSG11 Mask */

#define MCM_POSCR_OLSG21_Pos         5                                            /*!<MCM POSCR: OLSG21 Position */
#define MCM_POSCR_OLSG21_Msk         (0x1UL << MCM_POSCR_OLSG21_Pos)              /*!<MCM POSCR: OLSG21 Mask */

#define MCM_POSCR_OLSEN_Pos          7                                            /*!<MCM POSCR: OLSEN Position */
#define MCM_POSCR_OLSEN_Msk          (0x1UL << MCM_POSCR_OLSEN_Pos)               /*!<MCM POSCR: OLSEN Mask */

#define MCM_POSCR_Msk_ALL            (MCM_POSCR_OLSG0_Msk          |\
                                      MCM_POSCR_OLSG1_Msk          |\
                                      MCM_POSCR_OLSG2_Msk          |\
                                      MCM_POSCR_OLSG01_Msk         |\
                                      MCM_POSCR_OLSG11_Msk         |\
                                      MCM_POSCR_OLSG21_Msk         |\
                                      MCM_POSCR_OLSEN_Msk          )

#define MCM_POSTDCR_OSTDEN_Pos       7                                            /*!<MCM POSTDCR: OSTDEN Position */
#define MCM_POSTDCR_OSTDEN_Msk       (0x1UL << MCM_POSTDCR_OSTDEN_Pos)            /*!<MCM POSTDCR: OSTDEN Mask */

#define MCM_POSTDCR_Msk_ALL          (MCM_POSTDCR_OSTDEN_Msk      )

#define MCM_PWMINTEN_PTUD0IE_Pos     0                                            /*!<MCM PWMINTEN: PTUD0IE Position */
#define MCM_PWMINTEN_PTUD0IE_Msk     (0x1UL /*<< MCM_PWMINTEN_PTUD0IE_Pos*/)      /*!<MCM PWMINTEN: PTUD0IE Mask */

#define MCM_PWMINTEN_PTDD0IE_Pos     1                                            /*!<MCM PWMINTEN: PTDD0IE Position */
#define MCM_PWMINTEN_PTDD0IE_Msk     (0x1UL << MCM_PWMINTEN_PTDD0IE_Pos)          /*!<MCM PWMINTEN: PTDD0IE Mask */

#define MCM_PWMINTEN_PTUD1IE_Pos     2                                            /*!<MCM PWMINTEN: PTUD1IE Position */
#define MCM_PWMINTEN_PTUD1IE_Msk     (0x1UL << MCM_PWMINTEN_PTUD1IE_Pos)          /*!<MCM PWMINTEN: PTUD1IE Mask */

#define MCM_PWMINTEN_PTDD1IE_Pos     3                                            /*!<MCM PWMINTEN: PTDD1IE Position */
#define MCM_PWMINTEN_PTDD1IE_Msk     (0x1UL << MCM_PWMINTEN_PTDD1IE_Pos)          /*!<MCM PWMINTEN: PTDD1IE Mask */

#define MCM_PWMINTEN_PTUD2IE_Pos     4                                            /*!<MCM PWMINTEN: PTUD2IE Position */
#define MCM_PWMINTEN_PTUD2IE_Msk     (0x1UL << MCM_PWMINTEN_PTUD2IE_Pos)          /*!<MCM PWMINTEN: PTUD2IE Mask */

#define MCM_PWMINTEN_PTDD2IE_Pos     5                                            /*!<MCM PWMINTEN: PTDD2IE Position */
#define MCM_PWMINTEN_PTDD2IE_Msk     (0x1UL << MCM_PWMINTEN_PTDD2IE_Pos)          /*!<MCM PWMINTEN: PTDD2IE Mask */

#define MCM_PWMINTEN_PWMZIE_Pos      6                                            /*!<MCM PWMINTEN: PWMZIE Position */
#define MCM_PWMINTEN_PWMZIE_Msk      (0x1UL << MCM_PWMINTEN_PWMZIE_Pos)           /*!<MCM PWMINTEN: PWMZIE Mask */

#define MCM_PWMINTEN_PWMPIE_Pos      7                                            /*!<MCM PWMINTEN: PWMPIE Position */
#define MCM_PWMINTEN_PWMPIE_Msk      (0x1UL << MCM_PWMINTEN_PWMPIE_Pos)           /*!<MCM PWMINTEN: PWMPIE Mask */

#define MCM_PWMINTEN_FLTIE_Pos       8                                            /*!<MCM PWMINTEN: FLTIE Position */
#define MCM_PWMINTEN_FLTIE_Msk       (0x1UL << MCM_PWMINTEN_FLTIE_Pos)            /*!<MCM PWMINTEN: FLTIE Mask */

#define MCM_PWMINTEN_FLTCMP0IE_Pos   9                                            /*!<MCM PWMINTEN: FLTCMP0IE Position */
#define MCM_PWMINTEN_FLTCMP0IE_Msk   (0x1UL << MCM_PWMINTEN_FLTCMP0IE_Pos)        /*!<MCM PWMINTEN: FLTCMP0IE Mask */

#define MCM_PWMINTEN_FLTCMP1IE_Pos   10                                           /*!<MCM PWMINTEN: FLTCMP1IE Position */
#define MCM_PWMINTEN_FLTCMP1IE_Msk   (0x1UL << MCM_PWMINTEN_FLTCMP1IE_Pos)        /*!<MCM PWMINTEN: FLTCMP1IE Mask */

#define MCM_PWMINTEN_OIE_Pos         11                                           /*!<MCM PWMINTEN: OIE Position */
#define MCM_PWMINTEN_OIE_Msk         (0x1UL << MCM_PWMINTEN_OIE_Pos)              /*!<MCM PWMINTEN: OIE Mask */

#define MCM_PWMINTEN_OSTDIE_Pos      12                                           /*!<MCM PWMINTEN: OSTDIE Position */
#define MCM_PWMINTEN_OSTDIE_Msk      (0x1UL << MCM_PWMINTEN_OSTDIE_Pos)           /*!<MCM PWMINTEN: OSTDIE Mask */

#define MCM_PWMINTEN_Msk_ALL         (MCM_PWMINTEN_PTUD0IE_Msk     |\
                                      MCM_PWMINTEN_PTDD0IE_Msk     |\
                                      MCM_PWMINTEN_PTUD1IE_Msk     |\
                                      MCM_PWMINTEN_PTDD1IE_Msk     |\
                                      MCM_PWMINTEN_PTUD2IE_Msk     |\
                                      MCM_PWMINTEN_PTDD2IE_Msk     |\
                                      MCM_PWMINTEN_PWMZIE_Msk      |\
                                      MCM_PWMINTEN_PWMPIE_Msk      |\
                                      MCM_PWMINTEN_FLTIE_Msk       |\
                                      MCM_PWMINTEN_FLTCMP0IE_Msk   |\
                                      MCM_PWMINTEN_FLTCMP1IE_Msk   |\
                                      MCM_PWMINTEN_OIE_Msk         |\
                                      MCM_PWMINTEN_OSTDIE_Msk      )

#define MCM_PWMINTF_PTUD0IF_Pos      0                                            /*!<MCM PWMINTF: PTUD0IF Position */
#define MCM_PWMINTF_PTUD0IF_Msk      (0x1UL /*<< MCM_PWMINTF_PTUD0IF_Pos*/)       /*!<MCM PWMINTF: PTUD0IF Mask */

#define MCM_PWMINTF_PTDD0IF_Pos      1                                            /*!<MCM PWMINTF: PTDD0IF Position */
#define MCM_PWMINTF_PTDD0IF_Msk      (0x1UL << MCM_PWMINTF_PTDD0IF_Pos)           /*!<MCM PWMINTF: PTDD0IF Mask */

#define MCM_PWMINTF_PTUD1IF_Pos      2                                            /*!<MCM PWMINTF: PTUD1IF Position */
#define MCM_PWMINTF_PTUD1IF_Msk      (0x1UL << MCM_PWMINTF_PTUD1IF_Pos)           /*!<MCM PWMINTF: PTUD1IF Mask */

#define MCM_PWMINTF_PTDD1IF_Pos      3                                            /*!<MCM PWMINTF: PTDD1IF Position */
#define MCM_PWMINTF_PTDD1IF_Msk      (0x1UL << MCM_PWMINTF_PTDD1IF_Pos)           /*!<MCM PWMINTF: PTDD1IF Mask */

#define MCM_PWMINTF_PTUD2IF_Pos      4                                            /*!<MCM PWMINTF: PTUD2IF Position */
#define MCM_PWMINTF_PTUD2IF_Msk      (0x1UL << MCM_PWMINTF_PTUD2IF_Pos)           /*!<MCM PWMINTF: PTUD2IF Mask */

#define MCM_PWMINTF_PTDD2IF_Pos      5                                            /*!<MCM PWMINTF: PTDD2IF Position */
#define MCM_PWMINTF_PTDD2IF_Msk      (0x1UL << MCM_PWMINTF_PTDD2IF_Pos)           /*!<MCM PWMINTF: PTDD2IF Mask */

#define MCM_PWMINTF_PWMZIF_Pos       6                                            /*!<MCM PWMINTF: PWMZIF Position */
#define MCM_PWMINTF_PWMZIF_Msk       (0x1UL << MCM_PWMINTF_PWMZIF_Pos)            /*!<MCM PWMINTF: PWMZIF Mask */

#define MCM_PWMINTF_PWMPIF_Pos       7                                            /*!<MCM PWMINTF: PWMPIF Position */
#define MCM_PWMINTF_PWMPIF_Msk       (0x1UL << MCM_PWMINTF_PWMPIF_Pos)            /*!<MCM PWMINTF: PWMPIF Mask */

#define MCM_PWMINTF_FLTIF_Pos        8                                            /*!<MCM PWMINTF: FLTIF Position */
#define MCM_PWMINTF_FLTIF_Msk        (0x1UL << MCM_PWMINTF_FLTIF_Pos)             /*!<MCM PWMINTF: FLTIF Mask */

#define MCM_PWMINTF_FLTCMP0IF_Pos    9                                            /*!<MCM PWMINTF: FLTCMP0IF Position */
#define MCM_PWMINTF_FLTCMP0IF_Msk    (0x1UL << MCM_PWMINTF_FLTCMP0IF_Pos)         /*!<MCM PWMINTF: FLTCMP0IF Mask */

#define MCM_PWMINTF_FLTCMP1IF_Pos    10                                           /*!<MCM PWMINTF: FLTCMP1IF Position */
#define MCM_PWMINTF_FLTCMP1IF_Msk    (0x1UL << MCM_PWMINTF_FLTCMP1IF_Pos)         /*!<MCM PWMINTF: FLTCMP1IF Mask */

#define MCM_PWMINTF_OSF_Pos          11                                           /*!<MCM PWMINTF: OSF Position */
#define MCM_PWMINTF_OSF_Msk          (0x1UL << MCM_PWMINTF_OSF_Pos)               /*!<MCM PWMINTF: OSF Mask */

#define MCM_PWMINTF_OSTDF_Pos        12                                           /*!<MCM PWMINTF: OSTDF Position */
#define MCM_PWMINTF_OSTDF_Msk        (0x1UL << MCM_PWMINTF_OSTDF_Pos)             /*!<MCM PWMINTF: OSTDF Mask */

#define MCM_PWMINTF_SC0STAT_Pos      13                                           /*!<MCM PWMINTF: SC0STAT Position */
#define MCM_PWMINTF_SC0STAT_Msk      (0x1UL << MCM_PWMINTF_SC0STAT_Pos)           /*!<MCM PWMINTF: SC0STAT Mask */

#define MCM_PWMINTF_SC1STAT_Pos      14                                           /*!<MCM PWMINTF: SC1STAT Position */
#define MCM_PWMINTF_SC1STAT_Msk      (0x1UL << MCM_PWMINTF_SC1STAT_Pos)           /*!<MCM PWMINTF: SC1STAT Mask */

#define MCM_PWMINTF_SC2STAT_Pos      15                                           /*!<MCM PWMINTF: SC2STAT Position */
#define MCM_PWMINTF_SC2STAT_Msk      (0x1UL << MCM_PWMINTF_SC2STAT_Pos)           /*!<MCM PWMINTF: SC2STAT Mask */

#define MCM_PWMINTF_PTUD0IFC_Pos     16                                           /*!<MCM PWMINTF: PTUD0IFC Position */
#define MCM_PWMINTF_PTUD0IFC_Msk     (0x1UL << MCM_PWMINTF_PTUD0IFC_Pos)          /*!<MCM PWMINTF: PTUD0IFC Mask */

#define MCM_PWMINTF_PTDD0IFC_Pos     17                                           /*!<MCM PWMINTF: PTDD0IFC Position */
#define MCM_PWMINTF_PTDD0IFC_Msk     (0x1UL << MCM_PWMINTF_PTDD0IFC_Pos)          /*!<MCM PWMINTF: PTDD0IFC Mask */

#define MCM_PWMINTF_PTUD1IFC_Pos     18                                           /*!<MCM PWMINTF: PTUD1IFC Position */
#define MCM_PWMINTF_PTUD1IFC_Msk     (0x1UL << MCM_PWMINTF_PTUD1IFC_Pos)          /*!<MCM PWMINTF: PTUD1IFC Mask */

#define MCM_PWMINTF_PTDD1IFC_Pos     19                                           /*!<MCM PWMINTF: PTDD1IFC Position */
#define MCM_PWMINTF_PTDD1IFC_Msk     (0x1UL << MCM_PWMINTF_PTDD1IFC_Pos)          /*!<MCM PWMINTF: PTDD1IFC Mask */

#define MCM_PWMINTF_PTUD2IFC_Pos     20                                           /*!<MCM PWMINTF: PTUD2IFC Position */
#define MCM_PWMINTF_PTUD2IFC_Msk     (0x1UL << MCM_PWMINTF_PTUD2IFC_Pos)          /*!<MCM PWMINTF: PTUD2IFC Mask */

#define MCM_PWMINTF_PTDD2IFC_Pos     21                                           /*!<MCM PWMINTF: PTDD2IFC Position */
#define MCM_PWMINTF_PTDD2IFC_Msk     (0x1UL << MCM_PWMINTF_PTDD2IFC_Pos)          /*!<MCM PWMINTF: PTDD2IFC Mask */

#define MCM_PWMINTF_PWMZIFC_Pos      22                                           /*!<MCM PWMINTF: PWMZIFC Position */
#define MCM_PWMINTF_PWMZIFC_Msk      (0x1UL << MCM_PWMINTF_PWMZIFC_Pos)           /*!<MCM PWMINTF: PWMZIFC Mask */

#define MCM_PWMINTF_PWMPIFC_Pos      23                                           /*!<MCM PWMINTF: PWMPIFC Position */
#define MCM_PWMINTF_PWMPIFC_Msk      (0x1UL << MCM_PWMINTF_PWMPIFC_Pos)           /*!<MCM PWMINTF: PWMPIFC Mask */

#define MCM_PWMINTF_FLTIFC_Pos       24                                           /*!<MCM PWMINTF: FLTIFC Position */
#define MCM_PWMINTF_FLTIFC_Msk       (0x1UL << MCM_PWMINTF_FLTIFC_Pos)            /*!<MCM PWMINTF: FLTIFC Mask */

#define MCM_PWMINTF_FLTCMP0IFC_Pos   25                                           /*!<MCM PWMINTF: FLTCMP0IFC Position */
#define MCM_PWMINTF_FLTCMP0IFC_Msk   (0x1UL << MCM_PWMINTF_FLTCMP0IFC_Pos)        /*!<MCM PWMINTF: FLTCMP0IFC Mask */

#define MCM_PWMINTF_FLTCMP1IFC_Pos   26                                           /*!<MCM PWMINTF: FLTCMP1IFC Position */
#define MCM_PWMINTF_FLTCMP1IFC_Msk   (0x1UL << MCM_PWMINTF_FLTCMP1IFC_Pos)        /*!<MCM PWMINTF: FLTCMP1IFC Mask */

#define MCM_PWMINTF_OSFC_Pos         27                                           /*!<MCM PWMINTF: OSFC Position */
#define MCM_PWMINTF_OSFC_Msk         (0x1UL << MCM_PWMINTF_OSFC_Pos)              /*!<MCM PWMINTF: OSFC Mask */

#define MCM_PWMINTF_OSTDFC_Pos       28                                           /*!<MCM PWMINTF: OSTDFC Position */
#define MCM_PWMINTF_OSTDFC_Msk       (0x1UL << MCM_PWMINTF_OSTDFC_Pos)            /*!<MCM PWMINTF: OSTDFC Mask */

#define MCM_PWMINTF_SC0STATC_Pos     29                                           /*!<MCM PWMINTF: SC0STATC Position */
#define MCM_PWMINTF_SC0STATC_Msk     (0x1UL << MCM_PWMINTF_SC0STATC_Pos)          /*!<MCM PWMINTF: SC0STATC Mask */

#define MCM_PWMINTF_SC1STATC_Pos     30                                           /*!<MCM PWMINTF: SC1STATC Position */
#define MCM_PWMINTF_SC1STATC_Msk     (0x1UL << MCM_PWMINTF_SC1STATC_Pos)          /*!<MCM PWMINTF: SC1STATC Mask */

#define MCM_PWMINTF_SC2STATC_Pos     31                                           /*!<MCM PWMINTF: SC2STATC Position */
#define MCM_PWMINTF_SC2STATC_Msk     (0x1UL << MCM_PWMINTF_SC2STATC_Pos)          /*!<MCM PWMINTF: SC2STATC Mask */

#define MCM_PWMINTF_Msk_ALL          (MCM_PWMINTF_PTUD0IF_Msk      |\
                                      MCM_PWMINTF_PTDD0IF_Msk      |\
                                      MCM_PWMINTF_PTUD1IF_Msk      |\
                                      MCM_PWMINTF_PTDD1IF_Msk      |\
                                      MCM_PWMINTF_PTUD2IF_Msk      |\
                                      MCM_PWMINTF_PTDD2IF_Msk      |\
                                      MCM_PWMINTF_PWMZIF_Msk       |\
                                      MCM_PWMINTF_PWMPIF_Msk       |\
                                      MCM_PWMINTF_FLTIF_Msk        |\
                                      MCM_PWMINTF_FLTCMP0IF_Msk    |\
                                      MCM_PWMINTF_FLTCMP1IF_Msk    |\
                                      MCM_PWMINTF_OSF_Msk          |\
                                      MCM_PWMINTF_OSTDF_Msk        |\
                                      MCM_PWMINTF_SC0STAT_Msk      |\
                                      MCM_PWMINTF_SC1STAT_Msk      |\
                                      MCM_PWMINTF_SC2STAT_Msk      |\
                                      MCM_PWMINTF_PTUD0IFC_Msk     |\
                                      MCM_PWMINTF_PTDD0IFC_Msk     |\
                                      MCM_PWMINTF_PTUD1IFC_Msk     |\
                                      MCM_PWMINTF_PTDD1IFC_Msk     |\
                                      MCM_PWMINTF_PTUD2IFC_Msk     |\
                                      MCM_PWMINTF_PTDD2IFC_Msk     |\
                                      MCM_PWMINTF_PWMZIFC_Msk      |\
                                      MCM_PWMINTF_PWMPIFC_Msk      |\
                                      MCM_PWMINTF_FLTIFC_Msk       |\
                                      MCM_PWMINTF_FLTCMP0IFC_Msk   |\
                                      MCM_PWMINTF_FLTCMP1IFC_Msk   |\
                                      MCM_PWMINTF_OSFC_Msk         |\
                                      MCM_PWMINTF_OSTDFC_Msk       |\
                                      MCM_PWMINTF_SC0STATC_Msk     |\
                                      MCM_PWMINTF_SC1STATC_Msk     |\
                                      MCM_PWMINTF_SC2STATC_Msk     )

#define MCM_PWMRLDEN_PWMRLDEN_Pos    0                                            /*!<MCM PWMRLDEN: PWMRLDEN Position */
#define MCM_PWMRLDEN_PWMRLDEN_Msk    (0xFFUL /*<< MCM_PWMRLDEN_PWMRLDEN_Pos*/)    /*!<MCM PWMRLDEN: PWMRLDEN Mask */

#define MCM_PWMRLDEN_Msk_ALL         (MCM_PWMRLDEN_PWMRLDEN_Msk   )

#define MCM_PSCON_SHIFTRUN_Pos       0                                            /*!<MCM PSCON: SHIFTRUN Position */
#define MCM_PSCON_SHIFTRUN_Msk       (0x1UL /*<< MCM_PSCON_SHIFTRUN_Pos*/)        /*!<MCM PSCON: SHIFTRUN Mask */

#define MCM_PSCON_STATRUN_Pos        1                                            /*!<MCM PSCON: STATRUN Position */
#define MCM_PSCON_STATRUN_Msk        (0x1UL << MCM_PSCON_STATRUN_Pos)             /*!<MCM PSCON: STATRUN Mask */

#define MCM_PSCON_OVER_Pos           2                                            /*!<MCM PSCON: OVER Position */
#define MCM_PSCON_OVER_Msk           (0x1UL << MCM_PSCON_OVER_Pos)                /*!<MCM PSCON: OVER Mask */

#define MCM_PSCON_SECTOR_Pos         4                                            /*!<MCM PSCON: SECTOR Position */
#define MCM_PSCON_SECTOR_Msk         (0x7UL << MCM_PSCON_SECTOR_Pos)              /*!<MCM PSCON: SECTOR Mask */

#define MCM_PSCON_MAXSELECT_Pos      8                                            /*!<MCM PSCON: MAXSELECT Position */
#define MCM_PSCON_MAXSELECT_Msk      (0x3UL << MCM_PSCON_MAXSELECT_Pos)           /*!<MCM PSCON: MAXSELECT Mask */

#define MCM_PSCON_MINSELECT_Pos      10                                           /*!<MCM PSCON: MINSELECT Position */
#define MCM_PSCON_MINSELECT_Msk      (0x3UL << MCM_PSCON_MINSELECT_Pos)           /*!<MCM PSCON: MINSELECT Mask */

#define MCM_PSCON_Msk_ALL            (MCM_PSCON_SHIFTRUN_Msk       |\
                                      MCM_PSCON_STATRUN_Msk        |\
                                      MCM_PSCON_OVER_Msk           |\
                                      MCM_PSCON_SECTOR_Msk         |\
                                      MCM_PSCON_MAXSELECT_Msk      |\
                                      MCM_PSCON_MINSELECT_Msk      )

#define MCM_PWMDMAX_PWMDMAX_Pos      0                                            /*!<MCM PWMDMAX: PWMDMAX Position */
#define MCM_PWMDMAX_PWMDMAX_Msk      (0xFFFFUL /*<< MCM_PWMDMAX_PWMDMAX_Pos*/)    /*!<MCM PWMDMAX: PWMDMAX Mask */

#define MCM_PWMDMAX_Msk_ALL          (MCM_PWMDMAX_PWMDMAX_Msk     )

#define MCM_PWMDMIN_PWMDMIN_Pos      0                                            /*!<MCM PWMDMIN: PWMDMIN Position */
#define MCM_PWMDMIN_PWMDMIN_Msk      (0xFFFFUL /*<< MCM_PWMDMIN_PWMDMIN_Pos*/)    /*!<MCM PWMDMIN: PWMDMIN Mask */

#define MCM_PWMDMIN_Msk_ALL          (MCM_PWMDMIN_PWMDMIN_Msk     )

#define MCM_PWMDCMP1_PWMDCMP1_Pos    0                                            /*!<MCM PWMDCMP1: PWMDCMP1 Position */
#define MCM_PWMDCMP1_PWMDCMP1_Msk    (0xFFFFUL /*<< MCM_PWMDCMP1_PWMDCMP1_Pos*/)  /*!<MCM PWMDCMP1: PWMDCMP1 Mask */

#define MCM_PWMDCMP1_Msk_ALL         (MCM_PWMDCMP1_PWMDCMP1_Msk   )

#define MCM_PWMDCMP2_PWMDCMP2_Pos    0                                            /*!<MCM PWMDCMP2: PWMDCMP2 Position */
#define MCM_PWMDCMP2_PWMDCMP2_Msk    (0xFFFFUL /*<< MCM_PWMDCMP2_PWMDCMP2_Pos*/)  /*!<MCM PWMDCMP2: PWMDCMP2 Mask */

#define MCM_PWMDCMP2_Msk_ALL         (MCM_PWMDCMP2_PWMDCMP2_Msk   )

#define MCM_SC0CON_SCTIME_Pos        0                                            /*!<MCM SC0CON: SCTIME Position */
#define MCM_SC0CON_SCTIME_Msk        (0xFUL /*<< MCM_SC0CON_SCTIME_Pos*/)         /*!<MCM SC0CON: SCTIME Mask */

#define MCM_SC0CON_SCDEB_Pos         4                                            /*!<MCM SC0CON: SCDEB Position */
#define MCM_SC0CON_SCDEB_Msk         (0xFUL << MCM_SC0CON_SCDEB_Pos)              /*!<MCM SC0CON: SCDEB Mask */

#define MCM_SC0CON_SCPWM0EN_Pos      8                                            /*!<MCM SC0CON: SCPWM0EN Position */
#define MCM_SC0CON_SCPWM0EN_Msk      (0x1UL << MCM_SC0CON_SCPWM0EN_Pos)           /*!<MCM SC0CON: SCPWM0EN Mask */

#define MCM_SC0CON_SCPWM1EN_Pos      9                                            /*!<MCM SC0CON: SCPWM1EN Position */
#define MCM_SC0CON_SCPWM1EN_Msk      (0x1UL << MCM_SC0CON_SCPWM1EN_Pos)           /*!<MCM SC0CON: SCPWM1EN Mask */

#define MCM_SC0CON_SCPWM2EN_Pos      10                                           /*!<MCM SC0CON: SCPWM2EN Position */
#define MCM_SC0CON_SCPWM2EN_Msk      (0x1UL << MCM_SC0CON_SCPWM2EN_Pos)           /*!<MCM SC0CON: SCPWM2EN Mask */

#define MCM_SC0CON_SCS_Pos           11                                           /*!<MCM SC0CON: SCS Position */
#define MCM_SC0CON_SCS_Msk           (0x1UL << MCM_SC0CON_SCS_Pos)                /*!<MCM SC0CON: SCS Mask */

#define MCM_SC0CON_SCEN_Pos          12                                           /*!<MCM SC0CON: SCEN Position */
#define MCM_SC0CON_SCEN_Msk          (0x3UL << MCM_SC0CON_SCEN_Pos)               /*!<MCM SC0CON: SCEN Mask */

#define MCM_SC0CON_Msk_ALL           (MCM_SC0CON_SCTIME_Msk        |\
                                      MCM_SC0CON_SCDEB_Msk         |\
                                      MCM_SC0CON_SCPWM0EN_Msk      |\
                                      MCM_SC0CON_SCPWM1EN_Msk      |\
                                      MCM_SC0CON_SCPWM2EN_Msk      |\
                                      MCM_SC0CON_SCS_Msk           |\
                                      MCM_SC0CON_SCEN_Msk          )

#define MCM_SC1CON_SCTIME_Pos        0                                            /*!<MCM SC1CON: SCTIME Position */
#define MCM_SC1CON_SCTIME_Msk        (0xFUL /*<< MCM_SC1CON_SCTIME_Pos*/)         /*!<MCM SC1CON: SCTIME Mask */

#define MCM_SC1CON_SCDEB_Pos         4                                            /*!<MCM SC1CON: SCDEB Position */
#define MCM_SC1CON_SCDEB_Msk         (0xFUL << MCM_SC1CON_SCDEB_Pos)              /*!<MCM SC1CON: SCDEB Mask */

#define MCM_SC1CON_SCPWM0EN_Pos      8                                            /*!<MCM SC1CON: SCPWM0EN Position */
#define MCM_SC1CON_SCPWM0EN_Msk      (0x1UL << MCM_SC1CON_SCPWM0EN_Pos)           /*!<MCM SC1CON: SCPWM0EN Mask */

#define MCM_SC1CON_SCPWM1EN_Pos      9                                            /*!<MCM SC1CON: SCPWM1EN Position */
#define MCM_SC1CON_SCPWM1EN_Msk      (0x1UL << MCM_SC1CON_SCPWM1EN_Pos)           /*!<MCM SC1CON: SCPWM1EN Mask */

#define MCM_SC1CON_SCPWM2EN_Pos      10                                           /*!<MCM SC1CON: SCPWM2EN Position */
#define MCM_SC1CON_SCPWM2EN_Msk      (0x1UL << MCM_SC1CON_SCPWM2EN_Pos)           /*!<MCM SC1CON: SCPWM2EN Mask */

#define MCM_SC1CON_SCS_Pos           11                                           /*!<MCM SC1CON: SCS Position */
#define MCM_SC1CON_SCS_Msk           (0x1UL << MCM_SC1CON_SCS_Pos)                /*!<MCM SC1CON: SCS Mask */

#define MCM_SC1CON_SCEN_Pos          12                                           /*!<MCM SC1CON: SCEN Position */
#define MCM_SC1CON_SCEN_Msk          (0x3UL << MCM_SC1CON_SCEN_Pos)               /*!<MCM SC1CON: SCEN Mask */

#define MCM_SC1CON_Msk_ALL           (MCM_SC1CON_SCTIME_Msk        |\
                                      MCM_SC1CON_SCDEB_Msk         |\
                                      MCM_SC1CON_SCPWM0EN_Msk      |\
                                      MCM_SC1CON_SCPWM1EN_Msk      |\
                                      MCM_SC1CON_SCPWM2EN_Msk      |\
                                      MCM_SC1CON_SCS_Msk           |\
                                      MCM_SC1CON_SCEN_Msk          )

#define MCM_SC2CON_SCTIME_Pos        0                                            /*!<MCM SC2CON: SCTIME Position */
#define MCM_SC2CON_SCTIME_Msk        (0xFUL /*<< MCM_SC2CON_SCTIME_Pos*/)         /*!<MCM SC2CON: SCTIME Mask */

#define MCM_SC2CON_SCDEB_Pos         4                                            /*!<MCM SC2CON: SCDEB Position */
#define MCM_SC2CON_SCDEB_Msk         (0xFUL << MCM_SC2CON_SCDEB_Pos)              /*!<MCM SC2CON: SCDEB Mask */

#define MCM_SC2CON_SCPWM0EN_Pos      8                                            /*!<MCM SC2CON: SCPWM0EN Position */
#define MCM_SC2CON_SCPWM0EN_Msk      (0x1UL << MCM_SC2CON_SCPWM0EN_Pos)           /*!<MCM SC2CON: SCPWM0EN Mask */

#define MCM_SC2CON_SCPWM1EN_Pos      9                                            /*!<MCM SC2CON: SCPWM1EN Position */
#define MCM_SC2CON_SCPWM1EN_Msk      (0x1UL << MCM_SC2CON_SCPWM1EN_Pos)           /*!<MCM SC2CON: SCPWM1EN Mask */

#define MCM_SC2CON_SCPWM2EN_Pos      10                                           /*!<MCM SC2CON: SCPWM2EN Position */
#define MCM_SC2CON_SCPWM2EN_Msk      (0x1UL << MCM_SC2CON_SCPWM2EN_Pos)           /*!<MCM SC2CON: SCPWM2EN Mask */

#define MCM_SC2CON_SCS_Pos           11                                           /*!<MCM SC2CON: SCS Position */
#define MCM_SC2CON_SCS_Msk           (0x1UL << MCM_SC2CON_SCS_Pos)                /*!<MCM SC2CON: SCS Mask */

#define MCM_SC2CON_SCEN_Pos          12                                           /*!<MCM SC2CON: SCEN Position */
#define MCM_SC2CON_SCEN_Msk          (0x3UL << MCM_SC2CON_SCEN_Pos)               /*!<MCM SC2CON: SCEN Mask */

#define MCM_SC2CON_Msk_ALL           (MCM_SC2CON_SCTIME_Msk        |\
                                      MCM_SC2CON_SCDEB_Msk         |\
                                      MCM_SC2CON_SCPWM0EN_Msk      |\
                                      MCM_SC2CON_SCPWM1EN_Msk      |\
                                      MCM_SC2CON_SCPWM2EN_Msk      |\
                                      MCM_SC2CON_SCS_Msk           |\
                                      MCM_SC2CON_SCEN_Msk          )

#define MCM_FLTWEN_FLTWEN_Pos        0                                            /*!<MCM FLTWEN: FLTWEN Position */
#define MCM_FLTWEN_FLTWEN_Msk        (0xFFFFUL /*<< MCM_FLTWEN_FLTWEN_Pos*/)      /*!<MCM FLTWEN: FLTWEN Mask */

#define MCM_FLTWEN_Msk_ALL           (MCM_FLTWEN_FLTWEN_Msk       )

#define PCA_CR_PEN_Pos               0                                            /*!<PCA CR: PEN Position */
#define PCA_CR_PEN_Msk               (0x1UL /*<< PCA_CR_PEN_Pos*/)                /*!<PCA CR: PEN Mask */

#define PCA_CR_Msk_ALL               (PCA_CR_PEN_Msk              )

#define PCA_CFGR_CPS_Pos             0                                            /*!<PCA CFGR: CPS Position */
#define PCA_CFGR_CPS_Msk             (0x7UL /*<< PCA_CFGR_CPS_Pos*/)              /*!<PCA CFGR: CPS Mask */

#define PCA_CFGR_SDEN_Pos            6                                            /*!<PCA CFGR: SDEN Position */
#define PCA_CFGR_SDEN_Msk            (0x1UL << PCA_CFGR_SDEN_Pos)                 /*!<PCA CFGR: SDEN Mask */

#define PCA_CFGR_CIE_Pos             7                                            /*!<PCA CFGR: CIE Position */
#define PCA_CFGR_CIE_Msk             (0x1UL << PCA_CFGR_CIE_Pos)                  /*!<PCA CFGR: CIE Mask */

#define PCA_CFGR_PIE_Pos             8                                            /*!<PCA CFGR: PIE Position */
#define PCA_CFGR_PIE_Msk             (0x1UL << PCA_CFGR_PIE_Pos)                  /*!<PCA CFGR: PIE Mask */

#define PCA_CFGR_ADTSEL_Pos          9                                            /*!<PCA CFGR: ADTSEL Position */
#define PCA_CFGR_ADTSEL_Msk          (0x3UL << PCA_CFGR_ADTSEL_Pos)               /*!<PCA CFGR: ADTSEL Mask */

#define PCA_CFGR_CC0UE_Pos           12                                           /*!<PCA CFGR: CC0UE Position */
#define PCA_CFGR_CC0UE_Msk           (0x1UL << PCA_CFGR_CC0UE_Pos)                /*!<PCA CFGR: CC0UE Mask */

#define PCA_CFGR_CC1UE_Pos           13                                           /*!<PCA CFGR: CC1UE Position */
#define PCA_CFGR_CC1UE_Msk           (0x1UL << PCA_CFGR_CC1UE_Pos)                /*!<PCA CFGR: CC1UE Mask */

#define PCA_CFGR_CC2UE_Pos           14                                           /*!<PCA CFGR: CC2UE Position */
#define PCA_CFGR_CC2UE_Msk           (0x1UL << PCA_CFGR_CC2UE_Pos)                /*!<PCA CFGR: CC2UE Mask */

#define PCA_CFGR_PUE_Pos             15                                           /*!<PCA CFGR: PUE Position */
#define PCA_CFGR_PUE_Msk             (0x1UL << PCA_CFGR_PUE_Pos)                  /*!<PCA CFGR: PUE Mask */

#define PCA_CFGR_ECF_Pos             16                                           /*!<PCA CFGR: ECF Position */
#define PCA_CFGR_ECF_Msk             (0x3UL << PCA_CFGR_ECF_Pos)                  /*!<PCA CFGR: ECF Mask */

#define PCA_CFGR_SYN_Pos             18                                           /*!<PCA CFGR: SYN Position */
#define PCA_CFGR_SYN_Msk             (0x3UL << PCA_CFGR_SYN_Pos)                  /*!<PCA CFGR: SYN Mask */

#define PCA_CFGR_Msk_ALL             (PCA_CFGR_CPS_Msk             |\
                                      PCA_CFGR_SDEN_Msk            |\
                                      PCA_CFGR_CIE_Msk             |\
                                      PCA_CFGR_PIE_Msk             |\
                                      PCA_CFGR_ADTSEL_Msk          |\
                                      PCA_CFGR_CC0UE_Msk           |\
                                      PCA_CFGR_CC1UE_Msk           |\
                                      PCA_CFGR_CC2UE_Msk           |\
                                      PCA_CFGR_PUE_Msk             |\
                                      PCA_CFGR_ECF_Msk             |\
                                      PCA_CFGR_SYN_Msk             )

#define PCA_SR_CC0IF_Pos             0                                            /*!<PCA SR: CC0IF Position */
#define PCA_SR_CC0IF_Msk             (0x1UL /*<< PCA_SR_CC0IF_Pos*/)              /*!<PCA SR: CC0IF Mask */

#define PCA_SR_CC1IF_Pos             1                                            /*!<PCA SR: CC1IF Position */
#define PCA_SR_CC1IF_Msk             (0x1UL << PCA_SR_CC1IF_Pos)                  /*!<PCA SR: CC1IF Mask */

#define PCA_SR_CC2IF_Pos             2                                            /*!<PCA SR: CC2IF Position */
#define PCA_SR_CC2IF_Msk             (0x1UL << PCA_SR_CC2IF_Pos)                  /*!<PCA SR: CC2IF Mask */

#define PCA_SR_FLTIF_Pos             3                                            /*!<PCA SR: FLTIF Position */
#define PCA_SR_FLTIF_Msk             (0x1UL << PCA_SR_FLTIF_Pos)                  /*!<PCA SR: FLTIF Mask */

#define PCA_SR_PIF_Pos               4                                            /*!<PCA SR: PIF Position */
#define PCA_SR_PIF_Msk               (0x1UL << PCA_SR_PIF_Pos)                    /*!<PCA SR: PIF Mask */

#define PCA_SR_CIF_Pos               7                                            /*!<PCA SR: CIF Position */
#define PCA_SR_CIF_Msk               (0x1UL << PCA_SR_CIF_Pos)                    /*!<PCA SR: CIF Mask */

#define PCA_SR_CC0IFC_Pos            16                                           /*!<PCA SR: CC0IFC Position */
#define PCA_SR_CC0IFC_Msk            (0x1UL << PCA_SR_CC0IFC_Pos)                 /*!<PCA SR: CC0IFC Mask */

#define PCA_SR_CC1IFC_Pos            17                                           /*!<PCA SR: CC1IFC Position */
#define PCA_SR_CC1IFC_Msk            (0x1UL << PCA_SR_CC1IFC_Pos)                 /*!<PCA SR: CC1IFC Mask */

#define PCA_SR_CC2IFC_Pos            18                                           /*!<PCA SR: CC2IFC Position */
#define PCA_SR_CC2IFC_Msk            (0x1UL << PCA_SR_CC2IFC_Pos)                 /*!<PCA SR: CC2IFC Mask */

#define PCA_SR_FLTIFC_Pos            19                                           /*!<PCA SR: FLTIFC Position */
#define PCA_SR_FLTIFC_Msk            (0x1UL << PCA_SR_FLTIFC_Pos)                 /*!<PCA SR: FLTIFC Mask */

#define PCA_SR_PIFC_Pos              20                                           /*!<PCA SR: PIFC Position */
#define PCA_SR_PIFC_Msk              (0x1UL << PCA_SR_PIFC_Pos)                   /*!<PCA SR: PIFC Mask */

#define PCA_SR_CIFC_Pos              23                                           /*!<PCA SR: CIFC Position */
#define PCA_SR_CIFC_Msk              (0x1UL << PCA_SR_CIFC_Pos)                   /*!<PCA SR: CIFC Mask */

#define PCA_SR_Msk_ALL               (PCA_SR_CC0IF_Msk             |\
                                      PCA_SR_CC1IF_Msk             |\
                                      PCA_SR_CC2IF_Msk             |\
                                      PCA_SR_FLTIF_Msk             |\
                                      PCA_SR_PIF_Msk               |\
                                      PCA_SR_CIF_Msk               |\
                                      PCA_SR_CC0IFC_Msk            |\
                                      PCA_SR_CC1IFC_Msk            |\
                                      PCA_SR_CC2IFC_Msk            |\
                                      PCA_SR_FLTIFC_Msk            |\
                                      PCA_SR_PIFC_Msk              |\
                                      PCA_SR_CIFC_Msk              )

#define PCA_FORCE_FCO0_Pos           0                                            /*!<PCA FORCE: FCO0 Position */
#define PCA_FORCE_FCO0_Msk           (0x1UL /*<< PCA_FORCE_FCO0_Pos*/)            /*!<PCA FORCE: FCO0 Mask */

#define PCA_FORCE_FCO1_Pos           1                                            /*!<PCA FORCE: FCO1 Position */
#define PCA_FORCE_FCO1_Msk           (0x1UL << PCA_FORCE_FCO1_Pos)                /*!<PCA FORCE: FCO1 Mask */

#define PCA_FORCE_FCO2_Pos           2                                            /*!<PCA FORCE: FCO2 Position */
#define PCA_FORCE_FCO2_Msk           (0x1UL << PCA_FORCE_FCO2_Pos)                /*!<PCA FORCE: FCO2 Mask */

#define PCA_FORCE_Msk_ALL            (PCA_FORCE_FCO0_Msk           |\
                                      PCA_FORCE_FCO1_Msk           |\
                                      PCA_FORCE_FCO2_Msk           )

#define PCA_CNT_CNTL_Pos             0                                            /*!<PCA CNT: CNTL Position */
#define PCA_CNT_CNTL_Msk             (0xFFFFUL /*<< PCA_CNT_CNTL_Pos*/)           /*!<PCA CNT: CNTL Mask */

#define PCA_CNT_CNTH_Pos             16                                           /*!<PCA CNT: CNTH Position */
#define PCA_CNT_CNTH_Msk             (0xFFFFUL << PCA_CNT_CNTH_Pos)               /*!<PCA CNT: CNTH Mask */

#define PCA_CNT_Msk_ALL              (PCA_CNT_CNTL_Msk             |\
                                      PCA_CNT_CNTH_Msk             )

#define PCA_PSC_PSC_Pos              0                                            /*!<PCA PSC: PSC Position */
#define PCA_PSC_PSC_Msk              (0xFFFFUL /*<< PCA_PSC_PSC_Pos*/)            /*!<PCA PSC: PSC Mask */

#define PCA_PSC_Msk_ALL              (PCA_PSC_PSC_Msk             )

#define PCA_PR_PRL_Pos               0                                            /*!<PCA PR: PRL Position */
#define PCA_PR_PRL_Msk               (0xFFFFUL /*<< PCA_PR_PRL_Pos*/)             /*!<PCA PR: PRL Mask */

#define PCA_PR_PRH_Pos               16                                           /*!<PCA PR: PRH Position */
#define PCA_PR_PRH_Msk               (0xFFFFUL << PCA_PR_PRH_Pos)                 /*!<PCA PR: PRH Mask */

#define PCA_PR_Msk_ALL               (PCA_PR_PRL_Msk               |\
                                      PCA_PR_PRH_Msk               )

#define PCA_CCMR0_CCIE_Pos           0                                            /*!<PCA CCMR0: CCIE Position */
#define PCA_CCMR0_CCIE_Msk           (0x1UL /*<< PCA_CCMR0_CCIE_Pos*/)            /*!<PCA CCMR0: CCIE Mask */

#define PCA_CCMR0_TCP_Pos            2                                            /*!<PCA CCMR0: TCP Position */
#define PCA_CCMR0_TCP_Msk            (0x1UL << PCA_CCMR0_TCP_Pos)                 /*!<PCA CCMR0: TCP Mask */

#define PCA_CCMR0_CEN_Pos            3                                            /*!<PCA CCMR0: CEN Position */
#define PCA_CCMR0_CEN_Msk            (0x1UL << PCA_CCMR0_CEN_Pos)                 /*!<PCA CCMR0: CEN Mask */

#define PCA_CCMR0_FS_Pos             4                                            /*!<PCA CCMR0: FS Position */
#define PCA_CCMR0_FS_Msk             (0x3UL << PCA_CCMR0_FS_Pos)                  /*!<PCA CCMR0: FS Mask */

#define PCA_CCMR0_SM_Pos             6                                            /*!<PCA CCMR0: SM Position */
#define PCA_CCMR0_SM_Msk             (0x3UL << PCA_CCMR0_SM_Pos)                  /*!<PCA CCMR0: SM Mask */

#define PCA_CCMR0_CC_Pos             8                                            /*!<PCA CCMR0: CC Position */
#define PCA_CCMR0_CC_Msk             (0x1UL << PCA_CCMR0_CC_Pos)                  /*!<PCA CCMR0: CC Mask */

#define PCA_CCMR0_ICF_Pos            9                                            /*!<PCA CCMR0: ICF Position */
#define PCA_CCMR0_ICF_Msk            (0x7UL << PCA_CCMR0_ICF_Pos)                 /*!<PCA CCMR0: ICF Mask */

#define PCA_CCMR0_CSSEL_Pos          12                                           /*!<PCA CCMR0: CSSEL Position */
#define PCA_CCMR0_CSSEL_Msk          (0x1UL << PCA_CCMR0_CSSEL_Pos)               /*!<PCA CCMR0: CSSEL Mask */

#define PCA_CCMR0_Msk_ALL            (PCA_CCMR0_CCIE_Msk           |\
                                      PCA_CCMR0_TCP_Msk            |\
                                      PCA_CCMR0_CEN_Msk            |\
                                      PCA_CCMR0_FS_Msk             |\
                                      PCA_CCMR0_SM_Msk             |\
                                      PCA_CCMR0_CC_Msk             |\
                                      PCA_CCMR0_ICF_Msk            |\
                                      PCA_CCMR0_CSSEL_Msk          )

#define PCA_CCMR1_CCIE_Pos           0                                            /*!<PCA CCMR1: CCIE Position */
#define PCA_CCMR1_CCIE_Msk           (0x1UL /*<< PCA_CCMR1_CCIE_Pos*/)            /*!<PCA CCMR1: CCIE Mask */

#define PCA_CCMR1_TCP_Pos            2                                            /*!<PCA CCMR1: TCP Position */
#define PCA_CCMR1_TCP_Msk            (0x1UL << PCA_CCMR1_TCP_Pos)                 /*!<PCA CCMR1: TCP Mask */

#define PCA_CCMR1_CEN_Pos            3                                            /*!<PCA CCMR1: CEN Position */
#define PCA_CCMR1_CEN_Msk            (0x1UL << PCA_CCMR1_CEN_Pos)                 /*!<PCA CCMR1: CEN Mask */

#define PCA_CCMR1_FS_Pos             4                                            /*!<PCA CCMR1: FS Position */
#define PCA_CCMR1_FS_Msk             (0x3UL << PCA_CCMR1_FS_Pos)                  /*!<PCA CCMR1: FS Mask */

#define PCA_CCMR1_SM_Pos             6                                            /*!<PCA CCMR1: SM Position */
#define PCA_CCMR1_SM_Msk             (0x3UL << PCA_CCMR1_SM_Pos)                  /*!<PCA CCMR1: SM Mask */

#define PCA_CCMR1_CC_Pos             8                                            /*!<PCA CCMR1: CC Position */
#define PCA_CCMR1_CC_Msk             (0x1UL << PCA_CCMR1_CC_Pos)                  /*!<PCA CCMR1: CC Mask */

#define PCA_CCMR1_ICF_Pos            9                                            /*!<PCA CCMR1: ICF Position */
#define PCA_CCMR1_ICF_Msk            (0x7UL << PCA_CCMR1_ICF_Pos)                 /*!<PCA CCMR1: ICF Mask */

#define PCA_CCMR1_CSSEL_Pos          12                                           /*!<PCA CCMR1: CSSEL Position */
#define PCA_CCMR1_CSSEL_Msk          (0x1UL << PCA_CCMR1_CSSEL_Pos)               /*!<PCA CCMR1: CSSEL Mask */

#define PCA_CCMR1_Msk_ALL            (PCA_CCMR1_CCIE_Msk           |\
                                      PCA_CCMR1_TCP_Msk            |\
                                      PCA_CCMR1_CEN_Msk            |\
                                      PCA_CCMR1_FS_Msk             |\
                                      PCA_CCMR1_SM_Msk             |\
                                      PCA_CCMR1_CC_Msk             |\
                                      PCA_CCMR1_ICF_Msk            |\
                                      PCA_CCMR1_CSSEL_Msk          )

#define PCA_CCMR2_CCIE_Pos           0                                            /*!<PCA CCMR2: CCIE Position */
#define PCA_CCMR2_CCIE_Msk           (0x1UL /*<< PCA_CCMR2_CCIE_Pos*/)            /*!<PCA CCMR2: CCIE Mask */

#define PCA_CCMR2_TCP_Pos            2                                            /*!<PCA CCMR2: TCP Position */
#define PCA_CCMR2_TCP_Msk            (0x1UL << PCA_CCMR2_TCP_Pos)                 /*!<PCA CCMR2: TCP Mask */

#define PCA_CCMR2_CEN_Pos            3                                            /*!<PCA CCMR2: CEN Position */
#define PCA_CCMR2_CEN_Msk            (0x1UL << PCA_CCMR2_CEN_Pos)                 /*!<PCA CCMR2: CEN Mask */

#define PCA_CCMR2_FS_Pos             4                                            /*!<PCA CCMR2: FS Position */
#define PCA_CCMR2_FS_Msk             (0x3UL << PCA_CCMR2_FS_Pos)                  /*!<PCA CCMR2: FS Mask */

#define PCA_CCMR2_SM_Pos             6                                            /*!<PCA CCMR2: SM Position */
#define PCA_CCMR2_SM_Msk             (0x3UL << PCA_CCMR2_SM_Pos)                  /*!<PCA CCMR2: SM Mask */

#define PCA_CCMR2_CC_Pos             8                                            /*!<PCA CCMR2: CC Position */
#define PCA_CCMR2_CC_Msk             (0x1UL << PCA_CCMR2_CC_Pos)                  /*!<PCA CCMR2: CC Mask */

#define PCA_CCMR2_ICF_Pos            9                                            /*!<PCA CCMR2: ICF Position */
#define PCA_CCMR2_ICF_Msk            (0x7UL << PCA_CCMR2_ICF_Pos)                 /*!<PCA CCMR2: ICF Mask */

#define PCA_CCMR2_CSSEL_Pos          12                                           /*!<PCA CCMR2: CSSEL Position */
#define PCA_CCMR2_CSSEL_Msk          (0x1UL << PCA_CCMR2_CSSEL_Pos)               /*!<PCA CCMR2: CSSEL Mask */

#define PCA_CCMR2_Msk_ALL            (PCA_CCMR2_CCIE_Msk           |\
                                      PCA_CCMR2_TCP_Msk            |\
                                      PCA_CCMR2_CEN_Msk            |\
                                      PCA_CCMR2_FS_Msk             |\
                                      PCA_CCMR2_SM_Msk             |\
                                      PCA_CCMR2_CC_Msk             |\
                                      PCA_CCMR2_ICF_Msk            |\
                                      PCA_CCMR2_CSSEL_Msk          )

#define PCA_CCR0_CCR0L_Pos           0                                            /*!<PCA CCR0: CCR0L Position */
#define PCA_CCR0_CCR0L_Msk           (0xFFFFUL /*<< PCA_CCR0_CCR0L_Pos*/)         /*!<PCA CCR0: CCR0L Mask */

#define PCA_CCR0_CCR0H_Pos           16                                           /*!<PCA CCR0: CCR0H Position */
#define PCA_CCR0_CCR0H_Msk           (0xFFFFUL << PCA_CCR0_CCR0H_Pos)             /*!<PCA CCR0: CCR0H Mask */

#define PCA_CCR0_Msk_ALL             (PCA_CCR0_CCR0L_Msk           |\
                                      PCA_CCR0_CCR0H_Msk           )

#define PCA_CCR1_CCR1L_Pos           0                                            /*!<PCA CCR1: CCR1L Position */
#define PCA_CCR1_CCR1L_Msk           (0xFFFFUL /*<< PCA_CCR1_CCR1L_Pos*/)         /*!<PCA CCR1: CCR1L Mask */

#define PCA_CCR1_CCR1H_Pos           16                                           /*!<PCA CCR1: CCR1H Position */
#define PCA_CCR1_CCR1H_Msk           (0xFFFFUL << PCA_CCR1_CCR1H_Pos)             /*!<PCA CCR1: CCR1H Mask */

#define PCA_CCR1_Msk_ALL             (PCA_CCR1_CCR1L_Msk           |\
                                      PCA_CCR1_CCR1H_Msk           )

#define PCA_CCR2_CCR2L_Pos           0                                            /*!<PCA CCR2: CCR2L Position */
#define PCA_CCR2_CCR2L_Msk           (0xFFFFUL /*<< PCA_CCR2_CCR2L_Pos*/)         /*!<PCA CCR2: CCR2L Mask */

#define PCA_CCR2_CCR2H_Pos           16                                           /*!<PCA CCR2: CCR2H Position */
#define PCA_CCR2_CCR2H_Msk           (0xFFFFUL << PCA_CCR2_CCR2H_Pos)             /*!<PCA CCR2: CCR2H Mask */

#define PCA_CCR2_Msk_ALL             (PCA_CCR2_CCR2L_Msk           |\
                                      PCA_CCR2_CCR2H_Msk           )

#define PCA_LCKR_KEY_Pos             0                                            /*!<PCA LCKR: KEY Position */
#define PCA_LCKR_KEY_Msk             (0xFFFFUL /*<< PCA_LCKR_KEY_Pos*/)           /*!<PCA LCKR: KEY Mask */

#define PCA_LCKR_Msk_ALL             (PCA_LCKR_KEY_Msk            )

#define PCA_FLTWPR_KEY_Pos           0                                            /*!<PCA FLTWPR: KEY Position */
#define PCA_FLTWPR_KEY_Msk           (0xFFFFUL /*<< PCA_FLTWPR_KEY_Pos*/)         /*!<PCA FLTWPR: KEY Mask */

#define PCA_FLTWPR_Msk_ALL           (PCA_FLTWPR_KEY_Msk          )

#define PCA_FLTCR_FLTSTAT_Pos        0                                            /*!<PCA FLTCR: FLTSTAT Position */
#define PCA_FLTCR_FLTSTAT_Msk        (0x1UL /*<< PCA_FLTCR_FLTSTAT_Pos*/)         /*!<PCA FLTCR: FLTSTAT Mask */

#define PCA_FLTCR_FLTM_Pos           1                                            /*!<PCA FLTCR: FLTM Position */
#define PCA_FLTCR_FLTM_Msk           (0x1UL << PCA_FLTCR_FLTM_Pos)                /*!<PCA FLTCR: FLTM Mask */

#define PCA_FLTCR_FLT2S_Pos          2                                            /*!<PCA FLTCR: FLT2S Position */
#define PCA_FLTCR_FLT2S_Msk          (0x1UL << PCA_FLTCR_FLT2S_Pos)               /*!<PCA FLTCR: FLT2S Mask */

#define PCA_FLTCR_FLT2EN_Pos         3                                            /*!<PCA FLTCR: FLT2EN Position */
#define PCA_FLTCR_FLT2EN_Msk         (0x1UL << PCA_FLTCR_FLT2EN_Pos)              /*!<PCA FLTCR: FLT2EN Mask */

#define PCA_FLTCR_FLT2DEB_Pos        4                                            /*!<PCA FLTCR: FLT2DEB Position */
#define PCA_FLTCR_FLT2DEB_Msk        (0xFUL << PCA_FLTCR_FLT2DEB_Pos)             /*!<PCA FLTCR: FLT2DEB Mask */

#define PCA_FLTCR_FLT1SEL_Pos        8                                            /*!<PCA FLTCR: FLT1SEL Position */
#define PCA_FLTCR_FLT1SEL_Msk        (0x3UL << PCA_FLTCR_FLT1SEL_Pos)             /*!<PCA FLTCR: FLT1SEL Mask */

#define PCA_FLTCR_FLT1EN_Pos         10                                           /*!<PCA FLTCR: FLT1EN Position */
#define PCA_FLTCR_FLT1EN_Msk         (0x1UL << PCA_FLTCR_FLT1EN_Pos)              /*!<PCA FLTCR: FLT1EN Mask */

#define PCA_FLTCR_FLTSYN_Pos         11                                           /*!<PCA FLTCR: FLTSYN Position */
#define PCA_FLTCR_FLTSYN_Msk         (0x1UL << PCA_FLTCR_FLTSYN_Pos)              /*!<PCA FLTCR: FLTSYN Mask */

#define PCA_FLTCR_FOUT_Pos           12                                           /*!<PCA FLTCR: FOUT Position */
#define PCA_FLTCR_FOUT_Msk           (0x3UL << PCA_FLTCR_FOUT_Pos)                /*!<PCA FLTCR: FOUT Mask */

#define PCA_FLTCR_FLTIE_Pos          14                                           /*!<PCA FLTCR: FLTIE Position */
#define PCA_FLTCR_FLTIE_Msk          (0x1UL << PCA_FLTCR_FLTIE_Pos)               /*!<PCA FLTCR: FLTIE Mask */

#define PCA_FLTCR_Msk_ALL            (PCA_FLTCR_FLTSTAT_Msk        |\
                                      PCA_FLTCR_FLTM_Msk           |\
                                      PCA_FLTCR_FLT2S_Msk          |\
                                      PCA_FLTCR_FLT2EN_Msk         |\
                                      PCA_FLTCR_FLT2DEB_Msk        |\
                                      PCA_FLTCR_FLT1SEL_Msk        |\
                                      PCA_FLTCR_FLT1EN_Msk         |\
                                      PCA_FLTCR_FLTSYN_Msk         |\
                                      PCA_FLTCR_FOUT_Msk           |\
                                      PCA_FLTCR_FLTIE_Msk          )

#define TIM_CR_STR_Pos               0                                            /*!<TIM CR: STR Position */
#define TIM_CR_STR_Msk               (0x1UL /*<< TIM_CR_STR_Pos*/)                /*!<TIM CR: STR Mask */

#define TIM_CR_OPM_Pos               3                                            /*!<TIM CR: OPM Position */
#define TIM_CR_OPM_Msk               (0x1UL << TIM_CR_OPM_Pos)                    /*!<TIM CR: OPM Mask */

#define TIM_CR_CLKS_Pos              4                                            /*!<TIM CR: CLKS Position */
#define TIM_CR_CLKS_Msk              (0x3UL << TIM_CR_CLKS_Pos)                   /*!<TIM CR: CLKS Mask */

#define TIM_CR_IE_Pos                7                                            /*!<TIM CR: IE Position */
#define TIM_CR_IE_Msk                (0x1UL << TIM_CR_IE_Pos)                     /*!<TIM CR: IE Mask */

#define TIM_CR_TRIGEN_Pos            8                                            /*!<TIM CR: TRIGEN Position */
#define TIM_CR_TRIGEN_Msk            (0x1UL << TIM_CR_TRIGEN_Pos)                 /*!<TIM CR: TRIGEN Mask */

#define TIM_CR_ETEN_Pos              9                                            /*!<TIM CR: ETEN Position */
#define TIM_CR_ETEN_Msk              (0x1UL << TIM_CR_ETEN_Pos)                   /*!<TIM CR: ETEN Mask */

#define TIM_CR_TC_Pos                10                                           /*!<TIM CR: TC Position */
#define TIM_CR_TC_Msk                (0x1UL << TIM_CR_TC_Pos)                     /*!<TIM CR: TC Mask */

#define TIM_CR_ECF_Pos               12                                           /*!<TIM CR: ECF Position */
#define TIM_CR_ECF_Msk               (0x3UL << TIM_CR_ECF_Pos)                    /*!<TIM CR: ECF Mask */

#define TIM_CR_CASCEN_Pos            15                                           /*!<TIM CR: CASCEN Position */
#define TIM_CR_CASCEN_Msk            (0x1UL << TIM_CR_CASCEN_Pos)                 /*!<TIM CR: CASCEN Mask */

#define TIM_CR_Msk_ALL               (TIM_CR_STR_Msk               |\
                                      TIM_CR_OPM_Msk               |\
                                      TIM_CR_CLKS_Msk              |\
                                      TIM_CR_IE_Msk                |\
                                      TIM_CR_TRIGEN_Msk            |\
                                      TIM_CR_ETEN_Msk              |\
                                      TIM_CR_TC_Msk                |\
                                      TIM_CR_ECF_Msk               |\
                                      TIM_CR_CASCEN_Msk            )

#define TIM_TCNT_TCNTL_Pos           0                                            /*!<TIM TCNT: TCNTL Position */
#define TIM_TCNT_TCNTL_Msk           (0xFFFFUL /*<< TIM_TCNT_TCNTL_Pos*/)         /*!<TIM TCNT: TCNTL Mask */

#define TIM_TCNT_TCNTH_Pos           16                                           /*!<TIM TCNT: TCNTH Position */
#define TIM_TCNT_TCNTH_Msk           (0xFFFFUL << TIM_TCNT_TCNTH_Pos)             /*!<TIM TCNT: TCNTH Mask */

#define TIM_TCNT_Msk_ALL             (TIM_TCNT_TCNTL_Msk           |\
                                      TIM_TCNT_TCNTH_Msk           )

#define TIM_TPR_TPRL_Pos             0                                            /*!<TIM TPR: TPRL Position */
#define TIM_TPR_TPRL_Msk             (0xFFFFUL /*<< TIM_TPR_TPRL_Pos*/)           /*!<TIM TPR: TPRL Mask */

#define TIM_TPR_TPRH_Pos             16                                           /*!<TIM TPR: TPRH Position */
#define TIM_TPR_TPRH_Msk             (0xFFFFUL << TIM_TPR_TPRH_Pos)               /*!<TIM TPR: TPRH Mask */

#define TIM_TPR_Msk_ALL              (TIM_TPR_TPRL_Msk             |\
                                      TIM_TPR_TPRH_Msk             )

#define TIM_PSQ_PSQL_Pos             0                                            /*!<TIM PSQ: PSQL Position */
#define TIM_PSQ_PSQL_Msk             (0xFFFFUL /*<< TIM_PSQ_PSQL_Pos*/)           /*!<TIM PSQ: PSQL Mask */

#define TIM_PSQ_PSQH_Pos             16                                           /*!<TIM PSQ: PSQH Position */
#define TIM_PSQ_PSQH_Msk             (0xFFFFUL << TIM_PSQ_PSQH_Pos)               /*!<TIM PSQ: PSQH Mask */

#define TIM_PSQ_Msk_ALL              (TIM_PSQ_PSQL_Msk             |\
                                      TIM_PSQ_PSQH_Msk             )

#define TIM_TIMINTF_TF_Pos           0                                            /*!<TIM TIMINTF: TF Position */
#define TIM_TIMINTF_TF_Msk           (0x1UL /*<< TIM_TIMINTF_TF_Pos*/)            /*!<TIM TIMINTF: TF Mask */

#define TIM_TIMINTF_TFC_Pos          16                                           /*!<TIM TIMINTF: TFC Position */
#define TIM_TIMINTF_TFC_Msk          (0x1UL << TIM_TIMINTF_TFC_Pos)               /*!<TIM TIMINTF: TFC Mask */

#define TIM_TIMINTF_Msk_ALL          (TIM_TIMINTF_TF_Msk           |\
                                      TIM_TIMINTF_TFC_Msk          )

#define QEI_QEICON_QPMOD_Pos         0                                            /*!<QEI QEICON: QPMOD Position */
#define QEI_QEICON_QPMOD_Msk         (0x3UL /*<< QEI_QEICON_QPMOD_Pos*/)          /*!<QEI QEICON: QPMOD Mask */

#define QEI_QEICON_QTSR_Pos          2                                            /*!<QEI QEICON: QTSR Position */
#define QEI_QEICON_QTSR_Msk          (0x1UL << QEI_QEICON_QTSR_Pos)               /*!<QEI QEICON: QTSR Mask */

#define QEI_QEICON_QEIEN_Pos         3                                            /*!<QEI QEICON: QEIEN Position */
#define QEI_QEICON_QEIEN_Msk         (0x1UL << QEI_QEICON_QEIEN_Pos)              /*!<QEI QEICON: QEIEN Mask */

#define QEI_QEICON_QIDXEN_Pos        4                                            /*!<QEI QEICON: QIDXEN Position */
#define QEI_QEICON_QIDXEN_Msk        (0x1UL << QEI_QEICON_QIDXEN_Pos)             /*!<QEI QEICON: QIDXEN Mask */

#define QEI_QEICON_QSWAP_Pos         5                                            /*!<QEI QEICON: QSWAP Position */
#define QEI_QEICON_QSWAP_Msk         (0x1UL << QEI_QEICON_QSWAP_Pos)              /*!<QEI QEICON: QSWAP Mask */

#define QEI_QEICON_QIDXS_Pos         6                                            /*!<QEI QEICON: QIDXS Position */
#define QEI_QEICON_QIDXS_Msk         (0x1UL << QEI_QEICON_QIDXS_Pos)              /*!<QEI QEICON: QIDXS Mask */

#define QEI_QEICON_QPDIR_Pos         7                                            /*!<QEI QEICON: QPDIR Position */
#define QEI_QEICON_QPDIR_Msk         (0x1UL << QEI_QEICON_QPDIR_Pos)              /*!<QEI QEICON: QPDIR Mask */

#define QEI_QEICON_QTEPS_Pos         8                                            /*!<QEI QEICON: QTEPS Position */
#define QEI_QEICON_QTEPS_Msk         (0xFUL << QEI_QEICON_QTEPS_Pos)              /*!<QEI QEICON: QTEPS Mask */

#define QEI_QEICON_Msk_ALL           (QEI_QEICON_QPMOD_Msk         |\
                                      QEI_QEICON_QTSR_Msk          |\
                                      QEI_QEICON_QEIEN_Msk         |\
                                      QEI_QEICON_QIDXEN_Msk        |\
                                      QEI_QEICON_QSWAP_Msk         |\
                                      QEI_QEICON_QIDXS_Msk         |\
                                      QEI_QEICON_QPDIR_Msk         |\
                                      QEI_QEICON_QTEPS_Msk         )

#define QEI_QFLTCON_QABCPS_Pos       0                                            /*!<QEI QFLTCON: QABCPS Position */
#define QEI_QFLTCON_QABCPS_Msk       (0x7UL /*<< QEI_QFLTCON_QABCPS_Pos*/)        /*!<QEI QFLTCON: QABCPS Mask */

#define QEI_QFLTCON_QABFEN_Pos       3                                            /*!<QEI QFLTCON: QABFEN Position */
#define QEI_QFLTCON_QABFEN_Msk       (0x1UL << QEI_QFLTCON_QABFEN_Pos)            /*!<QEI QFLTCON: QABFEN Mask */

#define QEI_QFLTCON_QIDXCPS_Pos      4                                            /*!<QEI QFLTCON: QIDXCPS Position */
#define QEI_QFLTCON_QIDXCPS_Msk      (0x7UL << QEI_QFLTCON_QIDXCPS_Pos)           /*!<QEI QFLTCON: QIDXCPS Mask */

#define QEI_QFLTCON_QIDXFEN_Pos      7                                            /*!<QEI QFLTCON: QIDXFEN Position */
#define QEI_QFLTCON_QIDXFEN_Msk      (0x1UL << QEI_QFLTCON_QIDXFEN_Pos)           /*!<QEI QFLTCON: QIDXFEN Mask */

#define QEI_QFLTCON_Msk_ALL          (QEI_QFLTCON_QABCPS_Msk       |\
                                      QEI_QFLTCON_QABFEN_Msk       |\
                                      QEI_QFLTCON_QIDXCPS_Msk      |\
                                      QEI_QFLTCON_QIDXFEN_Msk      )

#define QEI_QPOSCNT_QPOSCNT_Pos      0                                            /*!<QEI QPOSCNT: QPOSCNT Position */
#define QEI_QPOSCNT_QPOSCNT_Msk      (0xFFFFUL /*<< QEI_QPOSCNT_QPOSCNT_Pos*/)    /*!<QEI QPOSCNT: QPOSCNT Mask */

#define QEI_QPOSCNT_Msk_ALL          (QEI_QPOSCNT_QPOSCNT_Msk     )

#define QEI_QPOSMAX_QPOSMAX_Pos      0                                            /*!<QEI QPOSMAX: QPOSMAX Position */
#define QEI_QPOSMAX_QPOSMAX_Msk      (0xFFFFUL /*<< QEI_QPOSMAX_QPOSMAX_Pos*/)    /*!<QEI QPOSMAX: QPOSMAX Mask */

#define QEI_QPOSMAX_Msk_ALL          (QEI_QPOSMAX_QPOSMAX_Msk     )

#define QEI_QCNTMIN_QCNTMIN_Pos      0                                            /*!<QEI QCNTMIN: QCNTMIN Position */
#define QEI_QCNTMIN_QCNTMIN_Msk      (0xFFFFUL /*<< QEI_QCNTMIN_QCNTMIN_Pos*/)    /*!<QEI QCNTMIN: QCNTMIN Mask */

#define QEI_QCNTMIN_Msk_ALL          (QEI_QCNTMIN_QCNTMIN_Msk     )

#define QEI_QTPSQ_QTPSQ_Pos          0                                            /*!<QEI QTPSQ: QTPSQ Position */
#define QEI_QTPSQ_QTPSQ_Msk          (0xFFFFUL /*<< QEI_QTPSQ_QTPSQ_Pos*/)        /*!<QEI QTPSQ: QTPSQ Mask */

#define QEI_QTPSQ_Msk_ALL            (QEI_QTPSQ_QTPSQ_Msk         )

#define QEI_QEIINT_QPEIE_Pos         0                                            /*!<QEI QEIINT: QPEIE Position */
#define QEI_QEIINT_QPEIE_Msk         (0x1UL /*<< QEI_QEIINT_QPEIE_Pos*/)          /*!<QEI QEIINT: QPEIE Mask */

#define QEI_QEIINT_QCEIE_Pos         1                                            /*!<QEI QEIINT: QCEIE Position */
#define QEI_QEIINT_QCEIE_Msk         (0x1UL << QEI_QEIINT_QCEIE_Pos)              /*!<QEI QEIINT: QCEIE Mask */

#define QEI_QEIINT_QEIIE_Pos         2                                            /*!<QEI QEIINT: QEIIE Position */
#define QEI_QEIINT_QEIIE_Msk         (0x1UL << QEI_QEIINT_QEIIE_Pos)              /*!<QEI QEIINT: QEIIE Mask */

#define QEI_QEIINT_QTCAPIE_Pos       3                                            /*!<QEI QEIINT: QTCAPIE Position */
#define QEI_QEIINT_QTCAPIE_Msk       (0x1UL << QEI_QEIINT_QTCAPIE_Pos)            /*!<QEI QEIINT: QTCAPIE Mask */

#define QEI_QEIINT_QTIE_Pos          4                                            /*!<QEI QEIINT: QTIE Position */
#define QEI_QEIINT_QTIE_Msk          (0x1UL << QEI_QEIINT_QTIE_Pos)               /*!<QEI QEIINT: QTIE Mask */

#define QEI_QEIINT_Msk_ALL           (QEI_QEIINT_QPEIE_Msk         |\
                                      QEI_QEIINT_QCEIE_Msk         |\
                                      QEI_QEIINT_QEIIE_Msk         |\
                                      QEI_QEIINT_QTCAPIE_Msk       |\
                                      QEI_QEIINT_QTIE_Msk          )

#define QEI_QTINTF_QPEIF_Pos         0                                            /*!<QEI QTINTF: QPEIF Position */
#define QEI_QTINTF_QPEIF_Msk         (0x1UL /*<< QEI_QTINTF_QPEIF_Pos*/)          /*!<QEI QTINTF: QPEIF Mask */

#define QEI_QTINTF_QCEIF_Pos         1                                            /*!<QEI QTINTF: QCEIF Position */
#define QEI_QTINTF_QCEIF_Msk         (0x1UL << QEI_QTINTF_QCEIF_Pos)              /*!<QEI QTINTF: QCEIF Mask */

#define QEI_QTINTF_QEIIF_Pos         2                                            /*!<QEI QTINTF: QEIIF Position */
#define QEI_QTINTF_QEIIF_Msk         (0x1UL << QEI_QTINTF_QEIIF_Pos)              /*!<QEI QTINTF: QEIIF Mask */

#define QEI_QTINTF_QTCAPIF_Pos       3                                            /*!<QEI QTINTF: QTCAPIF Position */
#define QEI_QTINTF_QTCAPIF_Msk       (0x1UL << QEI_QTINTF_QTCAPIF_Pos)            /*!<QEI QTINTF: QTCAPIF Mask */

#define QEI_QTINTF_QTIF_Pos          4                                            /*!<QEI QTINTF: QTIF Position */
#define QEI_QTINTF_QTIF_Msk          (0x1UL << QEI_QTINTF_QTIF_Pos)               /*!<QEI QTINTF: QTIF Mask */

#define QEI_QTINTF_QPEIFC_Pos        16                                           /*!<QEI QTINTF: QPEIFC Position */
#define QEI_QTINTF_QPEIFC_Msk        (0x1UL << QEI_QTINTF_QPEIFC_Pos)             /*!<QEI QTINTF: QPEIFC Mask */

#define QEI_QTINTF_QCEIFC_Pos        17                                           /*!<QEI QTINTF: QCEIFC Position */
#define QEI_QTINTF_QCEIFC_Msk        (0x1UL << QEI_QTINTF_QCEIFC_Pos)             /*!<QEI QTINTF: QCEIFC Mask */

#define QEI_QTINTF_QEIIFC_Pos        18                                           /*!<QEI QTINTF: QEIIFC Position */
#define QEI_QTINTF_QEIIFC_Msk        (0x1UL << QEI_QTINTF_QEIIFC_Pos)             /*!<QEI QTINTF: QEIIFC Mask */

#define QEI_QTINTF_QTCAPIFC_Pos      19                                           /*!<QEI QTINTF: QTCAPIFC Position */
#define QEI_QTINTF_QTCAPIFC_Msk      (0x1UL << QEI_QTINTF_QTCAPIFC_Pos)           /*!<QEI QTINTF: QTCAPIFC Mask */

#define QEI_QTINTF_QTIFC_Pos         20                                           /*!<QEI QTINTF: QTIFC Position */
#define QEI_QTINTF_QTIFC_Msk         (0x1UL << QEI_QTINTF_QTIFC_Pos)              /*!<QEI QTINTF: QTIFC Mask */

#define QEI_QTINTF_Msk_ALL           (QEI_QTINTF_QPEIF_Msk         |\
                                      QEI_QTINTF_QCEIF_Msk         |\
                                      QEI_QTINTF_QEIIF_Msk         |\
                                      QEI_QTINTF_QTCAPIF_Msk       |\
                                      QEI_QTINTF_QTIF_Msk          |\
                                      QEI_QTINTF_QPEIFC_Msk        |\
                                      QEI_QTINTF_QCEIFC_Msk        |\
                                      QEI_QTINTF_QEIIFC_Msk        |\
                                      QEI_QTINTF_QTCAPIFC_Msk      |\
                                      QEI_QTINTF_QTIFC_Msk         )

#define MACP_CORDCSR0_RUN_Pos        0                                            /*!<MACP CORDCSR0: RUN Position */
#define MACP_CORDCSR0_RUN_Msk        (0x1UL /*<< MACP_CORDCSR0_RUN_Pos*/)         /*!<MACP CORDCSR0: RUN Mask */

#define MACP_CORDCSR0_OVF_Pos        1                                            /*!<MACP CORDCSR0: OVF Position */
#define MACP_CORDCSR0_OVF_Msk        (0x1UL << MACP_CORDCSR0_OVF_Pos)             /*!<MACP CORDCSR0: OVF Mask */

#define MACP_CORDCSR0_KADJ_Pos       2                                            /*!<MACP CORDCSR0: KADJ Position */
#define MACP_CORDCSR0_KADJ_Msk       (0x1UL << MACP_CORDCSR0_KADJ_Pos)            /*!<MACP CORDCSR0: KADJ Mask */

#define MACP_CORDCSR0_XYMRS_Pos      3                                            /*!<MACP CORDCSR0: XYMRS Position */
#define MACP_CORDCSR0_XYMRS_Msk      (0x1UL << MACP_CORDCSR0_XYMRS_Pos)           /*!<MACP CORDCSR0: XYMRS Mask */

#define MACP_CORDCSR0_FORMAT_Pos     5                                            /*!<MACP CORDCSR0: FORMAT Position */
#define MACP_CORDCSR0_FORMAT_Msk     (0x3UL << MACP_CORDCSR0_FORMAT_Pos)          /*!<MACP CORDCSR0: FORMAT Mask */

#define MACP_CORDCSR0_MODE_Pos       7                                            /*!<MACP CORDCSR0: MODE Position */
#define MACP_CORDCSR0_MODE_Msk       (0x1UL << MACP_CORDCSR0_MODE_Pos)            /*!<MACP CORDCSR0: MODE Mask */

#define MACP_CORDCSR0_ITERA_Pos      8                                            /*!<MACP CORDCSR0: ITERA Position */
#define MACP_CORDCSR0_ITERA_Msk      (0x1FUL << MACP_CORDCSR0_ITERA_Pos)          /*!<MACP CORDCSR0: ITERA Mask */

#define MACP_CORDCSR0_ARITH_Pos      13                                           /*!<MACP CORDCSR0: ARITH Position */
#define MACP_CORDCSR0_ARITH_Msk      (0x3UL << MACP_CORDCSR0_ARITH_Pos)           /*!<MACP CORDCSR0: ARITH Mask */

#define MACP_CORDCSR0_Msk_ALL        (MACP_CORDCSR0_RUN_Msk        |\
                                      MACP_CORDCSR0_OVF_Msk        |\
                                      MACP_CORDCSR0_KADJ_Msk       |\
                                      MACP_CORDCSR0_XYMRS_Msk      |\
                                      MACP_CORDCSR0_FORMAT_Msk     |\
                                      MACP_CORDCSR0_MODE_Msk       |\
                                      MACP_CORDCSR0_ITERA_Msk      |\
                                      MACP_CORDCSR0_ARITH_Msk      )

#define MACP_CORDCSR1_RUN_Pos        0                                            /*!<MACP CORDCSR1: RUN Position */
#define MACP_CORDCSR1_RUN_Msk        (0x1UL /*<< MACP_CORDCSR1_RUN_Pos*/)         /*!<MACP CORDCSR1: RUN Mask */

#define MACP_CORDCSR1_OVF_Pos        1                                            /*!<MACP CORDCSR1: OVF Position */
#define MACP_CORDCSR1_OVF_Msk        (0x1UL << MACP_CORDCSR1_OVF_Pos)             /*!<MACP CORDCSR1: OVF Mask */

#define MACP_CORDCSR1_KADJ_Pos       2                                            /*!<MACP CORDCSR1: KADJ Position */
#define MACP_CORDCSR1_KADJ_Msk       (0x1UL << MACP_CORDCSR1_KADJ_Pos)            /*!<MACP CORDCSR1: KADJ Mask */

#define MACP_CORDCSR1_XYMRS_Pos      3                                            /*!<MACP CORDCSR1: XYMRS Position */
#define MACP_CORDCSR1_XYMRS_Msk      (0x1UL << MACP_CORDCSR1_XYMRS_Pos)           /*!<MACP CORDCSR1: XYMRS Mask */

#define MACP_CORDCSR1_FORMAT_Pos     5                                            /*!<MACP CORDCSR1: FORMAT Position */
#define MACP_CORDCSR1_FORMAT_Msk     (0x3UL << MACP_CORDCSR1_FORMAT_Pos)          /*!<MACP CORDCSR1: FORMAT Mask */

#define MACP_CORDCSR1_MODE_Pos       7                                            /*!<MACP CORDCSR1: MODE Position */
#define MACP_CORDCSR1_MODE_Msk       (0x1UL << MACP_CORDCSR1_MODE_Pos)            /*!<MACP CORDCSR1: MODE Mask */

#define MACP_CORDCSR1_ITERA_Pos      8                                            /*!<MACP CORDCSR1: ITERA Position */
#define MACP_CORDCSR1_ITERA_Msk      (0x1FUL << MACP_CORDCSR1_ITERA_Pos)          /*!<MACP CORDCSR1: ITERA Mask */

#define MACP_CORDCSR1_ARITH_Pos      13                                           /*!<MACP CORDCSR1: ARITH Position */
#define MACP_CORDCSR1_ARITH_Msk      (0x3UL << MACP_CORDCSR1_ARITH_Pos)           /*!<MACP CORDCSR1: ARITH Mask */

#define MACP_CORDCSR1_Msk_ALL        (MACP_CORDCSR1_RUN_Msk        |\
                                      MACP_CORDCSR1_OVF_Msk        |\
                                      MACP_CORDCSR1_KADJ_Msk       |\
                                      MACP_CORDCSR1_XYMRS_Msk      |\
                                      MACP_CORDCSR1_FORMAT_Msk     |\
                                      MACP_CORDCSR1_MODE_Msk       |\
                                      MACP_CORDCSR1_ITERA_Msk      |\
                                      MACP_CORDCSR1_ARITH_Msk      )

#define MACP_SVCON_RUN_Pos           0                                            /*!<MACP SVCON: RUN Position */
#define MACP_SVCON_RUN_Msk           (0x1UL /*<< MACP_SVCON_RUN_Pos*/)            /*!<MACP SVCON: RUN Mask */

#define MACP_SVCON_Msk_ALL           (MACP_SVCON_RUN_Msk          )

#define MACP_SVIQN_SVIQN_Pos         0                                            /*!<MACP SVIQN: SVIQN Position */
#define MACP_SVIQN_SVIQN_Msk         (0xFFUL /*<< MACP_SVIQN_SVIQN_Pos*/)         /*!<MACP SVIQN: SVIQN Mask */

#define MACP_SVIQN_SVTYP_Pos         8                                            /*!<MACP SVIQN: SVTYP Position */
#define MACP_SVIQN_SVTYP_Msk         (0x1UL << MACP_SVIQN_SVTYP_Pos)              /*!<MACP SVIQN: SVTYP Mask */

#define MACP_SVIQN_SATEN_Pos         9                                            /*!<MACP SVIQN: SATEN Position */
#define MACP_SVIQN_SATEN_Msk         (0x1UL << MACP_SVIQN_SATEN_Pos)              /*!<MACP SVIQN: SATEN Mask */

#define MACP_SVIQN_OVERAL_Pos        10                                           /*!<MACP SVIQN: OVERAL Position */
#define MACP_SVIQN_OVERAL_Msk        (0x1UL << MACP_SVIQN_OVERAL_Pos)             /*!<MACP SVIQN: OVERAL Mask */

#define MACP_SVIQN_OVERBL_Pos        11                                           /*!<MACP SVIQN: OVERBL Position */
#define MACP_SVIQN_OVERBL_Msk        (0x1UL << MACP_SVIQN_OVERBL_Pos)             /*!<MACP SVIQN: OVERBL Mask */

#define MACP_SVIQN_OVERCL_Pos        12                                           /*!<MACP SVIQN: OVERCL Position */
#define MACP_SVIQN_OVERCL_Msk        (0x1UL << MACP_SVIQN_OVERCL_Pos)             /*!<MACP SVIQN: OVERCL Mask */

#define MACP_SVIQN_OVERAH_Pos        13                                           /*!<MACP SVIQN: OVERAH Position */
#define MACP_SVIQN_OVERAH_Msk        (0x1UL << MACP_SVIQN_OVERAH_Pos)             /*!<MACP SVIQN: OVERAH Mask */

#define MACP_SVIQN_OVERBH_Pos        14                                           /*!<MACP SVIQN: OVERBH Position */
#define MACP_SVIQN_OVERBH_Msk        (0x1UL << MACP_SVIQN_OVERBH_Pos)             /*!<MACP SVIQN: OVERBH Mask */

#define MACP_SVIQN_OVERCH_Pos        15                                           /*!<MACP SVIQN: OVERCH Position */
#define MACP_SVIQN_OVERCH_Msk        (0x1UL << MACP_SVIQN_OVERCH_Pos)             /*!<MACP SVIQN: OVERCH Mask */

#define MACP_SVIQN_Msk_ALL           (MACP_SVIQN_SVIQN_Msk         |\
                                      MACP_SVIQN_SVTYP_Msk         |\
                                      MACP_SVIQN_SATEN_Msk         |\
                                      MACP_SVIQN_OVERAL_Msk        |\
                                      MACP_SVIQN_OVERBL_Msk        |\
                                      MACP_SVIQN_OVERCL_Msk        |\
                                      MACP_SVIQN_OVERAH_Msk        |\
                                      MACP_SVIQN_OVERBH_Msk        |\
                                      MACP_SVIQN_OVERCH_Msk        )

#define MACP_SVSECTOR_SVSECTOR_Pos   0                                            /*!<MACP SVSECTOR: SVSECTOR Position */
#define MACP_SVSECTOR_SVSECTOR_Msk   (0xFFUL /*<< MACP_SVSECTOR_SVSECTOR_Pos*/)   /*!<MACP SVSECTOR: SVSECTOR Mask */

#define MACP_SVSECTOR_Msk_ALL        (MACP_SVSECTOR_SVSECTOR_Msk  )

#define ADC_ADCON1_ADSOC_Pos         0                                            /*!<ADC ADCON1: ADSOC Position */
#define ADC_ADCON1_ADSOC_Msk         (0x1UL /*<< ADC_ADCON1_ADSOC_Pos*/)          /*!<ADC ADCON1: ADSOC Mask */

#define ADC_ADCON1_ADCTU_Pos         1                                            /*!<ADC ADCON1: ADCTU Position */
#define ADC_ADCON1_ADCTU_Msk         (0x3UL << ADC_ADCON1_ADCTU_Pos)              /*!<ADC ADCON1: ADCTU Mask */

#define ADC_ADCON1_REFC_Pos          4                                            /*!<ADC ADCON1: REFC Position */
#define ADC_ADCON1_REFC_Msk          (0x1UL << ADC_ADCON1_REFC_Pos)               /*!<ADC ADCON1: REFC Mask */

#define ADC_ADCON1_ADTGREN_Pos       5                                            /*!<ADC ADCON1: ADTGREN Position */
#define ADC_ADCON1_ADTGREN_Msk       (0x1UL << ADC_ADCON1_ADTGREN_Pos)            /*!<ADC ADCON1: ADTGREN Mask */

#define ADC_ADCON1_ADIE_Pos          6                                            /*!<ADC ADCON1: ADIE Position */
#define ADC_ADCON1_ADIE_Msk          (0x1UL << ADC_ADCON1_ADIE_Pos)               /*!<ADC ADCON1: ADIE Mask */

#define ADC_ADCON1_ADON_Pos          7                                            /*!<ADC ADCON1: ADON Position */
#define ADC_ADCON1_ADON_Msk          (0x1UL << ADC_ADCON1_ADON_Pos)               /*!<ADC ADCON1: ADON Mask */

#define ADC_ADCON1_ADOUT_Pos         8                                            /*!<ADC ADCON1: ADOUT Position */
#define ADC_ADCON1_ADOUT_Msk         (0x1UL << ADC_ADCON1_ADOUT_Pos)              /*!<ADC ADCON1: ADOUT Mask */

#define ADC_ADCON1_Msk_ALL           (ADC_ADCON1_ADSOC_Msk         |\
                                      ADC_ADCON1_ADCTU_Msk         |\
                                      ADC_ADCON1_REFC_Msk          |\
                                      ADC_ADCON1_ADTGREN_Msk       |\
                                      ADC_ADCON1_ADIE_Msk          |\
                                      ADC_ADCON1_ADON_Msk          |\
                                      ADC_ADCON1_ADOUT_Msk         )

#define ADC_ADCON2_TADC_Pos          0                                            /*!<ADC ADCON2: TADC Position */
#define ADC_ADCON2_TADC_Msk          (0xFUL /*<< ADC_ADCON2_TADC_Pos*/)           /*!<ADC ADCON2: TADC Mask */

#define ADC_ADCON2_ADMAXCH_Pos       4                                            /*!<ADC ADCON2: ADMAXCH Position */
#define ADC_ADCON2_ADMAXCH_Msk       (0xFUL << ADC_ADCON2_ADMAXCH_Pos)            /*!<ADC ADCON2: ADMAXCH Mask */

#define ADC_ADCON2_TS_Pos            8                                            /*!<ADC ADCON2: TS Position */
#define ADC_ADCON2_TS_Msk            (0xFUL << ADC_ADCON2_TS_Pos)                 /*!<ADC ADCON2: TS Mask */

#define ADC_ADCON2_TGAP_Pos          12                                           /*!<ADC ADCON2: TGAP Position */
#define ADC_ADCON2_TGAP_Msk          (0x7UL << ADC_ADCON2_TGAP_Pos)               /*!<ADC ADCON2: TGAP Mask */

#define ADC_ADCON2_Msk_ALL           (ADC_ADCON2_TADC_Msk          |\
                                      ADC_ADCON2_ADMAXCH_Msk       |\
                                      ADC_ADCON2_TS_Msk            |\
                                      ADC_ADCON2_TGAP_Msk          )

#define ADC_ADPCH_ADPCH_Pos          0                                            /*!<ADC ADPCH: ADPCH Position */
#define ADC_ADPCH_ADPCH_Msk          (0xFUL /*<< ADC_ADPCH_ADPCH_Pos*/)           /*!<ADC ADPCH: ADPCH Mask */

#define ADC_ADPCH_Msk_ALL            (ADC_ADPCH_ADPCH_Msk         )

#define ADC_ADDR0_ADDR0_Pos          0                                            /*!<ADC ADDR0: ADDR0 Position */
#define ADC_ADDR0_ADDR0_Msk          (0xFFFUL /*<< ADC_ADDR0_ADDR0_Pos*/)         /*!<ADC ADDR0: ADDR0 Mask */

#define ADC_ADDR0_Msk_ALL            (ADC_ADDR0_ADDR0_Msk         )

#define ADC_ADDR1_ADDR1_Pos          0                                            /*!<ADC ADDR1: ADDR1 Position */
#define ADC_ADDR1_ADDR1_Msk          (0xFFFUL /*<< ADC_ADDR1_ADDR1_Pos*/)         /*!<ADC ADDR1: ADDR1 Mask */

#define ADC_ADDR1_Msk_ALL            (ADC_ADDR1_ADDR1_Msk         )

#define ADC_ADDR2_ADDR2_Pos          0                                            /*!<ADC ADDR2: ADDR2 Position */
#define ADC_ADDR2_ADDR2_Msk          (0xFFFUL /*<< ADC_ADDR2_ADDR2_Pos*/)         /*!<ADC ADDR2: ADDR2 Mask */

#define ADC_ADDR2_Msk_ALL            (ADC_ADDR2_ADDR2_Msk         )

#define ADC_ADDR3_ADDR3_Pos          0                                            /*!<ADC ADDR3: ADDR3 Position */
#define ADC_ADDR3_ADDR3_Msk          (0xFFFUL /*<< ADC_ADDR3_ADDR3_Pos*/)         /*!<ADC ADDR3: ADDR3 Mask */

#define ADC_ADDR3_Msk_ALL            (ADC_ADDR3_ADDR3_Msk         )

#define ADC_ADDR4_ADDR4_Pos          0                                            /*!<ADC ADDR4: ADDR4 Position */
#define ADC_ADDR4_ADDR4_Msk          (0xFFFUL /*<< ADC_ADDR4_ADDR4_Pos*/)         /*!<ADC ADDR4: ADDR4 Mask */

#define ADC_ADDR4_Msk_ALL            (ADC_ADDR4_ADDR4_Msk         )

#define ADC_ADDR5_ADDR5_Pos          0                                            /*!<ADC ADDR5: ADDR5 Position */
#define ADC_ADDR5_ADDR5_Msk          (0xFFFUL /*<< ADC_ADDR5_ADDR5_Pos*/)         /*!<ADC ADDR5: ADDR5 Mask */

#define ADC_ADDR5_Msk_ALL            (ADC_ADDR5_ADDR5_Msk         )

#define ADC_ADDR6_ADDR6_Pos          0                                            /*!<ADC ADDR6: ADDR6 Position */
#define ADC_ADDR6_ADDR6_Msk          (0xFFFUL /*<< ADC_ADDR6_ADDR6_Pos*/)         /*!<ADC ADDR6: ADDR6 Mask */

#define ADC_ADDR6_Msk_ALL            (ADC_ADDR6_ADDR6_Msk         )

#define ADC_ADDR7_ADDR7_Pos          0                                            /*!<ADC ADDR7: ADDR7 Position */
#define ADC_ADDR7_ADDR7_Msk          (0xFFFUL /*<< ADC_ADDR7_ADDR7_Pos*/)         /*!<ADC ADDR7: ADDR7 Mask */

#define ADC_ADDR7_Msk_ALL            (ADC_ADDR7_ADDR7_Msk         )

#define ADC_ADDR8_ADDR8_Pos          0                                            /*!<ADC ADDR8: ADDR8 Position */
#define ADC_ADDR8_ADDR8_Msk          (0xFFFUL /*<< ADC_ADDR8_ADDR8_Pos*/)         /*!<ADC ADDR8: ADDR8 Mask */

#define ADC_ADDR8_Msk_ALL            (ADC_ADDR8_ADDR8_Msk         )

#define ADC_ADDR9_ADDR9_Pos          0                                            /*!<ADC ADDR9: ADDR9 Position */
#define ADC_ADDR9_ADDR9_Msk          (0xFFFUL /*<< ADC_ADDR9_ADDR9_Pos*/)         /*!<ADC ADDR9: ADDR9 Mask */

#define ADC_ADDR9_Msk_ALL            (ADC_ADDR9_ADDR9_Msk         )

#define ADC_ADDR10_ADDR10_Pos        0                                            /*!<ADC ADDR10: ADDR10 Position */
#define ADC_ADDR10_ADDR10_Msk        (0xFFFUL /*<< ADC_ADDR10_ADDR10_Pos*/)       /*!<ADC ADDR10: ADDR10 Mask */

#define ADC_ADDR10_Msk_ALL           (ADC_ADDR10_ADDR10_Msk       )

#define ADC_ADDR11_ADDR11_Pos        0                                            /*!<ADC ADDR11: ADDR11 Position */
#define ADC_ADDR11_ADDR11_Msk        (0xFFFUL /*<< ADC_ADDR11_ADDR11_Pos*/)       /*!<ADC ADDR11: ADDR11 Mask */

#define ADC_ADDR11_Msk_ALL           (ADC_ADDR11_ADDR11_Msk       )

#define ADC_ADDR12_ADDR12_Pos        0                                            /*!<ADC ADDR12: ADDR12 Position */
#define ADC_ADDR12_ADDR12_Msk        (0xFFFUL /*<< ADC_ADDR12_ADDR12_Pos*/)       /*!<ADC ADDR12: ADDR12 Mask */

#define ADC_ADDR12_Msk_ALL           (ADC_ADDR12_ADDR12_Msk       )

#define ADC_ADDR13_ADDR13_Pos        0                                            /*!<ADC ADDR13: ADDR13 Position */
#define ADC_ADDR13_ADDR13_Msk        (0xFFFUL /*<< ADC_ADDR13_ADDR13_Pos*/)       /*!<ADC ADDR13: ADDR13 Mask */

#define ADC_ADDR13_Msk_ALL           (ADC_ADDR13_ADDR13_Msk       )

#define ADC_ADDR14_ADDR14_Pos        0                                            /*!<ADC ADDR14: ADDR14 Position */
#define ADC_ADDR14_ADDR14_Msk        (0xFFFUL /*<< ADC_ADDR14_ADDR14_Pos*/)       /*!<ADC ADDR14: ADDR14 Mask */

#define ADC_ADDR14_Msk_ALL           (ADC_ADDR14_ADDR14_Msk       )

#define ADC_ADDR15_ADDR15_Pos        0                                            /*!<ADC ADDR15: ADDR15 Position */
#define ADC_ADDR15_ADDR15_Msk        (0xFFFUL /*<< ADC_ADDR15_ADDR15_Pos*/)       /*!<ADC ADDR15: ADDR15 Mask */

#define ADC_ADDR15_Msk_ALL           (ADC_ADDR15_ADDR15_Msk       )

#define ADC_ADCMPCON_CSEL_Pos        0                                            /*!<ADC ADCMPCON: CSEL Position */
#define ADC_ADCMPCON_CSEL_Msk        (0xFUL /*<< ADC_ADCMPCON_CSEL_Pos*/)         /*!<ADC ADCMPCON: CSEL Mask */

#define ADC_ADCMPCON_ADLIE_Pos       5                                            /*!<ADC ADCMPCON: ADLIE Position */
#define ADC_ADCMPCON_ADLIE_Msk       (0x1UL << ADC_ADCMPCON_ADLIE_Pos)            /*!<ADC ADCMPCON: ADLIE Mask */

#define ADC_ADCMPCON_ADGIE_Pos       7                                            /*!<ADC ADCMPCON: ADGIE Position */
#define ADC_ADCMPCON_ADGIE_Msk       (0x1UL << ADC_ADCMPCON_ADGIE_Pos)            /*!<ADC ADCMPCON: ADGIE Mask */

#define ADC_ADCMPCON_Msk_ALL         (ADC_ADCMPCON_CSEL_Msk        |\
                                      ADC_ADCMPCON_ADLIE_Msk       |\
                                      ADC_ADCMPCON_ADGIE_Msk       )

#define ADC_ADDGT_GT_Pos             0                                            /*!<ADC ADDGT: GT Position */
#define ADC_ADDGT_GT_Msk             (0xFFFFUL /*<< ADC_ADDGT_GT_Pos*/)           /*!<ADC ADDGT: GT Mask */

#define ADC_ADDGT_Msk_ALL            (ADC_ADDGT_GT_Msk            )

#define ADC_ADDLT_LT_Pos             0                                            /*!<ADC ADDLT: LT Position */
#define ADC_ADDLT_LT_Msk             (0xFFFFUL /*<< ADC_ADDLT_LT_Pos*/)           /*!<ADC ADDLT: LT Mask */

#define ADC_ADDLT_Msk_ALL            (ADC_ADDLT_LT_Msk            )

#define ADC_SEQCHSEL0_SEQCH0_Pos     0                                            /*!<ADC SEQCHSEL0: SEQCH0 Position */
#define ADC_SEQCHSEL0_SEQCH0_Msk     (0xFUL /*<< ADC_SEQCHSEL0_SEQCH0_Pos*/)      /*!<ADC SEQCHSEL0: SEQCH0 Mask */

#define ADC_SEQCHSEL0_SEQCH1_Pos     4                                            /*!<ADC SEQCHSEL0: SEQCH1 Position */
#define ADC_SEQCHSEL0_SEQCH1_Msk     (0xFUL << ADC_SEQCHSEL0_SEQCH1_Pos)          /*!<ADC SEQCHSEL0: SEQCH1 Mask */

#define ADC_SEQCHSEL0_SEQCH2_Pos     8                                            /*!<ADC SEQCHSEL0: SEQCH2 Position */
#define ADC_SEQCHSEL0_SEQCH2_Msk     (0xFUL << ADC_SEQCHSEL0_SEQCH2_Pos)          /*!<ADC SEQCHSEL0: SEQCH2 Mask */

#define ADC_SEQCHSEL0_SEQCH3_Pos     12                                           /*!<ADC SEQCHSEL0: SEQCH3 Position */
#define ADC_SEQCHSEL0_SEQCH3_Msk     (0xFUL << ADC_SEQCHSEL0_SEQCH3_Pos)          /*!<ADC SEQCHSEL0: SEQCH3 Mask */

#define ADC_SEQCHSEL0_SEQCH4_Pos     16                                           /*!<ADC SEQCHSEL0: SEQCH4 Position */
#define ADC_SEQCHSEL0_SEQCH4_Msk     (0xFUL << ADC_SEQCHSEL0_SEQCH4_Pos)          /*!<ADC SEQCHSEL0: SEQCH4 Mask */

#define ADC_SEQCHSEL0_SEQCH5_Pos     20                                           /*!<ADC SEQCHSEL0: SEQCH5 Position */
#define ADC_SEQCHSEL0_SEQCH5_Msk     (0xFUL << ADC_SEQCHSEL0_SEQCH5_Pos)          /*!<ADC SEQCHSEL0: SEQCH5 Mask */

#define ADC_SEQCHSEL0_SEQCH6_Pos     24                                           /*!<ADC SEQCHSEL0: SEQCH6 Position */
#define ADC_SEQCHSEL0_SEQCH6_Msk     (0xFUL << ADC_SEQCHSEL0_SEQCH6_Pos)          /*!<ADC SEQCHSEL0: SEQCH6 Mask */

#define ADC_SEQCHSEL0_SEQCH7_Pos     28                                           /*!<ADC SEQCHSEL0: SEQCH7 Position */
#define ADC_SEQCHSEL0_SEQCH7_Msk     (0xFUL << ADC_SEQCHSEL0_SEQCH7_Pos)          /*!<ADC SEQCHSEL0: SEQCH7 Mask */

#define ADC_SEQCHSEL0_Msk_ALL        (ADC_SEQCHSEL0_SEQCH0_Msk     |\
                                      ADC_SEQCHSEL0_SEQCH1_Msk     |\
                                      ADC_SEQCHSEL0_SEQCH2_Msk     |\
                                      ADC_SEQCHSEL0_SEQCH3_Msk     |\
                                      ADC_SEQCHSEL0_SEQCH4_Msk     |\
                                      ADC_SEQCHSEL0_SEQCH5_Msk     |\
                                      ADC_SEQCHSEL0_SEQCH6_Msk     |\
                                      ADC_SEQCHSEL0_SEQCH7_Msk     )

#define ADC_SEQCHSEL1_SEQCH8_Pos     0                                            /*!<ADC SEQCHSEL1: SEQCH8 Position */
#define ADC_SEQCHSEL1_SEQCH8_Msk     (0xFUL /*<< ADC_SEQCHSEL1_SEQCH8_Pos*/)      /*!<ADC SEQCHSEL1: SEQCH8 Mask */

#define ADC_SEQCHSEL1_SEQCH9_Pos     4                                            /*!<ADC SEQCHSEL1: SEQCH9 Position */
#define ADC_SEQCHSEL1_SEQCH9_Msk     (0xFUL << ADC_SEQCHSEL1_SEQCH9_Pos)          /*!<ADC SEQCHSEL1: SEQCH9 Mask */

#define ADC_SEQCHSEL1_SEQCH10_Pos    8                                            /*!<ADC SEQCHSEL1: SEQCH10 Position */
#define ADC_SEQCHSEL1_SEQCH10_Msk    (0xFUL << ADC_SEQCHSEL1_SEQCH10_Pos)         /*!<ADC SEQCHSEL1: SEQCH10 Mask */

#define ADC_SEQCHSEL1_SEQCH11_Pos    12                                           /*!<ADC SEQCHSEL1: SEQCH11 Position */
#define ADC_SEQCHSEL1_SEQCH11_Msk    (0xFUL << ADC_SEQCHSEL1_SEQCH11_Pos)         /*!<ADC SEQCHSEL1: SEQCH11 Mask */

#define ADC_SEQCHSEL1_SEQCH12_Pos    16                                           /*!<ADC SEQCHSEL1: SEQCH12 Position */
#define ADC_SEQCHSEL1_SEQCH12_Msk    (0xFUL << ADC_SEQCHSEL1_SEQCH12_Pos)         /*!<ADC SEQCHSEL1: SEQCH12 Mask */

#define ADC_SEQCHSEL1_SEQCH13_Pos    20                                           /*!<ADC SEQCHSEL1: SEQCH13 Position */
#define ADC_SEQCHSEL1_SEQCH13_Msk    (0xFUL << ADC_SEQCHSEL1_SEQCH13_Pos)         /*!<ADC SEQCHSEL1: SEQCH13 Mask */

#define ADC_SEQCHSEL1_SEQCH14_Pos    24                                           /*!<ADC SEQCHSEL1: SEQCH14 Position */
#define ADC_SEQCHSEL1_SEQCH14_Msk    (0xFUL << ADC_SEQCHSEL1_SEQCH14_Pos)         /*!<ADC SEQCHSEL1: SEQCH14 Mask */

#define ADC_SEQCHSEL1_SEQCH15_Pos    28                                           /*!<ADC SEQCHSEL1: SEQCH15 Position */
#define ADC_SEQCHSEL1_SEQCH15_Msk    (0xFUL << ADC_SEQCHSEL1_SEQCH15_Pos)         /*!<ADC SEQCHSEL1: SEQCH15 Mask */

#define ADC_SEQCHSEL1_Msk_ALL        (ADC_SEQCHSEL1_SEQCH8_Msk     |\
                                      ADC_SEQCHSEL1_SEQCH9_Msk     |\
                                      ADC_SEQCHSEL1_SEQCH10_Msk    |\
                                      ADC_SEQCHSEL1_SEQCH11_Msk    |\
                                      ADC_SEQCHSEL1_SEQCH12_Msk    |\
                                      ADC_SEQCHSEL1_SEQCH13_Msk    |\
                                      ADC_SEQCHSEL1_SEQCH14_Msk    |\
                                      ADC_SEQCHSEL1_SEQCH15_Msk    )

#define ADC_HARDCHSEL_PWMCMP1_Pos    0                                            /*!<ADC HARDCHSEL: PWMCMP1 Position */
#define ADC_HARDCHSEL_PWMCMP1_Msk    (0xFUL /*<< ADC_HARDCHSEL_PWMCMP1_Pos*/)     /*!<ADC HARDCHSEL: PWMCMP1 Mask */

#define ADC_HARDCHSEL_PWMCMP2_Pos    4                                            /*!<ADC HARDCHSEL: PWMCMP2 Position */
#define ADC_HARDCHSEL_PWMCMP2_Msk    (0xFUL << ADC_HARDCHSEL_PWMCMP2_Pos)         /*!<ADC HARDCHSEL: PWMCMP2 Mask */

#define ADC_HARDCHSEL_PWMCMP3_Pos    8                                            /*!<ADC HARDCHSEL: PWMCMP3 Position */
#define ADC_HARDCHSEL_PWMCMP3_Msk    (0xFUL << ADC_HARDCHSEL_PWMCMP3_Pos)         /*!<ADC HARDCHSEL: PWMCMP3 Mask */

#define ADC_HARDCHSEL_PWMCMP4_Pos    12                                           /*!<ADC HARDCHSEL: PWMCMP4 Position */
#define ADC_HARDCHSEL_PWMCMP4_Msk    (0xFUL << ADC_HARDCHSEL_PWMCMP4_Pos)         /*!<ADC HARDCHSEL: PWMCMP4 Mask */

#define ADC_HARDCHSEL_PCA0SEL_Pos    16                                           /*!<ADC HARDCHSEL: PCA0SEL Position */
#define ADC_HARDCHSEL_PCA0SEL_Msk    (0xFUL << ADC_HARDCHSEL_PCA0SEL_Pos)         /*!<ADC HARDCHSEL: PCA0SEL Mask */

#define ADC_HARDCHSEL_PCA1SEL_Pos    20                                           /*!<ADC HARDCHSEL: PCA1SEL Position */
#define ADC_HARDCHSEL_PCA1SEL_Msk    (0xFUL << ADC_HARDCHSEL_PCA1SEL_Pos)         /*!<ADC HARDCHSEL: PCA1SEL Mask */

#define ADC_HARDCHSEL_TIM8SEL_Pos    24                                           /*!<ADC HARDCHSEL: TIM8SEL Position */
#define ADC_HARDCHSEL_TIM8SEL_Msk    (0xFUL << ADC_HARDCHSEL_TIM8SEL_Pos)         /*!<ADC HARDCHSEL: TIM8SEL Mask */

#define ADC_HARDCHSEL_ADTRG_Pos      28                                           /*!<ADC HARDCHSEL: ADTRG Position */
#define ADC_HARDCHSEL_ADTRG_Msk      (0xFUL << ADC_HARDCHSEL_ADTRG_Pos)           /*!<ADC HARDCHSEL: ADTRG Mask */

#define ADC_HARDCHSEL_Msk_ALL        (ADC_HARDCHSEL_PWMCMP1_Msk    |\
                                      ADC_HARDCHSEL_PWMCMP2_Msk    |\
                                      ADC_HARDCHSEL_PWMCMP3_Msk    |\
                                      ADC_HARDCHSEL_PWMCMP4_Msk    |\
                                      ADC_HARDCHSEL_PCA0SEL_Msk    |\
                                      ADC_HARDCHSEL_PCA1SEL_Msk    |\
                                      ADC_HARDCHSEL_TIM8SEL_Msk    |\
                                      ADC_HARDCHSEL_ADTRG_Msk      )

#define ADC_HARDCHLH_PWMCMP1_Pos     0                                            /*!<ADC HARDCHLH: PWMCMP1 Position */
#define ADC_HARDCHLH_PWMCMP1_Msk     (0xFUL /*<< ADC_HARDCHLH_PWMCMP1_Pos*/)      /*!<ADC HARDCHLH: PWMCMP1 Mask */

#define ADC_HARDCHLH_PWMCMP2_Pos     4                                            /*!<ADC HARDCHLH: PWMCMP2 Position */
#define ADC_HARDCHLH_PWMCMP2_Msk     (0xFUL << ADC_HARDCHLH_PWMCMP2_Pos)          /*!<ADC HARDCHLH: PWMCMP2 Mask */

#define ADC_HARDCHLH_PWMCMP3_Pos     8                                            /*!<ADC HARDCHLH: PWMCMP3 Position */
#define ADC_HARDCHLH_PWMCMP3_Msk     (0xFUL << ADC_HARDCHLH_PWMCMP3_Pos)          /*!<ADC HARDCHLH: PWMCMP3 Mask */

#define ADC_HARDCHLH_PWMCMP4_Pos     12                                           /*!<ADC HARDCHLH: PWMCMP4 Position */
#define ADC_HARDCHLH_PWMCMP4_Msk     (0xFUL << ADC_HARDCHLH_PWMCMP4_Pos)          /*!<ADC HARDCHLH: PWMCMP4 Mask */

#define ADC_HARDCHLH_PCA0LH_Pos      16                                           /*!<ADC HARDCHLH: PCA0LH Position */
#define ADC_HARDCHLH_PCA0LH_Msk      (0xFUL << ADC_HARDCHLH_PCA0LH_Pos)           /*!<ADC HARDCHLH: PCA0LH Mask */

#define ADC_HARDCHLH_PCA1LH_Pos      20                                           /*!<ADC HARDCHLH: PCA1LH Position */
#define ADC_HARDCHLH_PCA1LH_Msk      (0xFUL << ADC_HARDCHLH_PCA1LH_Pos)           /*!<ADC HARDCHLH: PCA1LH Mask */

#define ADC_HARDCHLH_TIM8LH_Pos      24                                           /*!<ADC HARDCHLH: TIM8LH Position */
#define ADC_HARDCHLH_TIM8LH_Msk      (0xFUL << ADC_HARDCHLH_TIM8LH_Pos)           /*!<ADC HARDCHLH: TIM8LH Mask */

#define ADC_HARDCHLH_ADTRG_Pos       28                                           /*!<ADC HARDCHLH: ADTRG Position */
#define ADC_HARDCHLH_ADTRG_Msk       (0xFUL << ADC_HARDCHLH_ADTRG_Pos)            /*!<ADC HARDCHLH: ADTRG Mask */

#define ADC_HARDCHLH_Msk_ALL         (ADC_HARDCHLH_PWMCMP1_Msk     |\
                                      ADC_HARDCHLH_PWMCMP2_Msk     |\
                                      ADC_HARDCHLH_PWMCMP3_Msk     |\
                                      ADC_HARDCHLH_PWMCMP4_Msk     |\
                                      ADC_HARDCHLH_PCA0LH_Msk      |\
                                      ADC_HARDCHLH_PCA1LH_Msk      |\
                                      ADC_HARDCHLH_TIM8LH_Msk      |\
                                      ADC_HARDCHLH_ADTRG_Msk       )

#define ADC_ADGAPON_GAPEN_Pos        0                                            /*!<ADC ADGAPON: GAPEN Position */
#define ADC_ADGAPON_GAPEN_Msk        (0xFFFFUL /*<< ADC_ADGAPON_GAPEN_Pos*/)      /*!<ADC ADGAPON: GAPEN Mask */

#define ADC_ADGAPON_Msk_ALL          (ADC_ADGAPON_GAPEN_Msk       )

#define ADC_ADINTF_ADLIF_Pos         0                                            /*!<ADC ADINTF: ADLIF Position */
#define ADC_ADINTF_ADLIF_Msk         (0x1UL /*<< ADC_ADINTF_ADLIF_Pos*/)          /*!<ADC ADINTF: ADLIF Mask */

#define ADC_ADINTF_ADGIF_Pos         1                                            /*!<ADC ADINTF: ADGIF Position */
#define ADC_ADINTF_ADGIF_Msk         (0x1UL << ADC_ADINTF_ADGIF_Pos)              /*!<ADC ADINTF: ADGIF Mask */

#define ADC_ADINTF_ADIF_Pos          2                                            /*!<ADC ADINTF: ADIF Position */
#define ADC_ADINTF_ADIF_Msk          (0x1UL << ADC_ADINTF_ADIF_Pos)               /*!<ADC ADINTF: ADIF Mask */

#define ADC_ADINTF_ADLIFC_Pos        16                                           /*!<ADC ADINTF: ADLIFC Position */
#define ADC_ADINTF_ADLIFC_Msk        (0x1UL << ADC_ADINTF_ADLIFC_Pos)             /*!<ADC ADINTF: ADLIFC Mask */

#define ADC_ADINTF_ADGIFC_Pos        17                                           /*!<ADC ADINTF: ADGIFC Position */
#define ADC_ADINTF_ADGIFC_Msk        (0x1UL << ADC_ADINTF_ADGIFC_Pos)             /*!<ADC ADINTF: ADGIFC Mask */

#define ADC_ADINTF_ADIFC_Pos         18                                           /*!<ADC ADINTF: ADIFC Position */
#define ADC_ADINTF_ADIFC_Msk         (0x1UL << ADC_ADINTF_ADIFC_Pos)              /*!<ADC ADINTF: ADIFC Mask */

#define ADC_ADINTF_Msk_ALL           (ADC_ADINTF_ADLIF_Msk         |\
                                      ADC_ADINTF_ADGIF_Msk         |\
                                      ADC_ADINTF_ADIF_Msk          |\
                                      ADC_ADINTF_ADLIFC_Msk        |\
                                      ADC_ADINTF_ADGIFC_Msk        |\
                                      ADC_ADINTF_ADIFC_Msk         )

#define AMOC_CMP0CON_C0DEB_Pos       0                                            /*!<AMOC CMP0CON: C0DEB Position */
#define AMOC_CMP0CON_C0DEB_Msk       (0x7UL /*<< AMOC_CMP0CON_C0DEB_Pos*/)        /*!<AMOC CMP0CON: C0DEB Mask */

#define AMOC_CMP0CON_C0OUT_Pos       3                                            /*!<AMOC CMP0CON: C0OUT Position */
#define AMOC_CMP0CON_C0OUT_Msk       (0x1UL << AMOC_CMP0CON_C0OUT_Pos)            /*!<AMOC CMP0CON: C0OUT Mask */

#define AMOC_CMP0CON_C0PCHS_Pos      4                                            /*!<AMOC CMP0CON: C0PCHS Position */
#define AMOC_CMP0CON_C0PCHS_Msk      (0x7UL << AMOC_CMP0CON_C0PCHS_Pos)           /*!<AMOC CMP0CON: C0PCHS Mask */

#define AMOC_CMP0CON_C0NCHS_Pos      7                                            /*!<AMOC CMP0CON: C0NCHS Position */
#define AMOC_CMP0CON_C0NCHS_Msk      (0x1UL << AMOC_CMP0CON_C0NCHS_Pos)           /*!<AMOC CMP0CON: C0NCHS Mask */

#define AMOC_CMP0CON_C0IES_Pos       10                                           /*!<AMOC CMP0CON: C0IES Position */
#define AMOC_CMP0CON_C0IES_Msk       (0x3UL << AMOC_CMP0CON_C0IES_Pos)            /*!<AMOC CMP0CON: C0IES Mask */

#define AMOC_CMP0CON_C0OUTEN_Pos     12                                           /*!<AMOC CMP0CON: C0OUTEN Position */
#define AMOC_CMP0CON_C0OUTEN_Msk     (0x1UL << AMOC_CMP0CON_C0OUTEN_Pos)          /*!<AMOC CMP0CON: C0OUTEN Mask */

#define AMOC_CMP0CON_CP0NOUTEN_Pos   13                                           /*!<AMOC CMP0CON: CP0NOUTEN Position */
#define AMOC_CMP0CON_CP0NOUTEN_Msk   (0x1UL << AMOC_CMP0CON_CP0NOUTEN_Pos)        /*!<AMOC CMP0CON: CP0NOUTEN Mask */

#define AMOC_CMP0CON_CMP0VCMP_Pos    14                                           /*!<AMOC CMP0CON: CMP0VCMP Position */
#define AMOC_CMP0CON_CMP0VCMP_Msk    (0x1UL << AMOC_CMP0CON_CMP0VCMP_Pos)         /*!<AMOC CMP0CON: CMP0VCMP Mask */

#define AMOC_CMP0CON_CMP0EN_Pos      15                                           /*!<AMOC CMP0CON: CMP0EN Position */
#define AMOC_CMP0CON_CMP0EN_Msk      (0x1UL << AMOC_CMP0CON_CMP0EN_Pos)           /*!<AMOC CMP0CON: CMP0EN Mask */

#define AMOC_CMP0CON_CMP0VRS_Pos     16                                           /*!<AMOC CMP0CON: CMP0VRS Position */
#define AMOC_CMP0CON_CMP0VRS_Msk     (0x3FUL << AMOC_CMP0CON_CMP0VRS_Pos)         /*!<AMOC CMP0CON: CMP0VRS Mask */

#define AMOC_CMP0CON_CMPGAP_Pos      22                                           /*!<AMOC CMP0CON: CMPGAP Position */
#define AMOC_CMP0CON_CMPGAP_Msk      (0x3UL << AMOC_CMP0CON_CMPGAP_Pos)           /*!<AMOC CMP0CON: CMPGAP Mask */

#define AMOC_CMP0CON_PWMTRGS_Pos     24                                           /*!<AMOC CMP0CON: PWMTRGS Position */
#define AMOC_CMP0CON_PWMTRGS_Msk     (0x3UL << AMOC_CMP0CON_PWMTRGS_Pos)          /*!<AMOC CMP0CON: PWMTRGS Mask */

#define AMOC_CMP0CON_TRGPOL_Pos      26                                           /*!<AMOC CMP0CON: TRGPOL Position */
#define AMOC_CMP0CON_TRGPOL_Msk      (0x1UL << AMOC_CMP0CON_TRGPOL_Pos)           /*!<AMOC CMP0CON: TRGPOL Mask */

#define AMOC_CMP0CON_CMPAUTO_Pos     27                                           /*!<AMOC CMP0CON: CMPAUTO Position */
#define AMOC_CMP0CON_CMPAUTO_Msk     (0x1UL << AMOC_CMP0CON_CMPAUTO_Pos)          /*!<AMOC CMP0CON: CMPAUTO Mask */

#define AMOC_CMP0CON_C0OUT0_Pos      28                                           /*!<AMOC CMP0CON: C0OUT0 Position */
#define AMOC_CMP0CON_C0OUT0_Msk      (0x1UL << AMOC_CMP0CON_C0OUT0_Pos)           /*!<AMOC CMP0CON: C0OUT0 Mask */

#define AMOC_CMP0CON_C0OUT1_Pos      29                                           /*!<AMOC CMP0CON: C0OUT1 Position */
#define AMOC_CMP0CON_C0OUT1_Msk      (0x1UL << AMOC_CMP0CON_C0OUT1_Pos)           /*!<AMOC CMP0CON: C0OUT1 Mask */

#define AMOC_CMP0CON_C0OUT2_Pos      30                                           /*!<AMOC CMP0CON: C0OUT2 Position */
#define AMOC_CMP0CON_C0OUT2_Msk      (0x1UL << AMOC_CMP0CON_C0OUT2_Pos)           /*!<AMOC CMP0CON: C0OUT2 Mask */

#define AMOC_CMP0CON_Msk_ALL         (AMOC_CMP0CON_C0DEB_Msk       |\
                                      AMOC_CMP0CON_C0OUT_Msk       |\
                                      AMOC_CMP0CON_C0PCHS_Msk      |\
                                      AMOC_CMP0CON_C0NCHS_Msk      |\
                                      AMOC_CMP0CON_C0IES_Msk       |\
                                      AMOC_CMP0CON_C0OUTEN_Msk     |\
                                      AMOC_CMP0CON_CP0NOUTEN_Msk   |\
                                      AMOC_CMP0CON_CMP0VCMP_Msk    |\
                                      AMOC_CMP0CON_CMP0EN_Msk      |\
                                      AMOC_CMP0CON_CMP0VRS_Msk     |\
                                      AMOC_CMP0CON_CMPGAP_Msk      |\
                                      AMOC_CMP0CON_PWMTRGS_Msk     |\
                                      AMOC_CMP0CON_TRGPOL_Msk      |\
                                      AMOC_CMP0CON_CMPAUTO_Msk     |\
                                      AMOC_CMP0CON_C0OUT0_Msk      |\
                                      AMOC_CMP0CON_C0OUT1_Msk      |\
                                      AMOC_CMP0CON_C0OUT2_Msk      )

#define AMOC_CMP1CON_C1DEB_Pos       0                                            /*!<AMOC CMP1CON: C1DEB Position */
#define AMOC_CMP1CON_C1DEB_Msk       (0x7UL /*<< AMOC_CMP1CON_C1DEB_Pos*/)        /*!<AMOC CMP1CON: C1DEB Mask */

#define AMOC_CMP1CON_C1OUT_Pos       3                                            /*!<AMOC CMP1CON: C1OUT Position */
#define AMOC_CMP1CON_C1OUT_Msk       (0x1UL << AMOC_CMP1CON_C1OUT_Pos)            /*!<AMOC CMP1CON: C1OUT Mask */

#define AMOC_CMP1CON_C1PCHS_Pos      4                                            /*!<AMOC CMP1CON: C1PCHS Position */
#define AMOC_CMP1CON_C1PCHS_Msk      (0x7UL << AMOC_CMP1CON_C1PCHS_Pos)           /*!<AMOC CMP1CON: C1PCHS Mask */

#define AMOC_CMP1CON_C1NCHS_Pos      7                                            /*!<AMOC CMP1CON: C1NCHS Position */
#define AMOC_CMP1CON_C1NCHS_Msk      (0x1UL << AMOC_CMP1CON_C1NCHS_Pos)           /*!<AMOC CMP1CON: C1NCHS Mask */

#define AMOC_CMP1CON_C1SMT_Pos       8                                            /*!<AMOC CMP1CON: C1SMT Position */
#define AMOC_CMP1CON_C1SMT_Msk       (0x3UL << AMOC_CMP1CON_C1SMT_Pos)            /*!<AMOC CMP1CON: C1SMT Mask */

#define AMOC_CMP1CON_C1IES_Pos       10                                           /*!<AMOC CMP1CON: C1IES Position */
#define AMOC_CMP1CON_C1IES_Msk       (0x3UL << AMOC_CMP1CON_C1IES_Pos)            /*!<AMOC CMP1CON: C1IES Mask */

#define AMOC_CMP1CON_C1OUTEN_Pos     12                                           /*!<AMOC CMP1CON: C1OUTEN Position */
#define AMOC_CMP1CON_C1OUTEN_Msk     (0x1UL << AMOC_CMP1CON_C1OUTEN_Pos)          /*!<AMOC CMP1CON: C1OUTEN Mask */

#define AMOC_CMP1CON_CP1NOUTEN_Pos   13                                           /*!<AMOC CMP1CON: CP1NOUTEN Position */
#define AMOC_CMP1CON_CP1NOUTEN_Msk   (0x1UL << AMOC_CMP1CON_CP1NOUTEN_Pos)        /*!<AMOC CMP1CON: CP1NOUTEN Mask */

#define AMOC_CMP1CON_CMP1VCMP_Pos    14                                           /*!<AMOC CMP1CON: CMP1VCMP Position */
#define AMOC_CMP1CON_CMP1VCMP_Msk    (0x1UL << AMOC_CMP1CON_CMP1VCMP_Pos)         /*!<AMOC CMP1CON: CMP1VCMP Mask */

#define AMOC_CMP1CON_CMP1EN_Pos      15                                           /*!<AMOC CMP1CON: CMP1EN Position */
#define AMOC_CMP1CON_CMP1EN_Msk      (0x1UL << AMOC_CMP1CON_CMP1EN_Pos)           /*!<AMOC CMP1CON: CMP1EN Mask */

#define AMOC_CMP1CON_CMP1VRS_Pos     16                                           /*!<AMOC CMP1CON: CMP1VRS Position */
#define AMOC_CMP1CON_CMP1VRS_Msk     (0x3FUL << AMOC_CMP1CON_CMP1VRS_Pos)         /*!<AMOC CMP1CON: CMP1VRS Mask */

#define AMOC_CMP1CON_PWMTRGS_Pos     24                                           /*!<AMOC CMP1CON: PWMTRGS Position */
#define AMOC_CMP1CON_PWMTRGS_Msk     (0x3UL << AMOC_CMP1CON_PWMTRGS_Pos)          /*!<AMOC CMP1CON: PWMTRGS Mask */

#define AMOC_CMP1CON_TRGPOL_Pos      26                                           /*!<AMOC CMP1CON: TRGPOL Position */
#define AMOC_CMP1CON_TRGPOL_Msk      (0x1UL << AMOC_CMP1CON_TRGPOL_Pos)           /*!<AMOC CMP1CON: TRGPOL Mask */

#define AMOC_CMP1CON_Msk_ALL         (AMOC_CMP1CON_C1DEB_Msk       |\
                                      AMOC_CMP1CON_C1OUT_Msk       |\
                                      AMOC_CMP1CON_C1PCHS_Msk      |\
                                      AMOC_CMP1CON_C1NCHS_Msk      |\
                                      AMOC_CMP1CON_C1SMT_Msk       |\
                                      AMOC_CMP1CON_C1IES_Msk       |\
                                      AMOC_CMP1CON_C1OUTEN_Msk     |\
                                      AMOC_CMP1CON_CP1NOUTEN_Msk   |\
                                      AMOC_CMP1CON_CMP1VCMP_Msk    |\
                                      AMOC_CMP1CON_CMP1EN_Msk      |\
                                      AMOC_CMP1CON_CMP1VRS_Msk     |\
                                      AMOC_CMP1CON_PWMTRGS_Msk     |\
                                      AMOC_CMP1CON_TRGPOL_Msk      )

#define AMOC_CMPINTF_C0IF_Pos        0                                            /*!<AMOC CMPINTF: C0IF Position */
#define AMOC_CMPINTF_C0IF_Msk        (0x1UL /*<< AMOC_CMPINTF_C0IF_Pos*/)         /*!<AMOC CMPINTF: C0IF Mask */

#define AMOC_CMPINTF_C1IF_Pos        1                                            /*!<AMOC CMPINTF: C1IF Position */
#define AMOC_CMPINTF_C1IF_Msk        (0x1UL << AMOC_CMPINTF_C1IF_Pos)             /*!<AMOC CMPINTF: C1IF Mask */

#define AMOC_CMPINTF_C0IFC_Pos       16                                           /*!<AMOC CMPINTF: C0IFC Position */
#define AMOC_CMPINTF_C0IFC_Msk       (0x1UL << AMOC_CMPINTF_C0IFC_Pos)            /*!<AMOC CMPINTF: C0IFC Mask */

#define AMOC_CMPINTF_C1IFC_Pos       17                                           /*!<AMOC CMPINTF: C1IFC Position */
#define AMOC_CMPINTF_C1IFC_Msk       (0x1UL << AMOC_CMPINTF_C1IFC_Pos)            /*!<AMOC CMPINTF: C1IFC Mask */

#define AMOC_CMPINTF_Msk_ALL         (AMOC_CMPINTF_C0IF_Msk        |\
                                      AMOC_CMPINTF_C1IF_Msk        |\
                                      AMOC_CMPINTF_C0IFC_Msk       |\
                                      AMOC_CMPINTF_C1IFC_Msk       )

#define AMOC_OPCON_OP0EN_Pos         0                                            /*!<AMOC OPCON: OP0EN Position */
#define AMOC_OPCON_OP0EN_Msk         (0x1UL /*<< AMOC_OPCON_OP0EN_Pos*/)          /*!<AMOC OPCON: OP0EN Mask */

#define AMOC_OPCON_OP1EN_Pos         1                                            /*!<AMOC OPCON: OP1EN Position */
#define AMOC_OPCON_OP1EN_Msk         (0x1UL << AMOC_OPCON_OP1EN_Pos)              /*!<AMOC OPCON: OP1EN Mask */

#define AMOC_OPCON_OP2EN_Pos         2                                            /*!<AMOC OPCON: OP2EN Position */
#define AMOC_OPCON_OP2EN_Msk         (0x1UL << AMOC_OPCON_OP2EN_Pos)              /*!<AMOC OPCON: OP2EN Mask */

#define AMOC_OPCON_OP3EN_Pos         3                                            /*!<AMOC OPCON: OP3EN Position */
#define AMOC_OPCON_OP3EN_Msk         (0x1UL << AMOC_OPCON_OP3EN_Pos)              /*!<AMOC OPCON: OP3EN Mask */

#define AMOC_OPCON_OP0GSEL_Pos       4                                            /*!<AMOC OPCON: OP0GSEL Position */
#define AMOC_OPCON_OP0GSEL_Msk       (0x7UL << AMOC_OPCON_OP0GSEL_Pos)            /*!<AMOC OPCON: OP0GSEL Mask */

#define AMOC_OPCON_OP0GEN_Pos        7                                            /*!<AMOC OPCON: OP0GEN Position */
#define AMOC_OPCON_OP0GEN_Msk        (0x1UL << AMOC_OPCON_OP0GEN_Pos)             /*!<AMOC OPCON: OP0GEN Mask */

#define AMOC_OPCON_Msk_ALL           (AMOC_OPCON_OP0EN_Msk         |\
                                      AMOC_OPCON_OP1EN_Msk         |\
                                      AMOC_OPCON_OP2EN_Msk         |\
                                      AMOC_OPCON_OP3EN_Msk         |\
                                      AMOC_OPCON_OP0GSEL_Msk       |\
                                      AMOC_OPCON_OP0GEN_Msk        )

#define UART_FR_RI_Pos               0                                            /*!<UART FR: RI Position */
#define UART_FR_RI_Msk               (0x1UL /*<< UART_FR_RI_Pos*/)                /*!<UART FR: RI Mask */

#define UART_FR_TI_Pos               1                                            /*!<UART FR: TI Position */
#define UART_FR_TI_Msk               (0x1UL << UART_FR_TI_Pos)                    /*!<UART FR: TI Mask */

#define UART_FR_TC_Pos               2                                            /*!<UART FR: TC Position */
#define UART_FR_TC_Msk               (0x1UL << UART_FR_TC_Pos)                    /*!<UART FR: TC Mask */

#define UART_FR_TXCOL_Pos            3                                            /*!<UART FR: TXCOL Position */
#define UART_FR_TXCOL_Msk            (0x1UL << UART_FR_TXCOL_Pos)                 /*!<UART FR: TXCOL Mask */

#define UART_FR_RXOV_Pos             4                                            /*!<UART FR: RXOV Position */
#define UART_FR_RXOV_Msk             (0x1UL << UART_FR_RXOV_Pos)                  /*!<UART FR: RXOV Mask */

#define UART_FR_FE_Pos               5                                            /*!<UART FR: FE Position */
#define UART_FR_FE_Msk               (0x1UL << UART_FR_FE_Pos)                    /*!<UART FR: FE Mask */

#define UART_FR_PE_Pos               6                                            /*!<UART FR: PE Position */
#define UART_FR_PE_Msk               (0x1UL << UART_FR_PE_Pos)                    /*!<UART FR: PE Mask */

#define UART_FR_LBD_Pos              7                                            /*!<UART FR: LBD Position */
#define UART_FR_LBD_Msk              (0x1UL << UART_FR_LBD_Pos)                   /*!<UART FR: LBD Mask */

#define UART_FR_RIC_Pos              16                                           /*!<UART FR: RIC Position */
#define UART_FR_RIC_Msk              (0x1UL << UART_FR_RIC_Pos)                   /*!<UART FR: RIC Mask */

#define UART_FR_TCC_Pos              18                                           /*!<UART FR: TCC Position */
#define UART_FR_TCC_Msk              (0x1UL << UART_FR_TCC_Pos)                   /*!<UART FR: TCC Mask */

#define UART_FR_TXCOLC_Pos           19                                           /*!<UART FR: TXCOLC Position */
#define UART_FR_TXCOLC_Msk           (0x1UL << UART_FR_TXCOLC_Pos)                /*!<UART FR: TXCOLC Mask */

#define UART_FR_RXOVC_Pos            20                                           /*!<UART FR: RXOVC Position */
#define UART_FR_RXOVC_Msk            (0x1UL << UART_FR_RXOVC_Pos)                 /*!<UART FR: RXOVC Mask */

#define UART_FR_FEC_Pos              21                                           /*!<UART FR: FEC Position */
#define UART_FR_FEC_Msk              (0x1UL << UART_FR_FEC_Pos)                   /*!<UART FR: FEC Mask */

#define UART_FR_PEC_Pos              22                                           /*!<UART FR: PEC Position */
#define UART_FR_PEC_Msk              (0x1UL << UART_FR_PEC_Pos)                   /*!<UART FR: PEC Mask */

#define UART_FR_LBDC_Pos             23                                           /*!<UART FR: LBDC Position */
#define UART_FR_LBDC_Msk             (0x1UL << UART_FR_LBDC_Pos)                  /*!<UART FR: LBDC Mask */

#define UART_FR_Msk_ALL              (UART_FR_RI_Msk               |\
                                      UART_FR_TI_Msk               |\
                                      UART_FR_TC_Msk               |\
                                      UART_FR_TXCOL_Msk            |\
                                      UART_FR_RXOV_Msk             |\
                                      UART_FR_FE_Msk               |\
                                      UART_FR_PE_Msk               |\
                                      UART_FR_LBD_Msk              |\
                                      UART_FR_RIC_Msk              |\
                                      UART_FR_TCC_Msk              |\
                                      UART_FR_TXCOLC_Msk           |\
                                      UART_FR_RXOVC_Msk            |\
                                      UART_FR_FEC_Msk              |\
                                      UART_FR_PEC_Msk              |\
                                      UART_FR_LBDC_Msk             )

#define UART_TDR_TDR_Pos             0                                            /*!<UART TDR: TDR Position */
#define UART_TDR_TDR_Msk             (0xFFUL /*<< UART_TDR_TDR_Pos*/)             /*!<UART TDR: TDR Mask */

#define UART_TDR_TB8_Pos             8                                            /*!<UART TDR: TB8 Position */
#define UART_TDR_TB8_Msk             (0x1UL << UART_TDR_TB8_Pos)                  /*!<UART TDR: TB8 Mask */

#define UART_TDR_FIFOTDH_Pos         9                                            /*!<UART TDR: FIFOTDH Position */
#define UART_TDR_FIFOTDH_Msk         (0x7FFFFFUL << UART_TDR_FIFOTDH_Pos)         /*!<UART TDR: FIFOTDH Mask */

#define UART_TDR_Msk_ALL             (UART_TDR_TDR_Msk             |\
                                      UART_TDR_TB8_Msk             |\
                                      UART_TDR_FIFOTDH_Msk         )

#define UART_RDR_RDR_Pos             0                                            /*!<UART RDR: RDR Position */
#define UART_RDR_RDR_Msk             (0xFFUL /*<< UART_RDR_RDR_Pos*/)             /*!<UART RDR: RDR Mask */

#define UART_RDR_RB8_Pos             8                                            /*!<UART RDR: RB8 Position */
#define UART_RDR_RB8_Msk             (0x1UL << UART_RDR_RB8_Pos)                  /*!<UART RDR: RB8 Mask */

#define UART_RDR_FIFORDH_Pos         9                                            /*!<UART RDR: FIFORDH Position */
#define UART_RDR_FIFORDH_Msk         (0x7FFFFFUL << UART_RDR_FIFORDH_Pos)         /*!<UART RDR: FIFORDH Mask */

#define UART_RDR_Msk_ALL             (UART_RDR_RDR_Msk             |\
                                      UART_RDR_RB8_Msk             |\
                                      UART_RDR_FIFORDH_Msk         )

#define UART_ADDR_SADDR_Pos          0                                            /*!<UART ADDR: SADDR Position */
#define UART_ADDR_SADDR_Msk          (0xFFUL /*<< UART_ADDR_SADDR_Pos*/)          /*!<UART ADDR: SADDR Mask */

#define UART_ADDR_SMAR_Pos           8                                            /*!<UART ADDR: SMAR Position */
#define UART_ADDR_SMAR_Msk           (0xFFUL << UART_ADDR_SMAR_Pos)               /*!<UART ADDR: SMAR Mask */

#define UART_ADDR_Msk_ALL            (UART_ADDR_SADDR_Msk          |\
                                      UART_ADDR_SMAR_Msk           )

#define UART_BRT_SBRT_Pos            0                                            /*!<UART BRT: SBRT Position */
#define UART_BRT_SBRT_Msk            (0x7FFFUL /*<< UART_BRT_SBRT_Pos*/)          /*!<UART BRT: SBRT Mask */

#define UART_BRT_BFINE_Pos           16                                           /*!<UART BRT: BFINE Position */
#define UART_BRT_BFINE_Msk           (0xFUL << UART_BRT_BFINE_Pos)                /*!<UART BRT: BFINE Mask */

#define UART_BRT_Msk_ALL             (UART_BRT_SBRT_Msk            |\
                                      UART_BRT_BFINE_Msk           )

#define UART_CR_STOP_Pos             0                                            /*!<UART CR: STOP Position */
#define UART_CR_STOP_Msk             (0x1UL /*<< UART_CR_STOP_Pos*/)              /*!<UART CR: STOP Mask */

#define UART_CR_SBRTEN_Pos           1                                            /*!<UART CR: SBRTEN Position */
#define UART_CR_SBRTEN_Msk           (0x1UL << UART_CR_SBRTEN_Pos)                /*!<UART CR: SBRTEN Mask */

#define UART_CR_SMOD2_Pos            2                                            /*!<UART CR: SMOD2 Position */
#define UART_CR_SMOD2_Msk            (0x1UL << UART_CR_SMOD2_Pos)                 /*!<UART CR: SMOD2 Mask */

#define UART_CR_RIE_Pos              3                                            /*!<UART CR: RIE Position */
#define UART_CR_RIE_Msk              (0x1UL << UART_CR_RIE_Pos)                   /*!<UART CR: RIE Mask */

#define UART_CR_TIE_Pos              4                                            /*!<UART CR: TIE Position */
#define UART_CR_TIE_Msk              (0x1UL << UART_CR_TIE_Pos)                   /*!<UART CR: TIE Mask */

#define UART_CR_TCIE_Pos             5                                            /*!<UART CR: TCIE Position */
#define UART_CR_TCIE_Msk             (0x1UL << UART_CR_TCIE_Pos)                  /*!<UART CR: TCIE Mask */

#define UART_CR_LBDIE_Pos            6                                            /*!<UART CR: LBDIE Position */
#define UART_CR_LBDIE_Msk            (0x1UL << UART_CR_LBDIE_Pos)                 /*!<UART CR: LBDIE Mask */

#define UART_CR_LBDL_Pos             7                                            /*!<UART CR: LBDL Position */
#define UART_CR_LBDL_Msk             (0x1UL << UART_CR_LBDL_Pos)                  /*!<UART CR: LBDL Mask */

#define UART_CR_SMOD0_Pos            8                                            /*!<UART CR: SMOD0 Position */
#define UART_CR_SMOD0_Msk            (0x1UL << UART_CR_SMOD0_Pos)                 /*!<UART CR: SMOD0 Mask */

#define UART_CR_PS_Pos               10                                           /*!<UART CR: PS Position */
#define UART_CR_PS_Msk               (0x1UL << UART_CR_PS_Pos)                    /*!<UART CR: PS Mask */

#define UART_CR_MULTIE_Pos           11                                           /*!<UART CR: MULTIE Position */
#define UART_CR_MULTIE_Msk           (0x3UL << UART_CR_MULTIE_Pos)                /*!<UART CR: MULTIE Mask */

#define UART_CR_SM_Pos               13                                           /*!<UART CR: SM Position */
#define UART_CR_SM_Msk               (0x3UL << UART_CR_SM_Pos)                    /*!<UART CR: SM Mask */

#define UART_CR_SBK_Pos              15                                           /*!<UART CR: SBK Position */
#define UART_CR_SBK_Msk              (0x1UL << UART_CR_SBK_Pos)                   /*!<UART CR: SBK Mask */

#define UART_CR_LINEN_Pos            16                                           /*!<UART CR: LINEN Position */
#define UART_CR_LINEN_Msk            (0x1UL << UART_CR_LINEN_Pos)                 /*!<UART CR: LINEN Mask */

#define UART_CR_REN_Pos              17                                           /*!<UART CR: REN Position */
#define UART_CR_REN_Msk              (0x1UL << UART_CR_REN_Pos)                   /*!<UART CR: REN Mask */

#define UART_CR_TEN_Pos              18                                           /*!<UART CR: TEN Position */
#define UART_CR_TEN_Msk              (0x1UL << UART_CR_TEN_Pos)                   /*!<UART CR: TEN Mask */

#define UART_CR_RNEG_Pos             21                                           /*!<UART CR: RNEG Position */
#define UART_CR_RNEG_Msk             (0x1UL << UART_CR_RNEG_Pos)                  /*!<UART CR: RNEG Mask */

#define UART_CR_TNEG_Pos             22                                           /*!<UART CR: TNEG Position */
#define UART_CR_TNEG_Msk             (0x1UL << UART_CR_TNEG_Pos)                  /*!<UART CR: TNEG Mask */

#define UART_CR_FER_Pos              23                                           /*!<UART CR: FER Position */
#define UART_CR_FER_Msk              (0x1UL << UART_CR_FER_Pos)                   /*!<UART CR: FER Mask */

#define UART_CR_UARXFIFO_Pos         25                                           /*!<UART CR: UARXFIFO Position */
#define UART_CR_UARXFIFO_Msk         (0x1UL << UART_CR_UARXFIFO_Pos)              /*!<UART CR: UARXFIFO Mask */

#define UART_CR_UATXFIFO_Pos         26                                           /*!<UART CR: UATXFIFO Position */
#define UART_CR_UATXFIFO_Msk         (0x1UL << UART_CR_UATXFIFO_Pos)              /*!<UART CR: UATXFIFO Mask */

#define UART_CR_Msk_ALL              (UART_CR_STOP_Msk             |\
                                      UART_CR_SBRTEN_Msk           |\
                                      UART_CR_SMOD2_Msk            |\
                                      UART_CR_RIE_Msk              |\
                                      UART_CR_TIE_Msk              |\
                                      UART_CR_TCIE_Msk             |\
                                      UART_CR_LBDIE_Msk            |\
                                      UART_CR_LBDL_Msk             |\
                                      UART_CR_SMOD0_Msk            |\
                                      UART_CR_PS_Msk               |\
                                      UART_CR_MULTIE_Msk           |\
                                      UART_CR_SM_Msk               |\
                                      UART_CR_SBK_Msk              |\
                                      UART_CR_LINEN_Msk            |\
                                      UART_CR_REN_Msk              |\
                                      UART_CR_TEN_Msk              |\
                                      UART_CR_RNEG_Msk             |\
                                      UART_CR_TNEG_Msk             |\
                                      UART_CR_FER_Msk              |\
                                      UART_CR_UARXFIFO_Msk         |\
                                      UART_CR_UATXFIFO_Msk         )

#define SPI_FR_SPRI_Pos              0                                            /*!<SPI FR: SPRI Position */
#define SPI_FR_SPRI_Msk              (0x1UL /*<< SPI_FR_SPRI_Pos*/)               /*!<SPI FR: SPRI Mask */

#define SPI_FR_SPTI_Pos              1                                            /*!<SPI FR: SPTI Position */
#define SPI_FR_SPTI_Msk              (0x1UL << SPI_FR_SPTI_Pos)                   /*!<SPI FR: SPTI Mask */

#define SPI_FR_BUSY_Pos              2                                            /*!<SPI FR: BUSY Position */
#define SPI_FR_BUSY_Msk              (0x1UL << SPI_FR_BUSY_Pos)                   /*!<SPI FR: BUSY Mask */

#define SPI_FR_MODF_Pos              3                                            /*!<SPI FR: MODF Position */
#define SPI_FR_MODF_Msk              (0x1UL << SPI_FR_MODF_Pos)                   /*!<SPI FR: MODF Mask */

#define SPI_FR_RXOV_Pos              4                                            /*!<SPI FR: RXOV Position */
#define SPI_FR_RXOV_Msk              (0x1UL << SPI_FR_RXOV_Pos)                   /*!<SPI FR: RXOV Mask */

#define SPI_FR_WCOL_Pos              5                                            /*!<SPI FR: WCOL Position */
#define SPI_FR_WCOL_Msk              (0x1UL << SPI_FR_WCOL_Pos)                   /*!<SPI FR: WCOL Mask */

#define SPI_FR_SPRIC_Pos             16                                           /*!<SPI FR: SPRIC Position */
#define SPI_FR_SPRIC_Msk             (0x1UL << SPI_FR_SPRIC_Pos)                  /*!<SPI FR: SPRIC Mask */

#define SPI_FR_SPTIC_Pos             17                                           /*!<SPI FR: SPTIC Position */
#define SPI_FR_SPTIC_Msk             (0x1UL << SPI_FR_SPTIC_Pos)                  /*!<SPI FR: SPTIC Mask */

#define SPI_FR_MODFC_Pos             19                                           /*!<SPI FR: MODFC Position */
#define SPI_FR_MODFC_Msk             (0x1UL << SPI_FR_MODFC_Pos)                  /*!<SPI FR: MODFC Mask */

#define SPI_FR_RXOVC_Pos             20                                           /*!<SPI FR: RXOVC Position */
#define SPI_FR_RXOVC_Msk             (0x1UL << SPI_FR_RXOVC_Pos)                  /*!<SPI FR: RXOVC Mask */

#define SPI_FR_WCOLC_Pos             21                                           /*!<SPI FR: WCOLC Position */
#define SPI_FR_WCOLC_Msk             (0x1UL << SPI_FR_WCOLC_Pos)                  /*!<SPI FR: WCOLC Mask */

#define SPI_FR_Msk_ALL               (SPI_FR_SPRI_Msk              |\
                                      SPI_FR_SPTI_Msk              |\
                                      SPI_FR_BUSY_Msk              |\
                                      SPI_FR_MODF_Msk              |\
                                      SPI_FR_RXOV_Msk              |\
                                      SPI_FR_WCOL_Msk              |\
                                      SPI_FR_SPRIC_Msk             |\
                                      SPI_FR_SPTIC_Msk             |\
                                      SPI_FR_MODFC_Msk             |\
                                      SPI_FR_RXOVC_Msk             |\
                                      SPI_FR_WCOLC_Msk             )

#define SPI_CR_SPR_Pos               0                                            /*!<SPI CR: SPR Position */
#define SPI_CR_SPR_Msk               (0xFUL /*<< SPI_CR_SPR_Pos*/)                /*!<SPI CR: SPR Mask */

#define SPI_CR_SSDIS_Pos             4                                            /*!<SPI CR: SSDIS Position */
#define SPI_CR_SSDIS_Msk             (0x1UL << SPI_CR_SSDIS_Pos)                  /*!<SPI CR: SSDIS Mask */

#define SPI_CR_CPOL_Pos              5                                            /*!<SPI CR: CPOL Position */
#define SPI_CR_CPOL_Msk              (0x1UL << SPI_CR_CPOL_Pos)                   /*!<SPI CR: CPOL Mask */

#define SPI_CR_CPHA_Pos              6                                            /*!<SPI CR: CPHA Position */
#define SPI_CR_CPHA_Msk              (0x1UL << SPI_CR_CPHA_Pos)                   /*!<SPI CR: CPHA Mask */

#define SPI_CR_MSTR_Pos              7                                            /*!<SPI CR: MSTR Position */
#define SPI_CR_MSTR_Msk              (0x1UL << SPI_CR_MSTR_Pos)                   /*!<SPI CR: MSTR Mask */

#define SPI_CR_DIR_Pos               8                                            /*!<SPI CR: DIR Position */
#define SPI_CR_DIR_Msk               (0x1UL << SPI_CR_DIR_Pos)                    /*!<SPI CR: DIR Mask */

#define SPI_CR_SPRIE_Pos             10                                           /*!<SPI CR: SPRIE Position */
#define SPI_CR_SPRIE_Msk             (0x1UL << SPI_CR_SPRIE_Pos)                  /*!<SPI CR: SPRIE Mask */

#define SPI_CR_SPTIE_Pos             11                                           /*!<SPI CR: SPTIE Position */
#define SPI_CR_SPTIE_Msk             (0x1UL << SPI_CR_SPTIE_Pos)                  /*!<SPI CR: SPTIE Mask */

#define SPI_CR_SPIEN_Pos             14                                           /*!<SPI CR: SPIEN Position */
#define SPI_CR_SPIEN_Msk             (0x1UL << SPI_CR_SPIEN_Pos)                  /*!<SPI CR: SPIEN Mask */

#define SPI_CR_SPSFF_Pos             15                                           /*!<SPI CR: SPSFF Position */
#define SPI_CR_SPSFF_Msk             (0x1UL << SPI_CR_SPSFF_Pos)                  /*!<SPI CR: SPSFF Mask */

#define SPI_CR_SPDATL_Pos            16                                           /*!<SPI CR: SPDATL Position */
#define SPI_CR_SPDATL_Msk            (0x3UL << SPI_CR_SPDATL_Pos)                 /*!<SPI CR: SPDATL Mask */

#define SPI_CR_FIFOEN_Pos            18                                           /*!<SPI CR: FIFOEN Position */
#define SPI_CR_FIFOEN_Msk            (0x1UL << SPI_CR_FIFOEN_Pos)                 /*!<SPI CR: FIFOEN Mask */

#define SPI_CR_Msk_ALL               (SPI_CR_SPR_Msk               |\
                                      SPI_CR_SSDIS_Msk             |\
                                      SPI_CR_CPOL_Msk              |\
                                      SPI_CR_CPHA_Msk              |\
                                      SPI_CR_MSTR_Msk              |\
                                      SPI_CR_DIR_Msk               |\
                                      SPI_CR_SPRIE_Msk             |\
                                      SPI_CR_SPTIE_Msk             |\
                                      SPI_CR_SPIEN_Msk             |\
                                      SPI_CR_SPSFF_Msk             |\
                                      SPI_CR_SPDATL_Msk            |\
                                      SPI_CR_FIFOEN_Msk            )

#define TWI_FR_TWINT_Pos             0                                            /*!<TWI FR: TWINT Position */
#define TWI_FR_TWINT_Msk             (0x1UL /*<< TWI_FR_TWINT_Pos*/)              /*!<TWI FR: TWINT Mask */

#define TWI_FR_TFREE_Pos             2                                            /*!<TWI FR: TFREE Position */
#define TWI_FR_TFREE_Msk             (0x1UL << TWI_FR_TFREE_Pos)                  /*!<TWI FR: TFREE Mask */

#define TWI_FR_TOUT_Pos              3                                            /*!<TWI FR: TOUT Position */
#define TWI_FR_TOUT_Msk              (0x1UL << TWI_FR_TOUT_Pos)                   /*!<TWI FR: TOUT Mask */

#define TWI_FR_TWINTC_Pos            16                                           /*!<TWI FR: TWINTC Position */
#define TWI_FR_TWINTC_Msk            (0x1UL << TWI_FR_TWINTC_Pos)                 /*!<TWI FR: TWINTC Mask */

#define TWI_FR_TFREEC_Pos            18                                           /*!<TWI FR: TFREEC Position */
#define TWI_FR_TFREEC_Msk            (0x1UL << TWI_FR_TFREEC_Pos)                 /*!<TWI FR: TFREEC Mask */

#define TWI_FR_TOUTC_Pos             19                                           /*!<TWI FR: TOUTC Position */
#define TWI_FR_TOUTC_Msk             (0x1UL << TWI_FR_TOUTC_Pos)                  /*!<TWI FR: TOUTC Mask */

#define TWI_FR_Msk_ALL               (TWI_FR_TWINT_Msk             |\
                                      TWI_FR_TFREE_Msk             |\
                                      TWI_FR_TOUT_Msk              |\
                                      TWI_FR_TWINTC_Msk            |\
                                      TWI_FR_TFREEC_Msk            |\
                                      TWI_FR_TOUTC_Msk             )

#define TWI_STAT_SR_Pos              3                                            /*!<TWI STAT: SR Position */
#define TWI_STAT_SR_Msk              (0x1FUL << TWI_STAT_SR_Pos)                  /*!<TWI STAT: SR Mask */

#define TWI_STAT_Msk_ALL             (TWI_STAT_SR_Msk             )

#define TWI_HOC_HOC_Pos              0                                            /*!<TWI HOC: HOC Position */
#define TWI_HOC_HOC_Msk              (0xFFUL /*<< TWI_HOC_HOC_Pos*/)              /*!<TWI HOC: HOC Mask */

#define TWI_HOC_Msk_ALL              (TWI_HOC_HOC_Msk             )

#define TWI_BRT_BRT_Pos              0                                            /*!<TWI BRT: BRT Position */
#define TWI_BRT_BRT_Msk              (0xFFUL /*<< TWI_BRT_BRT_Pos*/)              /*!<TWI BRT: BRT Mask */

#define TWI_BRT_Msk_ALL              (TWI_BRT_BRT_Msk             )

#define TWI_DR_DR_Pos                0                                            /*!<TWI DR: DR Position */
#define TWI_DR_DR_Msk                (0xFFUL /*<< TWI_DR_DR_Pos*/)                /*!<TWI DR: DR Mask */

#define TWI_DR_Msk_ALL               (TWI_DR_DR_Msk               )

#define TWI_ADDR_GC_Pos              0                                            /*!<TWI ADDR: GC Position */
#define TWI_ADDR_GC_Msk              (0x1UL /*<< TWI_ADDR_GC_Pos*/)               /*!<TWI ADDR: GC Mask */

#define TWI_ADDR_ADDR_Pos            1                                            /*!<TWI ADDR: ADDR Position */
#define TWI_ADDR_ADDR_Msk            (0x7FUL << TWI_ADDR_ADDR_Pos)                /*!<TWI ADDR: ADDR Mask */

#define TWI_ADDR_TWIAMR_Pos          17                                           /*!<TWI ADDR: TWIAMR Position */
#define TWI_ADDR_TWIAMR_Msk          (0x7FUL << TWI_ADDR_TWIAMR_Pos)              /*!<TWI ADDR: TWIAMR Mask */

#define TWI_ADDR_Msk_ALL             (TWI_ADDR_GC_Msk              |\
                                      TWI_ADDR_ADDR_Msk            |\
                                      TWI_ADDR_TWIAMR_Msk          )

#define TWI_CR_AA_Pos                0                                            /*!<TWI CR: AA Position */
#define TWI_CR_AA_Msk                (0x1UL /*<< TWI_CR_AA_Pos*/)                 /*!<TWI CR: AA Mask */

#define TWI_CR_STO_Pos               1                                            /*!<TWI CR: STO Position */
#define TWI_CR_STO_Msk               (0x1UL << TWI_CR_STO_Pos)                    /*!<TWI CR: STO Mask */

#define TWI_CR_STA_Pos               2                                            /*!<TWI CR: STA Position */
#define TWI_CR_STA_Msk               (0x1UL << TWI_CR_STA_Pos)                    /*!<TWI CR: STA Mask */

#define TWI_CR_CR_Pos                4                                            /*!<TWI CR: CR Position */
#define TWI_CR_CR_Msk                (0x3UL << TWI_CR_CR_Pos)                     /*!<TWI CR: CR Mask */

#define TWI_CR_CNT_Pos               6                                            /*!<TWI CR: CNT Position */
#define TWI_CR_CNT_Msk               (0x3UL << TWI_CR_CNT_Pos)                    /*!<TWI CR: CNT Mask */

#define TWI_CR_EFREE_Pos             8                                            /*!<TWI CR: EFREE Position */
#define TWI_CR_EFREE_Msk             (0x1UL << TWI_CR_EFREE_Pos)                  /*!<TWI CR: EFREE Mask */

#define TWI_CR_ETOT_Pos              9                                            /*!<TWI CR: ETOT Position */
#define TWI_CR_ETOT_Msk              (0x1UL << TWI_CR_ETOT_Pos)                   /*!<TWI CR: ETOT Mask */

#define TWI_CR_TWINTE_Pos            10                                           /*!<TWI CR: TWINTE Position */
#define TWI_CR_TWINTE_Msk            (0x1UL << TWI_CR_TWINTE_Pos)                 /*!<TWI CR: TWINTE Mask */

#define TWI_CR_TWIEN_Pos             15                                           /*!<TWI CR: TWIEN Position */
#define TWI_CR_TWIEN_Msk             (0x1UL << TWI_CR_TWIEN_Pos)                  /*!<TWI CR: TWIEN Mask */

#define TWI_CR_Msk_ALL               (TWI_CR_AA_Msk                |\
                                      TWI_CR_STO_Msk               |\
                                      TWI_CR_STA_Msk               |\
                                      TWI_CR_CR_Msk                |\
                                      TWI_CR_CNT_Msk               |\
                                      TWI_CR_EFREE_Msk             |\
                                      TWI_CR_ETOT_Msk              |\
                                      TWI_CR_TWINTE_Msk            |\
                                      TWI_CR_TWIEN_Msk             )

#define CAN_BUF0_CNTSTAT_ST_Pos      0                                            /*!<CAN BUF0_CNTSTAT: ST Position */
#define CAN_BUF0_CNTSTAT_ST_Msk      (0xFUL /*<< CAN_BUF0_CNTSTAT_ST_Pos*/)       /*!<CAN BUF0_CNTSTAT: ST Mask */

#define CAN_BUF0_CNTSTAT_PRI_Pos     4                                            /*!<CAN BUF0_CNTSTAT: PRI Position */
#define CAN_BUF0_CNTSTAT_PRI_Msk     (0xFUL << CAN_BUF0_CNTSTAT_PRI_Pos)          /*!<CAN BUF0_CNTSTAT: PRI Mask */

#define CAN_BUF0_CNTSTAT_DLC_Pos     12                                           /*!<CAN BUF0_CNTSTAT: DLC Position */
#define CAN_BUF0_CNTSTAT_DLC_Msk     (0xFUL << CAN_BUF0_CNTSTAT_DLC_Pos)          /*!<CAN BUF0_CNTSTAT: DLC Mask */

#define CAN_BUF0_CNTSTAT_Msk_ALL     (CAN_BUF0_CNTSTAT_ST_Msk      |\
                                      CAN_BUF0_CNTSTAT_PRI_Msk     |\
                                      CAN_BUF0_CNTSTAT_DLC_Msk     )

#define CAN_BUF0_TSTP_TSTP_Pos       0                                            /*!<CAN BUF0_TSTP: TSTP Position */
#define CAN_BUF0_TSTP_TSTP_Msk       (0xFFFFUL /*<< CAN_BUF0_TSTP_TSTP_Pos*/)     /*!<CAN BUF0_TSTP: TSTP Mask */

#define CAN_BUF0_TSTP_Msk_ALL        (CAN_BUF0_TSTP_TSTP_Msk      )

#define CAN_BUF0_DATA3_DATAL_Pos     0                                            /*!<CAN BUF0_DATA3: DATAL Position */
#define CAN_BUF0_DATA3_DATAL_Msk     (0xFFUL /*<< CAN_BUF0_DATA3_DATAL_Pos*/)     /*!<CAN BUF0_DATA3: DATAL Mask */

#define CAN_BUF0_DATA3_DATAH_Pos     8                                            /*!<CAN BUF0_DATA3: DATAH Position */
#define CAN_BUF0_DATA3_DATAH_Msk     (0xFFUL << CAN_BUF0_DATA3_DATAH_Pos)         /*!<CAN BUF0_DATA3: DATAH Mask */

#define CAN_BUF0_DATA3_Msk_ALL       (CAN_BUF0_DATA3_DATAL_Msk     |\
                                      CAN_BUF0_DATA3_DATAH_Msk     )

#define CAN_BUF0_DATA2_DATAL_Pos     0                                            /*!<CAN BUF0_DATA2: DATAL Position */
#define CAN_BUF0_DATA2_DATAL_Msk     (0xFFUL /*<< CAN_BUF0_DATA2_DATAL_Pos*/)     /*!<CAN BUF0_DATA2: DATAL Mask */

#define CAN_BUF0_DATA2_DATAH_Pos     8                                            /*!<CAN BUF0_DATA2: DATAH Position */
#define CAN_BUF0_DATA2_DATAH_Msk     (0xFFUL << CAN_BUF0_DATA2_DATAH_Pos)         /*!<CAN BUF0_DATA2: DATAH Mask */

#define CAN_BUF0_DATA2_Msk_ALL       (CAN_BUF0_DATA2_DATAL_Msk     |\
                                      CAN_BUF0_DATA2_DATAH_Msk     )

#define CAN_BUF0_DATA1_DATAL_Pos     0                                            /*!<CAN BUF0_DATA1: DATAL Position */
#define CAN_BUF0_DATA1_DATAL_Msk     (0xFFUL /*<< CAN_BUF0_DATA1_DATAL_Pos*/)     /*!<CAN BUF0_DATA1: DATAL Mask */

#define CAN_BUF0_DATA1_DATAH_Pos     8                                            /*!<CAN BUF0_DATA1: DATAH Position */
#define CAN_BUF0_DATA1_DATAH_Msk     (0xFFUL << CAN_BUF0_DATA1_DATAH_Pos)         /*!<CAN BUF0_DATA1: DATAH Mask */

#define CAN_BUF0_DATA1_Msk_ALL       (CAN_BUF0_DATA1_DATAL_Msk     |\
                                      CAN_BUF0_DATA1_DATAH_Msk     )

#define CAN_BUF0_DATA0_DATAL_Pos     0                                            /*!<CAN BUF0_DATA0: DATAL Position */
#define CAN_BUF0_DATA0_DATAL_Msk     (0xFFUL /*<< CAN_BUF0_DATA0_DATAL_Pos*/)     /*!<CAN BUF0_DATA0: DATAL Mask */

#define CAN_BUF0_DATA0_DATAH_Pos     8                                            /*!<CAN BUF0_DATA0: DATAH Position */
#define CAN_BUF0_DATA0_DATAH_Msk     (0xFFUL << CAN_BUF0_DATA0_DATAH_Pos)         /*!<CAN BUF0_DATA0: DATAH Mask */

#define CAN_BUF0_DATA0_Msk_ALL       (CAN_BUF0_DATA0_DATAL_Msk     |\
                                      CAN_BUF0_DATA0_DATAH_Msk     )

#define CAN_BUF0_ID0_RTR_Pos         0                                            /*!<CAN BUF0_ID0: RTR Position */
#define CAN_BUF0_ID0_RTR_Msk         (0x1UL /*<< CAN_BUF0_ID0_RTR_Pos*/)          /*!<CAN BUF0_ID0: RTR Mask */

#define CAN_BUF0_ID0_ID_Pos          1                                            /*!<CAN BUF0_ID0: ID Position */
#define CAN_BUF0_ID0_ID_Msk          (0x7FFFUL << CAN_BUF0_ID0_ID_Pos)            /*!<CAN BUF0_ID0: ID Mask */

#define CAN_BUF0_ID0_Msk_ALL         (CAN_BUF0_ID0_RTR_Msk         |\
                                      CAN_BUF0_ID0_ID_Msk          )

#define CAN_BUF0_ID1_IDEX_Pos        0                                            /*!<CAN BUF0_ID1: IDEX Position */
#define CAN_BUF0_ID1_IDEX_Msk        (0x7UL /*<< CAN_BUF0_ID1_IDEX_Pos*/)         /*!<CAN BUF0_ID1: IDEX Mask */

#define CAN_BUF0_ID1_IDE_Pos         3                                            /*!<CAN BUF0_ID1: IDE Position */
#define CAN_BUF0_ID1_IDE_Msk         (0x1UL << CAN_BUF0_ID1_IDE_Pos)              /*!<CAN BUF0_ID1: IDE Mask */

#define CAN_BUF0_ID1_SRR_Pos         4                                            /*!<CAN BUF0_ID1: SRR Position */
#define CAN_BUF0_ID1_SRR_Msk         (0x1UL << CAN_BUF0_ID1_SRR_Pos)              /*!<CAN BUF0_ID1: SRR Mask */

#define CAN_BUF0_ID1_ID_Pos          5                                            /*!<CAN BUF0_ID1: ID Position */
#define CAN_BUF0_ID1_ID_Msk          (0x7FFUL << CAN_BUF0_ID1_ID_Pos)             /*!<CAN BUF0_ID1: ID Mask */

#define CAN_BUF0_ID1_Msk_ALL         (CAN_BUF0_ID1_IDEX_Msk        |\
                                      CAN_BUF0_ID1_IDE_Msk         |\
                                      CAN_BUF0_ID1_SRR_Msk         |\
                                      CAN_BUF0_ID1_ID_Msk          )

#define CAN_BUF1_CNTSTAT_ST_Pos      0                                            /*!<CAN BUF1_CNTSTAT: ST Position */
#define CAN_BUF1_CNTSTAT_ST_Msk      (0xFUL /*<< CAN_BUF1_CNTSTAT_ST_Pos*/)       /*!<CAN BUF1_CNTSTAT: ST Mask */

#define CAN_BUF1_CNTSTAT_PRI_Pos     4                                            /*!<CAN BUF1_CNTSTAT: PRI Position */
#define CAN_BUF1_CNTSTAT_PRI_Msk     (0xFUL << CAN_BUF1_CNTSTAT_PRI_Pos)          /*!<CAN BUF1_CNTSTAT: PRI Mask */

#define CAN_BUF1_CNTSTAT_DLC_Pos     12                                           /*!<CAN BUF1_CNTSTAT: DLC Position */
#define CAN_BUF1_CNTSTAT_DLC_Msk     (0xFUL << CAN_BUF1_CNTSTAT_DLC_Pos)          /*!<CAN BUF1_CNTSTAT: DLC Mask */

#define CAN_BUF1_CNTSTAT_Msk_ALL     (CAN_BUF1_CNTSTAT_ST_Msk      |\
                                      CAN_BUF1_CNTSTAT_PRI_Msk     |\
                                      CAN_BUF1_CNTSTAT_DLC_Msk     )

#define CAN_BUF1_TSTP_TSTP_Pos       0                                            /*!<CAN BUF1_TSTP: TSTP Position */
#define CAN_BUF1_TSTP_TSTP_Msk       (0xFFFFUL /*<< CAN_BUF1_TSTP_TSTP_Pos*/)     /*!<CAN BUF1_TSTP: TSTP Mask */

#define CAN_BUF1_TSTP_Msk_ALL        (CAN_BUF1_TSTP_TSTP_Msk      )

#define CAN_BUF1_DATA3_DATAL_Pos     0                                            /*!<CAN BUF1_DATA3: DATAL Position */
#define CAN_BUF1_DATA3_DATAL_Msk     (0xFFUL /*<< CAN_BUF1_DATA3_DATAL_Pos*/)     /*!<CAN BUF1_DATA3: DATAL Mask */

#define CAN_BUF1_DATA3_DATAH_Pos     8                                            /*!<CAN BUF1_DATA3: DATAH Position */
#define CAN_BUF1_DATA3_DATAH_Msk     (0xFFUL << CAN_BUF1_DATA3_DATAH_Pos)         /*!<CAN BUF1_DATA3: DATAH Mask */

#define CAN_BUF1_DATA3_Msk_ALL       (CAN_BUF1_DATA3_DATAL_Msk     |\
                                      CAN_BUF1_DATA3_DATAH_Msk     )

#define CAN_BUF1_DATA2_DATAL_Pos     0                                            /*!<CAN BUF1_DATA2: DATAL Position */
#define CAN_BUF1_DATA2_DATAL_Msk     (0xFFUL /*<< CAN_BUF1_DATA2_DATAL_Pos*/)     /*!<CAN BUF1_DATA2: DATAL Mask */

#define CAN_BUF1_DATA2_DATAH_Pos     8                                            /*!<CAN BUF1_DATA2: DATAH Position */
#define CAN_BUF1_DATA2_DATAH_Msk     (0xFFUL << CAN_BUF1_DATA2_DATAH_Pos)         /*!<CAN BUF1_DATA2: DATAH Mask */

#define CAN_BUF1_DATA2_Msk_ALL       (CAN_BUF1_DATA2_DATAL_Msk     |\
                                      CAN_BUF1_DATA2_DATAH_Msk     )

#define CAN_BUF1_DATA1_DATAL_Pos     0                                            /*!<CAN BUF1_DATA1: DATAL Position */
#define CAN_BUF1_DATA1_DATAL_Msk     (0xFFUL /*<< CAN_BUF1_DATA1_DATAL_Pos*/)     /*!<CAN BUF1_DATA1: DATAL Mask */

#define CAN_BUF1_DATA1_DATAH_Pos     8                                            /*!<CAN BUF1_DATA1: DATAH Position */
#define CAN_BUF1_DATA1_DATAH_Msk     (0xFFUL << CAN_BUF1_DATA1_DATAH_Pos)         /*!<CAN BUF1_DATA1: DATAH Mask */

#define CAN_BUF1_DATA1_Msk_ALL       (CAN_BUF1_DATA1_DATAL_Msk     |\
                                      CAN_BUF1_DATA1_DATAH_Msk     )

#define CAN_BUF1_DATA0_DATAL_Pos     0                                            /*!<CAN BUF1_DATA0: DATAL Position */
#define CAN_BUF1_DATA0_DATAL_Msk     (0xFFUL /*<< CAN_BUF1_DATA0_DATAL_Pos*/)     /*!<CAN BUF1_DATA0: DATAL Mask */

#define CAN_BUF1_DATA0_DATAH_Pos     8                                            /*!<CAN BUF1_DATA0: DATAH Position */
#define CAN_BUF1_DATA0_DATAH_Msk     (0xFFUL << CAN_BUF1_DATA0_DATAH_Pos)         /*!<CAN BUF1_DATA0: DATAH Mask */

#define CAN_BUF1_DATA0_Msk_ALL       (CAN_BUF1_DATA0_DATAL_Msk     |\
                                      CAN_BUF1_DATA0_DATAH_Msk     )

#define CAN_BUF1_ID0_RTR_Pos         0                                            /*!<CAN BUF1_ID0: RTR Position */
#define CAN_BUF1_ID0_RTR_Msk         (0x1UL /*<< CAN_BUF1_ID0_RTR_Pos*/)          /*!<CAN BUF1_ID0: RTR Mask */

#define CAN_BUF1_ID0_ID_Pos          1                                            /*!<CAN BUF1_ID0: ID Position */
#define CAN_BUF1_ID0_ID_Msk          (0x7FFFUL << CAN_BUF1_ID0_ID_Pos)            /*!<CAN BUF1_ID0: ID Mask */

#define CAN_BUF1_ID0_Msk_ALL         (CAN_BUF1_ID0_RTR_Msk         |\
                                      CAN_BUF1_ID0_ID_Msk          )

#define CAN_BUF1_ID1_IDEX_Pos        0                                            /*!<CAN BUF1_ID1: IDEX Position */
#define CAN_BUF1_ID1_IDEX_Msk        (0x7UL /*<< CAN_BUF1_ID1_IDEX_Pos*/)         /*!<CAN BUF1_ID1: IDEX Mask */

#define CAN_BUF1_ID1_IDE_Pos         3                                            /*!<CAN BUF1_ID1: IDE Position */
#define CAN_BUF1_ID1_IDE_Msk         (0x1UL << CAN_BUF1_ID1_IDE_Pos)              /*!<CAN BUF1_ID1: IDE Mask */

#define CAN_BUF1_ID1_SRR_Pos         4                                            /*!<CAN BUF1_ID1: SRR Position */
#define CAN_BUF1_ID1_SRR_Msk         (0x1UL << CAN_BUF1_ID1_SRR_Pos)              /*!<CAN BUF1_ID1: SRR Mask */

#define CAN_BUF1_ID1_ID_Pos          5                                            /*!<CAN BUF1_ID1: ID Position */
#define CAN_BUF1_ID1_ID_Msk          (0x7FFUL << CAN_BUF1_ID1_ID_Pos)             /*!<CAN BUF1_ID1: ID Mask */

#define CAN_BUF1_ID1_Msk_ALL         (CAN_BUF1_ID1_IDEX_Msk        |\
                                      CAN_BUF1_ID1_IDE_Msk         |\
                                      CAN_BUF1_ID1_SRR_Msk         |\
                                      CAN_BUF1_ID1_ID_Msk          )

#define CAN_BUF2_CNTSTAT_ST_Pos      0                                            /*!<CAN BUF2_CNTSTAT: ST Position */
#define CAN_BUF2_CNTSTAT_ST_Msk      (0xFUL /*<< CAN_BUF2_CNTSTAT_ST_Pos*/)       /*!<CAN BUF2_CNTSTAT: ST Mask */

#define CAN_BUF2_CNTSTAT_PRI_Pos     4                                            /*!<CAN BUF2_CNTSTAT: PRI Position */
#define CAN_BUF2_CNTSTAT_PRI_Msk     (0xFUL << CAN_BUF2_CNTSTAT_PRI_Pos)          /*!<CAN BUF2_CNTSTAT: PRI Mask */

#define CAN_BUF2_CNTSTAT_DLC_Pos     12                                           /*!<CAN BUF2_CNTSTAT: DLC Position */
#define CAN_BUF2_CNTSTAT_DLC_Msk     (0xFUL << CAN_BUF2_CNTSTAT_DLC_Pos)          /*!<CAN BUF2_CNTSTAT: DLC Mask */

#define CAN_BUF2_CNTSTAT_Msk_ALL     (CAN_BUF2_CNTSTAT_ST_Msk      |\
                                      CAN_BUF2_CNTSTAT_PRI_Msk     |\
                                      CAN_BUF2_CNTSTAT_DLC_Msk     )

#define CAN_BUF2_TSTP_TSTP_Pos       0                                            /*!<CAN BUF2_TSTP: TSTP Position */
#define CAN_BUF2_TSTP_TSTP_Msk       (0xFFFFUL /*<< CAN_BUF2_TSTP_TSTP_Pos*/)     /*!<CAN BUF2_TSTP: TSTP Mask */

#define CAN_BUF2_TSTP_Msk_ALL        (CAN_BUF2_TSTP_TSTP_Msk      )

#define CAN_BUF2_DATA3_DATAL_Pos     0                                            /*!<CAN BUF2_DATA3: DATAL Position */
#define CAN_BUF2_DATA3_DATAL_Msk     (0xFFUL /*<< CAN_BUF2_DATA3_DATAL_Pos*/)     /*!<CAN BUF2_DATA3: DATAL Mask */

#define CAN_BUF2_DATA3_DATAH_Pos     8                                            /*!<CAN BUF2_DATA3: DATAH Position */
#define CAN_BUF2_DATA3_DATAH_Msk     (0xFFUL << CAN_BUF2_DATA3_DATAH_Pos)         /*!<CAN BUF2_DATA3: DATAH Mask */

#define CAN_BUF2_DATA3_Msk_ALL       (CAN_BUF2_DATA3_DATAL_Msk     |\
                                      CAN_BUF2_DATA3_DATAH_Msk     )

#define CAN_BUF2_DATA2_DATAL_Pos     0                                            /*!<CAN BUF2_DATA2: DATAL Position */
#define CAN_BUF2_DATA2_DATAL_Msk     (0xFFUL /*<< CAN_BUF2_DATA2_DATAL_Pos*/)     /*!<CAN BUF2_DATA2: DATAL Mask */

#define CAN_BUF2_DATA2_DATAH_Pos     8                                            /*!<CAN BUF2_DATA2: DATAH Position */
#define CAN_BUF2_DATA2_DATAH_Msk     (0xFFUL << CAN_BUF2_DATA2_DATAH_Pos)         /*!<CAN BUF2_DATA2: DATAH Mask */

#define CAN_BUF2_DATA2_Msk_ALL       (CAN_BUF2_DATA2_DATAL_Msk     |\
                                      CAN_BUF2_DATA2_DATAH_Msk     )

#define CAN_BUF2_DATA1_DATAL_Pos     0                                            /*!<CAN BUF2_DATA1: DATAL Position */
#define CAN_BUF2_DATA1_DATAL_Msk     (0xFFUL /*<< CAN_BUF2_DATA1_DATAL_Pos*/)     /*!<CAN BUF2_DATA1: DATAL Mask */

#define CAN_BUF2_DATA1_DATAH_Pos     8                                            /*!<CAN BUF2_DATA1: DATAH Position */
#define CAN_BUF2_DATA1_DATAH_Msk     (0xFFUL << CAN_BUF2_DATA1_DATAH_Pos)         /*!<CAN BUF2_DATA1: DATAH Mask */

#define CAN_BUF2_DATA1_Msk_ALL       (CAN_BUF2_DATA1_DATAL_Msk     |\
                                      CAN_BUF2_DATA1_DATAH_Msk     )

#define CAN_BUF2_DATA0_DATAL_Pos     0                                            /*!<CAN BUF2_DATA0: DATAL Position */
#define CAN_BUF2_DATA0_DATAL_Msk     (0xFFUL /*<< CAN_BUF2_DATA0_DATAL_Pos*/)     /*!<CAN BUF2_DATA0: DATAL Mask */

#define CAN_BUF2_DATA0_DATAH_Pos     8                                            /*!<CAN BUF2_DATA0: DATAH Position */
#define CAN_BUF2_DATA0_DATAH_Msk     (0xFFUL << CAN_BUF2_DATA0_DATAH_Pos)         /*!<CAN BUF2_DATA0: DATAH Mask */

#define CAN_BUF2_DATA0_Msk_ALL       (CAN_BUF2_DATA0_DATAL_Msk     |\
                                      CAN_BUF2_DATA0_DATAH_Msk     )

#define CAN_BUF2_ID0_RTR_Pos         0                                            /*!<CAN BUF2_ID0: RTR Position */
#define CAN_BUF2_ID0_RTR_Msk         (0x1UL /*<< CAN_BUF2_ID0_RTR_Pos*/)          /*!<CAN BUF2_ID0: RTR Mask */

#define CAN_BUF2_ID0_ID_Pos          1                                            /*!<CAN BUF2_ID0: ID Position */
#define CAN_BUF2_ID0_ID_Msk          (0x7FFFUL << CAN_BUF2_ID0_ID_Pos)            /*!<CAN BUF2_ID0: ID Mask */

#define CAN_BUF2_ID0_Msk_ALL         (CAN_BUF2_ID0_RTR_Msk         |\
                                      CAN_BUF2_ID0_ID_Msk          )

#define CAN_BUF2_ID1_IDEX_Pos        0                                            /*!<CAN BUF2_ID1: IDEX Position */
#define CAN_BUF2_ID1_IDEX_Msk        (0x7UL /*<< CAN_BUF2_ID1_IDEX_Pos*/)         /*!<CAN BUF2_ID1: IDEX Mask */

#define CAN_BUF2_ID1_IDE_Pos         3                                            /*!<CAN BUF2_ID1: IDE Position */
#define CAN_BUF2_ID1_IDE_Msk         (0x1UL << CAN_BUF2_ID1_IDE_Pos)              /*!<CAN BUF2_ID1: IDE Mask */

#define CAN_BUF2_ID1_SRR_Pos         4                                            /*!<CAN BUF2_ID1: SRR Position */
#define CAN_BUF2_ID1_SRR_Msk         (0x1UL << CAN_BUF2_ID1_SRR_Pos)              /*!<CAN BUF2_ID1: SRR Mask */

#define CAN_BUF2_ID1_ID_Pos          5                                            /*!<CAN BUF2_ID1: ID Position */
#define CAN_BUF2_ID1_ID_Msk          (0x7FFUL << CAN_BUF2_ID1_ID_Pos)             /*!<CAN BUF2_ID1: ID Mask */

#define CAN_BUF2_ID1_Msk_ALL         (CAN_BUF2_ID1_IDEX_Msk        |\
                                      CAN_BUF2_ID1_IDE_Msk         |\
                                      CAN_BUF2_ID1_SRR_Msk         |\
                                      CAN_BUF2_ID1_ID_Msk          )

#define CAN_BUF3_CNTSTAT_ST_Pos      0                                            /*!<CAN BUF3_CNTSTAT: ST Position */
#define CAN_BUF3_CNTSTAT_ST_Msk      (0xFUL /*<< CAN_BUF3_CNTSTAT_ST_Pos*/)       /*!<CAN BUF3_CNTSTAT: ST Mask */

#define CAN_BUF3_CNTSTAT_PRI_Pos     4                                            /*!<CAN BUF3_CNTSTAT: PRI Position */
#define CAN_BUF3_CNTSTAT_PRI_Msk     (0xFUL << CAN_BUF3_CNTSTAT_PRI_Pos)          /*!<CAN BUF3_CNTSTAT: PRI Mask */

#define CAN_BUF3_CNTSTAT_DLC_Pos     12                                           /*!<CAN BUF3_CNTSTAT: DLC Position */
#define CAN_BUF3_CNTSTAT_DLC_Msk     (0xFUL << CAN_BUF3_CNTSTAT_DLC_Pos)          /*!<CAN BUF3_CNTSTAT: DLC Mask */

#define CAN_BUF3_CNTSTAT_Msk_ALL     (CAN_BUF3_CNTSTAT_ST_Msk      |\
                                      CAN_BUF3_CNTSTAT_PRI_Msk     |\
                                      CAN_BUF3_CNTSTAT_DLC_Msk     )

#define CAN_BUF3_TSTP_TSTP_Pos       0                                            /*!<CAN BUF3_TSTP: TSTP Position */
#define CAN_BUF3_TSTP_TSTP_Msk       (0xFFFFUL /*<< CAN_BUF3_TSTP_TSTP_Pos*/)     /*!<CAN BUF3_TSTP: TSTP Mask */

#define CAN_BUF3_TSTP_Msk_ALL        (CAN_BUF3_TSTP_TSTP_Msk      )

#define CAN_BUF3_DATA3_DATAL_Pos     0                                            /*!<CAN BUF3_DATA3: DATAL Position */
#define CAN_BUF3_DATA3_DATAL_Msk     (0xFFUL /*<< CAN_BUF3_DATA3_DATAL_Pos*/)     /*!<CAN BUF3_DATA3: DATAL Mask */

#define CAN_BUF3_DATA3_DATAH_Pos     8                                            /*!<CAN BUF3_DATA3: DATAH Position */
#define CAN_BUF3_DATA3_DATAH_Msk     (0xFFUL << CAN_BUF3_DATA3_DATAH_Pos)         /*!<CAN BUF3_DATA3: DATAH Mask */

#define CAN_BUF3_DATA3_Msk_ALL       (CAN_BUF3_DATA3_DATAL_Msk     |\
                                      CAN_BUF3_DATA3_DATAH_Msk     )

#define CAN_BUF3_DATA2_DATAL_Pos     0                                            /*!<CAN BUF3_DATA2: DATAL Position */
#define CAN_BUF3_DATA2_DATAL_Msk     (0xFFUL /*<< CAN_BUF3_DATA2_DATAL_Pos*/)     /*!<CAN BUF3_DATA2: DATAL Mask */

#define CAN_BUF3_DATA2_DATAH_Pos     8                                            /*!<CAN BUF3_DATA2: DATAH Position */
#define CAN_BUF3_DATA2_DATAH_Msk     (0xFFUL << CAN_BUF3_DATA2_DATAH_Pos)         /*!<CAN BUF3_DATA2: DATAH Mask */

#define CAN_BUF3_DATA2_Msk_ALL       (CAN_BUF3_DATA2_DATAL_Msk     |\
                                      CAN_BUF3_DATA2_DATAH_Msk     )

#define CAN_BUF3_DATA1_DATAL_Pos     0                                            /*!<CAN BUF3_DATA1: DATAL Position */
#define CAN_BUF3_DATA1_DATAL_Msk     (0xFFUL /*<< CAN_BUF3_DATA1_DATAL_Pos*/)     /*!<CAN BUF3_DATA1: DATAL Mask */

#define CAN_BUF3_DATA1_DATAH_Pos     8                                            /*!<CAN BUF3_DATA1: DATAH Position */
#define CAN_BUF3_DATA1_DATAH_Msk     (0xFFUL << CAN_BUF3_DATA1_DATAH_Pos)         /*!<CAN BUF3_DATA1: DATAH Mask */

#define CAN_BUF3_DATA1_Msk_ALL       (CAN_BUF3_DATA1_DATAL_Msk     |\
                                      CAN_BUF3_DATA1_DATAH_Msk     )

#define CAN_BUF3_DATA0_DATAL_Pos     0                                            /*!<CAN BUF3_DATA0: DATAL Position */
#define CAN_BUF3_DATA0_DATAL_Msk     (0xFFUL /*<< CAN_BUF3_DATA0_DATAL_Pos*/)     /*!<CAN BUF3_DATA0: DATAL Mask */

#define CAN_BUF3_DATA0_DATAH_Pos     8                                            /*!<CAN BUF3_DATA0: DATAH Position */
#define CAN_BUF3_DATA0_DATAH_Msk     (0xFFUL << CAN_BUF3_DATA0_DATAH_Pos)         /*!<CAN BUF3_DATA0: DATAH Mask */

#define CAN_BUF3_DATA0_Msk_ALL       (CAN_BUF3_DATA0_DATAL_Msk     |\
                                      CAN_BUF3_DATA0_DATAH_Msk     )

#define CAN_BUF3_ID0_RTR_Pos         0                                            /*!<CAN BUF3_ID0: RTR Position */
#define CAN_BUF3_ID0_RTR_Msk         (0x1UL /*<< CAN_BUF3_ID0_RTR_Pos*/)          /*!<CAN BUF3_ID0: RTR Mask */

#define CAN_BUF3_ID0_ID_Pos          1                                            /*!<CAN BUF3_ID0: ID Position */
#define CAN_BUF3_ID0_ID_Msk          (0x7FFFUL << CAN_BUF3_ID0_ID_Pos)            /*!<CAN BUF3_ID0: ID Mask */

#define CAN_BUF3_ID0_Msk_ALL         (CAN_BUF3_ID0_RTR_Msk         |\
                                      CAN_BUF3_ID0_ID_Msk          )

#define CAN_BUF3_ID1_IDEX_Pos        0                                            /*!<CAN BUF3_ID1: IDEX Position */
#define CAN_BUF3_ID1_IDEX_Msk        (0x7UL /*<< CAN_BUF3_ID1_IDEX_Pos*/)         /*!<CAN BUF3_ID1: IDEX Mask */

#define CAN_BUF3_ID1_IDE_Pos         3                                            /*!<CAN BUF3_ID1: IDE Position */
#define CAN_BUF3_ID1_IDE_Msk         (0x1UL << CAN_BUF3_ID1_IDE_Pos)              /*!<CAN BUF3_ID1: IDE Mask */

#define CAN_BUF3_ID1_SRR_Pos         4                                            /*!<CAN BUF3_ID1: SRR Position */
#define CAN_BUF3_ID1_SRR_Msk         (0x1UL << CAN_BUF3_ID1_SRR_Pos)              /*!<CAN BUF3_ID1: SRR Mask */

#define CAN_BUF3_ID1_ID_Pos          5                                            /*!<CAN BUF3_ID1: ID Position */
#define CAN_BUF3_ID1_ID_Msk          (0x7FFUL << CAN_BUF3_ID1_ID_Pos)             /*!<CAN BUF3_ID1: ID Mask */

#define CAN_BUF3_ID1_Msk_ALL         (CAN_BUF3_ID1_IDEX_Msk        |\
                                      CAN_BUF3_ID1_IDE_Msk         |\
                                      CAN_BUF3_ID1_SRR_Msk         |\
                                      CAN_BUF3_ID1_ID_Msk          )

#define CAN_BUF4_CNTSTAT_ST_Pos      0                                            /*!<CAN BUF4_CNTSTAT: ST Position */
#define CAN_BUF4_CNTSTAT_ST_Msk      (0xFUL /*<< CAN_BUF4_CNTSTAT_ST_Pos*/)       /*!<CAN BUF4_CNTSTAT: ST Mask */

#define CAN_BUF4_CNTSTAT_PRI_Pos     4                                            /*!<CAN BUF4_CNTSTAT: PRI Position */
#define CAN_BUF4_CNTSTAT_PRI_Msk     (0xFUL << CAN_BUF4_CNTSTAT_PRI_Pos)          /*!<CAN BUF4_CNTSTAT: PRI Mask */

#define CAN_BUF4_CNTSTAT_DLC_Pos     12                                           /*!<CAN BUF4_CNTSTAT: DLC Position */
#define CAN_BUF4_CNTSTAT_DLC_Msk     (0xFUL << CAN_BUF4_CNTSTAT_DLC_Pos)          /*!<CAN BUF4_CNTSTAT: DLC Mask */

#define CAN_BUF4_CNTSTAT_Msk_ALL     (CAN_BUF4_CNTSTAT_ST_Msk      |\
                                      CAN_BUF4_CNTSTAT_PRI_Msk     |\
                                      CAN_BUF4_CNTSTAT_DLC_Msk     )

#define CAN_BUF4_TSTP_TSTP_Pos       0                                            /*!<CAN BUF4_TSTP: TSTP Position */
#define CAN_BUF4_TSTP_TSTP_Msk       (0xFFFFUL /*<< CAN_BUF4_TSTP_TSTP_Pos*/)     /*!<CAN BUF4_TSTP: TSTP Mask */

#define CAN_BUF4_TSTP_Msk_ALL        (CAN_BUF4_TSTP_TSTP_Msk      )

#define CAN_BUF4_DATA3_DATAL_Pos     0                                            /*!<CAN BUF4_DATA3: DATAL Position */
#define CAN_BUF4_DATA3_DATAL_Msk     (0xFFUL /*<< CAN_BUF4_DATA3_DATAL_Pos*/)     /*!<CAN BUF4_DATA3: DATAL Mask */

#define CAN_BUF4_DATA3_DATAH_Pos     8                                            /*!<CAN BUF4_DATA3: DATAH Position */
#define CAN_BUF4_DATA3_DATAH_Msk     (0xFFUL << CAN_BUF4_DATA3_DATAH_Pos)         /*!<CAN BUF4_DATA3: DATAH Mask */

#define CAN_BUF4_DATA3_Msk_ALL       (CAN_BUF4_DATA3_DATAL_Msk     |\
                                      CAN_BUF4_DATA3_DATAH_Msk     )

#define CAN_BUF4_DATA2_DATAL_Pos     0                                            /*!<CAN BUF4_DATA2: DATAL Position */
#define CAN_BUF4_DATA2_DATAL_Msk     (0xFFUL /*<< CAN_BUF4_DATA2_DATAL_Pos*/)     /*!<CAN BUF4_DATA2: DATAL Mask */

#define CAN_BUF4_DATA2_DATAH_Pos     8                                            /*!<CAN BUF4_DATA2: DATAH Position */
#define CAN_BUF4_DATA2_DATAH_Msk     (0xFFUL << CAN_BUF4_DATA2_DATAH_Pos)         /*!<CAN BUF4_DATA2: DATAH Mask */

#define CAN_BUF4_DATA2_Msk_ALL       (CAN_BUF4_DATA2_DATAL_Msk     |\
                                      CAN_BUF4_DATA2_DATAH_Msk     )

#define CAN_BUF4_DATA1_DATAL_Pos     0                                            /*!<CAN BUF4_DATA1: DATAL Position */
#define CAN_BUF4_DATA1_DATAL_Msk     (0xFFUL /*<< CAN_BUF4_DATA1_DATAL_Pos*/)     /*!<CAN BUF4_DATA1: DATAL Mask */

#define CAN_BUF4_DATA1_DATAH_Pos     8                                            /*!<CAN BUF4_DATA1: DATAH Position */
#define CAN_BUF4_DATA1_DATAH_Msk     (0xFFUL << CAN_BUF4_DATA1_DATAH_Pos)         /*!<CAN BUF4_DATA1: DATAH Mask */

#define CAN_BUF4_DATA1_Msk_ALL       (CAN_BUF4_DATA1_DATAL_Msk     |\
                                      CAN_BUF4_DATA1_DATAH_Msk     )

#define CAN_BUF4_DATA0_DATAL_Pos     0                                            /*!<CAN BUF4_DATA0: DATAL Position */
#define CAN_BUF4_DATA0_DATAL_Msk     (0xFFUL /*<< CAN_BUF4_DATA0_DATAL_Pos*/)     /*!<CAN BUF4_DATA0: DATAL Mask */

#define CAN_BUF4_DATA0_DATAH_Pos     8                                            /*!<CAN BUF4_DATA0: DATAH Position */
#define CAN_BUF4_DATA0_DATAH_Msk     (0xFFUL << CAN_BUF4_DATA0_DATAH_Pos)         /*!<CAN BUF4_DATA0: DATAH Mask */

#define CAN_BUF4_DATA0_Msk_ALL       (CAN_BUF4_DATA0_DATAL_Msk     |\
                                      CAN_BUF4_DATA0_DATAH_Msk     )

#define CAN_BUF4_ID0_RTR_Pos         0                                            /*!<CAN BUF4_ID0: RTR Position */
#define CAN_BUF4_ID0_RTR_Msk         (0x1UL /*<< CAN_BUF4_ID0_RTR_Pos*/)          /*!<CAN BUF4_ID0: RTR Mask */

#define CAN_BUF4_ID0_ID_Pos          1                                            /*!<CAN BUF4_ID0: ID Position */
#define CAN_BUF4_ID0_ID_Msk          (0x7FFFUL << CAN_BUF4_ID0_ID_Pos)            /*!<CAN BUF4_ID0: ID Mask */

#define CAN_BUF4_ID0_Msk_ALL         (CAN_BUF4_ID0_RTR_Msk         |\
                                      CAN_BUF4_ID0_ID_Msk          )

#define CAN_BUF4_ID1_IDEX_Pos        0                                            /*!<CAN BUF4_ID1: IDEX Position */
#define CAN_BUF4_ID1_IDEX_Msk        (0x7UL /*<< CAN_BUF4_ID1_IDEX_Pos*/)         /*!<CAN BUF4_ID1: IDEX Mask */

#define CAN_BUF4_ID1_IDE_Pos         3                                            /*!<CAN BUF4_ID1: IDE Position */
#define CAN_BUF4_ID1_IDE_Msk         (0x1UL << CAN_BUF4_ID1_IDE_Pos)              /*!<CAN BUF4_ID1: IDE Mask */

#define CAN_BUF4_ID1_SRR_Pos         4                                            /*!<CAN BUF4_ID1: SRR Position */
#define CAN_BUF4_ID1_SRR_Msk         (0x1UL << CAN_BUF4_ID1_SRR_Pos)              /*!<CAN BUF4_ID1: SRR Mask */

#define CAN_BUF4_ID1_ID_Pos          5                                            /*!<CAN BUF4_ID1: ID Position */
#define CAN_BUF4_ID1_ID_Msk          (0x7FFUL << CAN_BUF4_ID1_ID_Pos)             /*!<CAN BUF4_ID1: ID Mask */

#define CAN_BUF4_ID1_Msk_ALL         (CAN_BUF4_ID1_IDEX_Msk        |\
                                      CAN_BUF4_ID1_IDE_Msk         |\
                                      CAN_BUF4_ID1_SRR_Msk         |\
                                      CAN_BUF4_ID1_ID_Msk          )

#define CAN_BUF5_CNTSTAT_ST_Pos      0                                            /*!<CAN BUF5_CNTSTAT: ST Position */
#define CAN_BUF5_CNTSTAT_ST_Msk      (0xFUL /*<< CAN_BUF5_CNTSTAT_ST_Pos*/)       /*!<CAN BUF5_CNTSTAT: ST Mask */

#define CAN_BUF5_CNTSTAT_PRI_Pos     4                                            /*!<CAN BUF5_CNTSTAT: PRI Position */
#define CAN_BUF5_CNTSTAT_PRI_Msk     (0xFUL << CAN_BUF5_CNTSTAT_PRI_Pos)          /*!<CAN BUF5_CNTSTAT: PRI Mask */

#define CAN_BUF5_CNTSTAT_DLC_Pos     12                                           /*!<CAN BUF5_CNTSTAT: DLC Position */
#define CAN_BUF5_CNTSTAT_DLC_Msk     (0xFUL << CAN_BUF5_CNTSTAT_DLC_Pos)          /*!<CAN BUF5_CNTSTAT: DLC Mask */

#define CAN_BUF5_CNTSTAT_Msk_ALL     (CAN_BUF5_CNTSTAT_ST_Msk      |\
                                      CAN_BUF5_CNTSTAT_PRI_Msk     |\
                                      CAN_BUF5_CNTSTAT_DLC_Msk     )

#define CAN_BUF5_TSTP_TSTP_Pos       0                                            /*!<CAN BUF5_TSTP: TSTP Position */
#define CAN_BUF5_TSTP_TSTP_Msk       (0xFFFFUL /*<< CAN_BUF5_TSTP_TSTP_Pos*/)     /*!<CAN BUF5_TSTP: TSTP Mask */

#define CAN_BUF5_TSTP_Msk_ALL        (CAN_BUF5_TSTP_TSTP_Msk      )

#define CAN_BUF5_DATA3_DATAL_Pos     0                                            /*!<CAN BUF5_DATA3: DATAL Position */
#define CAN_BUF5_DATA3_DATAL_Msk     (0xFFUL /*<< CAN_BUF5_DATA3_DATAL_Pos*/)     /*!<CAN BUF5_DATA3: DATAL Mask */

#define CAN_BUF5_DATA3_DATAH_Pos     8                                            /*!<CAN BUF5_DATA3: DATAH Position */
#define CAN_BUF5_DATA3_DATAH_Msk     (0xFFUL << CAN_BUF5_DATA3_DATAH_Pos)         /*!<CAN BUF5_DATA3: DATAH Mask */

#define CAN_BUF5_DATA3_Msk_ALL       (CAN_BUF5_DATA3_DATAL_Msk     |\
                                      CAN_BUF5_DATA3_DATAH_Msk     )

#define CAN_BUF5_DATA2_DATAL_Pos     0                                            /*!<CAN BUF5_DATA2: DATAL Position */
#define CAN_BUF5_DATA2_DATAL_Msk     (0xFFUL /*<< CAN_BUF5_DATA2_DATAL_Pos*/)     /*!<CAN BUF5_DATA2: DATAL Mask */

#define CAN_BUF5_DATA2_DATAH_Pos     8                                            /*!<CAN BUF5_DATA2: DATAH Position */
#define CAN_BUF5_DATA2_DATAH_Msk     (0xFFUL << CAN_BUF5_DATA2_DATAH_Pos)         /*!<CAN BUF5_DATA2: DATAH Mask */

#define CAN_BUF5_DATA2_Msk_ALL       (CAN_BUF5_DATA2_DATAL_Msk     |\
                                      CAN_BUF5_DATA2_DATAH_Msk     )

#define CAN_BUF5_DATA1_DATAL_Pos     0                                            /*!<CAN BUF5_DATA1: DATAL Position */
#define CAN_BUF5_DATA1_DATAL_Msk     (0xFFUL /*<< CAN_BUF5_DATA1_DATAL_Pos*/)     /*!<CAN BUF5_DATA1: DATAL Mask */

#define CAN_BUF5_DATA1_DATAH_Pos     8                                            /*!<CAN BUF5_DATA1: DATAH Position */
#define CAN_BUF5_DATA1_DATAH_Msk     (0xFFUL << CAN_BUF5_DATA1_DATAH_Pos)         /*!<CAN BUF5_DATA1: DATAH Mask */

#define CAN_BUF5_DATA1_Msk_ALL       (CAN_BUF5_DATA1_DATAL_Msk     |\
                                      CAN_BUF5_DATA1_DATAH_Msk     )

#define CAN_BUF5_DATA0_DATAL_Pos     0                                            /*!<CAN BUF5_DATA0: DATAL Position */
#define CAN_BUF5_DATA0_DATAL_Msk     (0xFFUL /*<< CAN_BUF5_DATA0_DATAL_Pos*/)     /*!<CAN BUF5_DATA0: DATAL Mask */

#define CAN_BUF5_DATA0_DATAH_Pos     8                                            /*!<CAN BUF5_DATA0: DATAH Position */
#define CAN_BUF5_DATA0_DATAH_Msk     (0xFFUL << CAN_BUF5_DATA0_DATAH_Pos)         /*!<CAN BUF5_DATA0: DATAH Mask */

#define CAN_BUF5_DATA0_Msk_ALL       (CAN_BUF5_DATA0_DATAL_Msk     |\
                                      CAN_BUF5_DATA0_DATAH_Msk     )

#define CAN_BUF5_ID0_RTR_Pos         0                                            /*!<CAN BUF5_ID0: RTR Position */
#define CAN_BUF5_ID0_RTR_Msk         (0x1UL /*<< CAN_BUF5_ID0_RTR_Pos*/)          /*!<CAN BUF5_ID0: RTR Mask */

#define CAN_BUF5_ID0_ID_Pos          1                                            /*!<CAN BUF5_ID0: ID Position */
#define CAN_BUF5_ID0_ID_Msk          (0x7FFFUL << CAN_BUF5_ID0_ID_Pos)            /*!<CAN BUF5_ID0: ID Mask */

#define CAN_BUF5_ID0_Msk_ALL         (CAN_BUF5_ID0_RTR_Msk         |\
                                      CAN_BUF5_ID0_ID_Msk          )

#define CAN_BUF5_ID1_IDEX_Pos        0                                            /*!<CAN BUF5_ID1: IDEX Position */
#define CAN_BUF5_ID1_IDEX_Msk        (0x7UL /*<< CAN_BUF5_ID1_IDEX_Pos*/)         /*!<CAN BUF5_ID1: IDEX Mask */

#define CAN_BUF5_ID1_IDE_Pos         3                                            /*!<CAN BUF5_ID1: IDE Position */
#define CAN_BUF5_ID1_IDE_Msk         (0x1UL << CAN_BUF5_ID1_IDE_Pos)              /*!<CAN BUF5_ID1: IDE Mask */

#define CAN_BUF5_ID1_SRR_Pos         4                                            /*!<CAN BUF5_ID1: SRR Position */
#define CAN_BUF5_ID1_SRR_Msk         (0x1UL << CAN_BUF5_ID1_SRR_Pos)              /*!<CAN BUF5_ID1: SRR Mask */

#define CAN_BUF5_ID1_ID_Pos          5                                            /*!<CAN BUF5_ID1: ID Position */
#define CAN_BUF5_ID1_ID_Msk          (0x7FFUL << CAN_BUF5_ID1_ID_Pos)             /*!<CAN BUF5_ID1: ID Mask */

#define CAN_BUF5_ID1_Msk_ALL         (CAN_BUF5_ID1_IDEX_Msk        |\
                                      CAN_BUF5_ID1_IDE_Msk         |\
                                      CAN_BUF5_ID1_SRR_Msk         |\
                                      CAN_BUF5_ID1_ID_Msk          )

#define CAN_BUF6_CNTSTAT_ST_Pos      0                                            /*!<CAN BUF6_CNTSTAT: ST Position */
#define CAN_BUF6_CNTSTAT_ST_Msk      (0xFUL /*<< CAN_BUF6_CNTSTAT_ST_Pos*/)       /*!<CAN BUF6_CNTSTAT: ST Mask */

#define CAN_BUF6_CNTSTAT_PRI_Pos     4                                            /*!<CAN BUF6_CNTSTAT: PRI Position */
#define CAN_BUF6_CNTSTAT_PRI_Msk     (0xFUL << CAN_BUF6_CNTSTAT_PRI_Pos)          /*!<CAN BUF6_CNTSTAT: PRI Mask */

#define CAN_BUF6_CNTSTAT_DLC_Pos     12                                           /*!<CAN BUF6_CNTSTAT: DLC Position */
#define CAN_BUF6_CNTSTAT_DLC_Msk     (0xFUL << CAN_BUF6_CNTSTAT_DLC_Pos)          /*!<CAN BUF6_CNTSTAT: DLC Mask */

#define CAN_BUF6_CNTSTAT_Msk_ALL     (CAN_BUF6_CNTSTAT_ST_Msk      |\
                                      CAN_BUF6_CNTSTAT_PRI_Msk     |\
                                      CAN_BUF6_CNTSTAT_DLC_Msk     )

#define CAN_BUF6_TSTP_TSTP_Pos       0                                            /*!<CAN BUF6_TSTP: TSTP Position */
#define CAN_BUF6_TSTP_TSTP_Msk       (0xFFFFUL /*<< CAN_BUF6_TSTP_TSTP_Pos*/)     /*!<CAN BUF6_TSTP: TSTP Mask */

#define CAN_BUF6_TSTP_Msk_ALL        (CAN_BUF6_TSTP_TSTP_Msk      )

#define CAN_BUF6_DATA3_DATAL_Pos     0                                            /*!<CAN BUF6_DATA3: DATAL Position */
#define CAN_BUF6_DATA3_DATAL_Msk     (0xFFUL /*<< CAN_BUF6_DATA3_DATAL_Pos*/)     /*!<CAN BUF6_DATA3: DATAL Mask */

#define CAN_BUF6_DATA3_DATAH_Pos     8                                            /*!<CAN BUF6_DATA3: DATAH Position */
#define CAN_BUF6_DATA3_DATAH_Msk     (0xFFUL << CAN_BUF6_DATA3_DATAH_Pos)         /*!<CAN BUF6_DATA3: DATAH Mask */

#define CAN_BUF6_DATA3_Msk_ALL       (CAN_BUF6_DATA3_DATAL_Msk     |\
                                      CAN_BUF6_DATA3_DATAH_Msk     )

#define CAN_BUF6_DATA2_DATAL_Pos     0                                            /*!<CAN BUF6_DATA2: DATAL Position */
#define CAN_BUF6_DATA2_DATAL_Msk     (0xFFUL /*<< CAN_BUF6_DATA2_DATAL_Pos*/)     /*!<CAN BUF6_DATA2: DATAL Mask */

#define CAN_BUF6_DATA2_DATAH_Pos     8                                            /*!<CAN BUF6_DATA2: DATAH Position */
#define CAN_BUF6_DATA2_DATAH_Msk     (0xFFUL << CAN_BUF6_DATA2_DATAH_Pos)         /*!<CAN BUF6_DATA2: DATAH Mask */

#define CAN_BUF6_DATA2_Msk_ALL       (CAN_BUF6_DATA2_DATAL_Msk     |\
                                      CAN_BUF6_DATA2_DATAH_Msk     )

#define CAN_BUF6_DATA1_DATAL_Pos     0                                            /*!<CAN BUF6_DATA1: DATAL Position */
#define CAN_BUF6_DATA1_DATAL_Msk     (0xFFUL /*<< CAN_BUF6_DATA1_DATAL_Pos*/)     /*!<CAN BUF6_DATA1: DATAL Mask */

#define CAN_BUF6_DATA1_DATAH_Pos     8                                            /*!<CAN BUF6_DATA1: DATAH Position */
#define CAN_BUF6_DATA1_DATAH_Msk     (0xFFUL << CAN_BUF6_DATA1_DATAH_Pos)         /*!<CAN BUF6_DATA1: DATAH Mask */

#define CAN_BUF6_DATA1_Msk_ALL       (CAN_BUF6_DATA1_DATAL_Msk     |\
                                      CAN_BUF6_DATA1_DATAH_Msk     )

#define CAN_BUF6_DATA0_DATAL_Pos     0                                            /*!<CAN BUF6_DATA0: DATAL Position */
#define CAN_BUF6_DATA0_DATAL_Msk     (0xFFUL /*<< CAN_BUF6_DATA0_DATAL_Pos*/)     /*!<CAN BUF6_DATA0: DATAL Mask */

#define CAN_BUF6_DATA0_DATAH_Pos     8                                            /*!<CAN BUF6_DATA0: DATAH Position */
#define CAN_BUF6_DATA0_DATAH_Msk     (0xFFUL << CAN_BUF6_DATA0_DATAH_Pos)         /*!<CAN BUF6_DATA0: DATAH Mask */

#define CAN_BUF6_DATA0_Msk_ALL       (CAN_BUF6_DATA0_DATAL_Msk     |\
                                      CAN_BUF6_DATA0_DATAH_Msk     )

#define CAN_BUF6_ID0_RTR_Pos         0                                            /*!<CAN BUF6_ID0: RTR Position */
#define CAN_BUF6_ID0_RTR_Msk         (0x1UL /*<< CAN_BUF6_ID0_RTR_Pos*/)          /*!<CAN BUF6_ID0: RTR Mask */

#define CAN_BUF6_ID0_ID_Pos          1                                            /*!<CAN BUF6_ID0: ID Position */
#define CAN_BUF6_ID0_ID_Msk          (0x7FFFUL << CAN_BUF6_ID0_ID_Pos)            /*!<CAN BUF6_ID0: ID Mask */

#define CAN_BUF6_ID0_Msk_ALL         (CAN_BUF6_ID0_RTR_Msk         |\
                                      CAN_BUF6_ID0_ID_Msk          )

#define CAN_BUF6_ID1_IDEX_Pos        0                                            /*!<CAN BUF6_ID1: IDEX Position */
#define CAN_BUF6_ID1_IDEX_Msk        (0x7UL /*<< CAN_BUF6_ID1_IDEX_Pos*/)         /*!<CAN BUF6_ID1: IDEX Mask */

#define CAN_BUF6_ID1_IDE_Pos         3                                            /*!<CAN BUF6_ID1: IDE Position */
#define CAN_BUF6_ID1_IDE_Msk         (0x1UL << CAN_BUF6_ID1_IDE_Pos)              /*!<CAN BUF6_ID1: IDE Mask */

#define CAN_BUF6_ID1_SRR_Pos         4                                            /*!<CAN BUF6_ID1: SRR Position */
#define CAN_BUF6_ID1_SRR_Msk         (0x1UL << CAN_BUF6_ID1_SRR_Pos)              /*!<CAN BUF6_ID1: SRR Mask */

#define CAN_BUF6_ID1_ID_Pos          5                                            /*!<CAN BUF6_ID1: ID Position */
#define CAN_BUF6_ID1_ID_Msk          (0x7FFUL << CAN_BUF6_ID1_ID_Pos)             /*!<CAN BUF6_ID1: ID Mask */

#define CAN_BUF6_ID1_Msk_ALL         (CAN_BUF6_ID1_IDEX_Msk        |\
                                      CAN_BUF6_ID1_IDE_Msk         |\
                                      CAN_BUF6_ID1_SRR_Msk         |\
                                      CAN_BUF6_ID1_ID_Msk          )

#define CAN_BUF7_CNTSTAT_ST_Pos      0                                            /*!<CAN BUF7_CNTSTAT: ST Position */
#define CAN_BUF7_CNTSTAT_ST_Msk      (0xFUL /*<< CAN_BUF7_CNTSTAT_ST_Pos*/)       /*!<CAN BUF7_CNTSTAT: ST Mask */

#define CAN_BUF7_CNTSTAT_PRI_Pos     4                                            /*!<CAN BUF7_CNTSTAT: PRI Position */
#define CAN_BUF7_CNTSTAT_PRI_Msk     (0xFUL << CAN_BUF7_CNTSTAT_PRI_Pos)          /*!<CAN BUF7_CNTSTAT: PRI Mask */

#define CAN_BUF7_CNTSTAT_DLC_Pos     12                                           /*!<CAN BUF7_CNTSTAT: DLC Position */
#define CAN_BUF7_CNTSTAT_DLC_Msk     (0xFUL << CAN_BUF7_CNTSTAT_DLC_Pos)          /*!<CAN BUF7_CNTSTAT: DLC Mask */

#define CAN_BUF7_CNTSTAT_Msk_ALL     (CAN_BUF7_CNTSTAT_ST_Msk      |\
                                      CAN_BUF7_CNTSTAT_PRI_Msk     |\
                                      CAN_BUF7_CNTSTAT_DLC_Msk     )

#define CAN_BUF7_TSTP_TSTP_Pos       0                                            /*!<CAN BUF7_TSTP: TSTP Position */
#define CAN_BUF7_TSTP_TSTP_Msk       (0xFFFFUL /*<< CAN_BUF7_TSTP_TSTP_Pos*/)     /*!<CAN BUF7_TSTP: TSTP Mask */

#define CAN_BUF7_TSTP_Msk_ALL        (CAN_BUF7_TSTP_TSTP_Msk      )

#define CAN_BUF7_DATA3_DATAL_Pos     0                                            /*!<CAN BUF7_DATA3: DATAL Position */
#define CAN_BUF7_DATA3_DATAL_Msk     (0xFFUL /*<< CAN_BUF7_DATA3_DATAL_Pos*/)     /*!<CAN BUF7_DATA3: DATAL Mask */

#define CAN_BUF7_DATA3_DATAH_Pos     8                                            /*!<CAN BUF7_DATA3: DATAH Position */
#define CAN_BUF7_DATA3_DATAH_Msk     (0xFFUL << CAN_BUF7_DATA3_DATAH_Pos)         /*!<CAN BUF7_DATA3: DATAH Mask */

#define CAN_BUF7_DATA3_Msk_ALL       (CAN_BUF7_DATA3_DATAL_Msk     |\
                                      CAN_BUF7_DATA3_DATAH_Msk     )

#define CAN_BUF7_DATA2_DATAL_Pos     0                                            /*!<CAN BUF7_DATA2: DATAL Position */
#define CAN_BUF7_DATA2_DATAL_Msk     (0xFFUL /*<< CAN_BUF7_DATA2_DATAL_Pos*/)     /*!<CAN BUF7_DATA2: DATAL Mask */

#define CAN_BUF7_DATA2_DATAH_Pos     8                                            /*!<CAN BUF7_DATA2: DATAH Position */
#define CAN_BUF7_DATA2_DATAH_Msk     (0xFFUL << CAN_BUF7_DATA2_DATAH_Pos)         /*!<CAN BUF7_DATA2: DATAH Mask */

#define CAN_BUF7_DATA2_Msk_ALL       (CAN_BUF7_DATA2_DATAL_Msk     |\
                                      CAN_BUF7_DATA2_DATAH_Msk     )

#define CAN_BUF7_DATA1_DATAL_Pos     0                                            /*!<CAN BUF7_DATA1: DATAL Position */
#define CAN_BUF7_DATA1_DATAL_Msk     (0xFFUL /*<< CAN_BUF7_DATA1_DATAL_Pos*/)     /*!<CAN BUF7_DATA1: DATAL Mask */

#define CAN_BUF7_DATA1_DATAH_Pos     8                                            /*!<CAN BUF7_DATA1: DATAH Position */
#define CAN_BUF7_DATA1_DATAH_Msk     (0xFFUL << CAN_BUF7_DATA1_DATAH_Pos)         /*!<CAN BUF7_DATA1: DATAH Mask */

#define CAN_BUF7_DATA1_Msk_ALL       (CAN_BUF7_DATA1_DATAL_Msk     |\
                                      CAN_BUF7_DATA1_DATAH_Msk     )

#define CAN_BUF7_DATA0_DATAL_Pos     0                                            /*!<CAN BUF7_DATA0: DATAL Position */
#define CAN_BUF7_DATA0_DATAL_Msk     (0xFFUL /*<< CAN_BUF7_DATA0_DATAL_Pos*/)     /*!<CAN BUF7_DATA0: DATAL Mask */

#define CAN_BUF7_DATA0_DATAH_Pos     8                                            /*!<CAN BUF7_DATA0: DATAH Position */
#define CAN_BUF7_DATA0_DATAH_Msk     (0xFFUL << CAN_BUF7_DATA0_DATAH_Pos)         /*!<CAN BUF7_DATA0: DATAH Mask */

#define CAN_BUF7_DATA0_Msk_ALL       (CAN_BUF7_DATA0_DATAL_Msk     |\
                                      CAN_BUF7_DATA0_DATAH_Msk     )

#define CAN_BUF7_ID0_RTR_Pos         0                                            /*!<CAN BUF7_ID0: RTR Position */
#define CAN_BUF7_ID0_RTR_Msk         (0x1UL /*<< CAN_BUF7_ID0_RTR_Pos*/)          /*!<CAN BUF7_ID0: RTR Mask */

#define CAN_BUF7_ID0_ID_Pos          1                                            /*!<CAN BUF7_ID0: ID Position */
#define CAN_BUF7_ID0_ID_Msk          (0x7FFFUL << CAN_BUF7_ID0_ID_Pos)            /*!<CAN BUF7_ID0: ID Mask */

#define CAN_BUF7_ID0_Msk_ALL         (CAN_BUF7_ID0_RTR_Msk         |\
                                      CAN_BUF7_ID0_ID_Msk          )

#define CAN_BUF7_ID1_IDEX_Pos        0                                            /*!<CAN BUF7_ID1: IDEX Position */
#define CAN_BUF7_ID1_IDEX_Msk        (0x7UL /*<< CAN_BUF7_ID1_IDEX_Pos*/)         /*!<CAN BUF7_ID1: IDEX Mask */

#define CAN_BUF7_ID1_IDE_Pos         3                                            /*!<CAN BUF7_ID1: IDE Position */
#define CAN_BUF7_ID1_IDE_Msk         (0x1UL << CAN_BUF7_ID1_IDE_Pos)              /*!<CAN BUF7_ID1: IDE Mask */

#define CAN_BUF7_ID1_SRR_Pos         4                                            /*!<CAN BUF7_ID1: SRR Position */
#define CAN_BUF7_ID1_SRR_Msk         (0x1UL << CAN_BUF7_ID1_SRR_Pos)              /*!<CAN BUF7_ID1: SRR Mask */

#define CAN_BUF7_ID1_ID_Pos          5                                            /*!<CAN BUF7_ID1: ID Position */
#define CAN_BUF7_ID1_ID_Msk          (0x7FFUL << CAN_BUF7_ID1_ID_Pos)             /*!<CAN BUF7_ID1: ID Mask */

#define CAN_BUF7_ID1_Msk_ALL         (CAN_BUF7_ID1_IDEX_Msk        |\
                                      CAN_BUF7_ID1_IDE_Msk         |\
                                      CAN_BUF7_ID1_SRR_Msk         |\
                                      CAN_BUF7_ID1_ID_Msk          )

#define CAN_BUF8_CNTSTAT_ST_Pos      0                                            /*!<CAN BUF8_CNTSTAT: ST Position */
#define CAN_BUF8_CNTSTAT_ST_Msk      (0xFUL /*<< CAN_BUF8_CNTSTAT_ST_Pos*/)       /*!<CAN BUF8_CNTSTAT: ST Mask */

#define CAN_BUF8_CNTSTAT_PRI_Pos     4                                            /*!<CAN BUF8_CNTSTAT: PRI Position */
#define CAN_BUF8_CNTSTAT_PRI_Msk     (0xFUL << CAN_BUF8_CNTSTAT_PRI_Pos)          /*!<CAN BUF8_CNTSTAT: PRI Mask */

#define CAN_BUF8_CNTSTAT_DLC_Pos     12                                           /*!<CAN BUF8_CNTSTAT: DLC Position */
#define CAN_BUF8_CNTSTAT_DLC_Msk     (0xFUL << CAN_BUF8_CNTSTAT_DLC_Pos)          /*!<CAN BUF8_CNTSTAT: DLC Mask */

#define CAN_BUF8_CNTSTAT_Msk_ALL     (CAN_BUF8_CNTSTAT_ST_Msk      |\
                                      CAN_BUF8_CNTSTAT_PRI_Msk     |\
                                      CAN_BUF8_CNTSTAT_DLC_Msk     )

#define CAN_BUF8_TSTP_TSTP_Pos       0                                            /*!<CAN BUF8_TSTP: TSTP Position */
#define CAN_BUF8_TSTP_TSTP_Msk       (0xFFFFUL /*<< CAN_BUF8_TSTP_TSTP_Pos*/)     /*!<CAN BUF8_TSTP: TSTP Mask */

#define CAN_BUF8_TSTP_Msk_ALL        (CAN_BUF8_TSTP_TSTP_Msk      )

#define CAN_BUF8_DATA3_DATAL_Pos     0                                            /*!<CAN BUF8_DATA3: DATAL Position */
#define CAN_BUF8_DATA3_DATAL_Msk     (0xFFUL /*<< CAN_BUF8_DATA3_DATAL_Pos*/)     /*!<CAN BUF8_DATA3: DATAL Mask */

#define CAN_BUF8_DATA3_DATAH_Pos     8                                            /*!<CAN BUF8_DATA3: DATAH Position */
#define CAN_BUF8_DATA3_DATAH_Msk     (0xFFUL << CAN_BUF8_DATA3_DATAH_Pos)         /*!<CAN BUF8_DATA3: DATAH Mask */

#define CAN_BUF8_DATA3_Msk_ALL       (CAN_BUF8_DATA3_DATAL_Msk     |\
                                      CAN_BUF8_DATA3_DATAH_Msk     )

#define CAN_BUF8_DATA2_DATAL_Pos     0                                            /*!<CAN BUF8_DATA2: DATAL Position */
#define CAN_BUF8_DATA2_DATAL_Msk     (0xFFUL /*<< CAN_BUF8_DATA2_DATAL_Pos*/)     /*!<CAN BUF8_DATA2: DATAL Mask */

#define CAN_BUF8_DATA2_DATAH_Pos     8                                            /*!<CAN BUF8_DATA2: DATAH Position */
#define CAN_BUF8_DATA2_DATAH_Msk     (0xFFUL << CAN_BUF8_DATA2_DATAH_Pos)         /*!<CAN BUF8_DATA2: DATAH Mask */

#define CAN_BUF8_DATA2_Msk_ALL       (CAN_BUF8_DATA2_DATAL_Msk     |\
                                      CAN_BUF8_DATA2_DATAH_Msk     )

#define CAN_BUF8_DATA1_DATAL_Pos     0                                            /*!<CAN BUF8_DATA1: DATAL Position */
#define CAN_BUF8_DATA1_DATAL_Msk     (0xFFUL /*<< CAN_BUF8_DATA1_DATAL_Pos*/)     /*!<CAN BUF8_DATA1: DATAL Mask */

#define CAN_BUF8_DATA1_DATAH_Pos     8                                            /*!<CAN BUF8_DATA1: DATAH Position */
#define CAN_BUF8_DATA1_DATAH_Msk     (0xFFUL << CAN_BUF8_DATA1_DATAH_Pos)         /*!<CAN BUF8_DATA1: DATAH Mask */

#define CAN_BUF8_DATA1_Msk_ALL       (CAN_BUF8_DATA1_DATAL_Msk     |\
                                      CAN_BUF8_DATA1_DATAH_Msk     )

#define CAN_BUF8_DATA0_DATAL_Pos     0                                            /*!<CAN BUF8_DATA0: DATAL Position */
#define CAN_BUF8_DATA0_DATAL_Msk     (0xFFUL /*<< CAN_BUF8_DATA0_DATAL_Pos*/)     /*!<CAN BUF8_DATA0: DATAL Mask */

#define CAN_BUF8_DATA0_DATAH_Pos     8                                            /*!<CAN BUF8_DATA0: DATAH Position */
#define CAN_BUF8_DATA0_DATAH_Msk     (0xFFUL << CAN_BUF8_DATA0_DATAH_Pos)         /*!<CAN BUF8_DATA0: DATAH Mask */

#define CAN_BUF8_DATA0_Msk_ALL       (CAN_BUF8_DATA0_DATAL_Msk     |\
                                      CAN_BUF8_DATA0_DATAH_Msk     )

#define CAN_BUF8_ID0_RTR_Pos         0                                            /*!<CAN BUF8_ID0: RTR Position */
#define CAN_BUF8_ID0_RTR_Msk         (0x1UL /*<< CAN_BUF8_ID0_RTR_Pos*/)          /*!<CAN BUF8_ID0: RTR Mask */

#define CAN_BUF8_ID0_ID_Pos          1                                            /*!<CAN BUF8_ID0: ID Position */
#define CAN_BUF8_ID0_ID_Msk          (0x7FFFUL << CAN_BUF8_ID0_ID_Pos)            /*!<CAN BUF8_ID0: ID Mask */

#define CAN_BUF8_ID0_Msk_ALL         (CAN_BUF8_ID0_RTR_Msk         |\
                                      CAN_BUF8_ID0_ID_Msk          )

#define CAN_BUF8_ID1_IDEX_Pos        0                                            /*!<CAN BUF8_ID1: IDEX Position */
#define CAN_BUF8_ID1_IDEX_Msk        (0x7UL /*<< CAN_BUF8_ID1_IDEX_Pos*/)         /*!<CAN BUF8_ID1: IDEX Mask */

#define CAN_BUF8_ID1_IDE_Pos         3                                            /*!<CAN BUF8_ID1: IDE Position */
#define CAN_BUF8_ID1_IDE_Msk         (0x1UL << CAN_BUF8_ID1_IDE_Pos)              /*!<CAN BUF8_ID1: IDE Mask */

#define CAN_BUF8_ID1_SRR_Pos         4                                            /*!<CAN BUF8_ID1: SRR Position */
#define CAN_BUF8_ID1_SRR_Msk         (0x1UL << CAN_BUF8_ID1_SRR_Pos)              /*!<CAN BUF8_ID1: SRR Mask */

#define CAN_BUF8_ID1_ID_Pos          5                                            /*!<CAN BUF8_ID1: ID Position */
#define CAN_BUF8_ID1_ID_Msk          (0x7FFUL << CAN_BUF8_ID1_ID_Pos)             /*!<CAN BUF8_ID1: ID Mask */

#define CAN_BUF8_ID1_Msk_ALL         (CAN_BUF8_ID1_IDEX_Msk        |\
                                      CAN_BUF8_ID1_IDE_Msk         |\
                                      CAN_BUF8_ID1_SRR_Msk         |\
                                      CAN_BUF8_ID1_ID_Msk          )

#define CAN_BUF9_CNTSTAT_ST_Pos      0                                            /*!<CAN BUF9_CNTSTAT: ST Position */
#define CAN_BUF9_CNTSTAT_ST_Msk      (0xFUL /*<< CAN_BUF9_CNTSTAT_ST_Pos*/)       /*!<CAN BUF9_CNTSTAT: ST Mask */

#define CAN_BUF9_CNTSTAT_PRI_Pos     4                                            /*!<CAN BUF9_CNTSTAT: PRI Position */
#define CAN_BUF9_CNTSTAT_PRI_Msk     (0xFUL << CAN_BUF9_CNTSTAT_PRI_Pos)          /*!<CAN BUF9_CNTSTAT: PRI Mask */

#define CAN_BUF9_CNTSTAT_DLC_Pos     12                                           /*!<CAN BUF9_CNTSTAT: DLC Position */
#define CAN_BUF9_CNTSTAT_DLC_Msk     (0xFUL << CAN_BUF9_CNTSTAT_DLC_Pos)          /*!<CAN BUF9_CNTSTAT: DLC Mask */

#define CAN_BUF9_CNTSTAT_Msk_ALL     (CAN_BUF9_CNTSTAT_ST_Msk      |\
                                      CAN_BUF9_CNTSTAT_PRI_Msk     |\
                                      CAN_BUF9_CNTSTAT_DLC_Msk     )

#define CAN_BUF9_TSTP_TSTP_Pos       0                                            /*!<CAN BUF9_TSTP: TSTP Position */
#define CAN_BUF9_TSTP_TSTP_Msk       (0xFFFFUL /*<< CAN_BUF9_TSTP_TSTP_Pos*/)     /*!<CAN BUF9_TSTP: TSTP Mask */

#define CAN_BUF9_TSTP_Msk_ALL        (CAN_BUF9_TSTP_TSTP_Msk      )

#define CAN_BUF9_DATA3_DATAL_Pos     0                                            /*!<CAN BUF9_DATA3: DATAL Position */
#define CAN_BUF9_DATA3_DATAL_Msk     (0xFFUL /*<< CAN_BUF9_DATA3_DATAL_Pos*/)     /*!<CAN BUF9_DATA3: DATAL Mask */

#define CAN_BUF9_DATA3_DATAH_Pos     8                                            /*!<CAN BUF9_DATA3: DATAH Position */
#define CAN_BUF9_DATA3_DATAH_Msk     (0xFFUL << CAN_BUF9_DATA3_DATAH_Pos)         /*!<CAN BUF9_DATA3: DATAH Mask */

#define CAN_BUF9_DATA3_Msk_ALL       (CAN_BUF9_DATA3_DATAL_Msk     |\
                                      CAN_BUF9_DATA3_DATAH_Msk     )

#define CAN_BUF9_DATA2_DATAL_Pos     0                                            /*!<CAN BUF9_DATA2: DATAL Position */
#define CAN_BUF9_DATA2_DATAL_Msk     (0xFFUL /*<< CAN_BUF9_DATA2_DATAL_Pos*/)     /*!<CAN BUF9_DATA2: DATAL Mask */

#define CAN_BUF9_DATA2_DATAH_Pos     8                                            /*!<CAN BUF9_DATA2: DATAH Position */
#define CAN_BUF9_DATA2_DATAH_Msk     (0xFFUL << CAN_BUF9_DATA2_DATAH_Pos)         /*!<CAN BUF9_DATA2: DATAH Mask */

#define CAN_BUF9_DATA2_Msk_ALL       (CAN_BUF9_DATA2_DATAL_Msk     |\
                                      CAN_BUF9_DATA2_DATAH_Msk     )

#define CAN_BUF9_DATA1_DATAL_Pos     0                                            /*!<CAN BUF9_DATA1: DATAL Position */
#define CAN_BUF9_DATA1_DATAL_Msk     (0xFFUL /*<< CAN_BUF9_DATA1_DATAL_Pos*/)     /*!<CAN BUF9_DATA1: DATAL Mask */

#define CAN_BUF9_DATA1_DATAH_Pos     8                                            /*!<CAN BUF9_DATA1: DATAH Position */
#define CAN_BUF9_DATA1_DATAH_Msk     (0xFFUL << CAN_BUF9_DATA1_DATAH_Pos)         /*!<CAN BUF9_DATA1: DATAH Mask */

#define CAN_BUF9_DATA1_Msk_ALL       (CAN_BUF9_DATA1_DATAL_Msk     |\
                                      CAN_BUF9_DATA1_DATAH_Msk     )

#define CAN_BUF9_DATA0_DATAL_Pos     0                                            /*!<CAN BUF9_DATA0: DATAL Position */
#define CAN_BUF9_DATA0_DATAL_Msk     (0xFFUL /*<< CAN_BUF9_DATA0_DATAL_Pos*/)     /*!<CAN BUF9_DATA0: DATAL Mask */

#define CAN_BUF9_DATA0_DATAH_Pos     8                                            /*!<CAN BUF9_DATA0: DATAH Position */
#define CAN_BUF9_DATA0_DATAH_Msk     (0xFFUL << CAN_BUF9_DATA0_DATAH_Pos)         /*!<CAN BUF9_DATA0: DATAH Mask */

#define CAN_BUF9_DATA0_Msk_ALL       (CAN_BUF9_DATA0_DATAL_Msk     |\
                                      CAN_BUF9_DATA0_DATAH_Msk     )

#define CAN_BUF9_ID0_RTR_Pos         0                                            /*!<CAN BUF9_ID0: RTR Position */
#define CAN_BUF9_ID0_RTR_Msk         (0x1UL /*<< CAN_BUF9_ID0_RTR_Pos*/)          /*!<CAN BUF9_ID0: RTR Mask */

#define CAN_BUF9_ID0_ID_Pos          1                                            /*!<CAN BUF9_ID0: ID Position */
#define CAN_BUF9_ID0_ID_Msk          (0x7FFFUL << CAN_BUF9_ID0_ID_Pos)            /*!<CAN BUF9_ID0: ID Mask */

#define CAN_BUF9_ID0_Msk_ALL         (CAN_BUF9_ID0_RTR_Msk         |\
                                      CAN_BUF9_ID0_ID_Msk          )

#define CAN_BUF9_ID1_IDEX_Pos        0                                            /*!<CAN BUF9_ID1: IDEX Position */
#define CAN_BUF9_ID1_IDEX_Msk        (0x7UL /*<< CAN_BUF9_ID1_IDEX_Pos*/)         /*!<CAN BUF9_ID1: IDEX Mask */

#define CAN_BUF9_ID1_IDE_Pos         3                                            /*!<CAN BUF9_ID1: IDE Position */
#define CAN_BUF9_ID1_IDE_Msk         (0x1UL << CAN_BUF9_ID1_IDE_Pos)              /*!<CAN BUF9_ID1: IDE Mask */

#define CAN_BUF9_ID1_SRR_Pos         4                                            /*!<CAN BUF9_ID1: SRR Position */
#define CAN_BUF9_ID1_SRR_Msk         (0x1UL << CAN_BUF9_ID1_SRR_Pos)              /*!<CAN BUF9_ID1: SRR Mask */

#define CAN_BUF9_ID1_ID_Pos          5                                            /*!<CAN BUF9_ID1: ID Position */
#define CAN_BUF9_ID1_ID_Msk          (0x7FFUL << CAN_BUF9_ID1_ID_Pos)             /*!<CAN BUF9_ID1: ID Mask */

#define CAN_BUF9_ID1_Msk_ALL         (CAN_BUF9_ID1_IDEX_Msk        |\
                                      CAN_BUF9_ID1_IDE_Msk         |\
                                      CAN_BUF9_ID1_SRR_Msk         |\
                                      CAN_BUF9_ID1_ID_Msk          )

#define CAN_BUF10_CNTSTAT_ST_Pos     0                                            /*!<CAN BUF10_CNTSTAT: ST Position */
#define CAN_BUF10_CNTSTAT_ST_Msk     (0xFUL /*<< CAN_BUF10_CNTSTAT_ST_Pos*/)      /*!<CAN BUF10_CNTSTAT: ST Mask */

#define CAN_BUF10_CNTSTAT_PRI_Pos    4                                            /*!<CAN BUF10_CNTSTAT: PRI Position */
#define CAN_BUF10_CNTSTAT_PRI_Msk    (0xFUL << CAN_BUF10_CNTSTAT_PRI_Pos)         /*!<CAN BUF10_CNTSTAT: PRI Mask */

#define CAN_BUF10_CNTSTAT_DLC_Pos    12                                           /*!<CAN BUF10_CNTSTAT: DLC Position */
#define CAN_BUF10_CNTSTAT_DLC_Msk    (0xFUL << CAN_BUF10_CNTSTAT_DLC_Pos)         /*!<CAN BUF10_CNTSTAT: DLC Mask */

#define CAN_BUF10_CNTSTAT_Msk_ALL    (CAN_BUF10_CNTSTAT_ST_Msk     |\
                                      CAN_BUF10_CNTSTAT_PRI_Msk    |\
                                      CAN_BUF10_CNTSTAT_DLC_Msk    )

#define CAN_BUF10_TSTP_TSTP_Pos      0                                            /*!<CAN BUF10_TSTP: TSTP Position */
#define CAN_BUF10_TSTP_TSTP_Msk      (0xFFFFUL /*<< CAN_BUF10_TSTP_TSTP_Pos*/)    /*!<CAN BUF10_TSTP: TSTP Mask */

#define CAN_BUF10_TSTP_Msk_ALL       (CAN_BUF10_TSTP_TSTP_Msk     )

#define CAN_BUF10_DATA3_DATAL_Pos    0                                            /*!<CAN BUF10_DATA3: DATAL Position */
#define CAN_BUF10_DATA3_DATAL_Msk    (0xFFUL /*<< CAN_BUF10_DATA3_DATAL_Pos*/)    /*!<CAN BUF10_DATA3: DATAL Mask */

#define CAN_BUF10_DATA3_DATAH_Pos    8                                            /*!<CAN BUF10_DATA3: DATAH Position */
#define CAN_BUF10_DATA3_DATAH_Msk    (0xFFUL << CAN_BUF10_DATA3_DATAH_Pos)        /*!<CAN BUF10_DATA3: DATAH Mask */

#define CAN_BUF10_DATA3_Msk_ALL      (CAN_BUF10_DATA3_DATAL_Msk    |\
                                      CAN_BUF10_DATA3_DATAH_Msk    )

#define CAN_BUF10_DATA2_DATAL_Pos    0                                            /*!<CAN BUF10_DATA2: DATAL Position */
#define CAN_BUF10_DATA2_DATAL_Msk    (0xFFUL /*<< CAN_BUF10_DATA2_DATAL_Pos*/)    /*!<CAN BUF10_DATA2: DATAL Mask */

#define CAN_BUF10_DATA2_DATAH_Pos    8                                            /*!<CAN BUF10_DATA2: DATAH Position */
#define CAN_BUF10_DATA2_DATAH_Msk    (0xFFUL << CAN_BUF10_DATA2_DATAH_Pos)        /*!<CAN BUF10_DATA2: DATAH Mask */

#define CAN_BUF10_DATA2_Msk_ALL      (CAN_BUF10_DATA2_DATAL_Msk    |\
                                      CAN_BUF10_DATA2_DATAH_Msk    )

#define CAN_BUF10_DATA1_DATAL_Pos    0                                            /*!<CAN BUF10_DATA1: DATAL Position */
#define CAN_BUF10_DATA1_DATAL_Msk    (0xFFUL /*<< CAN_BUF10_DATA1_DATAL_Pos*/)    /*!<CAN BUF10_DATA1: DATAL Mask */

#define CAN_BUF10_DATA1_DATAH_Pos    8                                            /*!<CAN BUF10_DATA1: DATAH Position */
#define CAN_BUF10_DATA1_DATAH_Msk    (0xFFUL << CAN_BUF10_DATA1_DATAH_Pos)        /*!<CAN BUF10_DATA1: DATAH Mask */

#define CAN_BUF10_DATA1_Msk_ALL      (CAN_BUF10_DATA1_DATAL_Msk    |\
                                      CAN_BUF10_DATA1_DATAH_Msk    )

#define CAN_BUF10_DATA0_DATAL_Pos    0                                            /*!<CAN BUF10_DATA0: DATAL Position */
#define CAN_BUF10_DATA0_DATAL_Msk    (0xFFUL /*<< CAN_BUF10_DATA0_DATAL_Pos*/)    /*!<CAN BUF10_DATA0: DATAL Mask */

#define CAN_BUF10_DATA0_DATAH_Pos    8                                            /*!<CAN BUF10_DATA0: DATAH Position */
#define CAN_BUF10_DATA0_DATAH_Msk    (0xFFUL << CAN_BUF10_DATA0_DATAH_Pos)        /*!<CAN BUF10_DATA0: DATAH Mask */

#define CAN_BUF10_DATA0_Msk_ALL      (CAN_BUF10_DATA0_DATAL_Msk    |\
                                      CAN_BUF10_DATA0_DATAH_Msk    )

#define CAN_BUF10_ID0_RTR_Pos        0                                            /*!<CAN BUF10_ID0: RTR Position */
#define CAN_BUF10_ID0_RTR_Msk        (0x1UL /*<< CAN_BUF10_ID0_RTR_Pos*/)         /*!<CAN BUF10_ID0: RTR Mask */

#define CAN_BUF10_ID0_ID_Pos         1                                            /*!<CAN BUF10_ID0: ID Position */
#define CAN_BUF10_ID0_ID_Msk         (0x7FFFUL << CAN_BUF10_ID0_ID_Pos)           /*!<CAN BUF10_ID0: ID Mask */

#define CAN_BUF10_ID0_Msk_ALL        (CAN_BUF10_ID0_RTR_Msk        |\
                                      CAN_BUF10_ID0_ID_Msk         )

#define CAN_BUF10_ID1_IDEX_Pos       0                                            /*!<CAN BUF10_ID1: IDEX Position */
#define CAN_BUF10_ID1_IDEX_Msk       (0x7UL /*<< CAN_BUF10_ID1_IDEX_Pos*/)        /*!<CAN BUF10_ID1: IDEX Mask */

#define CAN_BUF10_ID1_IDE_Pos        3                                            /*!<CAN BUF10_ID1: IDE Position */
#define CAN_BUF10_ID1_IDE_Msk        (0x1UL << CAN_BUF10_ID1_IDE_Pos)             /*!<CAN BUF10_ID1: IDE Mask */

#define CAN_BUF10_ID1_SRR_Pos        4                                            /*!<CAN BUF10_ID1: SRR Position */
#define CAN_BUF10_ID1_SRR_Msk        (0x1UL << CAN_BUF10_ID1_SRR_Pos)             /*!<CAN BUF10_ID1: SRR Mask */

#define CAN_BUF10_ID1_ID_Pos         5                                            /*!<CAN BUF10_ID1: ID Position */
#define CAN_BUF10_ID1_ID_Msk         (0x7FFUL << CAN_BUF10_ID1_ID_Pos)            /*!<CAN BUF10_ID1: ID Mask */

#define CAN_BUF10_ID1_Msk_ALL        (CAN_BUF10_ID1_IDEX_Msk       |\
                                      CAN_BUF10_ID1_IDE_Msk        |\
                                      CAN_BUF10_ID1_SRR_Msk        |\
                                      CAN_BUF10_ID1_ID_Msk         )

#define CAN_BUF11_CNTSTAT_ST_Pos     0                                            /*!<CAN BUF11_CNTSTAT: ST Position */
#define CAN_BUF11_CNTSTAT_ST_Msk     (0xFUL /*<< CAN_BUF11_CNTSTAT_ST_Pos*/)      /*!<CAN BUF11_CNTSTAT: ST Mask */

#define CAN_BUF11_CNTSTAT_PRI_Pos    4                                            /*!<CAN BUF11_CNTSTAT: PRI Position */
#define CAN_BUF11_CNTSTAT_PRI_Msk    (0xFUL << CAN_BUF11_CNTSTAT_PRI_Pos)         /*!<CAN BUF11_CNTSTAT: PRI Mask */

#define CAN_BUF11_CNTSTAT_DLC_Pos    12                                           /*!<CAN BUF11_CNTSTAT: DLC Position */
#define CAN_BUF11_CNTSTAT_DLC_Msk    (0xFUL << CAN_BUF11_CNTSTAT_DLC_Pos)         /*!<CAN BUF11_CNTSTAT: DLC Mask */

#define CAN_BUF11_CNTSTAT_Msk_ALL    (CAN_BUF11_CNTSTAT_ST_Msk     |\
                                      CAN_BUF11_CNTSTAT_PRI_Msk    |\
                                      CAN_BUF11_CNTSTAT_DLC_Msk    )

#define CAN_BUF11_TSTP_TSTP_Pos      0                                            /*!<CAN BUF11_TSTP: TSTP Position */
#define CAN_BUF11_TSTP_TSTP_Msk      (0xFFFFUL /*<< CAN_BUF11_TSTP_TSTP_Pos*/)    /*!<CAN BUF11_TSTP: TSTP Mask */

#define CAN_BUF11_TSTP_Msk_ALL       (CAN_BUF11_TSTP_TSTP_Msk     )

#define CAN_BUF11_DATA3_DATAL_Pos    0                                            /*!<CAN BUF11_DATA3: DATAL Position */
#define CAN_BUF11_DATA3_DATAL_Msk    (0xFFUL /*<< CAN_BUF11_DATA3_DATAL_Pos*/)    /*!<CAN BUF11_DATA3: DATAL Mask */

#define CAN_BUF11_DATA3_DATAH_Pos    8                                            /*!<CAN BUF11_DATA3: DATAH Position */
#define CAN_BUF11_DATA3_DATAH_Msk    (0xFFUL << CAN_BUF11_DATA3_DATAH_Pos)        /*!<CAN BUF11_DATA3: DATAH Mask */

#define CAN_BUF11_DATA3_Msk_ALL      (CAN_BUF11_DATA3_DATAL_Msk    |\
                                      CAN_BUF11_DATA3_DATAH_Msk    )

#define CAN_BUF11_DATA2_DATAL_Pos    0                                            /*!<CAN BUF11_DATA2: DATAL Position */
#define CAN_BUF11_DATA2_DATAL_Msk    (0xFFUL /*<< CAN_BUF11_DATA2_DATAL_Pos*/)    /*!<CAN BUF11_DATA2: DATAL Mask */

#define CAN_BUF11_DATA2_DATAH_Pos    8                                            /*!<CAN BUF11_DATA2: DATAH Position */
#define CAN_BUF11_DATA2_DATAH_Msk    (0xFFUL << CAN_BUF11_DATA2_DATAH_Pos)        /*!<CAN BUF11_DATA2: DATAH Mask */

#define CAN_BUF11_DATA2_Msk_ALL      (CAN_BUF11_DATA2_DATAL_Msk    |\
                                      CAN_BUF11_DATA2_DATAH_Msk    )

#define CAN_BUF11_DATA1_DATAL_Pos    0                                            /*!<CAN BUF11_DATA1: DATAL Position */
#define CAN_BUF11_DATA1_DATAL_Msk    (0xFFUL /*<< CAN_BUF11_DATA1_DATAL_Pos*/)    /*!<CAN BUF11_DATA1: DATAL Mask */

#define CAN_BUF11_DATA1_DATAH_Pos    8                                            /*!<CAN BUF11_DATA1: DATAH Position */
#define CAN_BUF11_DATA1_DATAH_Msk    (0xFFUL << CAN_BUF11_DATA1_DATAH_Pos)        /*!<CAN BUF11_DATA1: DATAH Mask */

#define CAN_BUF11_DATA1_Msk_ALL      (CAN_BUF11_DATA1_DATAL_Msk    |\
                                      CAN_BUF11_DATA1_DATAH_Msk    )

#define CAN_BUF11_DATA0_DATAL_Pos    0                                            /*!<CAN BUF11_DATA0: DATAL Position */
#define CAN_BUF11_DATA0_DATAL_Msk    (0xFFUL /*<< CAN_BUF11_DATA0_DATAL_Pos*/)    /*!<CAN BUF11_DATA0: DATAL Mask */

#define CAN_BUF11_DATA0_DATAH_Pos    8                                            /*!<CAN BUF11_DATA0: DATAH Position */
#define CAN_BUF11_DATA0_DATAH_Msk    (0xFFUL << CAN_BUF11_DATA0_DATAH_Pos)        /*!<CAN BUF11_DATA0: DATAH Mask */

#define CAN_BUF11_DATA0_Msk_ALL      (CAN_BUF11_DATA0_DATAL_Msk    |\
                                      CAN_BUF11_DATA0_DATAH_Msk    )

#define CAN_BUF11_ID0_RTR_Pos        0                                            /*!<CAN BUF11_ID0: RTR Position */
#define CAN_BUF11_ID0_RTR_Msk        (0x1UL /*<< CAN_BUF11_ID0_RTR_Pos*/)         /*!<CAN BUF11_ID0: RTR Mask */

#define CAN_BUF11_ID0_ID_Pos         1                                            /*!<CAN BUF11_ID0: ID Position */
#define CAN_BUF11_ID0_ID_Msk         (0x7FFFUL << CAN_BUF11_ID0_ID_Pos)           /*!<CAN BUF11_ID0: ID Mask */

#define CAN_BUF11_ID0_Msk_ALL        (CAN_BUF11_ID0_RTR_Msk        |\
                                      CAN_BUF11_ID0_ID_Msk         )

#define CAN_BUF11_ID1_IDEX_Pos       0                                            /*!<CAN BUF11_ID1: IDEX Position */
#define CAN_BUF11_ID1_IDEX_Msk       (0x7UL /*<< CAN_BUF11_ID1_IDEX_Pos*/)        /*!<CAN BUF11_ID1: IDEX Mask */

#define CAN_BUF11_ID1_IDE_Pos        3                                            /*!<CAN BUF11_ID1: IDE Position */
#define CAN_BUF11_ID1_IDE_Msk        (0x1UL << CAN_BUF11_ID1_IDE_Pos)             /*!<CAN BUF11_ID1: IDE Mask */

#define CAN_BUF11_ID1_SRR_Pos        4                                            /*!<CAN BUF11_ID1: SRR Position */
#define CAN_BUF11_ID1_SRR_Msk        (0x1UL << CAN_BUF11_ID1_SRR_Pos)             /*!<CAN BUF11_ID1: SRR Mask */

#define CAN_BUF11_ID1_ID_Pos         5                                            /*!<CAN BUF11_ID1: ID Position */
#define CAN_BUF11_ID1_ID_Msk         (0x7FFUL << CAN_BUF11_ID1_ID_Pos)            /*!<CAN BUF11_ID1: ID Mask */

#define CAN_BUF11_ID1_Msk_ALL        (CAN_BUF11_ID1_IDEX_Msk       |\
                                      CAN_BUF11_ID1_IDE_Msk        |\
                                      CAN_BUF11_ID1_SRR_Msk        |\
                                      CAN_BUF11_ID1_ID_Msk         )

#define CAN_BUF12_CNTSTAT_ST_Pos     0                                            /*!<CAN BUF12_CNTSTAT: ST Position */
#define CAN_BUF12_CNTSTAT_ST_Msk     (0xFUL /*<< CAN_BUF12_CNTSTAT_ST_Pos*/)      /*!<CAN BUF12_CNTSTAT: ST Mask */

#define CAN_BUF12_CNTSTAT_PRI_Pos    4                                            /*!<CAN BUF12_CNTSTAT: PRI Position */
#define CAN_BUF12_CNTSTAT_PRI_Msk    (0xFUL << CAN_BUF12_CNTSTAT_PRI_Pos)         /*!<CAN BUF12_CNTSTAT: PRI Mask */

#define CAN_BUF12_CNTSTAT_DLC_Pos    12                                           /*!<CAN BUF12_CNTSTAT: DLC Position */
#define CAN_BUF12_CNTSTAT_DLC_Msk    (0xFUL << CAN_BUF12_CNTSTAT_DLC_Pos)         /*!<CAN BUF12_CNTSTAT: DLC Mask */

#define CAN_BUF12_CNTSTAT_Msk_ALL    (CAN_BUF12_CNTSTAT_ST_Msk     |\
                                      CAN_BUF12_CNTSTAT_PRI_Msk    |\
                                      CAN_BUF12_CNTSTAT_DLC_Msk    )

#define CAN_BUF12_TSTP_TSTP_Pos      0                                            /*!<CAN BUF12_TSTP: TSTP Position */
#define CAN_BUF12_TSTP_TSTP_Msk      (0xFFFFUL /*<< CAN_BUF12_TSTP_TSTP_Pos*/)    /*!<CAN BUF12_TSTP: TSTP Mask */

#define CAN_BUF12_TSTP_Msk_ALL       (CAN_BUF12_TSTP_TSTP_Msk     )

#define CAN_BUF12_DATA3_DATAL_Pos    0                                            /*!<CAN BUF12_DATA3: DATAL Position */
#define CAN_BUF12_DATA3_DATAL_Msk    (0xFFUL /*<< CAN_BUF12_DATA3_DATAL_Pos*/)    /*!<CAN BUF12_DATA3: DATAL Mask */

#define CAN_BUF12_DATA3_DATAH_Pos    8                                            /*!<CAN BUF12_DATA3: DATAH Position */
#define CAN_BUF12_DATA3_DATAH_Msk    (0xFFUL << CAN_BUF12_DATA3_DATAH_Pos)        /*!<CAN BUF12_DATA3: DATAH Mask */

#define CAN_BUF12_DATA3_Msk_ALL      (CAN_BUF12_DATA3_DATAL_Msk    |\
                                      CAN_BUF12_DATA3_DATAH_Msk    )

#define CAN_BUF12_DATA2_DATAL_Pos    0                                            /*!<CAN BUF12_DATA2: DATAL Position */
#define CAN_BUF12_DATA2_DATAL_Msk    (0xFFUL /*<< CAN_BUF12_DATA2_DATAL_Pos*/)    /*!<CAN BUF12_DATA2: DATAL Mask */

#define CAN_BUF12_DATA2_DATAH_Pos    8                                            /*!<CAN BUF12_DATA2: DATAH Position */
#define CAN_BUF12_DATA2_DATAH_Msk    (0xFFUL << CAN_BUF12_DATA2_DATAH_Pos)        /*!<CAN BUF12_DATA2: DATAH Mask */

#define CAN_BUF12_DATA2_Msk_ALL      (CAN_BUF12_DATA2_DATAL_Msk    |\
                                      CAN_BUF12_DATA2_DATAH_Msk    )

#define CAN_BUF12_DATA1_DATAL_Pos    0                                            /*!<CAN BUF12_DATA1: DATAL Position */
#define CAN_BUF12_DATA1_DATAL_Msk    (0xFFUL /*<< CAN_BUF12_DATA1_DATAL_Pos*/)    /*!<CAN BUF12_DATA1: DATAL Mask */

#define CAN_BUF12_DATA1_DATAH_Pos    8                                            /*!<CAN BUF12_DATA1: DATAH Position */
#define CAN_BUF12_DATA1_DATAH_Msk    (0xFFUL << CAN_BUF12_DATA1_DATAH_Pos)        /*!<CAN BUF12_DATA1: DATAH Mask */

#define CAN_BUF12_DATA1_Msk_ALL      (CAN_BUF12_DATA1_DATAL_Msk    |\
                                      CAN_BUF12_DATA1_DATAH_Msk    )

#define CAN_BUF12_DATA0_DATAL_Pos    0                                            /*!<CAN BUF12_DATA0: DATAL Position */
#define CAN_BUF12_DATA0_DATAL_Msk    (0xFFUL /*<< CAN_BUF12_DATA0_DATAL_Pos*/)    /*!<CAN BUF12_DATA0: DATAL Mask */

#define CAN_BUF12_DATA0_DATAH_Pos    8                                            /*!<CAN BUF12_DATA0: DATAH Position */
#define CAN_BUF12_DATA0_DATAH_Msk    (0xFFUL << CAN_BUF12_DATA0_DATAH_Pos)        /*!<CAN BUF12_DATA0: DATAH Mask */

#define CAN_BUF12_DATA0_Msk_ALL      (CAN_BUF12_DATA0_DATAL_Msk    |\
                                      CAN_BUF12_DATA0_DATAH_Msk    )

#define CAN_BUF12_ID0_RTR_Pos        0                                            /*!<CAN BUF12_ID0: RTR Position */
#define CAN_BUF12_ID0_RTR_Msk        (0x1UL /*<< CAN_BUF12_ID0_RTR_Pos*/)         /*!<CAN BUF12_ID0: RTR Mask */

#define CAN_BUF12_ID0_ID_Pos         1                                            /*!<CAN BUF12_ID0: ID Position */
#define CAN_BUF12_ID0_ID_Msk         (0x7FFFUL << CAN_BUF12_ID0_ID_Pos)           /*!<CAN BUF12_ID0: ID Mask */

#define CAN_BUF12_ID0_Msk_ALL        (CAN_BUF12_ID0_RTR_Msk        |\
                                      CAN_BUF12_ID0_ID_Msk         )

#define CAN_BUF12_ID1_IDEX_Pos       0                                            /*!<CAN BUF12_ID1: IDEX Position */
#define CAN_BUF12_ID1_IDEX_Msk       (0x7UL /*<< CAN_BUF12_ID1_IDEX_Pos*/)        /*!<CAN BUF12_ID1: IDEX Mask */

#define CAN_BUF12_ID1_IDE_Pos        3                                            /*!<CAN BUF12_ID1: IDE Position */
#define CAN_BUF12_ID1_IDE_Msk        (0x1UL << CAN_BUF12_ID1_IDE_Pos)             /*!<CAN BUF12_ID1: IDE Mask */

#define CAN_BUF12_ID1_SRR_Pos        4                                            /*!<CAN BUF12_ID1: SRR Position */
#define CAN_BUF12_ID1_SRR_Msk        (0x1UL << CAN_BUF12_ID1_SRR_Pos)             /*!<CAN BUF12_ID1: SRR Mask */

#define CAN_BUF12_ID1_ID_Pos         5                                            /*!<CAN BUF12_ID1: ID Position */
#define CAN_BUF12_ID1_ID_Msk         (0x7FFUL << CAN_BUF12_ID1_ID_Pos)            /*!<CAN BUF12_ID1: ID Mask */

#define CAN_BUF12_ID1_Msk_ALL        (CAN_BUF12_ID1_IDEX_Msk       |\
                                      CAN_BUF12_ID1_IDE_Msk        |\
                                      CAN_BUF12_ID1_SRR_Msk        |\
                                      CAN_BUF12_ID1_ID_Msk         )

#define CAN_BUF13_CNTSTAT_ST_Pos     0                                            /*!<CAN BUF13_CNTSTAT: ST Position */
#define CAN_BUF13_CNTSTAT_ST_Msk     (0xFUL /*<< CAN_BUF13_CNTSTAT_ST_Pos*/)      /*!<CAN BUF13_CNTSTAT: ST Mask */

#define CAN_BUF13_CNTSTAT_PRI_Pos    4                                            /*!<CAN BUF13_CNTSTAT: PRI Position */
#define CAN_BUF13_CNTSTAT_PRI_Msk    (0xFUL << CAN_BUF13_CNTSTAT_PRI_Pos)         /*!<CAN BUF13_CNTSTAT: PRI Mask */

#define CAN_BUF13_CNTSTAT_DLC_Pos    12                                           /*!<CAN BUF13_CNTSTAT: DLC Position */
#define CAN_BUF13_CNTSTAT_DLC_Msk    (0xFUL << CAN_BUF13_CNTSTAT_DLC_Pos)         /*!<CAN BUF13_CNTSTAT: DLC Mask */

#define CAN_BUF13_CNTSTAT_Msk_ALL    (CAN_BUF13_CNTSTAT_ST_Msk     |\
                                      CAN_BUF13_CNTSTAT_PRI_Msk    |\
                                      CAN_BUF13_CNTSTAT_DLC_Msk    )

#define CAN_BUF13_TSTP_TSTP_Pos      0                                            /*!<CAN BUF13_TSTP: TSTP Position */
#define CAN_BUF13_TSTP_TSTP_Msk      (0xFFFFUL /*<< CAN_BUF13_TSTP_TSTP_Pos*/)    /*!<CAN BUF13_TSTP: TSTP Mask */

#define CAN_BUF13_TSTP_Msk_ALL       (CAN_BUF13_TSTP_TSTP_Msk     )

#define CAN_BUF13_DATA3_DATAL_Pos    0                                            /*!<CAN BUF13_DATA3: DATAL Position */
#define CAN_BUF13_DATA3_DATAL_Msk    (0xFFUL /*<< CAN_BUF13_DATA3_DATAL_Pos*/)    /*!<CAN BUF13_DATA3: DATAL Mask */

#define CAN_BUF13_DATA3_DATAH_Pos    8                                            /*!<CAN BUF13_DATA3: DATAH Position */
#define CAN_BUF13_DATA3_DATAH_Msk    (0xFFUL << CAN_BUF13_DATA3_DATAH_Pos)        /*!<CAN BUF13_DATA3: DATAH Mask */

#define CAN_BUF13_DATA3_Msk_ALL      (CAN_BUF13_DATA3_DATAL_Msk    |\
                                      CAN_BUF13_DATA3_DATAH_Msk    )

#define CAN_BUF13_DATA2_DATAL_Pos    0                                            /*!<CAN BUF13_DATA2: DATAL Position */
#define CAN_BUF13_DATA2_DATAL_Msk    (0xFFUL /*<< CAN_BUF13_DATA2_DATAL_Pos*/)    /*!<CAN BUF13_DATA2: DATAL Mask */

#define CAN_BUF13_DATA2_DATAH_Pos    8                                            /*!<CAN BUF13_DATA2: DATAH Position */
#define CAN_BUF13_DATA2_DATAH_Msk    (0xFFUL << CAN_BUF13_DATA2_DATAH_Pos)        /*!<CAN BUF13_DATA2: DATAH Mask */

#define CAN_BUF13_DATA2_Msk_ALL      (CAN_BUF13_DATA2_DATAL_Msk    |\
                                      CAN_BUF13_DATA2_DATAH_Msk    )

#define CAN_BUF13_DATA1_DATAL_Pos    0                                            /*!<CAN BUF13_DATA1: DATAL Position */
#define CAN_BUF13_DATA1_DATAL_Msk    (0xFFUL /*<< CAN_BUF13_DATA1_DATAL_Pos*/)    /*!<CAN BUF13_DATA1: DATAL Mask */

#define CAN_BUF13_DATA1_DATAH_Pos    8                                            /*!<CAN BUF13_DATA1: DATAH Position */
#define CAN_BUF13_DATA1_DATAH_Msk    (0xFFUL << CAN_BUF13_DATA1_DATAH_Pos)        /*!<CAN BUF13_DATA1: DATAH Mask */

#define CAN_BUF13_DATA1_Msk_ALL      (CAN_BUF13_DATA1_DATAL_Msk    |\
                                      CAN_BUF13_DATA1_DATAH_Msk    )

#define CAN_BUF13_DATA0_DATAL_Pos    0                                            /*!<CAN BUF13_DATA0: DATAL Position */
#define CAN_BUF13_DATA0_DATAL_Msk    (0xFFUL /*<< CAN_BUF13_DATA0_DATAL_Pos*/)    /*!<CAN BUF13_DATA0: DATAL Mask */

#define CAN_BUF13_DATA0_DATAH_Pos    8                                            /*!<CAN BUF13_DATA0: DATAH Position */
#define CAN_BUF13_DATA0_DATAH_Msk    (0xFFUL << CAN_BUF13_DATA0_DATAH_Pos)        /*!<CAN BUF13_DATA0: DATAH Mask */

#define CAN_BUF13_DATA0_Msk_ALL      (CAN_BUF13_DATA0_DATAL_Msk    |\
                                      CAN_BUF13_DATA0_DATAH_Msk    )

#define CAN_BUF13_ID0_RTR_Pos        0                                            /*!<CAN BUF13_ID0: RTR Position */
#define CAN_BUF13_ID0_RTR_Msk        (0x1UL /*<< CAN_BUF13_ID0_RTR_Pos*/)         /*!<CAN BUF13_ID0: RTR Mask */

#define CAN_BUF13_ID0_ID_Pos         1                                            /*!<CAN BUF13_ID0: ID Position */
#define CAN_BUF13_ID0_ID_Msk         (0x7FFFUL << CAN_BUF13_ID0_ID_Pos)           /*!<CAN BUF13_ID0: ID Mask */

#define CAN_BUF13_ID0_Msk_ALL        (CAN_BUF13_ID0_RTR_Msk        |\
                                      CAN_BUF13_ID0_ID_Msk         )

#define CAN_BUF13_ID1_IDEX_Pos       0                                            /*!<CAN BUF13_ID1: IDEX Position */
#define CAN_BUF13_ID1_IDEX_Msk       (0x7UL /*<< CAN_BUF13_ID1_IDEX_Pos*/)        /*!<CAN BUF13_ID1: IDEX Mask */

#define CAN_BUF13_ID1_IDE_Pos        3                                            /*!<CAN BUF13_ID1: IDE Position */
#define CAN_BUF13_ID1_IDE_Msk        (0x1UL << CAN_BUF13_ID1_IDE_Pos)             /*!<CAN BUF13_ID1: IDE Mask */

#define CAN_BUF13_ID1_SRR_Pos        4                                            /*!<CAN BUF13_ID1: SRR Position */
#define CAN_BUF13_ID1_SRR_Msk        (0x1UL << CAN_BUF13_ID1_SRR_Pos)             /*!<CAN BUF13_ID1: SRR Mask */

#define CAN_BUF13_ID1_ID_Pos         5                                            /*!<CAN BUF13_ID1: ID Position */
#define CAN_BUF13_ID1_ID_Msk         (0x7FFUL << CAN_BUF13_ID1_ID_Pos)            /*!<CAN BUF13_ID1: ID Mask */

#define CAN_BUF13_ID1_Msk_ALL        (CAN_BUF13_ID1_IDEX_Msk       |\
                                      CAN_BUF13_ID1_IDE_Msk        |\
                                      CAN_BUF13_ID1_SRR_Msk        |\
                                      CAN_BUF13_ID1_ID_Msk         )

#define CAN_BUF14_CNTSTAT_ST_Pos     0                                            /*!<CAN BUF14_CNTSTAT: ST Position */
#define CAN_BUF14_CNTSTAT_ST_Msk     (0xFUL /*<< CAN_BUF14_CNTSTAT_ST_Pos*/)      /*!<CAN BUF14_CNTSTAT: ST Mask */

#define CAN_BUF14_CNTSTAT_PRI_Pos    4                                            /*!<CAN BUF14_CNTSTAT: PRI Position */
#define CAN_BUF14_CNTSTAT_PRI_Msk    (0xFUL << CAN_BUF14_CNTSTAT_PRI_Pos)         /*!<CAN BUF14_CNTSTAT: PRI Mask */

#define CAN_BUF14_CNTSTAT_DLC_Pos    12                                           /*!<CAN BUF14_CNTSTAT: DLC Position */
#define CAN_BUF14_CNTSTAT_DLC_Msk    (0xFUL << CAN_BUF14_CNTSTAT_DLC_Pos)         /*!<CAN BUF14_CNTSTAT: DLC Mask */

#define CAN_BUF14_CNTSTAT_Msk_ALL    (CAN_BUF14_CNTSTAT_ST_Msk     |\
                                      CAN_BUF14_CNTSTAT_PRI_Msk    |\
                                      CAN_BUF14_CNTSTAT_DLC_Msk    )

#define CAN_BUF14_TSTP_TSTP_Pos      0                                            /*!<CAN BUF14_TSTP: TSTP Position */
#define CAN_BUF14_TSTP_TSTP_Msk      (0xFFFFUL /*<< CAN_BUF14_TSTP_TSTP_Pos*/)    /*!<CAN BUF14_TSTP: TSTP Mask */

#define CAN_BUF14_TSTP_Msk_ALL       (CAN_BUF14_TSTP_TSTP_Msk     )

#define CAN_BUF14_DATA3_DATAL_Pos    0                                            /*!<CAN BUF14_DATA3: DATAL Position */
#define CAN_BUF14_DATA3_DATAL_Msk    (0xFFUL /*<< CAN_BUF14_DATA3_DATAL_Pos*/)    /*!<CAN BUF14_DATA3: DATAL Mask */

#define CAN_BUF14_DATA3_DATAH_Pos    8                                            /*!<CAN BUF14_DATA3: DATAH Position */
#define CAN_BUF14_DATA3_DATAH_Msk    (0xFFUL << CAN_BUF14_DATA3_DATAH_Pos)        /*!<CAN BUF14_DATA3: DATAH Mask */

#define CAN_BUF14_DATA3_Msk_ALL      (CAN_BUF14_DATA3_DATAL_Msk    |\
                                      CAN_BUF14_DATA3_DATAH_Msk    )

#define CAN_BUF14_DATA2_DATAL_Pos    0                                            /*!<CAN BUF14_DATA2: DATAL Position */
#define CAN_BUF14_DATA2_DATAL_Msk    (0xFFUL /*<< CAN_BUF14_DATA2_DATAL_Pos*/)    /*!<CAN BUF14_DATA2: DATAL Mask */

#define CAN_BUF14_DATA2_DATAH_Pos    8                                            /*!<CAN BUF14_DATA2: DATAH Position */
#define CAN_BUF14_DATA2_DATAH_Msk    (0xFFUL << CAN_BUF14_DATA2_DATAH_Pos)        /*!<CAN BUF14_DATA2: DATAH Mask */

#define CAN_BUF14_DATA2_Msk_ALL      (CAN_BUF14_DATA2_DATAL_Msk    |\
                                      CAN_BUF14_DATA2_DATAH_Msk    )

#define CAN_BUF14_DATA1_DATAL_Pos    0                                            /*!<CAN BUF14_DATA1: DATAL Position */
#define CAN_BUF14_DATA1_DATAL_Msk    (0xFFUL /*<< CAN_BUF14_DATA1_DATAL_Pos*/)    /*!<CAN BUF14_DATA1: DATAL Mask */

#define CAN_BUF14_DATA1_DATAH_Pos    8                                            /*!<CAN BUF14_DATA1: DATAH Position */
#define CAN_BUF14_DATA1_DATAH_Msk    (0xFFUL << CAN_BUF14_DATA1_DATAH_Pos)        /*!<CAN BUF14_DATA1: DATAH Mask */

#define CAN_BUF14_DATA1_Msk_ALL      (CAN_BUF14_DATA1_DATAL_Msk    |\
                                      CAN_BUF14_DATA1_DATAH_Msk    )

#define CAN_BUF14_DATA0_DATAL_Pos    0                                            /*!<CAN BUF14_DATA0: DATAL Position */
#define CAN_BUF14_DATA0_DATAL_Msk    (0xFFUL /*<< CAN_BUF14_DATA0_DATAL_Pos*/)    /*!<CAN BUF14_DATA0: DATAL Mask */

#define CAN_BUF14_DATA0_DATAH_Pos    8                                            /*!<CAN BUF14_DATA0: DATAH Position */
#define CAN_BUF14_DATA0_DATAH_Msk    (0xFFUL << CAN_BUF14_DATA0_DATAH_Pos)        /*!<CAN BUF14_DATA0: DATAH Mask */

#define CAN_BUF14_DATA0_Msk_ALL      (CAN_BUF14_DATA0_DATAL_Msk    |\
                                      CAN_BUF14_DATA0_DATAH_Msk    )

#define CAN_BUF14_ID0_RTR_Pos        0                                            /*!<CAN BUF14_ID0: RTR Position */
#define CAN_BUF14_ID0_RTR_Msk        (0x1UL /*<< CAN_BUF14_ID0_RTR_Pos*/)         /*!<CAN BUF14_ID0: RTR Mask */

#define CAN_BUF14_ID0_ID_Pos         1                                            /*!<CAN BUF14_ID0: ID Position */
#define CAN_BUF14_ID0_ID_Msk         (0x7FFFUL << CAN_BUF14_ID0_ID_Pos)           /*!<CAN BUF14_ID0: ID Mask */

#define CAN_BUF14_ID0_Msk_ALL        (CAN_BUF14_ID0_RTR_Msk        |\
                                      CAN_BUF14_ID0_ID_Msk         )

#define CAN_BUF14_ID1_IDEX_Pos       0                                            /*!<CAN BUF14_ID1: IDEX Position */
#define CAN_BUF14_ID1_IDEX_Msk       (0x7UL /*<< CAN_BUF14_ID1_IDEX_Pos*/)        /*!<CAN BUF14_ID1: IDEX Mask */

#define CAN_BUF14_ID1_IDE_Pos        3                                            /*!<CAN BUF14_ID1: IDE Position */
#define CAN_BUF14_ID1_IDE_Msk        (0x1UL << CAN_BUF14_ID1_IDE_Pos)             /*!<CAN BUF14_ID1: IDE Mask */

#define CAN_BUF14_ID1_SRR_Pos        4                                            /*!<CAN BUF14_ID1: SRR Position */
#define CAN_BUF14_ID1_SRR_Msk        (0x1UL << CAN_BUF14_ID1_SRR_Pos)             /*!<CAN BUF14_ID1: SRR Mask */

#define CAN_BUF14_ID1_ID_Pos         5                                            /*!<CAN BUF14_ID1: ID Position */
#define CAN_BUF14_ID1_ID_Msk         (0x7FFUL << CAN_BUF14_ID1_ID_Pos)            /*!<CAN BUF14_ID1: ID Mask */

#define CAN_BUF14_ID1_Msk_ALL        (CAN_BUF14_ID1_IDEX_Msk       |\
                                      CAN_BUF14_ID1_IDE_Msk        |\
                                      CAN_BUF14_ID1_SRR_Msk        |\
                                      CAN_BUF14_ID1_ID_Msk         )

#define CAN_CGCR_CANEN_Pos           0                                            /*!<CAN CGCR: CANEN Position */
#define CAN_CGCR_CANEN_Msk           (0x1UL /*<< CAN_CGCR_CANEN_Pos*/)            /*!<CAN CGCR: CANEN Mask */

#define CAN_CGCR_CRX_Pos             1                                            /*!<CAN CGCR: CRX Position */
#define CAN_CGCR_CRX_Msk             (0x1UL << CAN_CGCR_CRX_Pos)                  /*!<CAN CGCR: CRX Mask */

#define CAN_CGCR_CTX_Pos             2                                            /*!<CAN CGCR: CTX Position */
#define CAN_CGCR_CTX_Msk             (0x1UL << CAN_CGCR_CTX_Pos)                  /*!<CAN CGCR: CTX Mask */

#define CAN_CGCR_BUFFLOCK_Pos        3                                            /*!<CAN CGCR: BUFFLOCK Position */
#define CAN_CGCR_BUFFLOCK_Msk        (0x1UL << CAN_CGCR_BUFFLOCK_Pos)             /*!<CAN CGCR: BUFFLOCK Mask */

#define CAN_CGCR_TSTPEN_Pos          4                                            /*!<CAN CGCR: TSTPEN Position */
#define CAN_CGCR_TSTPEN_Msk          (0x1UL << CAN_CGCR_TSTPEN_Pos)               /*!<CAN CGCR: TSTPEN Mask */

#define CAN_CGCR_DDIR_Pos            5                                            /*!<CAN CGCR: DDIR Position */
#define CAN_CGCR_DDIR_Msk            (0x1UL << CAN_CGCR_DDIR_Pos)                 /*!<CAN CGCR: DDIR Mask */

#define CAN_CGCR_LO_Pos              6                                            /*!<CAN CGCR: LO Position */
#define CAN_CGCR_LO_Msk              (0x1UL << CAN_CGCR_LO_Pos)                   /*!<CAN CGCR: LO Mask */

#define CAN_CGCR_IGNACK_Pos          7                                            /*!<CAN CGCR: IGNACK Position */
#define CAN_CGCR_IGNACK_Msk          (0x1UL << CAN_CGCR_IGNACK_Pos)               /*!<CAN CGCR: IGNACK Mask */

#define CAN_CGCR_LOOP_BACK_Pos       8                                            /*!<CAN CGCR: LOOP_BACK Position */
#define CAN_CGCR_LOOP_BACK_Msk       (0x1UL << CAN_CGCR_LOOP_BACK_Pos)            /*!<CAN CGCR: LOOP_BACK Mask */

#define CAN_CGCR_INTERNAL_Pos        9                                            /*!<CAN CGCR: INTERNAL Position */
#define CAN_CGCR_INTERNAL_Msk        (0x1UL << CAN_CGCR_INTERNAL_Pos)             /*!<CAN CGCR: INTERNAL Mask */

#define CAN_CGCR_DIAGEN_Pos          10                                           /*!<CAN CGCR: DIAGEN Position */
#define CAN_CGCR_DIAGEN_Msk          (0x1UL << CAN_CGCR_DIAGEN_Pos)               /*!<CAN CGCR: DIAGEN Mask */

#define CAN_CGCR_EIT_Pos             11                                           /*!<CAN CGCR: EIT Position */
#define CAN_CGCR_EIT_Msk             (0x1UL << CAN_CGCR_EIT_Pos)                  /*!<CAN CGCR: EIT Mask */

#define CAN_CGCR_Msk_ALL             (CAN_CGCR_CANEN_Msk           |\
                                      CAN_CGCR_CRX_Msk             |\
                                      CAN_CGCR_CTX_Msk             |\
                                      CAN_CGCR_BUFFLOCK_Msk        |\
                                      CAN_CGCR_TSTPEN_Msk          |\
                                      CAN_CGCR_DDIR_Msk            |\
                                      CAN_CGCR_LO_Msk              |\
                                      CAN_CGCR_IGNACK_Msk          |\
                                      CAN_CGCR_LOOP_BACK_Msk       |\
                                      CAN_CGCR_INTERNAL_Msk        |\
                                      CAN_CGCR_DIAGEN_Msk          |\
                                      CAN_CGCR_EIT_Msk             )

#define CAN_CTIM_TSEG2_Pos           0                                            /*!<CAN CTIM: TSEG2 Position */
#define CAN_CTIM_TSEG2_Msk           (0x7UL /*<< CAN_CTIM_TSEG2_Pos*/)            /*!<CAN CTIM: TSEG2 Mask */

#define CAN_CTIM_TSEG1_Pos           3                                            /*!<CAN CTIM: TSEG1 Position */
#define CAN_CTIM_TSEG1_Msk           (0xFUL << CAN_CTIM_TSEG1_Pos)                /*!<CAN CTIM: TSEG1 Mask */

#define CAN_CTIM_SJW_Pos             7                                            /*!<CAN CTIM: SJW Position */
#define CAN_CTIM_SJW_Msk             (0x3UL << CAN_CTIM_SJW_Pos)                  /*!<CAN CTIM: SJW Mask */

#define CAN_CTIM_PSC_Pos             9                                            /*!<CAN CTIM: PSC Position */
#define CAN_CTIM_PSC_Msk             (0x7FUL << CAN_CTIM_PSC_Pos)                 /*!<CAN CTIM: PSC Mask */

#define CAN_CTIM_Msk_ALL             (CAN_CTIM_TSEG2_Msk           |\
                                      CAN_CTIM_TSEG1_Msk           |\
                                      CAN_CTIM_SJW_Msk             |\
                                      CAN_CTIM_PSC_Msk             )

#define CAN_GMSKX_XRTR_Pos           0                                            /*!<CAN GMSKX: XRTR Position */
#define CAN_GMSKX_XRTR_Msk           (0x1UL /*<< CAN_GMSKX_XRTR_Pos*/)            /*!<CAN GMSKX: XRTR Mask */

#define CAN_GMSKX_GM_Pos             1                                            /*!<CAN GMSKX: GM Position */
#define CAN_GMSKX_GM_Msk             (0x7FFFUL << CAN_GMSKX_GM_Pos)               /*!<CAN GMSKX: GM Mask */

#define CAN_GMSKX_Msk_ALL            (CAN_GMSKX_XRTR_Msk           |\
                                      CAN_GMSKX_GM_Msk             )

#define CAN_GMSKB_GM_Pos             0                                            /*!<CAN GMSKB: GM Position */
#define CAN_GMSKB_GM_Msk             (0x7UL /*<< CAN_GMSKB_GM_Pos*/)              /*!<CAN GMSKB: GM Mask */

#define CAN_GMSKB_IDE_Pos            3                                            /*!<CAN GMSKB: IDE Position */
#define CAN_GMSKB_IDE_Msk            (0x1UL << CAN_GMSKB_IDE_Pos)                 /*!<CAN GMSKB: IDE Mask */

#define CAN_GMSKB_RTR_Pos            4                                            /*!<CAN GMSKB: RTR Position */
#define CAN_GMSKB_RTR_Msk            (0x1UL << CAN_GMSKB_RTR_Pos)                 /*!<CAN GMSKB: RTR Mask */

#define CAN_GMSKB_GME_Pos            5                                            /*!<CAN GMSKB: GME Position */
#define CAN_GMSKB_GME_Msk            (0x7FFUL << CAN_GMSKB_GME_Pos)               /*!<CAN GMSKB: GME Mask */

#define CAN_GMSKB_Msk_ALL            (CAN_GMSKB_GM_Msk             |\
                                      CAN_GMSKB_IDE_Msk            |\
                                      CAN_GMSKB_RTR_Msk            |\
                                      CAN_GMSKB_GME_Msk            )

#define CAN_BMSKX_XRTR_Pos           0                                            /*!<CAN BMSKX: XRTR Position */
#define CAN_BMSKX_XRTR_Msk           (0x1UL /*<< CAN_BMSKX_XRTR_Pos*/)            /*!<CAN BMSKX: XRTR Mask */

#define CAN_BMSKX_BM_Pos             1                                            /*!<CAN BMSKX: BM Position */
#define CAN_BMSKX_BM_Msk             (0x7FFFUL << CAN_BMSKX_BM_Pos)               /*!<CAN BMSKX: BM Mask */

#define CAN_BMSKX_Msk_ALL            (CAN_BMSKX_XRTR_Msk           |\
                                      CAN_BMSKX_BM_Msk             )

#define CAN_BMSKB_BM_Pos             0                                            /*!<CAN BMSKB: BM Position */
#define CAN_BMSKB_BM_Msk             (0x7UL /*<< CAN_BMSKB_BM_Pos*/)              /*!<CAN BMSKB: BM Mask */

#define CAN_BMSKB_IDE_Pos            3                                            /*!<CAN BMSKB: IDE Position */
#define CAN_BMSKB_IDE_Msk            (0x1UL << CAN_BMSKB_IDE_Pos)                 /*!<CAN BMSKB: IDE Mask */

#define CAN_BMSKB_RTR_Pos            4                                            /*!<CAN BMSKB: RTR Position */
#define CAN_BMSKB_RTR_Msk            (0x1UL << CAN_BMSKB_RTR_Pos)                 /*!<CAN BMSKB: RTR Mask */

#define CAN_BMSKB_BME_Pos            5                                            /*!<CAN BMSKB: BME Position */
#define CAN_BMSKB_BME_Msk            (0x7FFUL << CAN_BMSKB_BME_Pos)               /*!<CAN BMSKB: BME Mask */

#define CAN_BMSKB_Msk_ALL            (CAN_BMSKB_BM_Msk             |\
                                      CAN_BMSKB_IDE_Msk            |\
                                      CAN_BMSKB_RTR_Msk            |\
                                      CAN_BMSKB_BME_Msk            )

#define CAN_CIEN_IEN0_Pos            0                                            /*!<CAN CIEN: IEN0 Position */
#define CAN_CIEN_IEN0_Msk            (0x1UL /*<< CAN_CIEN_IEN0_Pos*/)             /*!<CAN CIEN: IEN0 Mask */

#define CAN_CIEN_IEN1_Pos            1                                            /*!<CAN CIEN: IEN1 Position */
#define CAN_CIEN_IEN1_Msk            (0x1UL << CAN_CIEN_IEN1_Pos)                 /*!<CAN CIEN: IEN1 Mask */

#define CAN_CIEN_IEN2_Pos            2                                            /*!<CAN CIEN: IEN2 Position */
#define CAN_CIEN_IEN2_Msk            (0x1UL << CAN_CIEN_IEN2_Pos)                 /*!<CAN CIEN: IEN2 Mask */

#define CAN_CIEN_IEN3_Pos            3                                            /*!<CAN CIEN: IEN3 Position */
#define CAN_CIEN_IEN3_Msk            (0x1UL << CAN_CIEN_IEN3_Pos)                 /*!<CAN CIEN: IEN3 Mask */

#define CAN_CIEN_IEN4_Pos            4                                            /*!<CAN CIEN: IEN4 Position */
#define CAN_CIEN_IEN4_Msk            (0x1UL << CAN_CIEN_IEN4_Pos)                 /*!<CAN CIEN: IEN4 Mask */

#define CAN_CIEN_IEN5_Pos            5                                            /*!<CAN CIEN: IEN5 Position */
#define CAN_CIEN_IEN5_Msk            (0x1UL << CAN_CIEN_IEN5_Pos)                 /*!<CAN CIEN: IEN5 Mask */

#define CAN_CIEN_IEN6_Pos            6                                            /*!<CAN CIEN: IEN6 Position */
#define CAN_CIEN_IEN6_Msk            (0x1UL << CAN_CIEN_IEN6_Pos)                 /*!<CAN CIEN: IEN6 Mask */

#define CAN_CIEN_IEN7_Pos            7                                            /*!<CAN CIEN: IEN7 Position */
#define CAN_CIEN_IEN7_Msk            (0x1UL << CAN_CIEN_IEN7_Pos)                 /*!<CAN CIEN: IEN7 Mask */

#define CAN_CIEN_IEN8_Pos            8                                            /*!<CAN CIEN: IEN8 Position */
#define CAN_CIEN_IEN8_Msk            (0x1UL << CAN_CIEN_IEN8_Pos)                 /*!<CAN CIEN: IEN8 Mask */

#define CAN_CIEN_IEN9_Pos            9                                            /*!<CAN CIEN: IEN9 Position */
#define CAN_CIEN_IEN9_Msk            (0x1UL << CAN_CIEN_IEN9_Pos)                 /*!<CAN CIEN: IEN9 Mask */

#define CAN_CIEN_IEN10_Pos           10                                           /*!<CAN CIEN: IEN10 Position */
#define CAN_CIEN_IEN10_Msk           (0x1UL << CAN_CIEN_IEN10_Pos)                /*!<CAN CIEN: IEN10 Mask */

#define CAN_CIEN_IEN11_Pos           11                                           /*!<CAN CIEN: IEN11 Position */
#define CAN_CIEN_IEN11_Msk           (0x1UL << CAN_CIEN_IEN11_Pos)                /*!<CAN CIEN: IEN11 Mask */

#define CAN_CIEN_IEN12_Pos           12                                           /*!<CAN CIEN: IEN12 Position */
#define CAN_CIEN_IEN12_Msk           (0x1UL << CAN_CIEN_IEN12_Pos)                /*!<CAN CIEN: IEN12 Mask */

#define CAN_CIEN_IEN13_Pos           13                                           /*!<CAN CIEN: IEN13 Position */
#define CAN_CIEN_IEN13_Msk           (0x1UL << CAN_CIEN_IEN13_Pos)                /*!<CAN CIEN: IEN13 Mask */

#define CAN_CIEN_IEN14_Pos           14                                           /*!<CAN CIEN: IEN14 Position */
#define CAN_CIEN_IEN14_Msk           (0x1UL << CAN_CIEN_IEN14_Pos)                /*!<CAN CIEN: IEN14 Mask */

#define CAN_CIEN_EIEN_Pos            15                                           /*!<CAN CIEN: EIEN Position */
#define CAN_CIEN_EIEN_Msk            (0x1UL << CAN_CIEN_EIEN_Pos)                 /*!<CAN CIEN: EIEN Mask */

#define CAN_CIEN_Msk_ALL             (CAN_CIEN_IEN0_Msk            |\
                                      CAN_CIEN_IEN1_Msk            |\
                                      CAN_CIEN_IEN2_Msk            |\
                                      CAN_CIEN_IEN3_Msk            |\
                                      CAN_CIEN_IEN4_Msk            |\
                                      CAN_CIEN_IEN5_Msk            |\
                                      CAN_CIEN_IEN6_Msk            |\
                                      CAN_CIEN_IEN7_Msk            |\
                                      CAN_CIEN_IEN8_Msk            |\
                                      CAN_CIEN_IEN9_Msk            |\
                                      CAN_CIEN_IEN10_Msk           |\
                                      CAN_CIEN_IEN11_Msk           |\
                                      CAN_CIEN_IEN12_Msk           |\
                                      CAN_CIEN_IEN13_Msk           |\
                                      CAN_CIEN_IEN14_Msk           |\
                                      CAN_CIEN_EIEN_Msk            )

#define CAN_CIPND_IPND0_Pos          0                                            /*!<CAN CIPND: IPND0 Position */
#define CAN_CIPND_IPND0_Msk          (0x1UL /*<< CAN_CIPND_IPND0_Pos*/)           /*!<CAN CIPND: IPND0 Mask */

#define CAN_CIPND_IPND1_Pos          1                                            /*!<CAN CIPND: IPND1 Position */
#define CAN_CIPND_IPND1_Msk          (0x1UL << CAN_CIPND_IPND1_Pos)               /*!<CAN CIPND: IPND1 Mask */

#define CAN_CIPND_IPND2_Pos          2                                            /*!<CAN CIPND: IPND2 Position */
#define CAN_CIPND_IPND2_Msk          (0x1UL << CAN_CIPND_IPND2_Pos)               /*!<CAN CIPND: IPND2 Mask */

#define CAN_CIPND_IPND3_Pos          3                                            /*!<CAN CIPND: IPND3 Position */
#define CAN_CIPND_IPND3_Msk          (0x1UL << CAN_CIPND_IPND3_Pos)               /*!<CAN CIPND: IPND3 Mask */

#define CAN_CIPND_IPND4_Pos          4                                            /*!<CAN CIPND: IPND4 Position */
#define CAN_CIPND_IPND4_Msk          (0x1UL << CAN_CIPND_IPND4_Pos)               /*!<CAN CIPND: IPND4 Mask */

#define CAN_CIPND_IPND5_Pos          5                                            /*!<CAN CIPND: IPND5 Position */
#define CAN_CIPND_IPND5_Msk          (0x1UL << CAN_CIPND_IPND5_Pos)               /*!<CAN CIPND: IPND5 Mask */

#define CAN_CIPND_IPND6_Pos          6                                            /*!<CAN CIPND: IPND6 Position */
#define CAN_CIPND_IPND6_Msk          (0x1UL << CAN_CIPND_IPND6_Pos)               /*!<CAN CIPND: IPND6 Mask */

#define CAN_CIPND_IPND7_Pos          7                                            /*!<CAN CIPND: IPND7 Position */
#define CAN_CIPND_IPND7_Msk          (0x1UL << CAN_CIPND_IPND7_Pos)               /*!<CAN CIPND: IPND7 Mask */

#define CAN_CIPND_IPND8_Pos          8                                            /*!<CAN CIPND: IPND8 Position */
#define CAN_CIPND_IPND8_Msk          (0x1UL << CAN_CIPND_IPND8_Pos)               /*!<CAN CIPND: IPND8 Mask */

#define CAN_CIPND_IPND9_Pos          9                                            /*!<CAN CIPND: IPND9 Position */
#define CAN_CIPND_IPND9_Msk          (0x1UL << CAN_CIPND_IPND9_Pos)               /*!<CAN CIPND: IPND9 Mask */

#define CAN_CIPND_IPND10_Pos         10                                           /*!<CAN CIPND: IPND10 Position */
#define CAN_CIPND_IPND10_Msk         (0x1UL << CAN_CIPND_IPND10_Pos)              /*!<CAN CIPND: IPND10 Mask */

#define CAN_CIPND_IPND11_Pos         11                                           /*!<CAN CIPND: IPND11 Position */
#define CAN_CIPND_IPND11_Msk         (0x1UL << CAN_CIPND_IPND11_Pos)              /*!<CAN CIPND: IPND11 Mask */

#define CAN_CIPND_IPND12_Pos         12                                           /*!<CAN CIPND: IPND12 Position */
#define CAN_CIPND_IPND12_Msk         (0x1UL << CAN_CIPND_IPND12_Pos)              /*!<CAN CIPND: IPND12 Mask */

#define CAN_CIPND_IPND13_Pos         13                                           /*!<CAN CIPND: IPND13 Position */
#define CAN_CIPND_IPND13_Msk         (0x1UL << CAN_CIPND_IPND13_Pos)              /*!<CAN CIPND: IPND13 Mask */

#define CAN_CIPND_IPND14_Pos         14                                           /*!<CAN CIPND: IPND14 Position */
#define CAN_CIPND_IPND14_Msk         (0x1UL << CAN_CIPND_IPND14_Pos)              /*!<CAN CIPND: IPND14 Mask */

#define CAN_CIPND_EIPND_Pos          15                                           /*!<CAN CIPND: EIPND Position */
#define CAN_CIPND_EIPND_Msk          (0x1UL << CAN_CIPND_EIPND_Pos)               /*!<CAN CIPND: EIPND Mask */

#define CAN_CIPND_Msk_ALL            (CAN_CIPND_IPND0_Msk          |\
                                      CAN_CIPND_IPND1_Msk          |\
                                      CAN_CIPND_IPND2_Msk          |\
                                      CAN_CIPND_IPND3_Msk          |\
                                      CAN_CIPND_IPND4_Msk          |\
                                      CAN_CIPND_IPND5_Msk          |\
                                      CAN_CIPND_IPND6_Msk          |\
                                      CAN_CIPND_IPND7_Msk          |\
                                      CAN_CIPND_IPND8_Msk          |\
                                      CAN_CIPND_IPND9_Msk          |\
                                      CAN_CIPND_IPND10_Msk         |\
                                      CAN_CIPND_IPND11_Msk         |\
                                      CAN_CIPND_IPND12_Msk         |\
                                      CAN_CIPND_IPND13_Msk         |\
                                      CAN_CIPND_IPND14_Msk         |\
                                      CAN_CIPND_EIPND_Msk          )

#define CAN_CICLR_ICLR0_Pos          0                                            /*!<CAN CICLR: ICLR0 Position */
#define CAN_CICLR_ICLR0_Msk          (0x1UL /*<< CAN_CICLR_ICLR0_Pos*/)           /*!<CAN CICLR: ICLR0 Mask */

#define CAN_CICLR_ICLR1_Pos          1                                            /*!<CAN CICLR: ICLR1 Position */
#define CAN_CICLR_ICLR1_Msk          (0x1UL << CAN_CICLR_ICLR1_Pos)               /*!<CAN CICLR: ICLR1 Mask */

#define CAN_CICLR_ICLR2_Pos          2                                            /*!<CAN CICLR: ICLR2 Position */
#define CAN_CICLR_ICLR2_Msk          (0x1UL << CAN_CICLR_ICLR2_Pos)               /*!<CAN CICLR: ICLR2 Mask */

#define CAN_CICLR_ICLR3_Pos          3                                            /*!<CAN CICLR: ICLR3 Position */
#define CAN_CICLR_ICLR3_Msk          (0x1UL << CAN_CICLR_ICLR3_Pos)               /*!<CAN CICLR: ICLR3 Mask */

#define CAN_CICLR_ICLR4_Pos          4                                            /*!<CAN CICLR: ICLR4 Position */
#define CAN_CICLR_ICLR4_Msk          (0x1UL << CAN_CICLR_ICLR4_Pos)               /*!<CAN CICLR: ICLR4 Mask */

#define CAN_CICLR_ICLR5_Pos          5                                            /*!<CAN CICLR: ICLR5 Position */
#define CAN_CICLR_ICLR5_Msk          (0x1UL << CAN_CICLR_ICLR5_Pos)               /*!<CAN CICLR: ICLR5 Mask */

#define CAN_CICLR_ICLR6_Pos          6                                            /*!<CAN CICLR: ICLR6 Position */
#define CAN_CICLR_ICLR6_Msk          (0x1UL << CAN_CICLR_ICLR6_Pos)               /*!<CAN CICLR: ICLR6 Mask */

#define CAN_CICLR_ICLR7_Pos          7                                            /*!<CAN CICLR: ICLR7 Position */
#define CAN_CICLR_ICLR7_Msk          (0x1UL << CAN_CICLR_ICLR7_Pos)               /*!<CAN CICLR: ICLR7 Mask */

#define CAN_CICLR_ICLR8_Pos          8                                            /*!<CAN CICLR: ICLR8 Position */
#define CAN_CICLR_ICLR8_Msk          (0x1UL << CAN_CICLR_ICLR8_Pos)               /*!<CAN CICLR: ICLR8 Mask */

#define CAN_CICLR_ICLR9_Pos          9                                            /*!<CAN CICLR: ICLR9 Position */
#define CAN_CICLR_ICLR9_Msk          (0x1UL << CAN_CICLR_ICLR9_Pos)               /*!<CAN CICLR: ICLR9 Mask */

#define CAN_CICLR_ICLR10_Pos         10                                           /*!<CAN CICLR: ICLR10 Position */
#define CAN_CICLR_ICLR10_Msk         (0x1UL << CAN_CICLR_ICLR10_Pos)              /*!<CAN CICLR: ICLR10 Mask */

#define CAN_CICLR_ICLR11_Pos         11                                           /*!<CAN CICLR: ICLR11 Position */
#define CAN_CICLR_ICLR11_Msk         (0x1UL << CAN_CICLR_ICLR11_Pos)              /*!<CAN CICLR: ICLR11 Mask */

#define CAN_CICLR_ICLR12_Pos         12                                           /*!<CAN CICLR: ICLR12 Position */
#define CAN_CICLR_ICLR12_Msk         (0x1UL << CAN_CICLR_ICLR12_Pos)              /*!<CAN CICLR: ICLR12 Mask */

#define CAN_CICLR_ICLR13_Pos         13                                           /*!<CAN CICLR: ICLR13 Position */
#define CAN_CICLR_ICLR13_Msk         (0x1UL << CAN_CICLR_ICLR13_Pos)              /*!<CAN CICLR: ICLR13 Mask */

#define CAN_CICLR_ICLR14_Pos         14                                           /*!<CAN CICLR: ICLR14 Position */
#define CAN_CICLR_ICLR14_Msk         (0x1UL << CAN_CICLR_ICLR14_Pos)              /*!<CAN CICLR: ICLR14 Mask */

#define CAN_CICLR_EICLR_Pos          15                                           /*!<CAN CICLR: EICLR Position */
#define CAN_CICLR_EICLR_Msk          (0x1UL << CAN_CICLR_EICLR_Pos)               /*!<CAN CICLR: EICLR Mask */

#define CAN_CICLR_Msk_ALL            (CAN_CICLR_ICLR0_Msk          |\
                                      CAN_CICLR_ICLR1_Msk          |\
                                      CAN_CICLR_ICLR2_Msk          |\
                                      CAN_CICLR_ICLR3_Msk          |\
                                      CAN_CICLR_ICLR4_Msk          |\
                                      CAN_CICLR_ICLR5_Msk          |\
                                      CAN_CICLR_ICLR6_Msk          |\
                                      CAN_CICLR_ICLR7_Msk          |\
                                      CAN_CICLR_ICLR8_Msk          |\
                                      CAN_CICLR_ICLR9_Msk          |\
                                      CAN_CICLR_ICLR10_Msk         |\
                                      CAN_CICLR_ICLR11_Msk         |\
                                      CAN_CICLR_ICLR12_Msk         |\
                                      CAN_CICLR_ICLR13_Msk         |\
                                      CAN_CICLR_ICLR14_Msk         |\
                                      CAN_CICLR_EICLR_Msk          )

#define CAN_CICEN_ICEN0_Pos          0                                            /*!<CAN CICEN: ICEN0 Position */
#define CAN_CICEN_ICEN0_Msk          (0x1UL /*<< CAN_CICEN_ICEN0_Pos*/)           /*!<CAN CICEN: ICEN0 Mask */

#define CAN_CICEN_ICEN1_Pos          1                                            /*!<CAN CICEN: ICEN1 Position */
#define CAN_CICEN_ICEN1_Msk          (0x1UL << CAN_CICEN_ICEN1_Pos)               /*!<CAN CICEN: ICEN1 Mask */

#define CAN_CICEN_ICEN2_Pos          2                                            /*!<CAN CICEN: ICEN2 Position */
#define CAN_CICEN_ICEN2_Msk          (0x1UL << CAN_CICEN_ICEN2_Pos)               /*!<CAN CICEN: ICEN2 Mask */

#define CAN_CICEN_ICEN3_Pos          3                                            /*!<CAN CICEN: ICEN3 Position */
#define CAN_CICEN_ICEN3_Msk          (0x1UL << CAN_CICEN_ICEN3_Pos)               /*!<CAN CICEN: ICEN3 Mask */

#define CAN_CICEN_ICEN4_Pos          4                                            /*!<CAN CICEN: ICEN4 Position */
#define CAN_CICEN_ICEN4_Msk          (0x1UL << CAN_CICEN_ICEN4_Pos)               /*!<CAN CICEN: ICEN4 Mask */

#define CAN_CICEN_ICEN5_Pos          5                                            /*!<CAN CICEN: ICEN5 Position */
#define CAN_CICEN_ICEN5_Msk          (0x1UL << CAN_CICEN_ICEN5_Pos)               /*!<CAN CICEN: ICEN5 Mask */

#define CAN_CICEN_ICEN6_Pos          6                                            /*!<CAN CICEN: ICEN6 Position */
#define CAN_CICEN_ICEN6_Msk          (0x1UL << CAN_CICEN_ICEN6_Pos)               /*!<CAN CICEN: ICEN6 Mask */

#define CAN_CICEN_ICEN7_Pos          7                                            /*!<CAN CICEN: ICEN7 Position */
#define CAN_CICEN_ICEN7_Msk          (0x1UL << CAN_CICEN_ICEN7_Pos)               /*!<CAN CICEN: ICEN7 Mask */

#define CAN_CICEN_ICEN8_Pos          8                                            /*!<CAN CICEN: ICEN8 Position */
#define CAN_CICEN_ICEN8_Msk          (0x1UL << CAN_CICEN_ICEN8_Pos)               /*!<CAN CICEN: ICEN8 Mask */

#define CAN_CICEN_ICEN9_Pos          9                                            /*!<CAN CICEN: ICEN9 Position */
#define CAN_CICEN_ICEN9_Msk          (0x1UL << CAN_CICEN_ICEN9_Pos)               /*!<CAN CICEN: ICEN9 Mask */

#define CAN_CICEN_ICEN10_Pos         10                                           /*!<CAN CICEN: ICEN10 Position */
#define CAN_CICEN_ICEN10_Msk         (0x1UL << CAN_CICEN_ICEN10_Pos)              /*!<CAN CICEN: ICEN10 Mask */

#define CAN_CICEN_ICEN11_Pos         11                                           /*!<CAN CICEN: ICEN11 Position */
#define CAN_CICEN_ICEN11_Msk         (0x1UL << CAN_CICEN_ICEN11_Pos)              /*!<CAN CICEN: ICEN11 Mask */

#define CAN_CICEN_ICEN12_Pos         12                                           /*!<CAN CICEN: ICEN12 Position */
#define CAN_CICEN_ICEN12_Msk         (0x1UL << CAN_CICEN_ICEN12_Pos)              /*!<CAN CICEN: ICEN12 Mask */

#define CAN_CICEN_ICEN13_Pos         13                                           /*!<CAN CICEN: ICEN13 Position */
#define CAN_CICEN_ICEN13_Msk         (0x1UL << CAN_CICEN_ICEN13_Pos)              /*!<CAN CICEN: ICEN13 Mask */

#define CAN_CICEN_ICEN14_Pos         14                                           /*!<CAN CICEN: ICEN14 Position */
#define CAN_CICEN_ICEN14_Msk         (0x1UL << CAN_CICEN_ICEN14_Pos)              /*!<CAN CICEN: ICEN14 Mask */

#define CAN_CICEN_EICEN_Pos          15                                           /*!<CAN CICEN: EICEN Position */
#define CAN_CICEN_EICEN_Msk          (0x1UL << CAN_CICEN_EICEN_Pos)               /*!<CAN CICEN: EICEN Mask */

#define CAN_CICEN_Msk_ALL            (CAN_CICEN_ICEN0_Msk          |\
                                      CAN_CICEN_ICEN1_Msk          |\
                                      CAN_CICEN_ICEN2_Msk          |\
                                      CAN_CICEN_ICEN3_Msk          |\
                                      CAN_CICEN_ICEN4_Msk          |\
                                      CAN_CICEN_ICEN5_Msk          |\
                                      CAN_CICEN_ICEN6_Msk          |\
                                      CAN_CICEN_ICEN7_Msk          |\
                                      CAN_CICEN_ICEN8_Msk          |\
                                      CAN_CICEN_ICEN9_Msk          |\
                                      CAN_CICEN_ICEN10_Msk         |\
                                      CAN_CICEN_ICEN11_Msk         |\
                                      CAN_CICEN_ICEN12_Msk         |\
                                      CAN_CICEN_ICEN13_Msk         |\
                                      CAN_CICEN_ICEN14_Msk         |\
                                      CAN_CICEN_EICEN_Msk          )

#define CAN_CSTPND_IST_Pos           0                                            /*!<CAN CSTPND: IST Position */
#define CAN_CSTPND_IST_Msk           (0xFUL /*<< CAN_CSTPND_IST_Pos*/)            /*!<CAN CSTPND: IST Mask */

#define CAN_CSTPND_IRQ_Pos           4                                            /*!<CAN CSTPND: IRQ Position */
#define CAN_CSTPND_IRQ_Msk           (0x1UL << CAN_CSTPND_IRQ_Pos)                /*!<CAN CSTPND: IRQ Mask */

#define CAN_CSTPND_NS_Pos            5                                            /*!<CAN CSTPND: NS Position */
#define CAN_CSTPND_NS_Msk            (0x7UL << CAN_CSTPND_NS_Pos)                 /*!<CAN CSTPND: NS Mask */

#define CAN_CSTPND_Msk_ALL           (CAN_CSTPND_IST_Msk           |\
                                      CAN_CSTPND_IRQ_Msk           |\
                                      CAN_CSTPND_NS_Msk            )

#define CAN_CANEC_TEC_Pos            0                                            /*!<CAN CANEC: TEC Position */
#define CAN_CANEC_TEC_Msk            (0xFFUL /*<< CAN_CANEC_TEC_Pos*/)            /*!<CAN CANEC: TEC Mask */

#define CAN_CANEC_REC_Pos            8                                            /*!<CAN CANEC: REC Position */
#define CAN_CANEC_REC_Msk            (0xFFUL << CAN_CANEC_REC_Pos)                /*!<CAN CANEC: REC Mask */

#define CAN_CANEC_Msk_ALL            (CAN_CANEC_TEC_Msk            |\
                                      CAN_CANEC_REC_Msk            )

#define CAN_CEDIAG_EFID_Pos          0                                            /*!<CAN CEDIAG: EFID Position */
#define CAN_CEDIAG_EFID_Msk          (0xFUL /*<< CAN_CEDIAG_EFID_Pos*/)           /*!<CAN CEDIAG: EFID Mask */

#define CAN_CEDIAG_EBID_Pos          4                                            /*!<CAN CEDIAG: EBID Position */
#define CAN_CEDIAG_EBID_Msk          (0x3FUL << CAN_CEDIAG_EBID_Pos)              /*!<CAN CEDIAG: EBID Mask */

#define CAN_CEDIAG_TXE_Pos           10                                           /*!<CAN CEDIAG: TXE Position */
#define CAN_CEDIAG_TXE_Msk           (0x1UL << CAN_CEDIAG_TXE_Pos)                /*!<CAN CEDIAG: TXE Mask */

#define CAN_CEDIAG_STUFF_Pos         11                                           /*!<CAN CEDIAG: STUFF Position */
#define CAN_CEDIAG_STUFF_Msk         (0x1UL << CAN_CEDIAG_STUFF_Pos)              /*!<CAN CEDIAG: STUFF Mask */

#define CAN_CEDIAG_CRCERR_Pos        12                                           /*!<CAN CEDIAG: CRCERR Position */
#define CAN_CEDIAG_CRCERR_Msk        (0x1UL << CAN_CEDIAG_CRCERR_Pos)             /*!<CAN CEDIAG: CRCERR Mask */

#define CAN_CEDIAG_MON_Pos           13                                           /*!<CAN CEDIAG: MON Position */
#define CAN_CEDIAG_MON_Msk           (0x1UL << CAN_CEDIAG_MON_Pos)                /*!<CAN CEDIAG: MON Mask */

#define CAN_CEDIAG_DRIVE_Pos         14                                           /*!<CAN CEDIAG: DRIVE Position */
#define CAN_CEDIAG_DRIVE_Msk         (0x1UL << CAN_CEDIAG_DRIVE_Pos)              /*!<CAN CEDIAG: DRIVE Mask */

#define CAN_CEDIAG_Msk_ALL           (CAN_CEDIAG_EFID_Msk          |\
                                      CAN_CEDIAG_EBID_Msk          |\
                                      CAN_CEDIAG_TXE_Msk           |\
                                      CAN_CEDIAG_STUFF_Msk         |\
                                      CAN_CEDIAG_CRCERR_Msk        |\
                                      CAN_CEDIAG_MON_Msk           |\
                                      CAN_CEDIAG_DRIVE_Msk         )

#define CAN_CTMR_CTMR_Pos            0                                            /*!<CAN CTMR: CTMR Position */
#define CAN_CTMR_CTMR_Msk            (0xFFFFUL /*<< CAN_CTMR_CTMR_Pos*/)          /*!<CAN CTMR: CTMR Mask */

#define CAN_CTMR_Msk_ALL             (CAN_CTMR_CTMR_Msk           )

#define FIFO_FR_RXTRIGF_Pos          0                                            /*!<FIFO FR: RXTRIGF Position */
#define FIFO_FR_RXTRIGF_Msk          (0x1UL /*<< FIFO_FR_RXTRIGF_Pos*/)           /*!<FIFO FR: RXTRIGF Mask */

#define FIFO_FR_TXTRIGF_Pos          1                                            /*!<FIFO FR: TXTRIGF Position */
#define FIFO_FR_TXTRIGF_Msk          (0x1UL << FIFO_FR_TXTRIGF_Pos)               /*!<FIFO FR: TXTRIGF Mask */

#define FIFO_FR_RXOVF_Pos            2                                            /*!<FIFO FR: RXOVF Position */
#define FIFO_FR_RXOVF_Msk            (0x1UL << FIFO_FR_RXOVF_Pos)                 /*!<FIFO FR: RXOVF Mask */

#define FIFO_FR_RXEMPT_Pos           4                                            /*!<FIFO FR: RXEMPT Position */
#define FIFO_FR_RXEMPT_Msk           (0x1UL << FIFO_FR_RXEMPT_Pos)                /*!<FIFO FR: RXEMPT Mask */

#define FIFO_FR_TXEMPT_Pos           5                                            /*!<FIFO FR: TXEMPT Position */
#define FIFO_FR_TXEMPT_Msk           (0x1UL << FIFO_FR_TXEMPT_Pos)                /*!<FIFO FR: TXEMPT Mask */

#define FIFO_FR_RXFULL_Pos           6                                            /*!<FIFO FR: RXFULL Position */
#define FIFO_FR_RXFULL_Msk           (0x1UL << FIFO_FR_RXFULL_Pos)                /*!<FIFO FR: RXFULL Mask */

#define FIFO_FR_TXFULL_Pos           7                                            /*!<FIFO FR: TXFULL Position */
#define FIFO_FR_TXFULL_Msk           (0x1UL << FIFO_FR_TXFULL_Pos)                /*!<FIFO FR: TXFULL Mask */

#define FIFO_FR_RXTRIGFC_Pos         16                                           /*!<FIFO FR: RXTRIGFC Position */
#define FIFO_FR_RXTRIGFC_Msk         (0x1UL << FIFO_FR_RXTRIGFC_Pos)              /*!<FIFO FR: RXTRIGFC Mask */

#define FIFO_FR_TXTRIGFC_Pos         17                                           /*!<FIFO FR: TXTRIGFC Position */
#define FIFO_FR_TXTRIGFC_Msk         (0x1UL << FIFO_FR_TXTRIGFC_Pos)              /*!<FIFO FR: TXTRIGFC Mask */

#define FIFO_FR_RXOVFC_Pos           18                                           /*!<FIFO FR: RXOVFC Position */
#define FIFO_FR_RXOVFC_Msk           (0x1UL << FIFO_FR_RXOVFC_Pos)                /*!<FIFO FR: RXOVFC Mask */

#define FIFO_FR_Msk_ALL              (FIFO_FR_RXTRIGF_Msk          |\
                                      FIFO_FR_TXTRIGF_Msk          |\
                                      FIFO_FR_RXOVF_Msk            |\
                                      FIFO_FR_RXEMPT_Msk           |\
                                      FIFO_FR_TXEMPT_Msk           |\
                                      FIFO_FR_RXFULL_Msk           |\
                                      FIFO_FR_TXFULL_Msk           |\
                                      FIFO_FR_RXTRIGFC_Msk         |\
                                      FIFO_FR_TXTRIGFC_Msk         |\
                                      FIFO_FR_RXOVFC_Msk           )

#define FIFO_CR_RXTRIGIE_Pos         0                                            /*!<FIFO CR: RXTRIGIE Position */
#define FIFO_CR_RXTRIGIE_Msk         (0x1UL /*<< FIFO_CR_RXTRIGIE_Pos*/)          /*!<FIFO CR: RXTRIGIE Mask */

#define FIFO_CR_TXTRIGIE_Pos         1                                            /*!<FIFO CR: TXTRIGIE Position */
#define FIFO_CR_TXTRIGIE_Msk         (0x1UL << FIFO_CR_TXTRIGIE_Pos)              /*!<FIFO CR: TXTRIGIE Mask */

#define FIFO_CR_RXOVFIE_Pos          2                                            /*!<FIFO CR: RXOVFIE Position */
#define FIFO_CR_RXOVFIE_Msk          (0x1UL << FIFO_CR_RXOVFIE_Pos)               /*!<FIFO CR: RXOVFIE Mask */

#define FIFO_CR_RXMODE_Pos           3                                            /*!<FIFO CR: RXMODE Position */
#define FIFO_CR_RXMODE_Msk           (0x1UL << FIFO_CR_RXMODE_Pos)                /*!<FIFO CR: RXMODE Mask */

#define FIFO_CR_RXMAP_Pos            4                                            /*!<FIFO CR: RXMAP Position */
#define FIFO_CR_RXMAP_Msk            (0x3UL << FIFO_CR_RXMAP_Pos)                 /*!<FIFO CR: RXMAP Mask */

#define FIFO_CR_TXMAP_Pos            6                                            /*!<FIFO CR: TXMAP Position */
#define FIFO_CR_TXMAP_Msk            (0x3UL << FIFO_CR_TXMAP_Pos)                 /*!<FIFO CR: TXMAP Mask */

#define FIFO_CR_RXRDBITW_Pos         8                                            /*!<FIFO CR: RXRDBITW Position */
#define FIFO_CR_RXRDBITW_Msk         (0x3UL << FIFO_CR_RXRDBITW_Pos)              /*!<FIFO CR: RXRDBITW Mask */

#define FIFO_CR_TXWRBITW_Pos         10                                           /*!<FIFO CR: TXWRBITW Position */
#define FIFO_CR_TXWRBITW_Msk         (0x3UL << FIFO_CR_TXWRBITW_Pos)              /*!<FIFO CR: TXWRBITW Mask */

#define FIFO_CR_RXTRIG_Pos           12                                           /*!<FIFO CR: RXTRIG Position */
#define FIFO_CR_RXTRIG_Msk           (0x3UL << FIFO_CR_RXTRIG_Pos)                /*!<FIFO CR: RXTRIG Mask */

#define FIFO_CR_TXTRIG_Pos           14                                           /*!<FIFO CR: TXTRIG Position */
#define FIFO_CR_TXTRIG_Msk           (0x3UL << FIFO_CR_TXTRIG_Pos)                /*!<FIFO CR: TXTRIG Mask */

#define FIFO_CR_RXFRST_Pos           16                                           /*!<FIFO CR: RXFRST Position */
#define FIFO_CR_RXFRST_Msk           (0x1UL << FIFO_CR_RXFRST_Pos)                /*!<FIFO CR: RXFRST Mask */

#define FIFO_CR_TXFRST_Pos           17                                           /*!<FIFO CR: TXFRST Position */
#define FIFO_CR_TXFRST_Msk           (0x1UL << FIFO_CR_TXFRST_Pos)                /*!<FIFO CR: TXFRST Mask */

#define FIFO_CR_RXFEN_Pos            18                                           /*!<FIFO CR: RXFEN Position */
#define FIFO_CR_RXFEN_Msk            (0x1UL << FIFO_CR_RXFEN_Pos)                 /*!<FIFO CR: RXFEN Mask */

#define FIFO_CR_TXFEN_Pos            19                                           /*!<FIFO CR: TXFEN Position */
#define FIFO_CR_TXFEN_Msk            (0x1UL << FIFO_CR_TXFEN_Pos)                 /*!<FIFO CR: TXFEN Mask */

#define FIFO_CR_Msk_ALL              (FIFO_CR_RXTRIGIE_Msk         |\
                                      FIFO_CR_TXTRIGIE_Msk         |\
                                      FIFO_CR_RXOVFIE_Msk          |\
                                      FIFO_CR_RXMODE_Msk           |\
                                      FIFO_CR_RXMAP_Msk            |\
                                      FIFO_CR_TXMAP_Msk            |\
                                      FIFO_CR_RXRDBITW_Msk         |\
                                      FIFO_CR_TXWRBITW_Msk         |\
                                      FIFO_CR_RXTRIG_Msk           |\
                                      FIFO_CR_TXTRIG_Msk           |\
                                      FIFO_CR_RXFRST_Msk           |\
                                      FIFO_CR_TXFRST_Msk           |\
                                      FIFO_CR_RXFEN_Msk            |\
                                      FIFO_CR_TXFEN_Msk            )



__STATIC_INLINE void NVIC_SetVectorBase(uint32_t vector_base){
	SCB->VTOR = vector_base;
}

__STATIC_INLINE void RCC_WriteEnable(){
	RCC->RCCLOCK = 0x33CC;
}
__STATIC_INLINE void RCC_WriteDisable(){
	RCC->RCCLOCK = 0;
}


#ifdef __cplusplus
}  /*extern "C"*/
#endif

#endif /*__SH3XF2XX_SB0_H__*/
/******************* (C) COPYRIGHT 2021 Sinowealth *****END OF FILE****/

