/*
            Copyright(C) 1997-2021.  Sinowealth Tech. Co., Ltd.
********************************************************************************
* @file    CFG33F2801.h  
* @author  
* @version V1.1.0
* @date    6-May-2022
* @brief   Keil configuration Wizard file.
********************************************************************************
*/
#ifndef __CFG33F2801_H__
#define __CFG33F2801_H__


//extern uint32_t SystemCoreClock;


/*****************************************************************************
//--------- <<< Use Configuration Wizard in Context Menu >>> -----------------
*****************************************************************************/
//<h>Debug Options
/**********************
//<q> Default Assert Function
**********************/     
#define     ASSERT_ENABLE       0
#if ASSERT_ENABLE==1
#define DEFAULT_ASSERT_ENABLE
#endif    

/**********************
// debug printf
**********************/    
/**********************
//<o>Debug Printf Select
//   <0=>No Printf support
//   <1=>UART0
//   <2=>UART1
//   <3=>UART2
**********************/     
#define  USE_MODULE_DBG_PRINTF   0
#if USE_MODULE_DBG_PRINTF
#define _MODULE_DBG_PRINTF
#endif
    

#if USE_MODULE_DBG_PRINTF==1
#define _DBG_DEVICE_UART
#define PTN_DBG_UART            UART0
#endif
#if USE_MODULE_DBG_PRINTF==2
#define _DBG_DEVICE_UART
#define PTN_DBG_UART            UART1
#endif
#if USE_MODULE_DBG_PRINTF==3
#define _DBG_DEVICE_UART
#define PTN_DBG_UART            UART2
#endif

//<e>Workbench Debug Options
//<i>1. See uart options in uart module configuration
//<i>2. Use this feature need including sinodbg_xxx.c and sinodbg_xxx.lib
#define SINODBG_ENABLE 0
#if SINODBG_ENABLE

/**********************
//       <o>Uart Port Select
//             <1=>UART 0
//             <2=>UART 1
//             <3=>UART 2
**********************/     
#define SINODBG_UART_SEL 2


#if SINODBG_UART_SEL==1
#define SINODBG_UART           UART0
#define SINODBG_UART_ISR      UART0_Handler                   
#endif

#if SINODBG_UART_SEL==2
#define SINODBG_UART          UART1
#define SINODBG_UART_ISR      UART1_Handler                   
#endif


#if SINODBG_UART_SEL==3
#define SINODBG_UART          UART2
#define SINODBG_UART_ISR      UART2_Handler                                                                                       
#endif

#define SINODBG_SENDMODE_FUNCCALL  0
#define SINODBG_SENDMODE_INTERRUPT 1
#define SINODBG_SENDMODE_DMA       2
/**********************
// <o>Sendback Data Mode
//     <0=> By Function Call
//     <1=> By Interrupt
***********************/
#define SINODBG_DATA_SEND_MODE     0

/**********************
//<o> Communication Buffer Size
//  <4=>16 Bytes
//  <5=>32 Bytes
//  <6=>64 Bytes
//  <7=>128 Bytes
//  <8=>256 Bytes
//  <9=>512 Bytes
//  <10=>1024 Bytes
**********************/    
#define SINODBG_COMM_BUFFER_MAX_SIZE   6  //4:16 5:32 6:64 7:128 8:256 9:512 10:1024
#define SINODBG_BUFFER_SIZE            (1<<SINODBG_COMM_BUFFER_MAX_SIZE)       

/**********************
//<o> Maximum Variable Count
//  <1=>1 
//  <2=>2 
//  <3=>3 
//  <4=>4 
//  <5=>5 
//  <6=>6 
//  <7=>7 
//  <8=>8 
//  <9=>9 
//  <10=>10 
//  <11=>11 
//  <12=>12 
**********************/    
#define SINODBG_AUTOSEND_MAX_VARS       8

#define SINODBG_CFG_8051       0x0
#define SINODBG_CFG_CORTEXM3   0x1
#define SINODBG_CFG_CORTEXM0   0x2
#define SINODBG_CFG_CORTEXM33  0x3
#define SINODBG_CFG_ARMSTAR    0x4
#define SINODBG_CFG_ICCLASS    4


#endif
/**********************
// </e> Enable Motor Debug Feature
**********************/   
//  </h> debug options

#ifdef __cplusplus
extern "C" {
extern void RetargetInit(void);
}
#else
extern void RetargetInit(void);
#endif

/***********************
//<e>Use Default SystemInit
************************/
#define     USE_DEFAULT_SYSTEMINIT 1
#if USE_DEFAULT_SYSTEMINIT
#define DEFAULT_SYSTEMINIT
#endif


/***********************
//<o> Clock Source  
//    <0=>HSI (8MHz)
//    <1=>HSE       
//    <2=>PLL       
**********************/     
#define     CLK_SRC             2
/*********************
//<o> HSI CLK 
**********************/
#define     HSI_CLK             8000000
/*********************
//<o> HSE CLK 
**********************/
#define     HSE_CLK             8000000
/*********************
//<e> Use PLL
**********************/


#define     PLL_EN              1
/***********************
//<o> PLL Clock Source  
//    <0=>HSI (8MHz)
//    <1=>HSE       
**********************/
#define     PLL_CLK_SRC         0


/*********************
//<q> CLK/2 TO PLL
**********************/
#define     PLL_XTPRE           1
#define PLL_IN PLL_CLK_SRC
/*********************
//<o> PLL MUL
**********************/
#define     PLL_MUL             42
/*********************
//<o> PLL DIV
**********************/
#define     PLL_DIV             1
/*********************
//</e>
**********************/
#if PLL_MUL < 15
#error "PLL MUL Need 15~78"
#endif
#ifdef _SH32F284
#if PLL_MUL > 46
#error "PLL MUL Need 15~46"
#endif
#else
#if PLL_MUL > 78
#error "PLL MUL Need 15~78"
#endif
#endif


#if PLL_DIV < 1
#error "PLL DIV Need 1~8"
#endif


/*********************
//<o>AHB CLOCK (HCLK)
//    <0=>FCLK/1
//    <1=>FCLK/2
//    <2=>FCLK/4
//    <3=>FCLK/8
//    <4=>FCLK/16
//    <5=>FCLK/32
**********************/
#define     CLK_AHB             0


/*********************
//<o>APB0 CLOCK
//    <0=>HCLK/1
//    <1=>HCLK/2
//    <2=>HCLK/4
//    <3=>HCLK/8
//    <4=>HCLK/16
**********************/
#define     CLK_APB0            1


/*********************
//<o>FLASH Latency
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
**********************/
#define     FLASH_LATENCY       2
/*********************
//<q> FLASH Prefetch
**********************/
#define     PREFETCH_EN         1
/*********************
//<q> FLASH Data Cache
**********************/
#define     DCACHE_EN           1


/***********************
//</e>
************************/
#if  (CLK_SRC == 0)
#define CLK_HZ   HSI_CLK
#elif (CLK_SRC == 1)
#define CLK_HZ   HSE_CLK
#else
#if (PLL_EN == 0)
#error ("System Clock Source is PLL, so PLL must enable")
#endif
#if (PLL_CLK_SRC == 0)
#define CLK_HZ   HSI_CLK
#else
#define CLK_HZ   HSE_CLK
#endif
#endif
#if (CLK_SRC == 2)
#define SYS_CLK  (CLK_HZ/(PLL_XTPRE+1) * PLL_MUL / PLL_DIV / 2)/(1<<CLK_AHB)
#else
#define SYS_CLK  CLK_HZ/(1<<CLK_AHB)
#endif
#if SYS_CLK > 35000000  && FLASH_LATENCY < 1
#error ("Flash Latency need >= 1")
#endif
#if SYS_CLK > 70000000  && FLASH_LATENCY < 2
#error ("Flash Latency need >= 2")
#endif
#if SYS_CLK > 110000000  && FLASH_LATENCY < 3
#error ("Flash Latency need >= 3")
#endif
#if SYS_CLK > 150000000  && FLASH_LATENCY < 4
#error ("Flash Latency need >= 4")
#endif
#if SYS_CLK > 180000000  && FLASH_LATENCY < 5
#error ("Flash Latency need >= 5")
#endif


#if (CLK_AHB == 0)
#define AHB_F 1
#elif (CLK_AHB == 1)
#define AHB_F 2
#elif (CLK_AHB == 2)
#define AHB_F 4
#elif (CLK_AHB == 3)
#define AHB_F 8
#elif (CLK_AHB == 4)
#define AHB_F 16
#elif (CLK_AHB == 5)
#define AHB_F 32
#endif
#if (CLK_APB0 == 1)
#define APB_F 2
#elif (CLK_APB0 == 0)
#define APB_F 1
#elif (CLK_APB0 == 2)
#define APB_F 4
#elif (CLK_APB0 == 3)
#define APB_F 8
#elif (CLK_APB0 == 4)
#define APB_F 16
#endif


//<h>NVIC&SysTick
//<e>SysTick
#define     CFG_SYSTICK_EN      0
// <o1>SysTickʼֵ <0-0xFFFFFF>
//<i>Systick counter is a 24 bit counter, and the cycle value shall be reasonably set according to the clock selection
// <o2>SysTickֵ(us) <0-100000000>
//<i>Systick counter is a 24 bit counter, and the cycle value shall be reasonably set according to the clock selection
// <o3>SysTickʱѡ
//    <0=>ⲿοʱHCLK/8
//    <1=>ںʱHCLK
// <q0>SysTickжʹλ
// <q4>SysTickϵʼʱ


#define     CFG_SYSTICK_INT_EN  0
#define     CFG_SYSTICK_VAL_INIT 0
#define     CFG_SYSTICK_RL_VALUE 1000
#define     CFG_SYSTICK_CR_CLK  0
#define     CFG_SYSTICK_START_EN 1
#if CFG_SYSTICK_CR_CLK
#define CFG_SYSTICK_CLK SYS_CLK
#else
#define CFG_SYSTICK_CLK SYS_CLK/8
#endif
#define CFG_SYSTICK_LOAD_INIT (unsigned long)(CFG_SYSTICK_RL_VALUE*(CFG_SYSTICK_CLK/1000000.0))
//</e>


//<o0.8..10>жȼλ
//<i>PRIGROUP ȼвռʽȼ
//<0=>3λռʽȼ, 0λȼ
//<5=>2λռʽȼ, 1λȼ
//<6=>1λռʽȼ, 2λȼ
//<7=>0λռʽȼ, 3λȼ
#define     CFG_SCB_PRIGROUP_INIT 0


//<e>жȼ
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_PRI_EN          0


//<o0.5..7>PRI_4 洢 fault ȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_SCB_SHP4_INIT   0


//<o0.5..7>PRI_5  fault ȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_SCB_SHP5_INIT   0


//<o0.5..7>PRI_6 ÷ fault ȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_SCB_SHP6_INIT   0


//<o0.5..7>PRI_11 SVC ȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ


#define     CFG_SCB_SHP11_INIT  0


//<o0.5..7>PRI_12 Լȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_SCB_SHP12_INIT  0


//<o0.5..7>PRI_14 PendSV ȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_SCB_SHP14_INIT  0


//<o0.5..7>PRI_15 SysTick ȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_SCB_SHP15_INIT  0
                                           

//<o0.5..7>HWINT_0 WWDTжϵȼ <0-7>  
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP0_INIT   0


//<o0.5..7>HWINT_1 BODжϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP1_INIT   0


//<o0.5..7>HWINT_2 RCCжϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP2_INIT   0


//<o0.5..7>HWINT_3 EXTI0жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP3_INIT   0


//<o0.5..7>HWINT_4 EXTI1жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP4_INIT   0


//<o0.5..7>HWINT_5 EXTI2жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP5_INIT   0


//<o0.5..7>HWINT_6 EXTI3жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP6_INIT   0


//<o0.5..7>HWINT_7 MCM_FLTжϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP7_INIT   0


//<o0.5..7>HWINT_8 MCM_PWMжϵȼ <0-7>
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP8_INIT   0


//<o0.5..7>HWINT_9 ADCжϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP9_INIT   0


//<o0.5..7>HWINT_10 PCA0жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP10_INIT  0


//<o0.5..7>HWINT_11 PCA1жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP11_INIT  0


//<o0.5..7>HWINT_12 PCA0_FLTжϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP12_INIT  0


//<o0.5..7>HWINT_13 PCA1_FLTжϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP13_INIT  0


//<o0.5..7>HWINT_14 CMP0жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP14_INIT  0


//<o0.5..7>HWINT_15 CMP1жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP15_INIT  0
//<o0.5..7>HWINT_16 QEIжϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP16_INIT  0


//<o0.5..7>HWINT_17 CANжϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP17_INIT  0


//<o0.5..7>HWINT_18 TWIжϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP18_INIT  0


//<o0.5..7>HWINT_19 SPIжϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP19_INIT  0


//<o0.5..7>HWINT_20 UART0жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP20_INIT  0


//<o0.5..7>HWINT_21 UART1жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP21_INIT  0


//<o0.5..7>HWINT_22 UART2жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP22_INIT  0


//<o0.5..7>HWINT_23 TIM7жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP23_INIT  0


//<o0.5..7>HWINT_24 TIM8жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP24_INIT  0


//<o0.5..7>HWINT_25 EXIT4_7жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP25_INIT  0


//<o0.5..7>HWINT_26 FIFO0жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP26_INIT  0


//<o0.5..7>HWINT_27 FIFO1жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP27_INIT  0


//<o0.5..7>HWINT_28 FIFO2жϵȼ <0-7> 
//<i>3BitȼΧ0-7
//<i>ѡ3λռʽȼ, 0λȼ3Bitݱʾ8ռȼ
//<i>2λռʽȼ, 1λȼ2Bitݱʾ4ռȼ1bitʾ2ȼ
//<i>1λռʽȼ, 2λȼ1Bitݱʾ2ռȼ2bitʾ4ȼ
//<i>0λռʽȼ, 3λȼ3bitʾ8ȼ
#define     CFG_NVIC_IP28_INIT  0
//</e>
//</h>

//<e>SYS_CFG
#define     CFG_SYSCFG_EN       0
//<h>PWRCR
//<q0.9>LVREN: Low Voltage Reset Enable
//<O0.8>LVR Level
//   <0=>4.1V
//   <1=>2.8V
//<q0.7>BODEN: Brownout Detection Enable
//<q0.6>BODIE: BOD Interrupt Enable
//<o0.4..5>BOD mode selection
//    <0=>Rising exceeds threshold
//    <1=>Falling exceeds threshold
//    <2=>Both
//<o0.0..3>BOD Voltage Selection
//    <0=>2.8V
//    <1=>2.9V
//    <2=>3.0V
//    <3=>3.1V
//    <4=>3.2V
//    <5=>3.3V
//    <6=>3.4V
//    <7=>3.5V
//    <8=>3.6V
//    <9=>3.7V
//    <10=>3.8V
//    <11=>3.9V
//    <12=>4.0V
//    <13=>4.1V
//    <14=>4.2V
//    <15=>4.3V
//</h>
#define     CFG_SYSCFG_PWRCR_INIT 0
//<h>SAFR
//<o0.0..1>OSCCFG:XTAL1/XTAL2 Port Function
//   <0=>XTAL1/XTAL2 use as GPIO
//   <1=>XTAL1/XTAL2 use as crystal input
//   <2=>XTAL1 use as clock input, XTAL2 use as GPIO  
//<o0.2>Emulation Port Fuction
//     <0=>SW support
//     <1=>SWIO/SWCLK use as GPIO
//<q0.5>EXTI0 Trigger NMI Enable
//<q0.6>BOD Trigger NMI Enable
//<q0.7>CSM Trigger NMI Enable
//</h>
#define     CFG_SYSCFG_SAFR_INIT 0
//<h>DBGCR
//<q0.15>TWI running even if the core is halted
//<q0.14>SPI running even if the core is halted
//<q0.13>UART running even if the core is halted
//<q0.12>MCM running even if the core is halted
//<q0.11>TIM running even if the core is halted
//<q0.10>PCA running even if the core is halted
//<q0.9>WWDT running even if the core is halted
//<q0.8>IWDT running even if the core is halted
//<q0.7>QEI running even if the core is halted
//<q0.6>CAN running even if the core is halted
//</h>
#define     CFG_SYSCFG_DBGCR_INIT 0
//***********************************************************/
//</e>

//<e>IWDT
#define     CFG_IWDT_EN         0
// <q0.15> IWDTON_Źʹ
//    <i>0:
//    <i>1:IWDT
//<i>CR_ŹƼĴ
//<i>0x000 b31~16 b15    b14~12 b11~0   
//<i>CR    LOCK   IWDTON IWDTPR IWDTRLR 
//<i>˿λֻOP_IWDT=0101bʱЧ
//<i>˿λĿͨOptionرտŹͨʽ򿪡
//<i>λá1Ӳڸλ塯0
// <o0.0..11> IWDTRLR_ŹؼĴ<0-4096>
//    ڶ忴Źװֵ 
#define     CFG_IWDTRLR_INIT    4095
// <o0.12..14> IWDTPR_Źʱ
//<0=>ֵ128ms
//<1=>ֵ256ms
//<2=>ֵ512ms
//<3=>ֵ1.024s (Ĭ)
//<4=>ֵ2.048s
//<5=>ֵ4.096s 
//<6=>ֵ8.192s
//<7=>ֵ16.384s
//<i>IWDTPR[2:0]ϵĬֵ011b
#define     CFG_IWDTPR_INIT     12288


//***********************************************************/
//</e>


//<e>WWDT
#define     CFG_WWDT_EN         0
//<i>CR_ڿŹƼĴ
//<i>0x000 b31~16 b15    b14    b13~11 b10~8  b7~0    
//<i>CR    LOCK   WWDTON WWDTIE -      WWDTPR WWDTRLR 
      

//<i>WTR_ڿŹڼĴ
//<i>0x00C b31~16 b15~8 b7~0    
//<i>WTR   LOCK   -     WWDTWTR 
// <q0.15> WWDTON_ڿŹʹ
//    <i>0: ֹWWDT
//    <i>1: WWDT
//<i>λá1Ӳڸλ塯0
// <o0.0..7> WWDTRLR_ڿŹؼĴ<0-255>
//    ڶ忴Źװֵ
// <o0.8..10> WWDTPR_ڿŹʱԤƵ
//    <0=>ԤƵ=1x256
//    <1=>ԤƵ=2x256
//    <2=>ԤƵ=4x256
//    <3=>ԤƵ=8x256
//    <4=>ԤƵ=16x256
//    <5=>ԤƵ=32x256
//    <6=>ԤƵ=64x256
//    <7=>ԤƵ=128x256
// <q0.14> WWDTIE_ڿŹιжʹ
//    <i>0: ֹWWDTж
//    <i>1: WWDTж


#define     CFG_WWDT_CR_INIT    255


#if ((CFG_WWDT_CR_INIT & (1<<14)) != 0)
	#define CFG_WWDT_INT_EN 1
#else
	#define CFG_WWDT_INT_EN 0
#endif


// <o0.0..7> WWDTWTR_ڿŹֵĴ<0-255>
//    ڶ忴ŹĴֵ
//    üĴдֻLOCKλΪ0x5AA5ʱд룬ơ
#define     CFG_WWDT_WTR_INIT   255
//***********************************************************/
//</e>
//<e>GPIO
#define     CFG_GPIO_EN         0


//<e>GPIOA  
#define     CFG_GPIOA_EN        1


// <h> Pin0  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA0_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA0_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA0_ODR         0


// <o> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
#define     CFG_PA0_OT          0


// <q> IE_˿ʹλ
#define     CFG_PA0_IE          1


// <o> TTLEN_˿TTLƽѡĴ
//    <0=>ѡCMOS루λ״̬
//    <1=>ѡTTL
#define     CFG_PA0_TTLEN       0


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA0_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA0_LOCK        0
// </h>


// <h> Pin1  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA1_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA1_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA1_ODR         0
// <q> IE_˿ʹλ
#define     CFG_PA1_IE          1
// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA1_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA1_LOCK        0
// </h>


// <h> Pin2  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA2_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA2_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA2_ODR         0


// <o> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
#define     CFG_PA2_OT          0


// <q> IE_˿ʹλ
#define     CFG_PA2_IE          1


// <o> TTLEN_˿TTLƽѡĴ
//    <0=>ѡCMOS루λ״̬
//    <1=>ѡTTL
#define     CFG_PA2_TTLEN       0


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA2_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA2_LOCK        0
// </h>


// <h> Pin3  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA3_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA3_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA3_ODR         0
// <q> IE_˿ʹλ
#define     CFG_PA3_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA3_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA3_LOCK        0
// </h>


// <h> Pin4  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA4_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA4_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA4_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PA4_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA4_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA4_LOCK        0
// </h>


// <h> Pin5  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA5_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA5_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA5_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PA5_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA5_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA5_LOCK        0
// </h>


// <h> Pin6  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA6_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA6_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA6_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PA6_IE          1


// <o> TTLEN_˿TTLƽѡĴ
//    <0=>ѡCMOS루λ״̬
//    <1=>ѡTTL
#define     CFG_PA6_TTLEN       0


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA6_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA6_LOCK        0
// </h>


// <h> Pin7 
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA7_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA7_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA7_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PA7_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA7_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA7_LOCK        0
// </h>


// <h> Pin8  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA8_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA8_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA8_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PA8_IE          1
// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA8_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA8_LOCK        0
// </h>


// <h> Pin9  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA9_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA9_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA9_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PA9_IE          1
// <o> TTLEN_˿TTLƽѡĴ
//    <0=>ѡCMOS루λ״̬
//    <1=>ѡTTL
#define     CFG_PA9_TTLEN       0


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA9_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA9_LOCK        0
// </h>


// <h> Pin10  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA10_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA10_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA10_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PA10_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA10_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA10_LOCK       0
// </h>


// <h> Pin11  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA11_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA11_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA11_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PA11_IE         1


// <o> TTLEN_˿TTLƽѡĴ
//    <0=>ѡCMOS루λ״̬
//    <1=>ѡTTL
#define     CFG_PA11_TTLEN      0


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA11_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA11_LOCK       0
// </h>


// <h> Pin12  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA12_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA12_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA12_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PA12_IE         1


// <o> TTLEN_˿TTLƽѡĴ
//    <0=>ѡCMOS루λ״̬
//    <1=>ѡTTL
#define     CFG_PA12_TTLEN      0


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA12_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA12_LOCK       0
// </h>


// <h> Pin13  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA13_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA13_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA13_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PA13_IE         1
// <o> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
#define     CFG_PA13_OT         0


// <o> TTLEN_˿TTLƽѡĴ
//    <0=>ѡCMOS루λ״̬
//    <1=>ѡTTL
#define     CFG_PA13_TTLEN      0


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA13_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA13_LOCK       0
// </h>


// <h> Pin14  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA14_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA14_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA14_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PA14_IE         1


// <o> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
#define     CFG_PA14_OT         0
// <o> TTLEN_˿TTLƽѡĴ
//    <0=>ѡCMOS루λ״̬
//    <1=>ѡTTL
#define     CFG_PA14_TTLEN      0


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA14_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA14_LOCK       0
// </h>


// <h> Pin15  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PA15_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PA15_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PA15_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PA15_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PA15_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PA15_LOCK       0
// </h>
//</e>


#define CFG_GPIO_OTYPER_A_INIT     (((uint32_t)CFG_PA14_OT<<14)\
                                      |(CFG_PA13_OT<<13)\
																		  |(CFG_PA2_OT<<2)\
																		  | CFG_PA0_OT)

#define CFG_GPIO_TTLEN_A_INIT     	(((uint32_t)CFG_PA14_TTLEN<<14)\
																		|(CFG_PA13_TTLEN<<13)\
																		|(CFG_PA12_TTLEN<<12)\
																		|(CFG_PA11_TTLEN<<11)\
																		|(CFG_PA9_TTLEN<<9)\
																		|(CFG_PA6_TTLEN<<6)\
																		|(CFG_PA2_TTLEN<<2)\
																		|(CFG_PA0_TTLEN<<0))

#define CFG_GPIO_IE_A_INIT     	(((uint32_t)CFG_PA15_IE<<15)\
																		|(CFG_PA14_IE<<14)\
																		|(CFG_PA13_IE<<13)\
																		|(CFG_PA12_IE<<12)\
																		|(CFG_PA11_IE<<11)\
																		|(CFG_PA10_IE<<10)\
																		|(CFG_PA9_IE<<9)\
																		|(CFG_PA8_IE<<8)\
																		|(CFG_PA7_IE<<7)\
																		|(CFG_PA6_IE<<6)\
																		|(CFG_PA5_IE<<5)\
																		|(CFG_PA4_IE<<4)\
																		|(CFG_PA3_IE<<3)\
																		|(CFG_PA2_IE<<2)\
																		|(CFG_PA1_IE<<1)\
																		|CFG_PA0_IE)
																		

#define CFG_GPIO_PUPDR_A_INIT     	(((uint32_t)CFG_PA15_PUPDR<<30)\
																		|(CFG_PA14_PUPDR<<28)\
																		|(CFG_PA13_PUPDR<<26)\
																		|(CFG_PA12_PUPDR<<24)\
																		|(CFG_PA11_PUPDR<<22)\
																		|(CFG_PA10_PUPDR<<20)\
																		|(CFG_PA9_PUPDR<<18)\
																		|(CFG_PA8_PUPDR<<16)\
																		|(CFG_PA7_PUPDR<<14)\
																		|(CFG_PA6_PUPDR<<12)\
																		|(CFG_PA5_PUPDR<<10)\
																		|(CFG_PA4_PUPDR<<8)\
																		|(CFG_PA3_PUPDR<<6)\
																		|(CFG_PA2_PUPDR<<4)\
																		|(CFG_PA1_PUPDR<<2)\
																		|CFG_PA0_PUPDR)
																		

#define CFG_GPIO_AFRH_A_INIT     		(((uint32_t)CFG_PA15_AFR<<28)\
																		|(CFG_PA14_AFR<<24)\
																		|(CFG_PA13_AFR<<20)\
																		|(CFG_PA12_AFR<<16)\
																		|(CFG_PA11_AFR<<12)\
																		|(CFG_PA10_AFR<<8)\
																		|(CFG_PA9_AFR<<4)\
																		|CFG_PA8_AFR)
															

#define CFG_GPIO_AFRL_A_INIT				(((uint32_t)CFG_PA7_AFR<<28)\
																		|(CFG_PA6_AFR<<24)\
																		|(CFG_PA5_AFR<<20)\
																		|(CFG_PA4_AFR<<16)\
																		|(CFG_PA3_AFR<<12)\
																		|(CFG_PA2_AFR<<8)\
																		|(CFG_PA1_AFR<<4)\
																		|CFG_PA0_AFR)																		
																		

#define CFG_GPIO_ODR_A_INIT         (((uint32_t)CFG_PA15_ODR<<15)\
																		|(CFG_PA14_ODR<<14)\
																		|(CFG_PA13_ODR<<13)\
																		|(CFG_PA12_ODR<<12)\
																		|(CFG_PA11_ODR<<11)\
																		|(CFG_PA10_ODR<<10)\
																		|(CFG_PA9_ODR<<9)\
																		|(CFG_PA8_ODR<<8)\
																		|(CFG_PA7_ODR<<7)\
																		|(CFG_PA6_ODR<<6)\
																		|(CFG_PA5_ODR<<5)\
																		|(CFG_PA4_ODR<<4)\
																		|(CFG_PA3_ODR<<3)\
																		|(CFG_PA2_ODR<<2)\
																		|(CFG_PA1_ODR<<1)\
																		|CFG_PA0_ODR)																		
																		

#define CFG_GPIO_MODER_A_INIT     	(((uint32_t)CFG_PA15_MODER<<15)\
																		|(CFG_PA14_MODER<<14)\
																		|(CFG_PA13_MODER<<13)\
																		|(CFG_PA12_MODER<<12)\
																		|(CFG_PA11_MODER<<11)\
																		|(CFG_PA10_MODER<<10)\
																		|(CFG_PA9_MODER<<9)\
																		|(CFG_PA8_MODER<<8)\
																		|(CFG_PA7_MODER<<7)\
																		|(CFG_PA6_MODER<<6)\
																		|(CFG_PA5_MODER<<5)\
																		|(CFG_PA4_MODER<<4)\
																		|(CFG_PA3_MODER<<3)\
																		|(CFG_PA2_MODER<<2)\
																		|(CFG_PA1_MODER<<1)\
																		|CFG_PA0_MODER)	
																		


#define CFG_GPIO_LCKR_A_INIT     	  (((uint32_t)CFG_PA15_LOCK<<15)\
																		|(CFG_PA14_LOCK<<14)\
																		|(CFG_PA13_LOCK<<13)\
																		|(CFG_PA12_LOCK<<12)\
																		|(CFG_PA11_LOCK<<11)\
																		|(CFG_PA10_LOCK<<10)\
																		|(CFG_PA9_LOCK<<9)\
																		|(CFG_PA8_LOCK<<8)\
																		|(CFG_PA7_LOCK<<7)\
																		|(CFG_PA6_LOCK<<6)\
																		|(CFG_PA5_LOCK<<5)\
																		|(CFG_PA4_LOCK<<4)\
																		|(CFG_PA3_LOCK<<3)\
																		|(CFG_PA2_LOCK<<2)\
																		|(CFG_PA1_LOCK<<1)\
																		|CFG_PA0_LOCK)	
																		

//<e>GPIOB  
#define     CFG_GPIOB_EN        0


// <h> Pin0  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB0_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB0_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB0_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PB0_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB0_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB0_LOCK        0
// </h>


// <h> Pin1  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB1_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB1_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB1_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PB1_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB1_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB1_LOCK        0
// </h>


// <h> Pin2  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB2_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB2_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB2_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PB2_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB2_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB2_LOCK        0
// </h>


// <h> Pin3  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB3_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB3_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB3_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PB3_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB3_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB3_LOCK        0
// </h>


// <h> Pin4  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB4_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB4_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB4_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PB4_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB4_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB4_LOCK        0
// </h>


// <h> Pin5  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB5_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB5_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB5_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PB5_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB5_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB5_LOCK        0
// </h>


// <h> Pin6  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB6_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB6_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB6_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PB6_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB6_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB6_LOCK        0
// </h>


// <h> Pin7 
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB7_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB7_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB7_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PB7_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB7_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB7_LOCK        0
// </h>


// <h> Pin8  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB8_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB8_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB8_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PB8_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB8_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB8_LOCK        0
// </h>


// <h> Pin9  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB9_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB9_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB9_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PB9_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB9_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB9_LOCK        0
// </h>


// <h> Pin10  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB10_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB10_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB10_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PB10_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB10_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB10_LOCK       0
// </h>


// <h> Pin11  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB11_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB11_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB11_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PB11_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB11_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB11_LOCK       0
// </h>


// <h> Pin12  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB12_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB12_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB12_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PB12_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB12_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB12_LOCK       0
// </h>


// <h> Pin13  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB13_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB13_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB13_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PB13_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB13_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB13_LOCK       0
// </h>


// <h> Pin14  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB14_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB14_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB14_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PB14_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB14_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB14_LOCK       0
// </h>


// <h> Pin15  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PB15_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PB15_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PB15_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PB15_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PB15_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PB15_LOCK       0
// </h>
//</e>


																	

#define CFG_GPIO_IE_B_INIT     	(((uint32_t)CFG_PB15_IE<<15)\
																		|(CFG_PB14_IE<<14)\
																		|(CFG_PB13_IE<<13)\
																		|(CFG_PB12_IE<<12)\
																		|(CFG_PB11_IE<<11)\
																		|(CFG_PB10_IE<<10)\
																		|(CFG_PB9_IE<<9)\
																		|(CFG_PB8_IE<<8)\
																		|(CFG_PB7_IE<<7)\
																		|(CFG_PB6_IE<<6)\
																		|(CFG_PB5_IE<<5)\
																		|(CFG_PB4_IE<<4)\
																		|(CFG_PB3_IE<<3)\
																		|(CFG_PB2_IE<<2)\
																		|(CFG_PB1_IE<<1)\
																		|CFG_PB0_IE)
																		

#define CFG_GPIO_PUPDR_B_INIT     	(((uint32_t)CFG_PB15_PUPDR<<30)\
																		|(CFG_PB14_PUPDR<<28)\
																		|(CFG_PB13_PUPDR<<26)\
																		|(CFG_PB12_PUPDR<<24)\
																		|(CFG_PB11_PUPDR<<22)\
																		|(CFG_PB10_PUPDR<<20)\
																		|(CFG_PB9_PUPDR<<18)\
																		|(CFG_PB8_PUPDR<<16)\
																		|(CFG_PB7_PUPDR<<14)\
																		|(CFG_PB6_PUPDR<<12)\
																		|(CFG_PB5_PUPDR<<10)\
																		|(CFG_PB4_PUPDR<<8)\
																		|(CFG_PB3_PUPDR<<6)\
																		|(CFG_PB2_PUPDR<<4)\
																		|(CFG_PB1_PUPDR<<2)\
																		|CFG_PB0_PUPDR)
																		

#define CFG_GPIO_AFRH_B_INIT     		(((uint32_t)CFG_PB15_AFR<<28)\
																		|(CFG_PB14_AFR<<24)\
																		|(CFG_PB13_AFR<<20)\
																		|(CFG_PB12_AFR<<16)\
																		|(CFG_PB11_AFR<<12)\
																		|(CFG_PB10_AFR<<8)\
																		|(CFG_PB9_AFR<<4)\
																		|CFG_PB8_AFR)
															

#define CFG_GPIO_AFRL_B_INIT				(((uint32_t)CFG_PB7_AFR<<28)\
																		|(CFG_PB6_AFR<<24)\
																		|(CFG_PB5_AFR<<20)\
																		|(CFG_PB4_AFR<<16)\
																		|(CFG_PB3_AFR<<12)\
																		|(CFG_PB2_AFR<<8)\
																		|(CFG_PB1_AFR<<4)\
																		|CFG_PB0_AFR)																		
																		

#define CFG_GPIO_ODR_B_INIT         (((uint32_t)CFG_PB15_ODR<<15)\
																		|(CFG_PB14_ODR<<14)\
																		|(CFG_PB13_ODR<<13)\
																		|(CFG_PB12_ODR<<12)\
																		|(CFG_PB11_ODR<<11)\
																		|(CFG_PB10_ODR<<10)\
																		|(CFG_PB9_ODR<<9)\
																		|(CFG_PB8_ODR<<8)\
																		|(CFG_PB7_ODR<<7)\
																		|(CFG_PB6_ODR<<6)\
																		|(CFG_PB5_ODR<<5)\
																		|(CFG_PB4_ODR<<4)\
																		|(CFG_PB3_ODR<<3)\
																		|(CFG_PB2_ODR<<2)\
																		|(CFG_PB1_ODR<<1)\
																		|CFG_PB0_ODR)																		
																		

#define CFG_GPIO_MODER_B_INIT     	(((uint32_t)CFG_PB15_MODER<<15)\
																		|(CFG_PB14_MODER<<14)\
																		|(CFG_PB13_MODER<<13)\
																		|(CFG_PB12_MODER<<12)\
																		|(CFG_PB11_MODER<<11)\
																		|(CFG_PB10_MODER<<10)\
																		|(CFG_PB9_MODER<<9)\
																		|(CFG_PB8_MODER<<8)\
																		|(CFG_PB7_MODER<<7)\
																		|(CFG_PB6_MODER<<6)\
																		|(CFG_PB5_MODER<<5)\
																		|(CFG_PB4_MODER<<4)\
																		|(CFG_PB3_MODER<<3)\
																		|(CFG_PB2_MODER<<2)\
																		|(CFG_PB1_MODER<<1)\
																		|CFG_PB0_MODER)	


#define CFG_GPIO_LCKR_B_INIT     	  (((uint32_t)CFG_PB15_LOCK<<15)\
																		|(CFG_PB14_LOCK<<14)\
																		|(CFG_PB13_LOCK<<13)\
																		|(CFG_PB12_LOCK<<12)\
																		|(CFG_PB11_LOCK<<11)\
																		|(CFG_PB10_LOCK<<10)\
																		|(CFG_PB9_LOCK<<9)\
																		|(CFG_PB8_LOCK<<8)\
																		|(CFG_PB7_LOCK<<7)\
																		|(CFG_PB6_LOCK<<6)\
																		|(CFG_PB5_LOCK<<5)\
																		|(CFG_PB4_LOCK<<4)\
																		|(CFG_PB3_LOCK<<3)\
																		|(CFG_PB2_LOCK<<2)\
																		|(CFG_PB1_LOCK<<1)\
																		|CFG_PB0_LOCK)	
																		

//<e>GPIOC  
#define     CFG_GPIOC_EN        0


// <h> Pin0  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC0_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC0_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC0_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PC0_IE          1


// <o> TTLEN_˿TTLƽѡĴ
//    <0=>ѡCMOS루λ״̬
//    <1=>ѡTTL
#define     CFG_PC0_TTLEN       0


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC0_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC0_LOCK        0
// </h>


// <h> Pin1  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC1_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC1_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC1_ODR         0


// <o> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
#define     CFG_PC1_OT          0


// <q> IE_˿ʹλ
#define     CFG_PC1_IE          1
// <o> TTLEN_˿TTLƽѡĴ
//    <0=>ѡCMOS루λ״̬
//    <1=>ѡTTL
#define     CFG_PC1_TTLEN       0


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC1_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC1_LOCK        0
// </h>


// <h> Pin2  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC2_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC2_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC2_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PC2_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC2_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC2_LOCK        0
// </h>


// <h> Pin3  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC3_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC3_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC3_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PC3_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC3_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC3_LOCK        0
// </h>


// <h> Pin4  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC4_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC4_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC4_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PC4_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC4_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC4_LOCK        0
// </h>


// <h> Pin5  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC5_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC5_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC5_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PC5_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC5_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC5_LOCK        0
// </h>


// <h> Pin6  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC6_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC6_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC6_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PC6_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC6_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC6_LOCK        0
// </h>


// <h> Pin7 
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC7_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC7_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC7_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PC7_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC7_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC7_LOCK        0
// </h>


// <h> Pin8  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC8_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC8_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC8_ODR         0


// <q> IE_˿ʹλ
#define     CFG_PC8_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC8_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC8_LOCK        0
// </h>


// <h> Pin9  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC9_AFR         0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC9_MODER       0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC9_ODR         0


// <o> OT_˿ʽ
//    <0=>λ״̬
//    <1=>©
#define     CFG_PC9_OT          0


// <q> IE_˿ʹλ
#define     CFG_PC9_IE          1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC9_PUPDR       0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC9_LOCK        0
// </h>


// <h> Pin10  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC10_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC10_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC10_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PC10_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC10_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC10_LOCK       0
// </h>


// <h> Pin11  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC11_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC11_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC11_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PC11_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC11_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC11_LOCK       0
// </h>


// <h> Pin12  
// <o> AFR_˿ڸùѡλ
//    AFRѡ:
//    <0=>AF0_Closed
//    <1=>AF1_GPIO
//    <2=>AF2_MCM
//    <3=>AF3_PCA_TIM7_TIM8
//    <4=>AF4_UART
//    <5=>AF5_SPI_TWI
//    <6=>AF6_CAN_CMP_QEI
//    <7=>AF7_Analog
#define     CFG_PC12_AFR        0


// <o> MODER_˿ģʽ
//    <0=>
//    <1=> 
#define     CFG_PC12_MODER      0


// <o> ODR_˿ƽ
//    <0=>͵ƽ
//    <1=>ߵƽ
#define     CFG_PC12_ODR        0


// <q> IE_˿ʹλ
#define     CFG_PC12_IE         1


// <o> PUPDR_˿
//    <0=>λ״̬
//    <1=>
#define     CFG_PC12_PUPDR      0


// <q> LCKy_˿λ
//    <0=>˿λδ
//    <1=>˿λ
#define     CFG_PC12_LOCK       0
// </h>
//</e>


#define CFG_GPIO_OTYPER_C_INIT     (((uint32_t)CFG_PC1_OT<<1)\
																		|CFG_PC0_OT)
																	

#define CFG_GPIO_IE_C_INIT     	(((uint32_t)CFG_PC12_IE<<12)\
																		|(CFG_PC11_IE<<11)\
																		|(CFG_PC10_IE<<10)\
																		|(CFG_PC9_IE<<9)\
																		|(CFG_PC8_IE<<8)\
																		|(CFG_PC7_IE<<7)\
																		|(CFG_PC6_IE<<6)\
																		|(CFG_PC5_IE<<5)\
																		|(CFG_PC4_IE<<4)\
																		|(CFG_PC3_IE<<3)\
																		|(CFG_PC2_IE<<2)\
																		|(CFG_PC1_IE<<1)\
																		|CFG_PC0_IE)
																		

#define CFG_GPIO_PUPDR_C_INIT     	(((uint32_t)CFG_PC12_PUPDR<<24)\
																		|(CFG_PC11_PUPDR<<22)\
																		|(CFG_PC10_PUPDR<<20)\
																		|(CFG_PC9_PUPDR<<18)\
																		|(CFG_PC8_PUPDR<<16)\
																		|(CFG_PC7_PUPDR<<14)\
																		|(CFG_PC6_PUPDR<<12)\
																		|(CFG_PC5_PUPDR<<10)\
																		|(CFG_PC4_PUPDR<<8)\
																		|(CFG_PC3_PUPDR<<6)\
																		|(CFG_PC2_PUPDR<<4)\
																		|(CFG_PC1_PUPDR<<2)\
																		|CFG_PC0_PUPDR)
																		

#define CFG_GPIO_AFRH_C_INIT     		(((uint32_t)CFG_PC12_AFR<<16)\
																		|(CFG_PC11_AFR<<12)\
																		|(CFG_PC10_AFR<<8)\
																		|(CFG_PC9_AFR<<4)\
																		|CFG_PC8_AFR)
															

#define CFG_GPIO_AFRL_C_INIT				(((uint32_t)CFG_PC7_AFR<<28)\
																		|(CFG_PC6_AFR<<24)\
																		|(CFG_PC5_AFR<<20)\
																		|(CFG_PC4_AFR<<16)\
																		|(CFG_PC3_AFR<<12)\
																		|(CFG_PC2_AFR<<8)\
																		|(CFG_PC1_AFR<<4)\
																		|CFG_PC0_AFR)																		
																		

#define CFG_GPIO_ODR_C_INIT         (((uint32_t)CFG_PC12_ODR<<12)\
																		|(CFG_PC11_ODR<<11)\
																		|(CFG_PC10_ODR<<10)\
																		|(CFG_PC9_ODR<<9)\
																		|(CFG_PC8_ODR<<8)\
																		|(CFG_PC7_ODR<<7)\
																		|(CFG_PC6_ODR<<6)\
																		|(CFG_PC5_ODR<<5)\
																		|(CFG_PC4_ODR<<4)\
																		|(CFG_PC3_ODR<<3)\
																		|(CFG_PC2_ODR<<2)\
																		|(CFG_PC1_ODR<<1)\
																		|CFG_PC0_ODR)																		
																		

#define CFG_GPIO_MODER_C_INIT     	(((uint32_t)CFG_PC12_MODER<<12)\
																		|(CFG_PC11_MODER<<11)\
																		|(CFG_PC10_MODER<<10)\
																		|(CFG_PC9_MODER<<9)\
																		|(CFG_PC8_MODER<<8)\
																		|(CFG_PC7_MODER<<7)\
																		|(CFG_PC6_MODER<<6)\
																		|(CFG_PC5_MODER<<5)\
																		|(CFG_PC4_MODER<<4)\
																		|(CFG_PC3_MODER<<3)\
																		|(CFG_PC2_MODER<<2)\
																		|(CFG_PC1_MODER<<1)\
																		|CFG_PC0_MODER)	


#define CFG_GPIO_LCKR_C_INIT     	  (((uint32_t)CFG_PC12_LOCK<<12)\
																		|(CFG_PC11_LOCK<<11)\
																		|(CFG_PC10_LOCK<<10)\
																		|(CFG_PC9_LOCK<<9)\
																		|(CFG_PC8_LOCK<<8)\
																		|(CFG_PC7_LOCK<<7)\
																		|(CFG_PC6_LOCK<<6)\
																		|(CFG_PC5_LOCK<<5)\
																		|(CFG_PC4_LOCK<<4)\
																		|(CFG_PC3_LOCK<<3)\
																		|(CFG_PC2_LOCK<<2)\
																		|(CFG_PC1_LOCK<<1)\
																		|CFG_PC0_LOCK)	


#define CFG_GPIO_TTLEN_C_INIT     	(((uint32_t)CFG_PC1_TTLEN<<1)\
																		|(CFG_PC0_TTLEN<<0))	

//</e>	


																	

//<e>EXTI
#define     CFG_EXTI_EN         0
//<e7>EXTI0
// <q0> IMR0_EXTI0ϵж
//     <i>0: yϵж
//     <i>1: yϵж
// <q1> EMR0_EXTI0ϵ¼
//     <i>0: yϵ¼
//     <i>1: yϵ¼
// <o2> TMR0_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR0_EXTI0ϵ/ߵƽжϺ¼
//     <i>0: ֹyϵ/ߵƽ(жϺ¼)
//     <i>1: yϵ/ߵƽ(жϺ¼)
// <q4> FTR0_EXTI0ϵ½/͵ƽжϺ¼
//     <i>0: ֹyϵ½/͵ƽ(жϺ¼)
//     <i>1: yϵ½/͵ƽ(жϺ¼)
// <o5> PS0_EXTI0ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o6> SN0_EXTI0ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
//</e>
#define     CFG_EXTI0_IMR_BIT   0
#define     CFG_EXTI0_EMR_BIT   0
#define     CFG_EXTI0_TMR_BIT   0
#define     CFG_EXTI0_RTR_BIT   0
#define     CFG_EXTI0_FTR_BIT   0
#define     CFG_EXTI0_PS_BIT    0
#define     CFG_EXTI0_SN_BIT    0
#define     CFG_EXTI0_EN        0


//<e7>EXTI1
// <q0> IMR1_EXTI1ϵж
//     <i>0: yϵж
//     <i>1: yϵж
// <q1> EMR1_EXTI1ϵ¼
//     <i>0: yϵ¼
//     <i>1: yϵ¼
// <o2> TMR1_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR1_EXTI1ϵ/ߵƽжϺ¼
//     <i>0: ֹyϵ/ߵƽ(жϺ¼)
//     <i>1: yϵ/ߵƽ(жϺ¼)
// <q4> FTR1_EXTI1ϵ½/͵ƽжϺ¼
//     <i>0: ֹyϵ½/͵ƽ(жϺ¼)
//     <i>1: yϵ½/͵ƽ(жϺ¼)
// <o5> PS1_EXTI1ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o6> SN1_EXTI1ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
//</e>
#define     CFG_EXTI1_IMR_BIT   0
#define     CFG_EXTI1_EMR_BIT   0
#define     CFG_EXTI1_TMR_BIT   0
#define     CFG_EXTI1_RTR_BIT   0
#define     CFG_EXTI1_FTR_BIT   0
#define     CFG_EXTI1_PS_BIT    0
#define     CFG_EXTI1_SN_BIT    0
#define     CFG_EXTI1_EN        0
//<e7>EXTI2
// <q0> IMR2_EXTI2ϵж
//     <i>0: yϵж
//     <i>1: yϵж
// <q1> EMR2_EXTI2ϵ¼
//     <i>0: yϵ¼
//     <i>1: yϵ¼
// <o2> TMR2_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//<i>شΪone-shotʽͨclear pending flag־λ
//<i>ƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR2_EXTI2ϵ/ߵƽжϺ¼
//     <i>0: ֹyϵ/ߵƽ(жϺ¼)
//     <i>1: yϵ/ߵƽ(жϺ¼)
// <q4> FTR2_EXTI2ϵ½/͵ƽжϺ¼
//     <i>0: ֹyϵ½/͵ƽ(жϺ¼)
//     <i>1: yϵ½/͵ƽ(жϺ¼)
// <o5> PS2_EXTI2ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o6> SN2_EXTI2ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
//</e>
#define     CFG_EXTI2_IMR_BIT   0
#define     CFG_EXTI2_EMR_BIT   0
#define     CFG_EXTI2_TMR_BIT   0
#define     CFG_EXTI2_RTR_BIT   0
#define     CFG_EXTI2_FTR_BIT   0
#define     CFG_EXTI2_PS_BIT    0
#define     CFG_EXTI2_SN_BIT    0
#define     CFG_EXTI2_EN        0
//<e7>EXTI3
// <q0> IMR3_EXTI3ϵж
//     <i>0: yϵж
//     <i>1: yϵж
// <q1> EMR3_EXTI3ϵ¼
//     <i>0: yϵ¼
//     <i>1: yϵ¼
// <o2> TMR3_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//<i>شΪone-shotʽͨclear pending flag־λ
//<i>ƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR3_EXTI3ϵ/ߵƽжϺ¼
//     <i>0: ֹyϵ/ߵƽ(жϺ¼)
//     <i>1: yϵ/ߵƽ(жϺ¼)
// <q4> FTR3_EXTI3ϵ½/͵ƽжϺ¼
//     <i>0: ֹyϵ½/͵ƽ(жϺ¼)
//     <i>1: yϵ½/͵ƽ(жϺ¼)
// <o5> PS3_EXTI3ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o6> SN3_EXTI3ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
//</e>
#define     CFG_EXTI3_IMR_BIT   0
#define     CFG_EXTI3_EMR_BIT   0
#define     CFG_EXTI3_TMR_BIT   0
#define     CFG_EXTI3_RTR_BIT   0
#define     CFG_EXTI3_FTR_BIT   0
#define     CFG_EXTI3_PS_BIT    0
#define     CFG_EXTI3_SN_BIT    0
#define     CFG_EXTI3_EN        0


//<e7>EXTI4
// <q0> IMR4_EXTI4ϵж
//     <i>0: yϵж
//     <i>1: yϵж
// <q1> EMR4_EXTI4ϵ¼
//     <i>0: yϵ¼
//     <i>1: yϵ¼
// <o2> TMR4_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λ
//<i>ƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR4_EXTI4ϵ/ߵƽжϺ¼
//     <i>0: ֹyϵ/ߵƽ(жϺ¼)
//     <i>1: yϵ/ߵƽ(жϺ¼)
// <q4> FTR4_EXTI4ϵ½/͵ƽжϺ¼
//     <i>0: ֹyϵ½/͵ƽ(жϺ¼)
//     <i>1: yϵ½/͵ƽ(жϺ¼)
// <o5> PS4_EXTI4ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o6> SN4_EXTI4ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
//</e>
#define     CFG_EXTI4_IMR_BIT   0
#define     CFG_EXTI4_EMR_BIT   0
#define     CFG_EXTI4_TMR_BIT   0
#define     CFG_EXTI4_RTR_BIT   0
#define     CFG_EXTI4_FTR_BIT   0
#define     CFG_EXTI4_PS_BIT    0
#define     CFG_EXTI4_SN_BIT    0
#define     CFG_EXTI4_EN        0


//<e7>EXTI5
// <q0> IMR5_EXTI5ϵж
//     <i>0: yϵж
//     <i>1: yϵж
// <q1> EMR5_EXTI5ϵ¼
//     <i>0: yϵ¼
//     <i>1: yϵ¼
// <o2> TMR5_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λ
//<i>ƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR5_EXTI5ϵ/ߵƽжϺ¼
//     <i>0: ֹyϵ/ߵƽ(жϺ¼)
//     <i>1: yϵ/ߵƽ(жϺ¼)
// <q4> FTR5_EXTI5ϵ½/͵ƽжϺ¼
//     <i>0: ֹyϵ½/͵ƽ(жϺ¼)
//     <i>1: yϵ½/͵ƽ(жϺ¼)
// <o5> PS5_EXTI5ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o6> SN5_EXTI5ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
//</e>
#define     CFG_EXTI5_IMR_BIT   0
#define     CFG_EXTI5_EMR_BIT   0
#define     CFG_EXTI5_TMR_BIT   0
#define     CFG_EXTI5_RTR_BIT   0
#define     CFG_EXTI5_FTR_BIT   0
#define     CFG_EXTI5_PS_BIT    0
#define     CFG_EXTI5_SN_BIT    0
#define     CFG_EXTI5_EN        0


//<e7>EXTI6
// <q0> IMR6_EXTI6ϵж
//     <i>0: yϵж
//     <i>1: yϵж
// <q1> EMR6_EXTI6ϵ¼
//     <i>0: yϵ¼
//     <i>1: yϵ¼
// <o2> TMR6_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR6_EXTI6ϵ/ߵƽжϺ¼
//     <i>0: ֹyϵ/ߵƽ(жϺ¼)
//     <i>1: yϵ/ߵƽ(жϺ¼)
// <q4> FTR6_EXTI6ϵ½/͵ƽжϺ¼
//     <i>0: ֹyϵ½/͵ƽ(жϺ¼)
//     <i>1: yϵ½/͵ƽ(жϺ¼)
// <o5> PS6_EXTI6ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o6> SN6_EXTI6ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
//</e>
#define     CFG_EXTI6_IMR_BIT   0
#define     CFG_EXTI6_EMR_BIT   0
#define     CFG_EXTI6_TMR_BIT   0
#define     CFG_EXTI6_RTR_BIT   0
#define     CFG_EXTI6_FTR_BIT   0
#define     CFG_EXTI6_PS_BIT    0
#define     CFG_EXTI6_SN_BIT    0
#define     CFG_EXTI6_EN        0


//<e7>EXTI7
// <q0> IMR7_EXTI7ϵж
//     <i>0: yϵж
//     <i>1: yϵж
// <q1> EMR7_EXTI7ϵ¼
//     <i>0: yϵ¼
//     <i>1: yϵ¼
// <o2> TMR7_EXTIϵĴģʽѡλ
//     <0=>ش
//     <1=>ƽ
//    <i>شΪone-shotʽͨclear pending flag־λƽΪlevelʽֻͨⲿƽ仯־λ޷ͨ
// <q3> RTR7_EXTI7ϵ/ߵƽжϺ¼
//     <i>0: ֹyϵ/ߵƽ(жϺ¼)
//     <i>1: yϵ/ߵƽ(жϺ¼)
// <q4> FTR7_EXTI7ϵ½/͵ƽжϺ¼
//     <i>0: ֹyϵ½/͵ƽ(жϺ¼)
//     <i>1: yϵ½/͵ƽ(жϺ¼)
// <o5> PS7_EXTI7ʱԤƵѡλ
//    <0=>1/1
//    <1=>1/4
//    <2=>1/16
//    <3=>1/128
// <o6> SN7_EXTI7ѡλ
//    <0=>1
//    <1=>2
//    <2=>3
//    <3=>4 
//</e>
#define     CFG_EXTI7_IMR_BIT   0
#define     CFG_EXTI7_EMR_BIT   0
#define     CFG_EXTI7_TMR_BIT   0
#define     CFG_EXTI7_RTR_BIT   0
#define     CFG_EXTI7_FTR_BIT   0
#define     CFG_EXTI7_PS_BIT    0
#define     CFG_EXTI7_SN_BIT    0
#define     CFG_EXTI7_EN        0


#define CFG_EXTI_CFG_INIT     (((uint32_t)CFG_EXTI7_EN<<7)\
															|(CFG_EXTI6_EN<<6)\
															|(CFG_EXTI5_EN<<5)\
															|(CFG_EXTI4_EN<<4)\
															|(CFG_EXTI3_EN<<3)\
															|(CFG_EXTI2_EN<<2)\
															|(CFG_EXTI1_EN<<1)\
															|CFG_EXTI0_EN)
#define CFG_EXTI_IMR_INIT     (((uint32_t)CFG_EXTI7_IMR_BIT<<7)\
															|(CFG_EXTI6_IMR_BIT<<6)\
															|(CFG_EXTI5_IMR_BIT<<5)\
															|(CFG_EXTI4_IMR_BIT<<4)\
															|(CFG_EXTI3_IMR_BIT<<3)\
															|(CFG_EXTI2_IMR_BIT<<2)\
															|(CFG_EXTI1_IMR_BIT<<1)\
															|CFG_EXTI0_IMR_BIT)


#define CFG_EXTI_EMR_INIT     (((uint32_t)CFG_EXTI7_EMR_BIT<<7)\
															|(CFG_EXTI6_EMR_BIT<<6)\
															|(CFG_EXTI5_EMR_BIT<<5)\
															|(CFG_EXTI4_EMR_BIT<<4)\
															|(CFG_EXTI3_EMR_BIT<<3)\
															|(CFG_EXTI2_EMR_BIT<<2)\
															|(CFG_EXTI1_EMR_BIT<<1)\
															|CFG_EXTI0_EMR_BIT)
															

#define CFG_EXTI_TMSR_INIT     (((uint32_t)CFG_EXTI7_TMR_BIT<<7)\
															|(CFG_EXTI6_TMR_BIT<<6)\
															|(CFG_EXTI5_TMR_BIT<<5)\
															|(CFG_EXTI4_TMR_BIT<<4)\
															|(CFG_EXTI3_TMR_BIT<<3)\
															|(CFG_EXTI2_TMR_BIT<<2)\
															|(CFG_EXTI1_TMR_BIT<<1)\
															|CFG_EXTI0_TMR_BIT)
															

#define CFG_EXTI_RTSR_INIT    (((uint32_t)CFG_EXTI7_RTR_BIT<<7)\
															|(CFG_EXTI6_RTR_BIT<<6)\
															|(CFG_EXTI5_RTR_BIT<<5)\
															|(CFG_EXTI4_RTR_BIT<<4)\
															|(CFG_EXTI3_RTR_BIT<<3)\
															|(CFG_EXTI2_RTR_BIT<<2)\
															|(CFG_EXTI1_RTR_BIT<<1)\
															|CFG_EXTI0_RTR_BIT)															


#define CFG_EXTI_FTSR_INIT    (((uint32_t)CFG_EXTI7_FTR_BIT<<7)\
															|(CFG_EXTI6_FTR_BIT<<6)\
															|(CFG_EXTI5_FTR_BIT<<5)\
															|(CFG_EXTI4_FTR_BIT<<4)\
															|(CFG_EXTI3_FTR_BIT<<3)\
															|(CFG_EXTI2_FTR_BIT<<2)\
															|(CFG_EXTI1_FTR_BIT<<1)\
															|CFG_EXTI0_FTR_BIT)		
															

#define CFG_EXTI_SAMP_INIT   (((uint32_t)CFG_EXTI7_PS_BIT<<30)\
															|(CFG_EXTI7_SN_BIT<<28)\
															|(CFG_EXTI6_PS_BIT<<26)\
															|(CFG_EXTI6_SN_BIT<<24)\
															|(CFG_EXTI5_PS_BIT<<22)\
															|(CFG_EXTI5_SN_BIT<<20)\
															|(CFG_EXTI4_PS_BIT<<18)\
															|(CFG_EXTI4_SN_BIT<<16)\
															|(CFG_EXTI3_PS_BIT<<14)\
															|(CFG_EXTI3_SN_BIT<<12)\
															|(CFG_EXTI2_PS_BIT<<10)\
															|(CFG_EXTI2_SN_BIT<<8)\
															|(CFG_EXTI1_PS_BIT<<6)\
															|(CFG_EXTI1_SN_BIT<<4)\
															|(CFG_EXTI0_PS_BIT<<2)\
															|CFG_EXTI0_SN_BIT)	
														

#define CFG_EXTI0_INT_EN CFG_EXTI0_EN
#define CFG_EXTI1_INT_EN CFG_EXTI1_EN
#define CFG_EXTI2_INT_EN CFG_EXTI2_EN
#define CFG_EXTI3_INT_EN CFG_EXTI3_EN
#define CFG_EXTI4_7_INT_EN (CFG_EXTI4_EN | CFG_EXTI5_EN | CFG_EXTI6_EN | CFG_EXTI7_EN )
//</e>


//<e>MCM
#define     CFG_MCM_PWMOE       0
#define  CFG_MCM_EN CFG_MCM_PWMOE
// <o> PWMPSQ_PWMƵϵ<0-65535>
//<i>PWMʱΪ(HCLK/(PSQ[15:0]+1)) 
#define     CFG_MCM_PWMPSQ_INIT 0


// <o> PWMP_PWMƵ (0-100000Hz) <0-100000> 
#define     CFG_MCM_PWMP_F      12000
//<o0>PWMD0:  PWM0ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ:ǶԳƲΣ(Ķģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o1>PWMD1:  PWM1ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ:ǶԳƲΣ(Ķģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o2>PWMD2:  PWM2ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ:ǶԳƲΣ(Ķģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o3>PWMD01: PWM01ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ:ǶԳƲΣ(Ķģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o4>PWMD11: PWM11ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ:ǶԳƲΣ(Ķģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
//<o5>PWMD21: PWM21ռձ (0.1%) <0-1000>
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ:ǶԳƲΣ(Ķģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ
#define     CFG_MCM_PWM0_DUTY   500
#define     CFG_MCM_PWM1_DUTY   500
#define     CFG_MCM_PWM2_DUTY   500
#define     CFG_MCM_PWM01_DUTY  500
#define     CFG_MCM_PWM11_DUTY  500
#define     CFG_MCM_PWM21_DUTY  500
// <o0.1..3> SECTOR_SVPWM趨λ
//<i>MAXMUMMIN
//    <0=>PWM2D > PWM1D > PWM0D
//    <1=>PWM2D > PWM0D > PWM1D
//    <2=>PWM0D > PWM2D > PWM1D
//    <3=>PWM0D > PWM1D > PWM2D
//    <4=>PWM1D > PWM0D > PWM2D
//    <5=>PWM1D > PWM2D > PWM0D
//    <i>趨110111ʱЧ
//    <i>SVPWM趨λͨλȷPWM0DPWM1DPWM2DĴС˳ֵʱĴС˳
#define     CFG_MCM_PSCON_L_INIT 0
// <q0.7> ʹֹͣPWM
//    <i>0: ֹ
//    <i>1: ʹ
#define     CFG_MCM_POSTDCR_INIT 0


//<h>PWM
// <o0.15> POUTMOD_PWM0/1/2ģʽ/λ
//    <0=>3ͨ
//    <1=>6·
//<i>16λռձȼĴ
//<i>ģʽ
//<i>PWMxD (x = 0-2)PWMx(x = 0-2)ԭʼ
//<i>PWMx1D (x = 0-2)PWMx1(x = 0-2)ԭʼ
//<i>ģʽԳƲ
//<i>PWM0DͬʱPWM0/01ԭʼ
//<i>PWM1DͬʱPWM1/11ԭʼ
//<i>PWM2DͬʱPWM2/21ԭʼ
//<i>ģʽ:ǶԳƲΣ(Ķģʽ´)
//<i>PWM0DͬʱPWM0/01
//<i>PWM01DͬʱPWM0/01̵ԭʼ
//<i>PWM1DͬʱPWM1/11̵ԭʼ
//<i>PWM11DͬʱPWM1/11̵ԭʼ
//<i>PWM2DͬʱPWM2/21̵ԭʼ
//<i>PWM21DͬʱPWM2/21̵ԭʼ


// <o0.12..14> POSTPS_Ƶϵ
//    <0=>޺Ƶ
//    <1=>жϡź¼źŽ2Ƶ
//    <2=>жϡź¼źŽ3Ƶ
//    <3=>жϡź¼źŽ4Ƶ
//    <4=>жϡź¼źŽ5Ƶ
//    <5=>жϡź¼źŽ6Ƶ
//    <6=>жϡź¼źŽ7Ƶ
//    <7=>жϡź¼źŽ8Ƶ
// <o0.10..11> PTMOD_PWM0/1/2ģʽ
//    <0=>ضģʽ   
//    <1=>Ķģʽ
//    <2=>μģʽ
//<i>ضģʽģʽ£ʱֻᷢƥ
//<i>Ķģʽģʽ£ʱᷢƥƥ
//<i>μģʽģʽ£ʱֻᷢƥ
// <o0.9> PWMSYM_PWMζԳԿ
//    <0=>ԳPWM
//    <1=>ǶԳPWM
//<i>ĶģʽĻʱЧ
// <o0.6> PDCON0_PWM0/PWM01ԭʼDUTYλ
//    <0=>ֵСռձȼĴʱΪDUTY
//    <1=>ֵڵռձȼĴʱΪDUTY
// <o0.7> PDCON1_PWM1/PWM11ԭʼDUTYλ
//    <0=>ֵСռձȼĴʱΪDUTY
//    <1=>ֵڵռձȼĴʱΪDUTY
// <o0.8> PDCON2_PWM2/PWM21ԭʼDUTYλ
//    <0=>ֵСռձȼĴʱΪDUTY
//    <1=>ֵڵռձȼĴʱΪDUTY
// <o0.0> PWM0S_PWM0Чƽѡλ
//    <0=>PWM0Dutyߵƽʱ͵ƽ
//    <1=>PWM0Duty͵ƽʱߵƽ
// <o0.1> PWM1S_PWM1Чƽѡλ
//    <0=>PWM1Dutyߵƽʱ͵ƽ
//    <1=>PWM1Duty͵ƽʱߵƽ
// <o0.2> PWM2S_PWM2Чƽѡλ
//    <0=>PWM2Dutyߵƽʱ͵ƽ
//    <1=>PWM2Duty͵ƽʱߵƽ
// <o0.3> PWM01S_PWM01Чƽѡλ
//    <0=>PWM01Duty͵ƽʱߵƽ
//    <1=>PWM01Dutyߵƽʱ͵ƽ
// <o0.4> PWM11S_PWM11Чƽѡλ
//    <0=>PWM11Duty͵ƽʱߵƽ
//    <1=>PWM11Dutyߵƽʱ͵ƽ
// <o0.5> PWM21S_PWM21Чƽѡλ
//    <0=>PWM21Duty͵ƽʱߵƽ
//    <1=>PWM21Dutyߵƽʱ͵ƽ


#define     CFG_MCM_PWMCON1_INIT 56
//</h>


//<h>PWM
// <o> PWMDT00_PWMͨ0(0.1us) <0-100>
#define     CFG_MCM_PWMDT00_DT  10


// <o> PWMDT01_PWMͨ0½(0.1us) <0-100>
#define     CFG_MCM_PWMDT01_DT  10


// <o> PWMDT10_PWMͨ1(0.1us) <0-100>
#define     CFG_MCM_PWMDT10_DT  10
// <o> PWMDT11_PWMͨ1½(0.1us) <0-100>
#define     CFG_MCM_PWMDT11_DT  10
// <o> PWMDT20_PWMͨ2(0.1us) <0-100>
#define     CFG_MCM_PWMDT20_DT  10
// <o> PWMDT21_PWMͨ2½(0.1us) <0-100>
#define     CFG_MCM_PWMDT21_DT  10
//</h>
//<h>ȽϼĴAD
// <o0.0..1> CMP1_ȽϼĴ1ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ1ʱᴥAD
//    <2=>ֻPWMȽϼĴ1ʱᴥAD
//PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ1ʱᴥAD
//PTMOD = 01ĶģʽЧ    
//<i>ADCADONPWMTRGENλ1
// <o1> PWMCMP1_¼Ƚֵ1ٷֱ(0.1%) <0-1000>
// <o0.2..3> CMP2_ȽϼĴ2ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ2ʱᴥAD
//    <2=>ֻPWMȽϼĴ2ʱᴥAD
// PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ2ʱᴥAD
//PTMOD = 01    ADCADONPWMTRGENλ1£
//<i>ADCADONPWMTRGENλ1
// <o2> PWMCMP2_¼Ƚֵ2ٷֱ(0.1%) <0-1000>
// <o0.4..5> CMP3_ȽϼĴ3ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ3ʱᴥAD
//    <2=>ֻPWMȽϼĴ3ʱᴥAD
//PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ3ʱᴥAD
//PTMOD = 01ĶģʽЧ    ADCADONPWMTRGENλ1£
//<i>ADCADONPWMTRGENλ1
// <o3> PWMCMP3_¼Ƚֵ3ٷֱ(0.1%) <0-1000>
// <o0.6..7> CMP4_ȽϼĴ4ADλ
//    <0=>AD
//    <1=>ֻҪPWMȽϼĴ4ʱᴥAD
//    <2=>ֻPWMȽϼĴ4ʱᴥAD
// PTMOD = 01ĶģʽЧ
//    <3=>ֻҪPWMڼȽϼĴ4ʱᴥAD
//PTMOD = 01    ADCADONPWMTRGENλ1£
//<i>ADCADONPWMTRGENλ1
// <o4> PWMCMP4_¼Ƚֵ4ٷֱ(0.1%) <0-1000>
//</h>
//<h>ͬ
// <o0.8> OSYNC_ֶ޸PWMx/PWMx1ͬλ
//    <0=>ֶ޸ĺЧ
//    <1=>ֶ޸PWMͬЧ
//<i>ֶ޸ͨPMANUALCON1/2Ĵʵ,һĴ޸,ʱЧɴ˼Ĵ
// <o0.9> DILDEN_PWMռձȼĴЧʹλ
//    <0=>PWMͬЧ
//    <1=>Ч
// <o0.10> CILDEN_PWM¼ȽϼĴЧʹλ
//    <0=>PWMͬЧ
//    <1=>Ч
// <q0.11> ZDLDEN_PWMƥʱռձȼĴĴ
//    <i> ֵܴǷ趨0ƥʱԶڼĴƵԤƵĴκμĴ
// <q0.12> PDLDEN_PWMƥʱռձȼĴĴ
//    <i>ۼĴãƥʱPWMڼĴƵԤƵĴ,ֻĶģʽЧ
// <q0.13> ZCMLDEN_PWMƥʱ¼Ĵ
//<i>PWMCMPxx=1,2,3,4,ƥʱ¼ȽϼĴADʽĴ(CMP1~4[1-0])ʹλ      
// <q0.14> PCMLDEN_PWMƥʱ¼Ĵ
//<i>ƥʱ¼ȽϼĴADʽĴ(CMP1~4[1-0])ʹλֻĶģʽЧ
// <q0.15> MCMSYNEN_MCM1MCM2ͬʹλ
//    <i>0: رMCM1MCM2ͬ
//    <i>1: MCM1MCM2ͬ
//    <i>Ϊ˷ֹֻMCM1.PWMOE[MCMSYNEN]MCM2.PWMOE[MCMSYNEN]ͬʱ1ܿͬ,ֻĶģʽЧ
//</h>


#define     CFG_MCM_PWMCON2_INIT 0
#define     CFG_MCM_PWMCMP1_VALUE 0
#define     CFG_MCM_PWMCMP2_VALUE 0
#define     CFG_MCM_PWMCMP3_VALUE 0
#define     CFG_MCM_PWMCMP4_VALUE 0
	

//<h>PWM0/1/2ֶ
//<i>PMANUALCON1_PWM0/1/2ֶüĴ1
//<i>0x058       b31~6 b5        b4        b3        b2       b1       b0       
//<i>PMANUALCON1 -     PMANUAL21 PMANUAL11 PMANUAL01 PMANUAL2 PMANUAL1 PMANUAL0 
//<i>PMANUALCON2_PWM0/1/2ֶüĴ2
//<i>0x05C       b31~6 b5     b4     b3     b2    b1    b0    
//<i>PMANUALCON2 -     POUT21 POUT11 POUT01 POUT2 POUT1 POUT0 
// <o0.0> PMANUAL0_PWM0λ
//    <0=>PWM0PWM
//    <1=>PWM0PMANUALCON2ĴеPOUT0λ
// <o0.1> PMANUAL1_PWM1λ
//    <0=>PWM1PWM
//    <1=>PWM1PMANUALCON2ĴеPOUT1λ
// <o0.2> PMANUAL2_PWM2λ
//    <0=>PWM2PWM
//    <1=>PWM2PMANUALCON2ĴеPOUT2λ
// <o0.3> PMANUAL01_PWM01λ
//    <0=>PWM01PWM
//    <1=>PWM01PMANUALCON2ĴеPOUT01λ
// <o0.4> PMANUAL11_PWM11λ
//    <0=>PWM11PWM
//    <1=>PWM11PMANUALCON2ĴеPOUT11λ
// <o0.5> PMANUAL21_PWM21λ
//    <0=>PWM21PWM
//    <1=>PWM21PMANUALCON2ĴеPOUT21λ
#define     CFG_MCM_PMANUALCON1_INIT 0


//<h>PMANUALCON2_PWM0/1/2ֶüĴ2
//<i>0x05C       b31~6 b5     b4     b3     b2    b1    b0    
//<i>PMANUALCON2 -     POUT21 POUT11 POUT01 POUT2 POUT1 POUT0 
// <o0.0> POUT0_PMANUAL0 = 1ʱPWM0ڵƽ
//    <0=>0
//    <1=>1
// <o0.1> POUT1_PMANUAL1 = 1ʱPWM1ڵƽ
//    <0=>0
//    <1=>1
// <o0.2> POUT2_PMANUAL2 = 1ʱPWM2ڵƽ
//    <0=>0
//    <1=>1
// <o0.3> POUT01_PMANUAL01 = 1ʱPWM01ڵƽ
//    <0=>0
//    <1=>1
// <o0.4> POUT11_PMANUAL11 = 1ʱPWM11ڵƽ
//    <0=>0
//    <1=>1
// <o0.5> POUT21_PMANUAL21 = 1ʱPWM21ڵƽ
//    <0=>0
//    <1=>1
#define     CFG_MCM_PMANUALCON2_INIT 0
//</h>
//</h>


//<h>ϼ
//<h>FLTCON_FLTŹϼⱣPWM0/1/2Ĵ
//<i>0x060  b31~24 b23~22 b21~20 b19 b18       b17       b16       b15    b14   b13   b12      b11    b10   b9    b8       b7~4    b3     b2    b1    b0       
//<i>FLTCON -      FOUT1  FOUT0  -   FLT0STATC FLT1STATC FLT2STATC FLT0EN FLT0S FLT0M FLT0STAT FLT1EN FLT1S FLT1M FLT1STAT FLT2DEB FLT2EN FLT2S FLT2M FLT2STAT 
// <o0.1> FLT2M_⹦ģʽѡ
//<i>ģʽ⵽ЧFLTSTAT Ӳ1PWMֹͣΪЧʱ״ֲ̬䣬ֻеFLTSTATPWMβŻPWMʱ0ʱ̻ڼĴPWMPֵƥʱָһֱЧʱFLTSTAT޷
//<i>ģʽPWMֱɹϼƣЧFLTSTATӲ1رPWMΪЧFLTSTATԶ0PWM0/1/2νPWMʱ0ʱԶָ
//    <0=>ģʽ
//    <1=>ģʽ
// <o0.2> FLT2S_ϼ2Чƽѡλ
//    <0=>ϼ2 FLTߵƽЧ
//    <1=>ϼ2 FLT͵ƽЧ
// <o0.3> FLT2EN_ϼ2ܿλ
//    <0=>ϼ2ֹܽ
//    <1=>ϼ2ܴ򿪣ԴΪFLT
// <o0.4..7> FLT2DEB_ϼ2˲ѡ
//  <0=>˲
//  <1=>0.5us
//  <2=>1us
//  <3=>1.5us
//  <4=>2us
//  <5=>3us
//  <6=>4us
//  <7=>6us
//  <8=>8us
//  <9=>10us
//  <10=>12us
//  <11=>14us
//  <12=>16us
//  <13=>20us
//  <14=>24us
//  <15=>32us
//  <i>˲ʱ䲻Ǿȷֵ
//  <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.9> FLT1M_⹦ģʽѡ
//<i>ģʽ⵽ЧFLTSTAT Ӳ1PWMֹͣΪЧʱ״ֲ̬䣬ֻеFLTSTATPWMβŻPWMʱ0ʱ̻ڼĴPWMPֵƥʱָһֱЧʱFLTSTAT޷
//<i>ģʽPWMֱɹϼƣЧFLTSTATӲ1رPWMΪЧFLTSTATԶ0PWM0/1/2νPWMʱ0ʱԶָ
//    <0=>ģʽ
//    <1=>ģʽ
// <o0.10> FLT1S_ϼ1Чƽѡλ
//  <0=>ϼ1 CMP1ߵƽЧ
//  <1=>ϼ1 CMP1͵ƽЧ
// <o0.11> FLT1EN_Ƚ1MCMλ
//    <0=>ϼ1ֹܽ
//    <1=>ϼ1ܴ
// <o0.13> FLT0M_⹦ģʽѡ
//<i>ģʽ⵽ЧFLTSTAT Ӳ1PWMֹͣΪЧʱ״ֲ̬䣬ֻеFLTSTATPWMβŻPWMʱ0ʱ̻ڼĴPWMPֵƥʱָһֱЧʱFLTSTAT޷
//<i>ģʽPWMֱɹϼƣЧFLTSTATӲ1رPWMΪЧFLTSTATԶ0PWM0/1/2νPWMʱ0ʱԶָ
//    <0=>ģʽ
//    <1=>ģʽ
// <o0.14> FLT0S_ϼ0Чƽѡλ
//    <0=>ϼ0 CMP0ߵƽЧ
//    <1=>ϼ0 CMP0͵ƽЧ
// <o0.15> FLT0EN_Ƚ0MCMλ
//    <0=>ϼ0ֹܽ
//    <1=>ϼ0ܴ
// <o0.20..21> FOUT0_ϷPWMx״̬ѡλ
//    <0=>̬
//    <2=>͵ƽ
//    <3=>ߵƽ
// <o0.22..23> FOUT1_ϷPWMx1״̬ѡλ
//    <0=>̬
//    <2=>͵ƽ
//    <3=>ߵƽ
//</h>

#define     CFG_MCM_FLTCON_INIT 0
//</h>


//<e0.7>PWMʹ
//<i>0x064 b31~8 b7    b6 b5     b4     b3     b2    b1    b0    
//<i>POSCR -     OLSEN -  OLSG21 OLSG11 OLSG01 OLSG2 OLSG1 OLSG0 
// <o0.0> OLSG0_·PWM0Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.1> OLSG1_·PWM1Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.2> OLSG2_·PWM2Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.3> OLSG01_·PWM01Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.4> OLSG11_·PWM11Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
// <o0.5> OLSG21_·PWM21Чƽ趨λ
//    <0=>͵ƽЧ
//    <1=>ߵƽЧ
//</e>
#define     CFG_MCM_POSCR_INIT  0


//<h>PWMж
//<i>0x074    b31~13 b12    b11 b10       b9        b8    b7     b6     b5      b4      b3      b2      b1      b0      
//<i>PWMINTEN -      OSTDIE OIE FLTCMP1IE FLTCMP0IE FLTIE PWMPIE PWMZIE PTDD2IE PTUD2IE PTDD1IE PTUD1IE PTDD0IE PTUD0IE
// <q0.0> PTUD0IE_PWMʱPWM0Dƥʱж
//    <i>0: ֹPWMʱPWM0Dƥʱж
//    <i>1: PWMʱPWM0Dƥʱж
// <q0.1> PTDD0IE_PWMʱPWM0Dƥʱж
//<i>ֻĶģʽЧ


// <q0.2> PTUD1IE_PWMʱPWM1Dƥʱж


// <q0.3> PTDD1IE_PWMʱPWM1Dƥʱж
//<i>ֻĶģʽЧ


// <q0.4> PTUD2IE_PWMʱPWM2Dƥʱж


// <q0.5> PTDD2IE_PWMʱPWM2Dƥʱж
//<i>ֻĶģʽЧ


// <q0.6> PWMZIE_PWMʱ㴥ж


// <q0.7> PWMPIE_PWMʱƥ䴥ж
//<i>ֻĶģʽЧ


// <q0.8> FLTIE_жλ
//    <i>0: ֹϼж
//    <i>1: ϼж
// <q0.9> FLTCMP0IE_CMP0жλ
//    <i>0: ֹϼж
//    <i>1: ϼж
// <q0.10> FLTCMP1IE_CMP1жλ
//    <i>0: ֹϼж
//    <i>1: ϼж
// <q0.11> OIE_·жλ
//    <i>0: ֹж
//    <i>1: ж
// <q0.12> OSTDIE_ֹͣPWMжʹλ
//    <i>0: ֹж
//    <i>1: ж
//</h>

#define     CFG_MCM_PWMINTEN_INIT 0


#if ((CFG_MCM_PWMINTEN_INIT & 0xFF) != 0)
	#define CFG_MCM_PWM_INT_EN 1
#else
	#define CFG_MCM_PWM_INT_EN 0
#endif


#if ((CFG_MCM_PWMINTEN_INIT & 0x700) != 0)
	#define CFG_MCM_FLT_INT_EN 1
#else
	#define CFG_MCM_FLT_INT_EN 0
#endif


//PWMRLDEN
//0x078    b31~8 b7~0     
//PWMRLDEN -     PWMRLDEN 
//PWMRLDEN_Ĵ޸ĺؿƼĴ
//    0x55:ģĴ޸
//    0xAA:ģļĴ
//    PWMģļĴжϱ־ĴPWMINTFֶƼĴPMANUALCON2FLTCONPOSCRPOSTDCR⣬Ĵ޸ֻеPWMRLDEN = 0x55ʱ޸ģ޸Ч
//    PWMģһЩĴлĴռձȼĴPWMxD&PWMx1DڼĴPWMPPWMʱԤƵĴPWMPSQƵĴPOSTPS[2:0]@ PWMCON1DutyѡĴPDCONx@PWMCON1ԳԿƼĴPWMSYM@PWMCON1ĴPWMDTxxȽϼĴADλCMPx@PWMCON2PWM¼ĴPWMCMPx


#define CFG_MCM_PWMRLDEN_INIT	0x0


//<h>PWM
//<i>PSCON
//<i>0x080 b31~12 b11~10    b9~8      b7 b6~4   b3 b2   b1      b0       
//<i>PSCON -      MINSELECT MAXSELECT -  SECTOR -  OVER STATRUN SHIFTRUN 


// <o0.8..9> MAXSELECT_ʱޱȽֵȽϺPWMռձֵѡλ
//    <0=>κʱPWMxռձȣPWMxDֵ
//    <1=>PWMxDڵPWMDMAXʱPWMxD޸ΪPWMDMAX򲻱
//    <2=>PWMxDڵPWMDMAXʱPWMxD޸ΪֵPWMP򲻱
// <o0.10..11> MINSELECT_ʱޱȽֵȽϺPWMռձֵѡλ
//    <0=>κʱPWMxռձȣPWMxDֵ
//    <1=>PWMxDСڵPWMDMINʱPWMxD޸ΪPWMDMIN򲻱
//    <2=>PWMxDСڵPWMDMINʱPWMxD޸Ϊ0򲻱
#define     CFG_MCM_PSCON_H_INIT 0
#define CFG_MCM_PSCON_INIT	(CFG_MCM_PSCON_L_INIT|CFG_MCM_PSCON_H_INIT)
// PWMDMAX_PWMռձޱȽϼĴ
// <o> PWMDMAX_PWMռձޱȽֵ(0.1%) <0-1000> 
//PWMDMAX
//0x080   b31~16 b15~0   
//PWMDMAX -      PWMDMAX 
#define     CFG_MCM_PWMDMAX_VALUE 0
// PWMDMIN_PWMռձޱȽϼĴ
// <o> PWMDMIN_PWMռձޱȽֵ(0.1%) <0-1000> 
//PWMDMIN
//0x084   b31~16 b15~0   
//PWMDMIN -      PWMDMIN 
#define     CFG_MCM_PWMDMIN_VALUE 0


// <o> PWMDCMP1_PWMռձСĴ1 <0-65535>
//<i>PWMDCMP1
//<i>0x088    b31~16 b15~0    
//<i>PWMDCMP1 -      PWMDCMP1 
#define     CFG_MCM_PWMDCMP1_INIT 0


// <o0> PWMDCMP2_PWMռձСĴ2 <0-65535>
//<i>PWMDCMP2
//<i>0x08C    b31~16 b15~0    
//<i>PWMDCMP2 -      PWMDCMP2 
#define     CFG_MCM_PWMDCMP2_INIT 0
//</h>


//<h>
//<e0.12>Ƚź0ʹ
//<i>0x094  b31~14 b13~12 b11 b10      b9       b8       b7~4  b3~0   
//<i>SC0CON -      SCEN   SCS SCPWM2EN SCPWM1EN SCPWM0EN SCDEB SCTIME  
//SCEN_SC0ʹ
// <o0.12..13> SCEN_0ܿλ
//    <0=>0ֹܽ
//    <1=>SC0Ϊ0
//    <2=>CMP0Ϊ0룬ߵƽЧ
//    <3=>CMP1Ϊ0룬ߵƽЧ
// <o0.11> SCS_SC0Чƽѡλ
//    <0=>SC0ߵƽЧ
//    <1=>SC0͵ƽЧ
// <q0.8> SCPWM0EN_SC0PWM0ʹ
// <q0.9> SCPWM1EN_SC0PWM1ʹ
// <q0.10> SCPWM2EN_SC0PWM2ʹ
// <o0.0..3> SCTIME_ʱѡλ
//    <0=>һƥʱָ
//    <1=>1200*HCLK
//    <2=>1600*HCLK
//    <3=>2000*HCLK
//    <4=>2400*HCLK
//    <5=>2800*HCLK
//    <6=>3200*HCLK
//    <7=>4000*HCLK
//    <8=>4800*HCLK
//    <9=>6400*HCLK
//    <10=>8000*HCLK
//    <11=>16000*HCLK
//    <12=>32000*HCLK
//    <13=>48000*HCLK
//    <14=>64000*HCLK
//    <15=>ֶָMCMͨSC0STATC@PWMINTF
// <o0.4..7> SCDEB_SC0˲ѡ
//    <0=>0
//    <1=>40*HCLK
//    <2=>80*HCLK
//    <3=>120*HCLK
//    <4=>160*HCLK
//    <5=>240*HCLK
//    <6=>320*HCLK
//    <7=>480*HCLK
//    <8=>640*HCLK
//    <9=>800*HCLK
//    <10=>960*HCLK
//    <11=>1120*HCLK
//    <12=>1280*HCLK
//    <13=>1600*HCLK
//    <14=>1920*HCLK
//    <15=>2560*HCLK
//   <i>˲ʱ䲻Ǿȷֵ
//   <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0


//</e>
#define     CFG_MCM_SC0CON_INIT 0
//<e0.12>Ƚź1ʹ
//<i>0x098  b31~14 b13~12 b11 b10      b9       b8       b7~4  b3~0   
//<i>SC1CON -      SCEN   SCS SCPWM2EN SCPWM1EN SCPWM0EN SCDEB SCTIME 
// <o0.12..13> SCEN_1ܿλ
//    <0=>1ֹܽ
//    <1=>SC1Ϊ1
//    <2=>CMP0Ϊ1룬ߵƽЧ
//    <3=>CMP1Ϊ1룬ߵƽЧ
// <o0.11> SCS_SC1Чƽѡλ
//    <0=>SC1ߵƽЧ
//    <1=>SC1͵ƽЧ
// <q0.8> SCPWM0EN_SC1PWM0ʹ
// <q0.9> SCPWM1EN_SC1PWM1ʹ
// <q0.10> SCPWM2EN_SC1PWM2ʹ
// <o0.0..3> SCTIME_ʱѡλ
//    <0=>һƥʱָ
//    <1=>1200*HCLK
//    <2=>1600*HCLK
//    <3=>2000*HCLK
//    <4=>2400*HCLK
//    <5=>2800*HCLK
//    <6=>3200*HCLK
//    <7=>4000*HCLK
//    <8=>4800*HCLK
//    <9=>6400*HCLK
//    <10=>8000*HCLK
//    <11=>16000*HCLK
//    <12=>32000*HCLK
//    <13=>48000*HCLK
//    <14=>64000*HCLK
//    <15=>ֶָMCMͨSC0STATC@PWMINTF
// <o0.4..7> SCDEB_SC1˲ѡ
//    <0=>0
//    <1=>40*HCLK
//    <2=>80*HCLK
//    <3=>120*HCLK
//    <4=>160*HCLK
//    <5=>240*HCLK
//    <6=>320*HCLK
//    <7=>480*HCLK
//    <8=>640*HCLK
//    <9=>800*HCLK
//    <10=>960*HCLK
//    <11=>1120*HCLK
//    <12=>1280*HCLK
//    <13=>1600*HCLK
//    <14=>1920*HCLK
//    <15=>2560*HCLK
//   <i>˲ʱ䲻Ǿȷֵ
//   <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0


//</e>
#define     CFG_MCM_SC1CON_INIT 0


//<e0.12>Ƚź2ʹ
//<i>0x09C  b31~14 b13~12 b11 b10      b9       b8       b7~4  b3~0   
//<i>SC2CON -      SCEN   SCS SCPWM2EN SCPWM1EN SCPWM0EN SCDEB SCTIME 
// <o0.12..13> SCEN_2ܿλ
//    <0=>2ֹܽ
//    <1=>SC2Ϊ2
//    <2=>CMP0Ϊ2룬ߵƽЧ
//    <3=>CMP1Ϊ2룬ߵƽЧ
// <o0.11> SCS_SC2Чƽѡλ
//    <0=>SC2ߵƽЧ
//    <1=>SC2͵ƽЧ
// <q0.8> SCPWM0EN_SC2PWM0ʹ
// <q0.9> SCPWM1EN_SC2PWM1ʹ
// <q0.10> SCPWM2EN_SC2PWM2ʹ
// <o0.0..3> SCTIME_ʱѡλ
//    <0=>һƥʱָ
//    <1=>1200*HCLK
//    <2=>1600*HCLK
//    <3=>2000*HCLK
//    <4=>2400*HCLK
//    <5=>2800*HCLK
//    <6=>3200*HCLK
//    <7=>4000*HCLK
//    <8=>4800*HCLK
//    <9=>6400*HCLK
//    <10=>8000*HCLK
//    <11=>16000*HCLK
//    <12=>32000*HCLK
//    <13=>48000*HCLK
//    <14=>64000*HCLK
//    <15=>ֶָMCMͨSC0STATC@PWMINTF
// <o0.4..7> SCDEB_SC2˲ѡ
//    <0=>0
//    <1=>40*HCLK
//    <2=>80*HCLK
//    <3=>120*HCLK
//    <4=>160*HCLK
//    <5=>240*HCLK
//    <6=>320*HCLK
//    <7=>480*HCLK
//    <8=>640*HCLK
//    <9=>800*HCLK
//    <10=>960*HCLK
//    <11=>1120*HCLK
//    <12=>1280*HCLK
//    <13=>1600*HCLK
//    <14=>1920*HCLK
//    <15=>2560*HCLK
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲2Ϊ͵ƽ1С˲,˲0ͬʱΪ0
//</e>
#define     CFG_MCM_SC2CON_INIT 0
//</h>


//</e>


#define CFG_MCM_CLK		(unsigned long)(SYS_CLK/(CFG_MCM_PWMPSQ_INIT + 1))
#if (CFG_MCM_PWMCON1_INIT & (1<<10)) 
	#define CFG_MCM_PWMP_MODE 2
#else
	#define CFG_MCM_PWMP_MODE 1
#endif


#define CFG_MCM_PWMP_INIT (uint16_t)(CFG_MCM_CLK/CFG_MCM_PWMP_F/CFG_MCM_PWMP_MODE)
#define CFG_MCM_PWM0D_INIT (uint16_t)(CFG_MCM_PWMP_INIT*CFG_MCM_PWM0_DUTY/1000)
#define CFG_MCM_PWM1D_INIT (uint16_t)(CFG_MCM_PWMP_INIT*CFG_MCM_PWM1_DUTY/1000)
#define CFG_MCM_PWM2D_INIT (uint16_t)(CFG_MCM_PWMP_INIT*CFG_MCM_PWM2_DUTY/1000)
#define CFG_MCM_PWM01D_INIT (uint16_t)(CFG_MCM_PWMP_INIT*CFG_MCM_PWM01_DUTY/1000)
#define CFG_MCM_PWM11D_INIT (uint16_t)(CFG_MCM_PWMP_INIT*CFG_MCM_PWM11_DUTY/1000)
#define CFG_MCM_PWM21D_INIT (uint16_t)(CFG_MCM_PWMP_INIT*CFG_MCM_PWM21_DUTY/1000)


#define CFG_MCM_PWMDT21_INIT ((uint16_t)(CFG_MCM_PWMDT21_DT*CFG_MCM_CLK/10000000))
#define CFG_MCM_PWMDT20_INIT ((uint16_t)(CFG_MCM_PWMDT20_DT*CFG_MCM_CLK/10000000))
#define CFG_MCM_PWMDT11_INIT ((uint16_t)(CFG_MCM_PWMDT11_DT*CFG_MCM_CLK/10000000))
#define CFG_MCM_PWMDT10_INIT ((uint16_t)(CFG_MCM_PWMDT10_DT*CFG_MCM_CLK/10000000))
#define CFG_MCM_PWMDT01_INIT ((uint16_t)(CFG_MCM_PWMDT01_DT*CFG_MCM_CLK/10000000))
#define CFG_MCM_PWMDT00_INIT ((uint16_t)(CFG_MCM_PWMDT00_DT*CFG_MCM_CLK/10000000))


#define CFG_MCM_PWMDMIN_INIT	(uint16_t)(CFG_MCM_PWMDMIN_VALUE*CFG_MCM_PWMP_INIT/1000)
#define CFG_MCM_PWMDMAX_INIT	(uint16_t)(CFG_MCM_PWMDMAX_VALUE*CFG_MCM_PWMP_INIT/1000)


#define CFG_MCM_PWMCMP1_INIT	(uint16_t)(CFG_MCM_PWMCMP1_VALUE*CFG_MCM_PWMP_INIT/1000)
#define CFG_MCM_PWMCMP2_INIT	(uint16_t)(CFG_MCM_PWMCMP2_VALUE*CFG_MCM_PWMP_INIT/1000)
#define CFG_MCM_PWMCMP3_INIT	(uint16_t)(CFG_MCM_PWMCMP3_VALUE*CFG_MCM_PWMP_INIT/1000)
#define CFG_MCM_PWMCMP4_INIT	(uint16_t)(CFG_MCM_PWMCMP4_VALUE*CFG_MCM_PWMP_INIT/1000)
#if ((CFG_MCM_PWMOE) && ((CFG_PB3_AFR != 2)&&(CFG_PB2_AFR != 2)&&(CFG_PB1_AFR != 2)&&(CFG_PB4_AFR != 2)&&(CFG_PB5_AFR != 2)&&(CFG_PB6_AFR != 2)))
#warning "MCM PWM PIN(PB3/PB2/PB1/PB6/PB5/PB4) AF2 function mapping is not enable."
#endif


#if ((CFG_MCM_PWMOE) && (CFG_MCM_SC0CON_INIT &(1<<12)) && ((CFG_PB7_AFR != 2)&&(CFG_PA1_AFR != 2)))
#error "MCM_SC0 PIN(PB7) AF2 function mapping is not enable."
#endif


#if ((CFG_MCM_PWMOE) && (CFG_MCM_SC1CON_INIT &(1<<12)) && ((CFG_PB8_AFR != 2)&&(CFG_PA10_AFR != 2)))
#error "MCM_SC1 PIN(PB8) AF2 function mapping is not enable."
#endif


#if ((CFG_MCM_PWMOE) && (CFG_MCM_SC2CON_INIT &(1<<12)) && ((CFG_PB9_AFR != 2)&&(CFG_PA15_AFR != 2)))
#error "MCM_SC2 PIN(PB9) AF2 function mapping is not enable."
#endif


#if ((CFG_MCM_PWMOE) && (CFG_MCM_FLTCON_INIT &(1<<3)) && (CFG_PB0_AFR != 2))
#error "MCM_FLT PIN(PB0) AF2 function mapping is not enable."
#endif


//<e>PCA
#define     CFG_PCA_EN          0
//***********************************************************/
//<e>PCA0
#define     CFG_PCA0_EN         0
//<i>CR_PCAx ʹܼĴ
//<i>0x000 b31~1 b0  
//<i>CR    -     PEN 
// <q0.0> PEN_PCAx /ʱпλ
//  <i>0: ֹPCAx/ʱ
//  <i>1: PCAx/ʱ
#define     CFG_PCA0_CR_INIT    0


//<e>ƵռձԶPRCCRx
//<i>÷ʽPCAxģʽ
#define     CFG_PCA_C0_EN       0


// <o> PCA0Ƶ (0-100000Hz) <0-100000> 
#define     CFG_PCA_PCA0_PR_F   1000
//<o0>PCA0A:  PCA0A/Ƚ/ռձ (0.1%) <0-1000>
#define     CFG_PCA_PCA0A_DUTY  400
//<o0>PCA0B:  PCA0B/Ƚ/ռձ (0.1%) <0-1000>
#define     CFG_PCA_PCA0B_DUTY  200
//<o0>PCA0C:  PCA0C/Ƚ/ռձ (0.1%) <0-1000>
#define     CFG_PCA_PCA0C_DUTY  300
//</e>


//<e>üPRCCRx
//<i>÷ʽPCAxģʽ
#define     CFG_PCA0_E0_EN      0


//<h>PR_PCAx ֵ
//<i>0x018 b31~16 b15~0 
//<i>PR    PRH    PRL   
// <o0.0..15> PRL_PCAx ֵֽڣLSB<0-0xFFFF> 
// <o0.16..31> PRH_PCAx ֵֽڣMSB<0-0xFFFF> 
#define     CFG_PCA0_PR         0x0
//</h>


//<h>CCR0_PCAx Ƚ/׽ģ0׽ֵ
//<i>0x028 b31~16 b15~0 
//<i>CCR0  CCR0H  CCR0L 
// <o0.0..15> CCR0L_PCAx Ƚ/׽ģ0Ĵֽ <0-0xFFFF>
// <o0.16..31> CCR0H_PCAx Ƚ/׽ģ0Ĵֽ<0-0xFFFF>
//</h>
#define     CFG_PCA0_CCR0       0x0


//<h>CCR1_PCAx Ƚ/׽ģ1׽ֵ
//<i>0x02C b31~16 b15~0 
//<i>CCR1  CCR1H  CCR1L 
// <o0.0..15> CCR1L_PCAx Ƚ/׽ģ1ĴֽڣLSB<0-0xFFFF>
// <o0.16..31> CCR1H_PCAx Ƚ/׽ģ1ĴֽڣMSB<0-0xFFFF>
//</h>
#define     CFG_PCA0_CCR1       0x0


//<h>CCR2_PCAx Ƚ/׽ģ2׽ֵ
//<i>0x030 b31~16 b15~0 
//<i>CCR2  CCR2H  CCR2L 
// <o0.0..15> CCR2L_PCAx Ƚ/׽ģ2ĴֽڣLSB<0-0xFFFF> 
// <o0.16..31> CCR2H_PCAx Ƚ/׽ģ2ĴֽڣMSB<0-0xFFFF>
//</h>
#define     CFG_PCA0_CCR2       0x0
//</e>


//<i>PSC_ԤƵ
//<i>0x014 b31~16 b15~0 
//<i>PSC   -      PSC   
// <o0.0..15> PSC_ԤƵ <0-0xFFFF>
#define     CFG_PCA0_PSC_INIT   0
// <o0.0..2> CPS_PCAx/ʱʱѡ 
//    <0=>PCLKʱ
//    <1=>PCAxECI½
//    <2=>RC128K
// <o0.6> SDEN_PCAx ģʽѡλ
//    <0=>PCAxϼݲģʽ
//    <1=>PCAxǲģʽ
//    <i>PCAxϼݲģʽ, ʱPCAxȽϲ׽ģģʽֹ
//    <i>PCAxǲģʽʱPCAxȽϲ׽ģľݲģʽֹ


//<h>CNT_PCAxĴ
//<i>0x010 b31~16 b15~0 
//<i>CNT   CNTH   CNTL  
// <o1.0..15> CNTL_PCAxֵ16λ <0-0xFFFF>
// <o1.16..31> CNTH_PCAxֵ16λ <0-0xFFFF>
//</h>


//<h>PCAx ʽ
//<i>0x004 b31~20 b19~18 b17~16 b15 b14   b13   b12   b11 b10~9  b8  b7  b6   b5~3 b2~0 
//<i>CFGR  -      SYN    ECF    PUE CC2UE CC1UE CC0UE -   ADTSEL PIE CIE SDEN -    CPS  


//<i>PCAx趨ΪģʽеһʱȽϲ׽ģһбģʽʹҲЧġ
// <q0.7> CIE_PCAx/ʱжλ
//    <i>0: ֹж
//    <i>1: CIFλʱ PCAx/ʱж
//λPCAx/ʱCIFжϵλ
// <q0.8> PIE_PCAx/ʱжλ
//    <i>0: ֹж
//    <i>1: PIFλʱ PCAx/ʱڵж
//λPCAx/ʱڣPIFжϵλ
// <o0.12> CC0UE_PCAxȽģ0ʹλ
//    <0=>д뵽CCR0ֵһЧ
//    <1=>д뵽CCR0ֵЧ
// <o0.13> CC1UE_PCAxȽģ1ʹλ
//    <0=>д뵽CCR1ֵһЧ
//    <1=>д뵽CCR1ֵЧ
// <o0.14> CC2UE_PCAxȽģ2ʹλ
//    <0=>д뵽CCR2ֵһЧ
//    <1=>д뵽CCR2ֵЧ
// <o0.15> PUE_PCAxֵʹλ
//    <0=>д뵽PRĴֵһЧ
//    <1=>д뵽PRĴֵЧ
// <o0.16..17> ECF_PCAx_ECIź˲ʱ
//    <0=>˲
//    <1=>˲ʱΪ8*PCLK
//    <2=>˲ʱΪ16*PCLK
//    <3=>˲ʱΪ32*PCLK
// <o0.18..19> SYN_PCAx_ͬʹλ
//    <0=>ͬ
//    <1=>PENλ10һPCAģͬ
//    <2=>PENλ10MCMʹλͬ
// <o0.9..10> ADTSEL_PCAxADCѡλ
//    <0=>ADC
//    <1=>ϼԴADC
//    <2=>¼ADC
//    <3=>/¼ԴADC
//<i>ADTSELΪ10b11bֻSDEN=1ʱЧSDENΪ0ʱADTSELΪ1xb൱00b
//<i>ADTR_ȽϴĴ
//<i>0x038 b31~0 
//<i>ADTR  DATA  
// <o2.0..31> DATA_ADCȽϼĴ
//<i>˼ĴֵƥʱᴥADCת <0-0xFFFFFFFF>
//</h>


#define     CFG_PCA0_CFGR_INIT  7
#define     CFG_PCA0_CNT_INIT   0x0
#define     CFG_PCA0_ADTR_INIT  0


//<h>CCMR0_PCAxA ׽/Ƚģ0ƼĴ
//<i>0x01C b31~13 b12   b11~9 b8 b7~6 b5~4 b3  b2  b1 b0   
//<i>CCMR0 -      CSSEL ICF   CC SM   FS   CEN TCP -  CCIE 
// <q0.3> CEN_Ƚ/׽ģ鹦ʹλ
//    <i>0: ֹȽ/׽ģ0
//    <i>1: ʹܱȽ/׽ģ0
// <o0.4..7>  PCAxģʽѡλ
//    <0=>׽ʽش
//		<2=>׽ʽڸش
//  	<3=>׽ʽش
//    <4=>Ƚƥ,ƥ
//    <6=>Ƚƥ,ƥ
//    <8=>Ƶģʽ
//  	<12=>PWMģʽ16λPWM1ģʽ
//  	<13=>PWMģʽ32λPWM2ģʽ
//  	<14=>PWMģʽ32λPWM3ģʽ
//  	<15=>PWMģʽ32λPWM4ģʽ
// <o0.2> TCP_λ
//    <0=>ʼƽΪߵƽ
//    <1=>ʼƽΪ͵ƽ
// <q0.0> CCIE_׽/Ƚϱ־жλ
//    <i>0: ֹȽϲ׽/Ƚж
//    <i>1: ֹȽϲ׽/Ƚжϣ CCIFλ1ʱ׽/Ƚϱ־ж
// <o0.8> CC_ʱʹλ
//    <0=>¼ʱֵ
//    <1=>¼ʱֵ
// <o0.9..11> ICF_PCAxA벶׽ź˲ʱ
//    <0=>˲
//    <1=>˲ʱΪ40*PCLK
//    <2=>˲ʱΪ80*PCLK
//    <3=>˲ʱΪ160*PCLK
//    <4=>˲ʱΪ320*PCLK
//    <5=>˲ʱΪ640*PCLK
//    <6=>˲ʱΪ1280*PCLK
//    <7=>˲ʱΪ2560*PCLK
//<i>Mode0ģʽЧ
// <o0.12> CSSEL_Դѡλ
//    <0=>ѡPCAxAΪԴ
//    <1=>ѡȽ0C0OUT0ΪԴ
//<i>λֻڲģʽЧSM=00ģʽ²Ϊ1
//</h>

#define     CFG_PCA0_CCMR0_INIT 512


//<h>CCMR1_PCAxB ׽/Ƚģ1ƼĴ
//<i>0x020 b31~13 b12   b11~9 b8 b7~6 b5~4 b3  b2  b1 b0   
//<i>CCMR1 -      CSSEL ICF   CC SM   FS   CEN TCP -  CCIE 
// <q0.3> CEN_Ƚ/׽ģ鹦ʹλ
//    <i>0: ֹȽ/׽ģ0
//    <i>1: ʹܱȽ/׽ģ0
// <o0.4..7> PCAxģʽѡλ
//    <0=>׽ʽش
//		<2=>׽ʽڸش
//  	<3=>׽ʽش
//    <4=>Ƚƥ,ƥ
//    <6=>Ƚƥ,ƥ
//    <8=>Ƶģʽ
//  	<12=>PWMģʽ16λPWM1ģʽ
//  	<13=>PWMģʽ32λPWM2ģʽ
//  	<14=>PWMģʽ32λPWM3ģʽ
//  	<15=>PWMģʽ32λPWM4ģʽ
// <o0.2> TCP_λ
//    <0=>ʼƽΪߵƽ
//    <1=>ʼƽΪ͵ƽ
// <q0.0> CCIE_׽/Ƚϱ־жλ
//    <i>0: ֹȽϲ׽/Ƚж
//    <i>1: ֹȽϲ׽/Ƚжϣ CCIFλ1ʱ׽/Ƚϱ־ж
// <o0.8> CC_ʱʹλ
//    <0=>¼ʱֵ
//    <1=>¼ʱֵ
// <o0.9..11> ICF_PCAxB벶׽ź˲ʱ
//    <0=>˲
//    <1=>˲ʱΪ40*PCLK
//    <2=>˲ʱΪ80*PCLK
//    <3=>˲ʱΪ160*PCLK
//    <4=>˲ʱΪ320*PCLK
//    <5=>˲ʱΪ640*PCLK
//    <6=>˲ʱΪ1280*PCLK
//    <7=>˲ʱΪ2560*PCLK
//<i>Mode0ģʽЧ
// <o0.12> CSSEL_Դѡλ
//    <0=>ѡPCAxBΪԴ
//    <1=>ѡȽ0C0OUT0ΪԴ
//<i>λֻڲģʽЧSM=00ģʽ²Ϊ1
//</h>
#define     CFG_PCA0_CCMR1_INIT 512


//<h>CCMR2_PCAxC ׽/Ƚģ2ƼĴ
//<i>0x024 b31~13 b12   b11~9 b8 b7~6 b5~4 b3  b2  b1 b0   
//<i>CCMR2 -      CSSEL ICF   CC SM   FS   CEN TCP -  CCIE 
// <q0.3> CEN_Ƚ/׽ģ鹦ʹλ
//    <i>0: ֹȽ/׽ģ0
//    <i>1: ʹܱȽ/׽ģ0
// <o0.4..7> PCAxģʽѡλ
//    <0=>׽ʽش
//		<2=>׽ʽڸش
//  	<3=>׽ʽش
//    <4=>Ƚƥ,ƥ
//    <6=>Ƚƥ,ƥ
//    <8=>Ƶģʽ
//  	<12=>PWMģʽ16λPWM1ģʽ
//  	<13=>PWMģʽ32λPWM2ģʽ
//  	<14=>PWMģʽ32λPWM3ģʽ
//  	<15=>PWMģʽ32λPWM4ģʽ
// <o0.2> TCP_λ
//    <0=>ʼƽΪߵƽ
//    <1=>ʼƽΪ͵ƽ
// <q0.0> CCIE_׽/Ƚϱ־жλ
//    <i>0: ֹȽϲ׽/Ƚж
//    <i>1: ֹȽϲ׽/Ƚжϣ CCIFλ1ʱ׽/Ƚϱ־ж
// <o0.8> CC_ʱʹλ
//    <0=>¼ʱֵ
//    <1=>¼ʱֵ
// <o0.9..11> ICF_PCAxC벶׽ź˲ʱ
//    <0=>˲
//    <1=>˲ʱΪ40*PCLK
//    <2=>˲ʱΪ80*PCLK
//    <3=>˲ʱΪ160*PCLK
//    <4=>˲ʱΪ320*PCLK
//    <5=>˲ʱΪ640*PCLK
//    <6=>˲ʱΪ1280*PCLK
//    <7=>˲ʱΪ2560*PCLK
//<i>Mode0ģʽЧ
// <o0.12> CSSEL_Դѡλ
//    <0=>ѡPCAxCΪԴ
//    <1=>ѡȽ0C0OUT0ΪԴ
//<i>λֻڲģʽЧSM=00ģʽ²Ϊ1
//</h>
#define     CFG_PCA0_CCMR2_INIT 512


#define CFG_PCA0_FLTWPR_INIT	0x0
//<h>FLTCR_PWM0/1/2ϼⱣĴ
//<i>0x040 b31~15 b14   b13~12 b11    b10    b9~8    b7~4    b3     b2    b1   b0      
//<i>FLTCR -      FLTIE FOUT   FLTSYN FLT1EN FLT1SEL FLT2DEB FLT2EN FLT2S FLTM FLTSTAT 
// <o0.10> FLT1EN_ϼ1ܿλ
//    <0=>ϼ1ֹܽ
//    <1=>ϼ1ܴ򿪣ԴѡȽ0Ƚ1
// <o0.8..9> FLT1SEL_ϼ1Դѡλ
//    <0=>Ƚ0˲ΪPCAϼ1ԴߵƽЧ
//    <1=>Ƚ1˲ΪPCAϼ1ԴߵƽЧ
// <o0.3> FLT2EN_ϼ2ܿλ
//    <0=>ϼ2ֹܽ
//    <1=>ϼ2ܴ򿪣ԴΪFLT
// <o0.2> FLT2S_ϼ2Чƽѡλ
//    <0=>FLTߵƽЧ
//    <1=>FLT͵ƽЧ
// <o0.4..7> FLT2DEB_ϼ2˲ѡ
//    <0=>˲
//    <1=>0.5us
//    <2=>1us
//    <3=>1.5us
//    <4=>2us
//    <5=>3us
//    <6=>4us
//    <7=>6us
//    <8=>8us
//    <9=>10us
//    <10=>12us
//    <11=>14us
//    <12=>16us
//    <13=>20us
//    <14=>24us
//    <15=>32us
//<i>˲ʱ䲻Ǿȷֵ
//<i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.1> FLTM_⹦ģʽѡ
//    <0=>ģʽ
//    <1=>ģʽ
// <q0.11> FLTSYN_ϼͬλ
//  <i>0: ϼͬƽֹ
//  <i>1: ϼͬʹ
//<i>PCAxĴλΪ1ʱһPCAĹϼ⣨ϼ1͹ϼ2ͬʱPCAΪԤõ״̬
// <o0.12..13> FOUT_Ϸ״̬ѡλ
//    <0=>̬
//    <2=>͵ƽ
//    <3=>ߵƽ
// <q0.14> FLTIE_жλ
//    <i>0: ֹϼж
//    <i>1: ϼж


//<i>ģʽ⵽ЧFLTSTAT Ӳ1PCAĲνֹͣΪЧʱ״ֲ̬䣬ֻеFLTSTAT󣬲βŻڷ¼ʱָһֱЧʱFLTSTAT޷
//<i>ģʽPCAĲֱɹϼƣЧFLTSTATӲ1رPCAĲΪЧFLTSTATԶ0PCAxA/B/Cνڷ¼ʱԶָ
//</h>
#define     CFG_PCA0_FLTCR_INIT 0


#if (CFG_PCA0_CFGR_INIT & 1) 
	#define CFG_PCA0_CLK		(unsigned long)(SYS_CLK/APB_F/(CFG_PCA0_PSC_INIT + 1))
#elif (CFG_PCA0_CFGR_INIT & (1<<1)) 
	#define CFG_PCA0_CLK		(unsigned long)(128000/(CFG_PCA0_PSC_INIT + 1))		
#else
	#define CFG_PCA0_CLK		(unsigned long)(SYS_CLK/APB_F/(CFG_PCA0_PSC_INIT + 1))
#endif
#if (CFG_PCA0_CFGR_INIT & (1<<6)) 
	#define CFG_PCA0_SDEN_MODE 2
#else
	#define CFG_PCA0_SDEN_MODE 1
#endif


#if (CFG_PCA_C0_EN == 1)	
	#define CFG_PCA0_PR_INIT (uint32_t)(CFG_PCA0_CLK/CFG_PCA_PCA0_PR_F/CFG_PCA0_SDEN_MODE)
#else
	#define CFG_PCA0_PR_INIT			CFG_PCA0_PR
#endif


#if (CFG_PCA_C0_EN == 1)	
	#define CFG_PCA0_CCR0_INIT (uint32_t)(CFG_PCA0_PR_INIT*CFG_PCA_PCA0A_DUTY/1000)
	#define CFG_PCA0_CCR1_INIT (uint32_t)(CFG_PCA0_PR_INIT*CFG_PCA_PCA0B_DUTY/1000)
	#define CFG_PCA0_CCR2_INIT (uint32_t)(CFG_PCA0_PR_INIT*CFG_PCA_PCA0C_DUTY/1000)
#else
	#define CFG_PCA0_CCR0_INIT 		CFG_PCA0_CCR0
	#define CFG_PCA0_CCR1_INIT 		CFG_PCA0_CCR1
	#define CFG_PCA0_CCR2_INIT 		CFG_PCA0_CCR2
#endif
#define CFG_PCA0_INT_EN (((CFG_PCA0_CFGR_INIT & 0x80)>>7) | ((CFG_PCA0_CFGR_INIT & 0x100)>>8)| (CFG_PCA0_CCMR0_INIT & 0x01) |(CFG_PCA0_CCMR1_INIT & 0x01)|(CFG_PCA0_CCMR2_INIT & 0x01))
#define CFG_PCA0_FLT_INT_EN ((CFG_PCA0_FLTCR_INIT>>14)&0x01)
//</e>


//***********************************************************/
//<e>PCA1
#define     CFG_PCA1_EN         0
//<i>CR_PCAx ʹܼĴ
//<i>0x000 b31~1 b0  
//<i>CR    -     PEN 
// <q0.0> PEN_PCAx /ʱпλ
//  <i>0: ֹPCAx/ʱ
//  <i>1: PCAx/ʱ
#define     CFG_PCA1_CR_INIT    0
//<e>ƵռձԶPRCCRx
//<i>÷ʽPCAxģʽ
#define     CFG_PCA_C1_EN       0


// <o> PCA1Ƶ (0-100000Hz) <0-100000> 
#define     CFG_PCA_PCA1_PR_F   1000
//<o0>PCA1A:  PCA1A/Ƚ/ռձ (0.1%) <0-1000>
#define     CFG_PCA_PCA1A_DUTY  400
//<o0>PCA1B:  PCA1B/Ƚ/ռձ (0.1%) <0-1000>
#define     CFG_PCA_PCA1B_DUTY  200
//<o0>PCA1C:  PCA1C/Ƚ/ռձ (0.1%) <0-1000>
#define     CFG_PCA_PCA1C_DUTY  300
//</e>


//<e>üPRCCRx
//<i>÷ʽPCAxģʽ
#define     CFG_PCA1_E0_EN      0


//<h>PR_PCAx ֵ
//<i>0x018 b31~16 b15~0 
//<i>PR    PRH    PRL   
// <o0.0..15> PRL_PCAx ֵֽڣLSB<0-0xFFFF> 
// <o0.16..31> PRH_PCAx ֵֽڣMSB<0-0xFFFF> 
#define     CFG_PCA1_PR         0x0
//</h>


//<h>CCR0_PCAx Ƚ/׽ģ0׽ֵ
//<i>0x028 b31~16 b15~0 
//<i>CCR0  CCR0H  CCR0L 
// <o0.0..15> CCR0L_PCAx Ƚ/׽ģ0Ĵֽ<0-0xFFFF> 
// <o0.16..31> CCR0H_PCAx Ƚ/׽ģ0Ĵֽ<0-0xFFFF> 
//</h>
#define     CFG_PCA1_CCR0       0x0


//<h>CCR1_PCAx Ƚ/׽ģ1׽ֵ
//<i>0x02C b31~16 b15~0 
//<i>CCR1  CCR1H  CCR1L 
// <o0.0..15> CCR1L_PCAx Ƚ/׽ģ1ĴֽڣLSB<0-0xFFFF> 
// <o0.16..31> CCR1H_PCAx Ƚ/׽ģ1ĴֽڣMSB<0-0xFFFF> 
//</h>
#define     CFG_PCA1_CCR1       0x0


//<h>CCR2_PCAx Ƚ/׽ģ2׽ֵ
//<i>0x030 b31~16 b15~0 
//<i>CCR2  CCR2H  CCR2L 
// <o0.0..15> CCR2L_PCAx Ƚ/׽ģ2ĴֽڣLSB<0-0xFFFF> 
// <o0.16..31> CCR2H_PCAx Ƚ/׽ģ2ĴֽڣMSB<0-0xFFFF> 
//</h>
#define     CFG_PCA1_CCR2       0x0
//</e>


//<i>PSC_ԤƵ
//<i>0x014 b31~16 b15~0 
//<i>PSC   -      PSC   
// <o0.0..15> PSC_ԤƵ <0-0xFFFF>
#define     CFG_PCA1_PSC_INIT   0
// <o0.0..2> CPS_PCAx/ʱʱѡ 
//    <0=>PCLKʱ
//    <1=>PCAxECI½
//    <2=>RC128K
// <o0.6> SDEN_PCAx ģʽѡλ
//    <0=>PCAxϼݲģʽ
//    <1=>PCAxǲģʽ
//    <i>PCAxϼݲģʽ, ʱPCAxȽϲ׽ģģʽֹ
//    <i>PCAxǲģʽʱPCAxȽϲ׽ģľݲģʽֹ


//<h>CNT_PCAxĴ
//<i>0x010 b31~16 b15~0 
//<i>CNT   CNTH   CNTL  
// <o1.0..15> CNTL_PCAxֵ16λ <0-0xFFFF>
// <o1.16..31> CNTH_PCAxֵ16λ <0-0xFFFF>
//</h>


//<h>PCAx ʽ
//<i>0x004 b31~20 b19~18 b17~16 b15 b14   b13   b12   b11 b10~9  b8  b7  b6   b5~3 b2~0 
//<i>CFGR  -      SYN    ECF    PUE CC2UE CC1UE CC0UE -   ADTSEL PIE CIE SDEN -    CPS  


//<i>PCAx趨ΪģʽеһʱȽϲ׽ģһбģʽʹҲЧġ
// <q0.7> CIE_PCAx/ʱжλ
//    <i>0: ֹж
//    <i>1: CIFλʱ PCAx/ʱж
//λPCAx/ʱCIFжϵλ
// <q0.8> PIE_PCAx/ʱжλ
//    <i>0: ֹж
//    <i>1: PIFλʱ PCAx/ʱڵж
//λPCAx/ʱڣPIFжϵλ
// <o0.12> CC0UE_PCAxȽģ0ʹλ
//    <0=>д뵽CCR0ֵһЧ
//    <1=>д뵽CCR0ֵЧ
// <o0.13> CC1UE_PCAxȽģ1ʹλ
//    <0=>д뵽CCR1ֵһЧ
//    <1=>д뵽CCR1ֵЧ
// <o0.14> CC2UE_PCAxȽģ2ʹλ
//    <0=>д뵽CCR2ֵһЧ
//    <1=>д뵽CCR2ֵЧ
// <o0.15> PUE_PCAxֵʹλ
//    <0=>д뵽PRĴֵһЧ
//    <1=>д뵽PRĴֵЧ
// <o0.16..17> ECF_PCAx_ECIź˲ʱ
//    <0=>˲
//    <1=>˲ʱΪ8*PCLK
//    <2=>˲ʱΪ16*PCLK
//    <3=>˲ʱΪ32*PCLK
// <o0.18..19> SYN_PCAx_ͬʹλ
//    <0=>ͬ
//    <1=>PENλ10һPCAģͬ
//    <2=>PENλ10MCMʹλͬ
// <o0.9..10> ADTSEL_PCAxADCѡλ
//    <0=>ADC
//    <1=>ϼԴADC
//    <2=>¼ADC
//    <3=>/¼ԴADC
//<i>ADTSELΪ10b11bֻSDEN=1ʱЧSDENΪ0ʱADTSELΪ1xb൱00b
//<i>ADTR_ȽϴĴ
//<i>0x038 b31~0 
//<i>ADTR  DATA  
// <o2.0..31> DATA_ADCȽϼĴ
//<i>˼ĴֵƥʱᴥADCת <0-0xFFFFFFFF>
//</h>


#define     CFG_PCA1_CFGR_INIT  0
#define     CFG_PCA1_CNT_INIT   0x0
#define     CFG_PCA1_ADTR_INIT  0


//<h>CCMR0_PCAxA ׽/Ƚģ0ƼĴ
//<i>0x01C b31~13 b12   b11~9 b8 b7~6 b5~4 b3  b2  b1 b0   
//<i>CCMR0 -      CSSEL ICF   CC SM   FS   CEN TCP -  CCIE 
// <q0.3> CEN_Ƚ/׽ģ鹦ʹλ
//    <i>0: ֹȽ/׽ģ0
//    <i>1: ʹܱȽ/׽ģ0
// <o0.4..7> PCAxģʽѡλ
//    <0=>׽ʽش
//		<2=>׽ʽڸش
//  	<3=>׽ʽش
//    <4=>Ƚƥ,ƥ
//    <6=>Ƚƥ,ƥ
//    <8=>Ƶģʽ
//  	<12=>PWMģʽ16λPWM1ģʽ
//  	<13=>PWMģʽ32λPWM2ģʽ
//  	<14=>PWMģʽ32λPWM3ģʽ
//  	<15=>PWMģʽ32λPWM4ģʽ
// <o0.2> TCP_λ
//    <0=>ʼƽΪߵƽ
//    <1=>ʼƽΪ͵ƽ
// <q0.0> CCIE_׽/Ƚϱ־жλ
//    <i>0: ֹȽϲ׽/Ƚж
//    <i>1: ֹȽϲ׽/Ƚжϣ CCIFλ1ʱ׽/Ƚϱ־ж
// <o0.8> CC_ʱʹλ
//    <0=>¼ʱֵ
//    <1=>¼ʱֵ
// <o0.9..11> ICF_PCAxA벶׽ź˲ʱ
//    <0=>˲
//    <1=>˲ʱΪ40*PCLK
//    <2=>˲ʱΪ80*PCLK
//    <3=>˲ʱΪ160*PCLK
//    <4=>˲ʱΪ320*PCLK
//    <5=>˲ʱΪ640*PCLK
//    <6=>˲ʱΪ1280*PCLK
//    <7=>˲ʱΪ2560*PCLK
//<i>Mode0ģʽЧ
// <o0.12> CSSEL_Դѡλ
//    <0=>ѡPCAxAΪԴ
//    <1=>ѡȽ0C0OUT0ΪԴ
//<i>λֻڲģʽЧSM=00ģʽ²Ϊ1
//</h>

#define     CFG_PCA1_CCMR0_INIT 132


//<h>CCMR1_PCAxB ׽/Ƚģ1ƼĴ
//<i>0x020 b31~13 b12   b11~9 b8 b7~6 b5~4 b3  b2  b1 b0   
//<i>CCMR1 -      CSSEL ICF   CC SM   FS   CEN TCP -  CCIE 
// <q0.3> CEN_Ƚ/׽ģ鹦ʹλ
//    <i>0: ֹȽ/׽ģ0
//    <i>1: ʹܱȽ/׽ģ0
// <o0.4..7> PCAxģʽѡλ
//    <0=>׽ʽش
//		<2=>׽ʽڸش
//  	<3=>׽ʽش
//    <4=>Ƚƥ,ƥ
//    <6=>Ƚƥ,ƥ
//    <8=>Ƶģʽ
//  	<12=>PWMģʽ16λPWM1ģʽ
//  	<13=>PWMģʽ32λPWM2ģʽ
//  	<14=>PWMģʽ32λPWM3ģʽ
//  	<15=>PWMģʽ32λPWM4ģʽ
// <o0.2> TCP_λ
//    <0=>ʼƽΪߵƽ
//    <1=>ʼƽΪ͵ƽ
// <q0.0> CCIE_׽/Ƚϱ־жλ
//    <i>0: ֹȽϲ׽/Ƚж
//    <i>1: ֹȽϲ׽/Ƚжϣ CCIFλ1ʱ׽/Ƚϱ־ж
// <o0.8> CC_ʱʹλ
//    <0=>¼ʱֵ
//    <1=>¼ʱֵ
// <o0.9..11> ICF_PCAxB벶׽ź˲ʱ
//    <0=>˲
//    <1=>˲ʱΪ40*PCLK
//    <2=>˲ʱΪ80*PCLK
//    <3=>˲ʱΪ160*PCLK
//    <4=>˲ʱΪ320*PCLK
//    <5=>˲ʱΪ640*PCLK
//    <6=>˲ʱΪ1280*PCLK
//    <7=>˲ʱΪ2560*PCLK
//<i>Mode0ģʽЧ
// <o0.12> CSSEL_Դѡλ
//    <0=>ѡPCAxBΪԴ
//    <1=>ѡȽ0C0OUT0ΪԴ
//<i>λֻڲģʽЧSM=00ģʽ²Ϊ1
//</h>
#define     CFG_PCA1_CCMR1_INIT 128


//<h>CCMR2_PCAxC ׽/Ƚģ2ƼĴ
//<i>0x024 b31~13 b12   b11~9 b8 b7~6 b5~4 b3  b2  b1 b0   
//<i>CCMR2 -      CSSEL ICF   CC SM   FS   CEN TCP -  CCIE 
// <q0.3> CEN_Ƚ/׽ģ鹦ʹλ
//    <i>0: ֹȽ/׽ģ0
//    <i>1: ʹܱȽ/׽ģ0
// <o0.4..7> PCAxģʽѡλ
//    <0=>׽ʽش
//		<2=>׽ʽڸش
//  	<3=>׽ʽش
//    <4=>Ƚƥ,ƥ
//    <6=>Ƚƥ,ƥ
//    <8=>Ƶģʽ
//  	<12=>PWMģʽ16λPWM1ģʽ
//  	<13=>PWMģʽ32λPWM2ģʽ
//  	<14=>PWMģʽ32λPWM3ģʽ
//  	<15=>PWMģʽ32λPWM4ģʽ
// <o0.2> TCP_λ
//    <0=>ʼƽΪߵƽ
//    <1=>ʼƽΪ͵ƽ
// <q0.0> CCIE_׽/Ƚϱ־жλ
//    <i>0: ֹȽϲ׽/Ƚж
//    <i>1: ֹȽϲ׽/Ƚжϣ CCIFλ1ʱ׽/Ƚϱ־ж
// <o0.8> CC_ʱʹλ
//    <0=>¼ʱֵ
//    <1=>¼ʱֵ
// <o0.9..11> ICF_PCAxC벶׽ź˲ʱ
//    <0=>˲
//    <1=>˲ʱΪ40*PCLK
//    <2=>˲ʱΪ80*PCLK
//    <3=>˲ʱΪ160*PCLK
//    <4=>˲ʱΪ320*PCLK
//    <5=>˲ʱΪ640*PCLK
//    <6=>˲ʱΪ1280*PCLK
//    <7=>˲ʱΪ2560*PCLK
//<i>Mode0ģʽЧ
// <o0.12> CSSEL_Դѡλ
//    <0=>ѡPCAxCΪԴ
//    <1=>ѡȽ0C0OUT0ΪԴ
//<i>λֻڲģʽЧSM=00ģʽ²Ϊ1
//</h>
#define     CFG_PCA1_CCMR2_INIT 132


#define CFG_PCA1_FLTWPR_INIT	0x0
//<h>FLTCR_PWM0/1/2ϼⱣĴ
//<i>0x040 b31~15 b14   b13~12 b11    b10    b9~8    b7~4    b3     b2    b1   b0      
//<i>FLTCR -      FLTIE FOUT   FLTSYN FLT1EN FLT1SEL FLT2DEB FLT2EN FLT2S FLTM FLTSTAT 
// <o0.10> FLT1EN_ϼ1ܿλ
//    <0=>ϼ1ֹܽ
//    <1=>ϼ1ܴ򿪣ԴѡȽ0Ƚ1
// <o0.8..9> FLT1SEL_ϼ1Դѡλ
//    <0=>Ƚ0˲ΪPCAϼ1ԴߵƽЧ
//    <1=>Ƚ1˲ΪPCAϼ1ԴߵƽЧ
// <o0.3> FLT2EN_ϼ2ܿλ
//    <0=>ϼ2ֹܽ
//    <1=>ϼ2ܴ򿪣ԴΪFLT
// <o0.2> FLT2S_ϼ2Чƽѡλ
//    <0=>FLTߵƽЧ
//    <1=>FLT͵ƽЧ
// <o0.4..7> FLT2DEB_ϼ2˲ѡ
//    <0=>˲
//    <1=>0.5us
//    <2=>1us
//    <3=>1.5us
//    <4=>2us
//    <5=>3us
//    <6=>4us
//    <7=>6us
//    <8=>8us
//    <9=>10us
//    <10=>12us
//    <11=>14us
//    <12=>16us
//    <13=>20us
//    <14=>24us
//    <15=>32us
//<i>˲ʱ䲻Ǿȷֵ
//<i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.1> FLTM_⹦ģʽѡ
//    <0=>ģʽ
//    <1=>ģʽ
// <q0.11> FLTSYN_ϼͬλ
//  <i>0: ϼͬƽֹ
//  <i>1: ϼͬʹ
//<i>PCAxĴλΪ1ʱһPCAĹϼ⣨ϼ1͹ϼ2ͬʱPCAΪԤõ״̬
// <o0.12..13> FOUT_Ϸ״̬ѡλ
//    <0=>̬
//    <2=>͵ƽ
//    <3=>ߵƽ
// <q0.14> FLTIE_жλ
//    <i>0: ֹϼж
//    <i>1: ϼж


//<i>ģʽ⵽ЧFLTSTAT Ӳ1PCAĲνֹͣΪЧʱ״ֲ̬䣬ֻеFLTSTAT󣬲βŻڷ¼ʱָһֱЧʱFLTSTAT޷
//<i>ģʽPCAĲֱɹϼƣЧFLTSTATӲ1رPCAĲΪЧFLTSTATԶ0PCAxA/B/Cνڷ¼ʱԶָ
//</h>
#define     CFG_PCA1_FLTCR_INIT 0


#if (CFG_PCA1_CFGR_INIT & 1) 
	#define CFG_PCA1_CLK		(unsigned long)(SYS_CLK/APB_F/(CFG_PCA1_PSC_INIT + 1))
#elif (CFG_PCA1_CFGR_INIT & (1<<1)) 
	#define CFG_PCA1_CLK		(unsigned long)(128000/(CFG_PCA1_PSC_INIT + 1))		
#else
	#define CFG_PCA1_CLK		(unsigned long)(SYS_CLK/APB_F/(CFG_PCA1_PSC_INIT + 1))
#endif
#if (CFG_PCA1_CFGR_INIT & (1<<6)) 
	#define CFG_PCA1_SDEN_MODE 2
#else
	#define CFG_PCA1_SDEN_MODE 1
#endif


#if (CFG_PCA_C1_EN == 1)	
	#define CFG_PCA1_PR_INIT (uint32_t)(CFG_PCA1_CLK/CFG_PCA_PCA1_PR_F/CFG_PCA1_SDEN_MODE)
	#define CFG_PCA1_CCR0_INIT (uint32_t)(CFG_PCA1_PR_INIT*CFG_PCA_PCA1A_DUTY/1000)
	#define CFG_PCA1_CCR1_INIT (uint32_t)(CFG_PCA1_PR_INIT*CFG_PCA_PCA1B_DUTY/1000)
	#define CFG_PCA1_CCR2_INIT (uint32_t)(CFG_PCA1_PR_INIT*CFG_PCA_PCA1C_DUTY/1000)
#else
	#define CFG_PCA1_PR_INIT			CFG_PCA1_PR
	#define CFG_PCA1_CCR0_INIT 		CFG_PCA1_CCR0
	#define CFG_PCA1_CCR1_INIT 		CFG_PCA1_CCR1
	#define CFG_PCA1_CCR2_INIT 		CFG_PCA1_CCR2
#endif


#define CFG_PCA1_INT_EN (((CFG_PCA1_CFGR_INIT & 0x80)>>7) | ((CFG_PCA1_CFGR_INIT & 0x100)>>8)| (CFG_PCA1_CCMR0_INIT & 0x01) |(CFG_PCA1_CCMR1_INIT & 0x01)|(CFG_PCA1_CCMR2_INIT & 0x01))
#define CFG_PCA1_FLT_INT_EN ((CFG_PCA1_FLTCR_INIT>>14)&0x01)
//</e>


//***********************************************************/
//</e>


//<e>TIMER
#define     CFG_TIM_EN          0
//***********************************************************/
//<e>TIM7
#define     CFG_TIM7_EN         0
//<i>CR_TIMƼĴ
//<i>0x000 b31~16 b15    b14 b13~12 b11 b10 b9   b8     b7 b6 b5~4 b3  b2~1 b0  
//<i>CR    -      CASCEN -   ECF    -   TC  ETEN TRIGEN IE -  CLKS OPM -    STR 
// <o0.4..5> CLKS_TIMxʱԴICLKѡλ
//    <0=>ڲAPBʱӣPCLK
//    <1=>Tn(n=7,8)룬Զ
//    <2=>ڲLSI 128KHz RC
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <o1>TIM7ʼֵ <0-0xFFFF>


// <o2>TIM7ֵ(us) <0-100000000>


//<i>PSQ_TIMԤƵĴ
//<i>0x00C b31~16 b15~0 
//<i>PSQ   PSQH   PSQL  
// <o3> ʱƵֵ<0-65535>
//<i>ȫTIMЧ
//<i>ʱʱΪ(ICLK/(PSQ[15:0]+1))  


// <o0.3> ģʽ
//    <0=>ʱxʱʱֹͣ
//    <1=>ʱxʱʱֹͣ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <q0.7> TIMxжʹλ
//    <i>0: ֹʱTIMxж
//    <i>1: ʱTIMxж
// <q0.8> TIMxⲿģʹλ
//    <i>0: ʱxֹģ
//    <i>1: ʱxģ
// <q0.9> TIMx¼ʹλ
//    <i>0: ֹʱں
//    <i>1: ʱں
//   <i>֮Ϊ32λʱ
// <q0.10> Ƚλ
//    <i>0: ֹʱxȽ
//    <i>1: ʱxȽ
//<i>ʱȽʱ(TC=1)ʱԴѡTn(n=7,8)ڡ
// <o0.12..13> TxΪʱԴ˲ʱ
//    <0=>˲
//    <1=>˲ʱΪ8*PCLK
//    <2=>˲ʱΪ16*PCLK
//    <3=>˲ʱΪ32*PCLK
//<q4>ʱ7ϵʼʱ


#define     CFG_TIM7_CR_INIT    0
#define     CFG_TIM7_TCNT_INIT 0
#define     CFG_TIM7_RL_VALUE   0
#define     CFG_TIM7_PSQ_INIT   0
#define     CFG_TIM7_CR_START   0


#if ((CFG_TIM7_CR_INIT & (1<<7)) != 0)
	#define CFG_TIM7_INT_EN 1
#else
	#define CFG_TIM7_INT_EN 0
#endif


#if (CFG_TIM7_CR_INIT & 0x30) == 0x0
#define CFG_TIM7_CLK		(unsigned long)(SYS_CLK/APB_F/(CFG_TIM7_PSQ_INIT + 1)) 
#elif (CFG_TIM7_CR_INIT & 0x30) == 0x10
#define CFG_TIM7_CLK		100000 	
#elif (CFG_TIM7_CR_INIT & 0x30) == 0x20
#define CFG_TIM7_CLK		128000 	
#endif

#define CFG_TIM7_TPR_INIT (unsigned long)(CFG_TIM7_RL_VALUE*(CFG_TIM7_CLK/1000000.0))

//</e>
#if ((CFG_TIM_EN) && (CFG_TIM7_EN) && ((CFG_TIM7_CR_INIT & (1<<10)) || (CFG_TIM7_CR_INIT & (1<<4))) && ((CFG_PA0_AFR != 3)&&(CFG_PA3_AFR != 3)))
#error "TIM7 T7(PA0/PA3) AF3 function mapping is not enable."
#endif

//***********************************************************/
//<e>TIM8
#define     CFG_TIM8_EN         0
//<i>CR_TIMƼĴ
//<i>0x000 b31~16 b15    b14 b13~12 b11 b10 b9   b8     b7 b6 b5~4 b3  b2~1 b0  
//<i>CR    -      CASCEN -   ECF    -   TC  ETEN TRIGEN IE -  CLKS OPM -    STR 
// <o0.4..5> TIMxʱԴICLKѡλ
//    <0=>ڲAPBʱӣPCLK
//    <1=>Tn(n=7,8)룬Զ
//    <2=>ڲLSI 128KHz RC
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <o1>TIM8ʼֵ <0-0xFFFF>


// <o2>TIM8ֵ(us) <0-100000000>


//<i>TIMԤƵĴ
//<i>0x00C b31~16 b15~0 
//<i>PSQ   PSQH   PSQL  
// <o3> ʱƵֵ<0-65535>
//<i>ȫTIMЧ
//<i>ʱʱΪ(ICLK/(PSQ[15:0]+1))  


// <o0.3> OPM_ģʽ
//    <0=>ʱxʱʱֹͣ
//    <1=>ʱxʱʱֹͣ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <q0.7> TIMxжʹλ
//    <i>0: ֹʱTIMxж
//    <i>1: ʱTIMxж
// <q0.8> TIMxⲿģʹλ
//    <i>0: ʱxֹģ
//    <i>1: ʱxģ
// <q0.9> TIMx¼ʹλ
//    <i>0: ֹʱں
//    <i>1: ʱں
//   <i>֮Ϊ32λʱ
// <q0.10> Ƚλ
//    <i>0: ֹʱxȽ
//    <i>1: ʱxȽ
//<i>ʱȽʱ(TC=1)ʱԴѡTn(n=7,8)ڡ
// <o0.12..13> TxΪʱԴ˲ʱ
//    <0=>˲
//    <1=>˲ʱΪ8*PCLK
//    <2=>˲ʱΪ16*PCLK
//    <3=>˲ʱΪ32*PCLK
//<q4>TIM8ϵʼʱ


#define     CFG_TIM8_CR_INIT    0
#define     CFG_TIM8_TCNT_INIT 0
#define     CFG_TIM8_RL_VALUE   0
#define     CFG_TIM8_PSQ_INIT   0
#define     CFG_TIM8_CR_START   0


#if ((CFG_TIM8_CR_INIT & (1<<7)) != 0)
	#define CFG_TIM8_INT_EN 1
#else
	#define CFG_TIM8_INT_EN 0
#endif


#if (CFG_TIM8_CR_INIT & 0x30) == 0x0
#define CFG_TIM8_CLK		(unsigned long)(SYS_CLK/APB_F/(CFG_TIM8_PSQ_INIT + 1)) 
#elif (CFG_TIM8_CR_INIT & 0x30) == 0x10
#define CFG_TIM8_CLK		100000 	
#elif (CFG_TIM8_CR_INIT & 0x30) == 0x20
#define CFG_TIM8_CLK		128000 	
#endif


#define CFG_TIM8_TPR_INIT (unsigned long)(CFG_TIM8_RL_VALUE*(CFG_TIM8_CLK/1000000.0))//</e>
#if ((CFG_TIM_EN) && (CFG_TIM8_EN) && ((CFG_TIM8_CR_INIT & (1<<10)) || (CFG_TIM8_CR_INIT & (1<<4))) && ((CFG_PA2_AFR != 3)&&(CFG_PB14_AFR != 3)))
#error "TIM8 T8(PA2/PB14) AF3 function mapping is not enable."
#endif
//</e>
//***********************************************************/
//<e>TIM7&TIM8
#define     CFG_TIM78_EN        0
//<i>ʱT7൱32λTimerT8Ч
//<i>CR_TIMƼĴ
//<i>0x000 b31~16 b15    b14~11 b10 b9   b8     b7 b6 b5~4 b3  b2~1 b0  
//<i>CR    -      CASCEN -      TC  ETEN TRIGEN -  IE CLKS OPM -    STR 
// <o0.4..5> CLKS_TIMxʱԴICLKѡλ
//    <0=>ڲAPBʱӣPCLK
//    <1=>Tx룬Զ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <o1>ʼֵ <0-0xFFFFFFFF>


// <o2>ֵ(us) <0-100000000>


//<i>PSQ_TIMԤƵĴ
//<i>0x00C b31~16 b15~0 
//<i>PSQ   PSQH   PSQL  
// <o3> PSQL_ʱƵֵ<0-65535>
//<i>ȫTIMЧ
//<i>ʱʱΪ(ICLK/(PSQ[15:0]+1))  


// <o0.3> OPM_ģʽ
//    <0=>ʱxʱʱֹͣ
//    <1=>ʱxʱʱֹͣ
//<i>ʱ16λTIMĴλЧֻԣλTIMĴλһ
// <q0.7> IE_TIMxжʹλ
//    <i>0: ֹʱTIMxж
//    <i>1: ʱTIMxж
// <q0.8> TRIGEN_TIMxⲿģʹλ
//    <i>0: ʱxֹģ
//    <i>1: ʱxģ
// <q0.9> ETEN_TIMx¼ʹλ
//    <i>0: ֹʱں
//    <i>1: ʱں
//   <i>֮Ϊ32λʱ
// <q0.10> TC_Ƚλ
//    <i>0: ֹʱxȽ
//    <i>1: ʱxȽ
//<i>ʱȽʱ(TC=1)ʱԴѡTn(n=7,8)ڡ


//<q4>ϵʼʱ


#define     CFG_TIM78_CR_VALUE  0x0
#define     CFG_TIM78_TCNT_INIT 0x0
#define     CFG_TIM78_RL_VALUE  10000
#define     CFG_TIM78_PSQ_INIT  0x0
#define     CFG_TIM78_CR_START  0x0


#define CFG_TIM78_CR_INIT (CFG_TIM78_CR_VALUE|(CFG_TIM78_EN<<15))


#if ((CFG_TIM78_CR_INIT & (1<<7)) != 0)
	#define CFG_TIM78_INT_EN 1
#else
	#define CFG_TIM78_INT_EN 0
#endif


#if (CFG_TIM78_CR_INIT & 0x30) == 0x0
#define CFG_TIM78_CLK		(SYS_CLK/APB_F/(CFG_TIM78_PSQ_INIT + 1)) 
#elif (CFG_TIM78_CR_INIT & 0x30) == 0x10
#define CFG_TIM78_CLK		128000 	
#elif (CFG_TIM78_CR_INIT & 0x30) == 0x20
#define CFG_TIM78_CLK		128000 	
#endif

#define CFG_TIM78_TPR_INIT ((unsigned long)(CFG_TIM78_RL_VALUE*(CFG_TIM78_CLK/1000000.0)))


//</e>
#if ((CFG_TIM_EN) && (CFG_TIM78_EN) && ((CFG_TIM78_CR_INIT & (1<<10)) || (CFG_TIM78_CR_INIT & (1<<4))) && ((CFG_PA0_AFR != 3)&&(CFG_PA2_AFR != 3)&&(CFG_PA3_AFR != 3)&&(CFG_PB14_AFR != 3)))
#error "TIM7/8 T7/8(PA0/PA2/PA3/PB14) AF3 function mapping is not enable."
#endif
//</e>


//<e>MACP
#define     CFG_MACP_EN         0
//<h>CORDCSR0_CORDIC״̬Ĵ0
//<i>0x000    b31~15 b14~13 b12~8 b7   b6~5   b4 b3    b2   b1  b0  
//<i>CORDCSR0 -      ARITH  ITERA MODE FORMAT -  XYMRS KADJ OVF RUN 


// <o0.13..14> ARITH_CORDIC㷨ѡ
//   <0=>Բ
//   <1=>Ժ
//   <2=>˫
// <o0.8..12> ITERA_ѡ<0-31>
//<i>Ϊ31ĬϰFORMAT
//    <i>IQ24/IQ26ʽ£Ĭ27ε
//    <i>IQ15ʽ£16ΣҪûֶ޸
//<i>һҪݸʽƥ䣬ûҲΪھٶ֮Ȩ⣬ϸľҪο۷ûȷϣ˴ֻжϡ
// <o0.7> MODE_CORDICģʽѡλ
//    <0=>תģʽ
//    <1=>ģʽ
// <o0.5..6> FORMAT_CORDICݸʽ
//   <0=>IQ26ʽ
//   <1=>IQ24ʽ
//   <2=>IQ15ʽ
//<i>IQ26/IQ24ʹ27λCORDIC㣬IQ15ʹ16λCORDIC㡣
//<i>ݸʽ֣ûʹʽ룬Ҫе
// <o0.3> XYMRS_CORDICXYȵѡλ
//    <0=>һεXYΪս
//    <1=>һεXY2Ϊս
//    <i>ȷXYMRSλɱ
// <o0.2> KADJ_CORDICKӵѡλ
//    <0=>1/K
//    <1=>1/KK
//    <i>K=1.64676
//</h>
#define     CFG_MACP_CORDCSR0_INIT 6912


//<h>CORDCSR1_CORDIC״̬Ĵ1
//<i>0x010    b31~15 b14~13 b12~8 b7   b6~5   b4 b3    b2   b1  b0  
//<i>CORDCSR1 -      ARITH  ITERA MODE FORMAT -  XYMRS KADJ OVF RUN 
// <o0.13..14> ARITH_CORDIC㷨ѡ
//   <0=>Բ
//   <1=>Ժ
//   <2=>˫
// <o0.8..12> ITERA_ѡ<0-31>
//<i>Ϊ31ĬϰFORMAT
//    <i>IQ24/IQ26ʽ£Ĭ27ε
//    <i>IQ15ʽ£16ΣҪûֶ޸
//<i>һҪݸʽƥ䣬ûҲΪھٶ֮Ȩ⣬ϸľҪο۷ûȷϣ˴ֻжϡ
// <o0.7> MODE_CORDICģʽѡλ
//    <0=>תģʽ
//    <1=>ģʽ
// <o0.5..6> FORMAT_CORDICݸʽ
//   <0=>IQ26ʽ
//   <1=>IQ24ʽ
//   <2=>IQ15ʽ
//<i>IQ26/IQ24ʹ27λCORDIC㣬IQ15ʹ16λCORDIC㡣
//<i>ݸʽ֣ûʹʽ룬Ҫе
// <o0.3> XYMRS_CORDICXYȵѡλ
//    <0=>һεXYΪս
//    <1=>һεXY2Ϊս
//    <i>ȷXYMRSλɱ
// <o0.2> KADJ_CORDICKӵѡλ
//    <0=>1/K
//    <1=>1/KK
//    <i>K=1.64676
//</h>

#define     CFG_MACP_CORDCSR1_INIT 6912
//<h>SVUALPHA_SVPWMUalphaֵĴ
//<i>0x204    b31~0    
//<i>SVUALPHA SVUALPHA 
// <o0.0..31> SVUALPHA_SVPWMUalphaֵ <0-2147483648>
//</h>

#define     CFG_MACP_SVUALPHA_INIT 0
//<h>SVUBETA_SVPWMUbetaֵĴ
//<i>0x208   b31~0   
//<i>SVUBETA SVUBETA 
// <o0.0..31> SVUBETA_SVPWMUbetaֵ <0-2147483648>
//</h>

#define     CFG_MACP_SVUBETA_INIT 0
//<h>SVIQN_SVPWMݸʽüĴ
//<i>0x20C b31~16 b15    b14    b13    b12    b11    b10    b9    b8    b7~0  
//<i>SVIQN -      OVERCH OVERBH OVERAH OVERCL OVERBL OVERAL SATEN SVTYP SVIQN 
// <o0.0..7> SVIQN_SVPWMݸʽ
// <o0.8> SVTYP_ʽ߶ʽѡλ
//  <0=>߶ʽ
//  <1=>ʽ
// <q0.9> SATEN_ʹλ
//  <i>0: ֹ
//  <i>1: ʹ
//</h>

#define     CFG_MACP_SVIQN_INIT 0
//***********************************************************/
//</e>
//<e>ADC
#define     CFG_ADC_EN          0
//***********************************************************/
//<h>ADCON1_ADCƼĴ1
//<i>0x000  b31~9 b8    b7   b6   b5      b4   b3 b2~1  b0    
//<i>ADCON1 -     ADOUT ADON ADIE ADTGREN REFC -  ADCTU ADSOC 
// <q0.7> ADON_ADCλ
//    <i>0: ֹADCxģ
//    <i>1: ADCxģ
// <q0.0> ADSOC_ADCͨADתλ
// <o0.1..2> ADCTU_ADCͨеתʽλ
//    <0=>תʽ
//    <1=>תʽ
//    <2=>תʽ
//    <3=>ģʽ
//    <i>޸ĸÿλһADתʱŲЧ
// <o0.4> REFC_׼ѹѡλ
//    <0=>ѡVDDΪ׼ѹ
//    <1=>ѡⲿVREF˿Ϊ׼ѹ
// <q0.5> ADTGREN_ⲿADTRGŴADCʹλ
// <q0.6> ADIE_ͨתжʹλ
//    <i>0: ֹADCתж
//    <i>1: ʹADCתж
// <q0.8> ADOUT_ͨADTRGADSOC״̬λ
#define     CFG_ADC_ADCON1_INIT 134
//</h>
#if ((CFG_ADC_ADCON1_INIT & (1<<6)) != 0)
	#define CFG_ADC_INT_EN 1
#else
	#define CFG_ADC_INT_EN 0
#endif


//<h>ADCON2_ADCƼĴ2
//<i>0x004  b31~15 b14~12 b11~8 b7~4    b3~0 
//<i>ADCON2 -      TGAP    TS  ADMAXCH TADC 
// <o0.0..3> TADC_ADCʱѡ
//    <0=>ADCʱtAD = 1 tPCLK
//    <1=>ADCʱtAD = 2 tPCLK
//    <2=>ADCʱtAD = 3 tPCLK
//    <3=>ADCʱtAD = 4 tPCLK
//    <4=>ADCʱtAD = 5 tPCLK
//    <5=>ADCʱtAD = 6 tPCLK
//    <6=>ADCʱtAD = 8 tPCLK
//    <7=>ADCʱtAD = 12 tPCLK
//    <8=>ADCʱtAD = 16 tPCLK
//    <9=>ADCʱtAD = 24 tPCLK
//    <10=>ADCʱtAD = 32 tPCLK
//    <11=>ADCʱtAD = 48 tPCLK
//    <12=>ADCʱtAD = 64 tPCLK
//    <13=>ADCʱtAD = 128 tPCLK
//    <14=>ADCʱtAD = 256 tPCLK
//    <15=>ADCʱtAD = 320 tPCLK
//    <i>tHCLKΪHCLKʱ
// <o0.4..7> ADMAXCH_һADת̵ģͨ:
//<0=>1
//<1=>2
//<2=>3
//<3=>4
//<4=>5
//<5=>6
//<6=>7
//<7=>8
//<8=>9
//<9=>10
//<10=>11
//<11=>12
//<12=>13
//<13=>14
//<14=>15
//<15=>16
//    <i>һADת̵ģͨΪADMAXCH+1
// <o0.8..11> TS_ʱ:
//<0=>1ADCʱ
//<1=>2ADCʱ
//<2=>3ADCʱ
//<3=>4ADCʱ
//<4=>5ADCʱ
//<5=>6ADCʱ
//<6=>7ADCʱ
//<7=>8ADCʱ
//<8=>9ADCʱ
//<9=>10ADCʱ
//<10=>11ADCʱ
//<11=>12ADCʱ
//<12=>13ADCʱ
//<13=>14ADCʱ
//<14=>15ADCʱ
//<15=>16ADCʱ
//<i>1 tAD   (TS [3-0]+1) * tAD  16 tAD
//<i>һͨܲʱ:TS + TGAP ˴TS֣
//<i>ܲʱ䷶Χ:1 tAD  ((TS[3~0])+1+TGAP[2~0]*GAPEN)* tAD  144 tAD TGAPGAPENǷʹܣ
//<i>TS[3:0]ǰӵADCŵĴ裬ԻѲȣѡ1 * tADΪʱʱȷӵADCŵĴ迹21.3.10
//<i>TADC豣֤ADCʱ Tadc  25ns
//<i>12bitģʽһܹͨתʱ = 15tAD + ʱ䣻10bitģʽһܹͨתʱ = 13tAD + ʱ
// <o0.12..14> TGAP_ת֮ͨʱλ
//<i>һתУһͨתϵһͨʼ֮ʱ
//<0=>޵ȴʱ
//<1=>2ADCʱ
//<2=>4ADCʱ
//<3=>8ADCʱ
//<4=>16ADCʱ
//<5=>32ADCʱ
//<6=>64ADCʱ
//<7=>128ADCʱ
//</h>
#define     CFG_ADC_ADCON2_INIT 4865


//<h>ADCMPCON_ADCȽϿƼĴ
//<i>0x04C    b31~8 b7    b6 b5    b4 b3~0 
//<i>ADCMPCON -     ADGIE -  ADLIE -  CSEL 
// <o0.0..3> CSEL_ڱȽϵĽĴѡλ
//    <0=>ѡADDR0еֵADDGTADDLTȽ
//    <1=>ѡADDR1еֵADDGTADDLTȽ
//    <2=>ѡADDR2еֵADDGTADDLTȽ
//    <3=>ѡADDR3еֵADDGTADDLTȽ
//    <4=>ѡADDR4еֵADDGTADDLTȽ
//    <5=>ѡADDR5еֵADDGTADDLTȽ
//    <6=>ѡADDR6еֵADDGTADDLTȽ
//    <7=>ѡADDR7еֵADDGTADDLTȽ
//    <8=>ѡADDR8еֵADDGTADDLTȽ
//    <9=>ѡADDR8еֵADDGTADDLTȽ
//    <10=>ѡADDR10еֵADDGTADDLTȽ
//    <11=>ѡADDR11еֵADDGTADDLTȽ
//    <12=>ѡADDR12еֵADDGTADDLTȽ
//    <13=>ѡADDR13еֵADDGTADDLTȽ
//    <14=>ѡADDR14еֵADDGTADDLTȽ
//    <15=>ѡADDR15еֵADDGTADDLTȽ
// <q0.5> ADLIE_ޱȽжʹλ
//    <i>0: ֹޱȽж
//    <i>1: ʹޱȽж
// <q0.7> ADGIE_ޱȽжʹλ
//    <i>0: ֹޱȽж
//    <i>1: ʹޱȽж
//</h>

#define     CFG_ADC_ADCMPCON_INIT 0


//<h>ADDGT_ADCޱȽϼĴ
//<i>0x050 b31~16 b15~0 
//<i>ADDGT -      GT    
// <o0.0..15> GT_ADCޱȽϼĴ<0-65535>
//һתʱADCMPCONĴCSELλָĴֵADDGTеֵȽϣڵADDGTеֵADCMPCONеADGIFλ1ADGIFλΪ1ֱ 
//</h>
#define     CFG_ADC_ADDGT_INIT  0


//<h>ADDLT_ADCޱȽϼĴ
//<i>0x054 b31~16 b15~0 
//<i>ADDLT -      LT    
// <o0.0..15> LT_ADCޱȽϼĴ<0-65535>
//һתʱADCMPCONĴCSELλָĴֵADDLTеֵȽϣСڵADDLTеֵADCMPCONеADLIFλ1ADLIFλΪ1ֱ 
//</h>
#define     CFG_ADC_ADDLT_INIT  0


//<h>SEQCHSEL0_ADCͨѡĴ0
//<i>0x058     b31~28 b27~24 b23~20 b19~16 b15~12 b11~8  b7~4   b3~0   
//<i>SEQCHSEL0 SEQCH7 SEQCH6 SEQCH5 SEQCH4 SEQCH3 SEQCH2 SEQCH1 SEQCH0 
// <o> SEQCH0_ģͨ0ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH0      13


// <o> SEQCH1_ģͨ1ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH1      13
// <o> SEQCH2_ģͨ2ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH2      0x0
// <o0> SEQCH3_ģͨ3ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH3      1
// <o> SEQCH4_ģͨ4ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH4      2
// <o> SEQCH5_ģͨ5ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH5      0x0
// <o> SEQCH6_ģͨ6ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH6      0x0
// <o> SEQCH7_ģͨ7ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH7      0x0
//</h>


#define CFG_ADC_SEQCHSEL0_INIT	(((uint32_t)CFG_ADC_SEQCH7<<28)\
																|(CFG_ADC_SEQCH6<<24)\
																|(CFG_ADC_SEQCH5<<20)\
																|(CFG_ADC_SEQCH4<<16)\
																|(CFG_ADC_SEQCH3<<12)\
																|(CFG_ADC_SEQCH2<<8)\
																|(CFG_ADC_SEQCH1<<4)\
																|CFG_ADC_SEQCH0)


//<h>SEQCHSEL1_ADCͨѡĴ1
//<i>0x05C     b31~28  b27~24  b23~20  b19~16  b15~12  b11~8   b7~4   b3~0   
//<i>SEQCHSEL1 SEQCH15 SEQCH14 SEQCH13 SEQCH12 SEQCH11 SEQCH10 SEQCH9 SEQCH8 
// <o> SEQCH8_ģͨ8ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH8      0x0


// <o> SEQCH9_ģͨ9ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH9      0x0
// <o> SEQCH10_ģͨ10ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH10     0
// <o0> SEQCH11_ģͨ11ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH11     0
// <o> SEQCH12_ģͨ12ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH12     0
// <o> SEQCH13_ģͨ13ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH13     0
// <o> SEQCH14_ģͨ14ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH14     0
// <o> SEQCH15_ģͨ15ѡӦģͨ:
//    <0=>AN0
//    <1=>AN1
//    <2=>AN2
//    <3=>AN3
//    <4=>AN4
//    <5=>AN5
//    <6=>AN6
//    <7=>AN7
//    <8=>AN8
//    <9=>AN9
//    <10=>AN10
//    <11=>OP0OUT/AN11
//    <12=>OP1OUT/AN12
//    <13=>OP2OUT/AN13
//    <14=>OP3OUT/AN14
//    <15=>Vbg
#define     CFG_ADC_SEQCH15     0
//</h>


#define CFG_ADC_SEQCHSEL1_INIT	(((uint32_t)CFG_ADC_SEQCH15<<28)\
																|(CFG_ADC_SEQCH14<<24)\
																|(CFG_ADC_SEQCH13<<20)\
																|(CFG_ADC_SEQCH12<<16)\
																|(CFG_ADC_SEQCH11<<12)\
																|(CFG_ADC_SEQCH10<<8)\
																|(CFG_ADC_SEQCH9<<4)\
																|CFG_ADC_SEQCH8)
																

//<h>HARDCHSEL_ģʽӲADCʼͨѡλ
// <o> ADTRG_ⲿADTRGADCʼͨѡλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHSEL_ADTRG 0


// <o> TIM8SEL_TIM8ADCʼͨѡλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHSEL_TIM8SEL 0


// <o> PCA1SEL_PCA1ADCʼͨѡλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHSEL_PCA1SEL 0


// <o> PCA0SEL_PCA0ADCʼͨѡλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHSEL_PCA0SEL 0


// <o> PWMCMP4_MCMPWMCMP4ADCʼͨѡλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHSEL_PWMCMP4 0


// <o> PWMCMP3_MCMPWMCMP3ADCʼͨѡλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHSEL_PWMCMP3 2


// <o> PWMCMP2_MCMPWMCMP2ADCʼͨѡλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHSEL_PWMCMP2 1


// <o> PWMCMP1_MCMPWMCMP1ADCʼͨѡλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHSEL_PWMCMP1 0
#define CFG_ADC_HARDCHSEL_INIT 	(((uint32_t)CFG_HARDCHSEL_ADTRG<<28)\
																|(CFG_HARDCHSEL_TIM8SEL<<24)\
																|(CFG_HARDCHSEL_PCA1SEL<<20)\
																|(CFG_HARDCHSEL_PCA0SEL<<16)\
																|(CFG_HARDCHSEL_PWMCMP4<<12)\
																|(CFG_HARDCHSEL_PWMCMP3<<8)\
																|(CFG_HARDCHSEL_PWMCMP2<<4)\
																|CFG_HARDCHSEL_PWMCMP1)
//</h>
//<h>HARDCHLH_ģʽӲADCͨλ
// <o> ADTRG_ⲿADTRGADCͨλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHLH_ADTRG  0


// <o> TIM8SEL_TIM8ADCͨλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHLH_TIM8SEL 0


// <o> PCA1SEL_PCA1ADCͨλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHLH_PCA1SEL 0


// <o> PCA0SEL_PCA0ADCͨλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHLH_PCA0SEL 0


// <o> PWMCMP4_MCMPWMCMP4ADCͨλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHLH_PWMCMP4 0


// <o> PWMCMP3_MCMPWMCMP3ADCͨλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHLH_PWMCMP3 2


// <o> PWMCMP2_MCMPWMCMP2ADCͨλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHLH_PWMCMP2 0


// <o> PWMCMP1_MCMPWMCMP1ADCͨλ
//    <0=>0
//    <1=>1
//    <2=>2
//    <3=>3
//    <4=>4
//    <5=>5
//    <6=>6
//    <7=>7
//    <8=>8
//    <9=>9
//    <10=>10
//    <11=>11
//    <12=>12
//    <13=>13
//    <14=>14
//    <15=>15
#define     CFG_HARDCHLH_PWMCMP1 0
//</h>
#define CFG_ADC_HARDCHLH_INIT 	(((uint32_t)CFG_HARDCHLH_ADTRG<<28)\
																|(CFG_HARDCHLH_TIM8SEL<<24)\
																|(CFG_HARDCHLH_PCA1SEL<<20)\
																|(CFG_HARDCHLH_PCA0SEL<<16)\
																|(CFG_HARDCHLH_PWMCMP4<<12)\
																|(CFG_HARDCHLH_PWMCMP3<<8)\
																|(CFG_HARDCHLH_PWMCMP2<<4)\
																|CFG_HARDCHLH_PWMCMP1)


																

//<h>ADGAPON_ADCͨGAPλ
//<i>0x068   b31~16  b15     b14     b13     b12     b11     b10     b9     b8    b7     b6     b5     b4     b3     b2     b1     b0     
//<i>ADGAPON -     GAPEN15 GAPEN14 GAPEN13 GAPEN12 GAPEN11 GAPEN10 GAPEN9 GAPEN8 GAPEN7 GAPEN6 GAPEN5 GAPEN4 GAPEN3 GAPEN2 GAPEN1 GAPEN0 
// <q0.0> GAPEN0_ADCͨ0GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.1> GAPEN1_ADCͨ1GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.2> GAPEN2_ADCͨ2GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.3> GAPEN3_ADCͨ3GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.4> GAPEN4_ADCͨ4GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.5> GAPEN5_ADCͨ5GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.6> GAPEN6_ADCͨ6GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.7> GAPEN7_ADCͨ7GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.8> GAPEN8_ADCͨ8GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.9> GAPEN9_ADCͨ9GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.10> GAPEN10_ADCͨ10GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.11> GAPEN11_ADCͨ11GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.12> GAPEN12_ADCͨ12GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.13> GAPEN13_ADCͨ13GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.14> GAPEN14_ADCͨ14GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
// <q0.15> GAPEN15_ADCͨ15GAPʱʹλ
//<i>0: ֹ
//<i>1: ʹ
//</h>
#define     CFG_ADC_ADGAPON_INIT 0


#if 0
#if ((CFG_ADC_EN) && (CFG_ADC_EN) \
									&& ((CFG_ADC_SEQCH1 == 0x1)||(CFG_ADC_SEQCH2 == 0x1)||(CFG_ADC_SEQCH3 == 0x1)||(CFG_ADC_SEQCH4 == 0x1)\
											||(CFG_ADC_SEQCH5 == 0x1)||(CFG_ADC_SEQCH6 == 0x1)||(CFG_ADC_SEQCH7 == 0x1))\
									&& (CFG_PD8_AFR != 7))
#error "ADC1 AN1(PB8) AF7 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC_EN) \
									&& ((CFG_ADC_SEQCH1 == 0x2)||(CFG_ADC_SEQCH2 == 0x2)||(CFG_ADC_SEQCH3 == 0x2)||(CFG_ADC_SEQCH4 == 0x2)\
											||(CFG_ADC_SEQCH5 == 0x2)||(CFG_ADC_SEQCH6 == 0x2)||(CFG_ADC_SEQCH7 == 0x2))\
									&& (CFG_PD9_AFR != 7))
#error "ADC1 AN2(PB9) AF7 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC_EN) \
									&& ((CFG_ADC_SEQCH1 == 0x3)||(CFG_ADC_SEQCH2 == 0x3)||(CFG_ADC_SEQCH3 == 0x3)||(CFG_ADC_SEQCH4 == 0x3)\
											||(CFG_ADC_SEQCH5 == 0x3)||(CFG_ADC_SEQCH6 == 0x3)||(CFG_ADC_SEQCH7 == 0x3))\
									&& (CFG_PD10_AFR != 7))
#error "ADC1 AN3(PD10) AF7 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC_EN) \
									&& ((CFG_ADC_SEQCH1 == 0x4)||(CFG_ADC_SEQCH2 == 0x4)||(CFG_ADC_SEQCH3 == 0x4)||(CFG_ADC_SEQCH4 == 0x4)\
											||(CFG_ADC_SEQCH5 == 0x4)||(CFG_ADC_SEQCH6 == 0x4)||(CFG_ADC_SEQCH7 == 0x4))\
									&& (CFG_PD11_AFR != 7))
#error "ADC1 AN4(PD11) AF7 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC_EN) \
									&& ((CFG_ADC_SEQCH1 == 0x5)||(CFG_ADC_SEQCH2 == 0x5)||(CFG_ADC_SEQCH3 == 0x5)||(CFG_ADC_SEQCH4 == 0x5)\
											||(CFG_ADC_SEQCH5 == 0x5)||(CFG_ADC_SEQCH6 == 0x5)||(CFG_ADC_SEQCH7 == 0x5))\
									&& (CFG_PD12_AFR != 7))
#error "ADC1 AN5(PD12) AF7 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC_EN) \
									&& ((CFG_ADC_SEQCH1 == 0x6)||(CFG_ADC_SEQCH2 == 0x6)||(CFG_ADC_SEQCH3 == 0x6)||(CFG_ADC_SEQCH4 == 0x6)\
											||(CFG_ADC_SEQCH5 == 0x6)||(CFG_ADC_SEQCH6 == 0x6)||(CFG_ADC_SEQCH7 == 0x6))\
									&& (CFG_PD13_AFR != 7))
#error "ADC1 AN6(PD13) AF7 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC_EN) \
									&& ((CFG_ADC_SEQCH1 == 0x7)||(CFG_ADC_SEQCH2 == 0x7)||(CFG_ADC_SEQCH3 == 0x7)||(CFG_ADC_SEQCH4 == 0x7)\
											||(CFG_ADC_SEQCH5 == 0x7)||(CFG_ADC_SEQCH6 == 0x7)||(CFG_ADC_SEQCH7 == 0x7))\
									&& (CFG_PD14_AFR != 7))
#error "ADC1 AN7(PD14) AF7 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC_EN) \
									&& ((CFG_ADC_SEQCH1 == 0xB )||(CFG_ADC_SEQCH2 == 0xB)||(CFG_ADC_SEQCH3 == 0xB)||(CFG_ADC_SEQCH4 == 0xB)\
											||(CFG_ADC_SEQCH5 == 0xB)||(CFG_ADC_SEQCH6 == 0xB)||(CFG_ADC_SEQCH7 == 0xB))\
									&& (CFG_PD4_AFR != 7))
#error "ADC1 OP1OUT(PD4) AF7 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC_EN) \
									&& ((CFG_ADC_SEQCH1 == 0xC)||(CFG_ADC_SEQCH2 == 0xC)||(CFG_ADC_SEQCH3 == 0xC)||(CFG_ADC_SEQCH4 == 0xC)\
											||(CFG_ADC_SEQCH5 == 0xC)||(CFG_ADC_SEQCH6 == 0xC)||(CFG_ADC_SEQCH7 == 0xC))\
									&& (CFG_PD1_AFR != 7))
#error "ADC1 OP2OUT(PD1) AF7 function mapping is not enable."
#endif
#if ((CFG_ADC_EN) && (CFG_ADC_EN) \
									&& ((CFG_ADC_SEQCH1 == 0xD)||(CFG_ADC_SEQCH2 == 0xD)||(CFG_ADC_SEQCH3 == 0xD)||(CFG_ADC_SEQCH4 == 0xD)\
											||(CFG_ADC_SEQCH5 == 0xD)||(CFG_ADC_SEQCH6 == 0xD)||(CFG_ADC_SEQCH7 == 0xD))\
									&& (CFG_PC15_AFR != 7))
#error "ADC1 OP3OUT(PC15) AF7 function mapping is not enable."
#endif


#if ((CFG_ADC_EN) && (CFG_ADC_EN) && (CFG_ADC_ADCON1_INIT & (1<<8) == (1<<8)) && ((CFG_PB3_AFR != 7)&&(CFG_PC5_AFR != 7)&&(CFG_PD7_AFR != 7)))
#error "ADTRG1(PB3/PC5/PD7) AF10 function mapping is not enable."
#endif


#if ((CFG_ADC_EN) && (CFG_ADC_EN) && (CFG_ADC_ADCON1_INIT & (2<<8) == (1<<8)) && ((CFG_PB4_AFR != 7)&&(CFG_PC6_AFR != 7)&&(CFG_PD6_AFR != 7)))
#error "ADTRG2(PB4/PC6/PD6) AF10 function mapping is not enable."
#endif


#if ((CFG_ADC_EN) && (CFG_ADC_EN) && (CFG_ADC_ADCON1_INIT & (4<<8) == (1<<8)) && ((CFG_PB5_AFR != 7)&&(CFG_PC7_AFR != 7)&&(CFG_PD5_AFR != 7)))
#error "ADTRG3(PB5/PC7/PD5) AF10 function mapping is not enable."
#endif
#endif


//***********************************************************/
//</e>


//<e>QEI
#define     CFG_QEI_EN          0
//<h>QEICON_QEIƼĴ
//<i>0x000  b31~12 b11~8 b7    b6    b5    b4     b3    b2   b1~0  
//<i>QEICON -      QTEPS QPDIR QIDXS QSWAP QIDXEN QEIEN QTSR QPMOD 
// <o0.3> QEIEN_QEIʹܿλ
//    <0=>QEIܹر
//    <1=>QEIܴ򿪣幤ģʽQPMOD
// <o0.0..1> QPMOD_QEIλüѡλ
//    <0=>x2ģʽʹINDExλλü
//    <1=>x2ģʽλü0~QPOSMAxԶѭ
//    <2=>x4ģʽʹINDExλλü
//    <3=>x4ģʽλü0~QPOSMAxԶѭ
// <q0.2> QTSR_QEIʱλ
//    <i>0: Qtimer
//    <i>1: Qtimer
//<i>λΪQEIENΪ0ʱQtimerǷĿλQEIENΪ1ʱλЧ
// <o0.4> QIDXEN_λüλʹλ
//    <0=>INDExܸλλü
//    <1=>INDExԸλλü
//<i>QPMOD=00/10ʱЧ
// <o0.5> QSWAP_QEAQEB뽻ѡλ
//    <0=>QEAQEBδֱṩ
//    <1=>QEAQEBṩ
// <o0.8..11> QTEPS_QEI(QTimer)׽¼Ƶλ
//    <0=>QCLK/1
//    <1=>QCLK/2
//    <2=>QCLK/4
//    <3=>QCLK/8
//    <4=>QCLK/16
//    <5=>QCLK/32
//    <6=>QCLK/64
//    <7=>QCLK/128
//    <8=>QCLK/256
//    <9=>QCLK/512
//    <10=>QCLK/1024
//    <11=>QCLK/2048
//<i>QEIܴʱЧ
//</h>
#define     CFG_QEI_QEICON_INIT 0


//<h>QFLTCON_QEI˲ƼĴ
//<i>0x004   b31~8 b7      b6~4    b3     b2~0   
//<i>QFLTCON -     QIDXFEN QIDXCPS QABFEN QABCPS 
// <o0.0..2> QABCPS_QEAQEB˲ʱӷƵϵ
//    <0=>1/1 PCLK
//    <1=>1/2 PCLK
//    <2=>1/4 PCLK
//    <3=>1/16 PCLK
//    <4=>1/32 PCLK
//    <5=>1/64 PCLK
//    <6=>1/128 PCLK
//    <7=>1/256 PCLK
// <q0.3> QABFEN_QEAQEB˲ʹλ
//    <i>0: ֹQEAQEBŵ˲
//    <i>1: ʹQEAQEBŵ˲
// <o0.4..6> QIDXCPS_INDEx˲ʱӷƵϵ
//    <0=>1/1 PCLK
//    <1=>1/2 PCLK
//    <2=>1/4 PCLK
//    <3=>1/16 PCLK
//    <4=>1/32 PCLK
//    <5=>1/64 PCLK
//    <6=>1/128 PCLK
//    <7=>1/256 PCLK
// <q0.7> QIDXFEN_INDEx˲ʹλ
//    <i>0: ֹINDExŵ˲
//    <i>1: ʹINDExŵ˲
//</h>
#define     CFG_QEI_QFLTCON_INIT 0
//<h>QPOSMAX_QEIֵĴ
//<i>0x00C   b31~16 b15~0   
//<i>QPOSMAX -      QPOSMAX 
// <o0.0..15> QPOSMAX_λüֵĴ <0-65535>
//</h>
#define     CFG_QEI_QPOSMAX_INIT 0


//<h>QCNTMIN_QEIڲ׽ʱСֵ
//<i>0x018   b31~16 b15~0   
//<i>QCNTMIN -      QCNTMIN 
// <o0.0..15> QCNTMIN_׽¼СQCNTֵ<0-65535>
//<i>׽¼ʱQCNTֵСQCNTMINĴֵ˴β׽¼
//<i>ͬʱڲĲ׽Ƶ1ֱ׽QCNTֵQCNTMINѷƵʹʱQCNTԶ浽QTMLATС 
//</h>
#define     CFG_QEI_QCNTMIN_INIT 0


//<h>QTPR_QEIڼĴ
//<i>0x01C b31~0 
//<i>QTPR  QTPR  
// <o0.0..31> QTPR_32bitڼĴ
//</h>
#define     CFG_QEI_QTPR_INIT   0


//<h>QTPSQ_QEIԤƵֵ
//<i>0x020 b31~16 b15~0 
//<i>QTPSQ -      QTPSQ 
// <o0.0..15> QTPSQ_ԤƵֵ <0-65535>
//</h>
#define     CFG_QEI_QTPSQ_INIT  0


//<h>QEIINT_QEIжϺ״̬Ĵ
//<i>0x024  b31~5 b4   b3      b2    b1    b0    
//<i>QEIINT -     QTIE QTCAPIE QEIIE QCEIE QPEIE 
// <q0.0> QPEIE_λжʹλ
//    <i>0: ֹλж
//    <i>1: ʹλж
//<i>QEA/QEBźͬʱΪλ
// <q0.1> QCEIE_жʹλ,INDExźŸλλüģʽ
//    <i>0: ֹж
//    <i>1: ʹܴж
//<i>INDExźŸλλüģʽ£жʹλ
// <q0.2> QEIIE_QEIжʹλ
//    <i>0: ֹQEIж
//    <i>1: ʹQEIж
// <q0.3> QTCAPIE_QTimer׽¼жʹλ
//    <i>0: ֹ׽¼ʱж
//    <i>1: ׽¼ʱж
//<i>QEIܴʱЧ
// <q0.4> QTIE_Qtimerжʹλ
//    <i>0: ֹQtimer¼ʱж
//    <i>1: Qtimer¼ʱж
//</h>


#define     CFG_QEI_QEIINT_INIT 0


#if ((CFG_QEI_QEIINT_INIT & 0x1F) != 0)
	#define CFG_QEI_INT_EN 1
#else
	#define CFG_QEI_INT_EN 0
#endif
//***********************************************************/
//</e>
#if ((CFG_QEI_EN) && (CFG_QEI_QEICON_INIT & (1<<3)) && ((CFG_PB7_AFR != 6)&&(CFG_PC9_AFR != 6)))
#error "QEI QEA(PB7/PC9) AF6 function mapping is not enable."
#endif


#if ((CFG_QEI_EN) && (CFG_QEI_QEICON_INIT & (1<<3)) && ((CFG_PB8_AFR != 6)&&(CFG_PC10_AFR != 6)))
#error "QEI QEB(PB8/PC10) AF6 function mapping is not enable."
#endif


#if ((CFG_QEI_EN) && (CFG_QEI_QEICON_INIT & (1<<3)) && ((CFG_PB9_AFR != 6)&&(CFG_PC11_AFR != 6)))
#error "QEI INDEX(PB9/PC11) AF6 function mapping is not enable."
#endif


//<e>AMOC
#define     CFG_AMOC_EN         0
//<h>CMP0CON_Ƚ0ƼĴ
//<i>0x000   b31 b30    b29    b28    b27     b26    b25~24  b23~22 b21~16  b15    b14      b13       b12     b11~10 b9~8 b7     b6~4   b3    b2~0  
//<i>CMP0CON -   C0OUT2 C0OUT1 C0OUT0 CMPAUTO TRGPOL PWMTRGS CMPGAP CMP0VRS CMP0EN CMP0VCMP CP0NOUTEN C0OUTEN C0IES  -    C0NCHS C0PCHS C0OUT C0DEB 
// <q0.15> CMP0EN_Ƚ0ʹܿλ
//    <i>0: Ƚ0ر
//    <i>1: Ƚ0
// <o0.0..2> C0DEB_Ƚ0ź˲ʱ
//    <0=>˲
//    <1=>˲ʱ䳣Ϊ0.5us
//    <2=>˲ʱ䳣Ϊ1us
//    <3=>˲ʱ䳣Ϊ2us
//    <4=>˲ʱ䳣Ϊ4us
//    <5=>˲ʱ䳣Ϊ8us
//    <6=>˲ʱ䳣Ϊ12us
//    <7=>˲ʱ䳣Ϊ16us
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.4..6> C0PCHS_Ƚ0ͬѡλ
//    <0=>ѡOP0P0ΪȽ0ͬ
//    <1=>ѡOP0P1ΪȽ0ͬ
//    <2=>ѡOP0P2ΪȽ0ͬ
//    <4=>ѡOP1OUTΪȽ0ͬ
//    <5=>ѡOP2OUTΪȽ0ͬ
//    <6=>ѡOP3OUTΪȽ0ͬ
// <o0.7> C0NCHS_Ƚ0ѡλ
//    <0=>ѡC0NΪȽ0
//    <1=>ѡڲοCMP0VRSΪȽ0
// <o0.10..11> C0IES_Ƚ0жģʽѡλ
//    <0=>жϱ־
//    <1=>½شȽ0ɸ߱ʱжϱ־
//    <2=>شȽ0ɵͱʱжϱ־
//    <3=>˫شȽ0ɸ߱ʱɵͱʱжϱ־
// <o0.12> C0OUTEN_Ƚ0 I/Oʹ
//    <0=>ͨȽ0CP0OUTCP0OUTΪͨIO
//    <1=>ͨȽ0CP0OUT
//    <i>I/OǴ˲ܵģ˲ΪC0DEB[2:0]趨ֵ
// <q0.13> CP0NOUTEN_ȽNΪڲ׼Դʱ,ȽNǷCP0N
//    <i>0:
//    <i>1:
//    <i>ֻC0NCHSΪ1ʱOP0ENΪ0ʱλЧ
// <o0.14> CMP0VCMP_Ƚ0˲οѹԴVcmpѡλ
//    <0=>VDD
//    <1=>Vref


// <o0.16..21> CMP0VRS_Ƚ0˲οѹѡ<0-63>
//    <i>(1+CMP0VRS)/ 64 *Vcmp
//    <i>˵ѹΧΪ1/64~64/64
// <o0.22..23> CMPGAP_ԶȽϼ
// <0=>ȽϼΪ32APBʱ
// <1=>ȽϼΪ48APBʱ
// <2=>ȽϼΪ64APBʱ
// <3=>ȽϼΪ80APBʱ
// <o0.24..25> PWMTRGS_Ƚ0ͬȽϿλ
//<0=>ȽģʽͬȽϹ
//<1=>PWM0ͬ
//<2=>PWM1ͬ
//<3=>PWM2ͬ
// <o0.26> TRGPOL_Ƚ0ͬȽϹܿλ
//<0=>PWMЧڼȽ
//<1=>PWMЧڼȽ
// <o0.27> CMPAUTO_Ƚ0ԶȽϹʹλ
//<0=>رԶȽ
//<1=>ԶȽ
//<i>λΪ0ʱȽ2C0PCHSλξλΪ1ʱOP0P0~OP0P2ΪȽ2
//</h>

#define     CFG_AMOC_CMP0CON_INIT 0


#if ((CFG_AMOC_CMP0CON_INIT & (3<<10)) != 0)
	#define CFG_CMP0_INT_EN 1
#else
	#define CFG_CMP0_INT_EN 0
#endif
//<h>CMP1CON_Ƚ1ƼĴ
//<i>0x004   b31~27 b26    b25~24  b23~22 b21~16  b15    b14      b13       b12     b11~10 b9~8  b7     b6~4   b3    b2~0  
//<i>CMP1CON -      TRGPOL PWMTRGS -      CMP1VRS CMP1EN CMP1VCMP CP1NOUTEN C1OUTEN C1IES  C1SMT C1NCHS C1PCHS C1OUT C1DEB 
// <q0.15> CMP1EN_Ƚ1ʹܿλ
//    <i>0: Ƚ1ر
//    <i>1: Ƚ1
// <o0.0..2> C1DEB_Ƚ1ź˲ʱ
//    <0=>˲
//    <1=>˲ʱ䳣Ϊ0.5us
//    <2=>˲ʱ䳣Ϊ1us
//    <3=>˲ʱ䳣Ϊ2us
//    <4=>˲ʱ䳣Ϊ4us
//    <5=>˲ʱ䳣Ϊ8us
//    <6=>˲ʱ䳣Ϊ12us
//    <7=>˲ʱ䳣Ϊ16us
//    <i>˲ʱ䲻Ǿȷֵ
//    <i>˲㷨˵:HSIʱӲ˲롣ֻ֣Ϊߵƽ1趨ĳ˲1ͬʱΪ˲Ϊ͵ƽ1С˲,˲0ͬʱΪ0
// <o0.4..6> C1PCHS_Ƚ1ͬѡλ
//    <0=>ѡC1P0ΪȽ1ͬ
//    <1=>ѡC1P1ΪȽ1ͬ
//    <2=>ѡC1P2ΪȽ1ͬ
//    <3=>ѡOP0OUTΪȽ1ͬ
//    <4=>ѡOP1OUTΪȽ1ͬ
//    <5=>ѡOP2OUTΪȽ1ͬ
//    <6=>ѡOP3OUTΪȽ1ͬ
// <o0.7> C1NCHS_Ƚ1ѡλ
//    <0=>ѡC1NΪȽ1
//    <1=>ѡڲοCM1VRSΪȽ1ˣCP1NΪͨIO
//    <i>õڲVREFǰ100us׼Դ򿪣Ĵ[AGCON:VREFEN]λ1
// <o0.8..9> C1SMT_Ƚ1ʩصѹѡλ
//    <0=>ûʩش
//    <1=>ʩشΪ10mv
//    <2=>ʩشΪ20mv
//    <3=>ʩشΪ50mv
// <o0.10..11> C1IES_Ƚ1жģʽѡλ
//    <0=>жϱ־
//    <1=>½شȽ1ɸ߱ʱжϱ־
//    <2=>شȽ1ɵͱʱжϱ־
//    <3=>˫شȽ1ɸ߱ʱɵͱʱжϱ־
// <o0.12> C1OUTEN_Ƚ1I/Oʹ
//    <0=>ͨȽ1CP1OUTCP1OUTΪͨIO
//    <1=>ͨȽ1CP1OUT
//    <i>I/OǴ˲ܵģ˲ΪC1DEB[2:0]趨ֵ
// <o0.13> CP1NOUTEN_ȽNΪڲ׼Դʱ,ȽNǷCP1N
//    <0=>
//    <1=>
//    <i>ֻC1NCHSΪ1ʱλЧ
// <o0.14> CMP1VCMP_Ƚ1˲οѹԴVcmpѡλ
//    <0=>VDD
//    <1=>Vref
// <o0.16..21> CMP1VRS_Ƚ1˲οѹѡλ<0-63>
//    <i>(1+CMP1VRS)/ 64 *Vcmp
//    <i>˵ѹΧΪ1/64~64/64
//</h>

#define     CFG_AMOC_CMP1CON_INIT 0


#if ((CFG_AMOC_CMP1CON_INIT & (3<<10)) != 0)
	#define CFG_CMP1_INT_EN 1
#else
	#define CFG_CMP1_INT_EN 0
#endif
//<h>OPCON_ŴƼĴ1
//<i>0x00C b31~8 b7     b6~4    b3    b2    b1    b0    
//<i>OPCON -     OP0GEN OP0GSEL OP3EN OP2EN OP1EN OP0EN 
// <q0.0> OP0EN_Ŵ0ʹܿλ
//    <i>0: Ŵ0ر
//    <i>1: Ŵ0
//  <i>IOóģ룬ӦI/O AFĴΪģAF
//  <i>OP0ENOP0뵱OPãֻеOP0ENΪ0ʱOP0ܵȽá
// <q0.1> OP1EN_Ŵ1ʹܿλ
//    <i>0: Ŵ1ر
//    <i>1: Ŵ1
//<i>IOóģ룬ӦI/O AFĴΪģAF
// <q0.2> OP2EN_Ŵ2ʹܿλ
//    <i>0: Ŵ2ر
//    <i>1: Ŵ2
//<i>IOóģ룬ӦI/O AFĴΪģAF
// <q0.3> OP3EN_Ŵ3ʹܿλ
//    <i>0: Ŵ3ر
//    <i>1: Ŵ3
//<i>IOóģ룬ӦI/O AFĴΪģAF
// <o0.4..6> OP0GSEL_Ŵ0ϵѡ
//<0=>ڲϵȷx1 
//<1=>ڲϵȷx4
//<2=>ڲϵȷx6
//<3=>ڲϵȷx8
//<4=>ڲϵȷx12
//<5=>ڲϵȷx16
//<6=>ڲϵȷx24
//<7=>ڲϵȷx32
// <q0.7> OP0GEN_Ŵ0OP0P0ŵڲʹλ
//<i>0: ֹ
//<i>1: ʹ
//</h>
#define     CFG_AMOC_OPCON_INIT 0
//</e>


//<e>UART
#define     CFG_UART_EN         0
//***********************************************************/
//<e>UART0
#define     CFG_UART0_EN        0
//       <o>Baudrate
//             <256000=> 256000
//             <115200=> 115200
//             <57600=>  57600
//             <38400=>  38400
//             <19200=>  19200
//             <9600=>   9600
//             <4800=>   4800
//             <2400=>   2400
//             <1200=>   1200
//             <600=>     600
#define     CFG_UART0_BAUDRATE  115200
//<h>ADDR_UARTַüĴ
//<i>0x10 b31~16 b15~8 b7~0  
//<i>ADDR -      SMAR  SADDR 
// <o0.0..7> SADDR_UARTӲַ<0-0xFF>
// <o0.8..15> SMAR_λμĴ<0-0xFF>
//<i>SADDRЩλᱻ
//</h>
#define     CFG_UART0_ADDR_INIT 0
//<h>CR_UARTƼĴ
//<i>0x18 b31~27 b26      b25      b24 b23 b22  b21  b20 b19 b18 b17 b16   b15 b14~13 b12~11 b10 b9 b8    b7   b6    b5   b4  b3  b2    b1     b0   
//<i>CR   -      UATXFIFO UARXFIFO -   FER TNEG RNEG -   -   TEN REN LINEN SBK SM     MULTIE PS  -  SMOD0 LBDL LBDIE TCIE TIE RIE SMOD2 SBRTEN STOP 
// <o0.13..14> SM_UARTзʽλ
//    <0=>ʽ0ͬʽ̶
//    <1=>ʽ18λ첽ʽɱ䲨
//    <2=>ʽ29λ첽ʽ̶
//    <3=>ʽ39λ첽ʽɱ䲨
// <o0.0> STOP_ֹͣλλѡλ
//     <0=>ѡʹ1λֹͣλ
//     <1=>ѡʹ2λֹͣλ
// <o0.1> SBRTEN_UARTʷʹܿλ
//    <0=>òʷ
//    <1=>ʹܲʷ
// <o0.2> SMOD2_UARTʽ2ʿλ
//    <0=>ڷʽ2УΪPCLK1ʱӵ1/256
//    <1=>ڷʽ2УΪPCLK1ʱӵ1/128
// <q0.3> RIE_ֽڽжʹλ
//    <i>0: ֹжϱ־λRIж
//    <i>1: жϱ־λRIж
// <q0.4> TIE_ֽڴжʹλ
//    <i>0: ֹжϱ־λTIж
//    <i>1: жϱ־λTIж 
// <q0.5> TCIE_ȫݷжʹλ
//    <i>0: ֹݷɱ־λTCжϹ
//    <i>1: ݷɱ־λTCжϹ
// <o0.8> SMOD0_UARTʽ0ʿλ
//    <0=>ڷʽ0УΪPCLK1ʱӵ1/48
//    <1=>ڷʽ0УΪPCLK1ʱӵ1/12
// <o0.10> PS_żУѡλ
//  <0=>У
//  <1=>żУ
// <o0.11..12> MULTIE_ھλѡλ
//  <0=>Զ
//  <1=>ͨѶ־λ
//  <2=>żУλ
// <q0.17> REN_UARTչʹλ
//    <i>0:ýչ
//    <i>1:ʹܽչ
// <q0.18> TEN_UART͹ʹλ
//    <i>0:÷͹
//    <i>1:ʹܷ͹
// <o0.21> RNEG_UARTռԿλ
//    <0=>ݲȡ
//    <1=>ȡ
// <o0.22> TNEG_UARTͼԿλ
//    <0=>ݲȡ
//    <1=>ȡ
// <q0.23> FER_֡λ
//    <i>0: ֹֹͣλȷϼ飬κֹͣλλRI
//    <i>1: ֹͣλȷϼ飬ֻЧֹͣλ(1)λRI
// <e0.16> LINģʽ
//    <i>0: ֹLINģʽ
//    <i>1: ʹLINģʽ
// <o0.15> SBK_LINͬʹλ
//    <0=>ͬ
//    <1=>ͬɺԶ
// <q0.6> LBDIE_LINϷָжʹλ
//    <i>0: ֹLINϷָжϹ
//    <i>1: LINϷָжϹ
// <o0.7> LBDL_ֵͬ
//  <0=>͵ƽȴ10BIT͵ƽ
//  <1=>͵ƽȴ11BIT͵ƽ
//</e>
//<h>FIFO
// <o0.24> UARXMODE_UART Rx FIFO MODEѡλ
//    <0=>8bits Mode
//    <1=>(8+N)bits Mode
// <o0.25> UARXFIFO_UART Rx FIFOܿ
//    <0=>׼UART 
//    <1=>Rx FIFOUART
// <o0.26> UATXFIFO_UART Tx FIFOܿ
//    <0=>׼UART 
//    <1=>Tx FIFOUART
//</h>
//</h>
#define     CFG_UART0_CR_INIT   401410


#if ((CFG_UART0_CR_INIT & (0xF<<3)) != 0)
	#define CFG_UART0_INT_EN 1
#else
	#define CFG_UART0_INT_EN 0
#endif


#define CFG_UART0_CLK		(SYS_CLK/APB_F)
#if ((CFG_UART0_CR_INIT & 0x2000) == 0x2000)
#define CFG_UART0_SBRT_VALUE 	(CFG_UART0_CLK/16/CFG_UART0_BAUDRATE-1)
#define CFG_UART0_BFINE_VALUE 	(CFG_UART0_CLK/CFG_UART0_BAUDRATE - 16*CFG_UART0_SBRT_VALUE)
#define CFG_UART0_BRT_INIT	(CFG_UART0_SBRT_VALUE | (CFG_UART0_BFINE_VALUE<<16))
#else
#define CFG_UART0_BRT_INIT	0
#endif


//</e>


#if ((CFG_UART_EN) && (CFG_UART0_EN) && (CFG_UART0_CR_INIT & (1<<17)) && ((CFG_PA11_AFR != 4)&&(CFG_PA7_AFR != 4)))
#warning "UART0 RXD0(PA11/PA7) AF4 function mapping is not enable."
#endif


#if ((CFG_UART_EN) && (CFG_UART0_EN) && (CFG_UART0_CR_INIT & (1<<18)) && ((CFG_PA12_AFR != 4)&&(CFG_PA8_AFR != 4)))
#warning "UART0 TXD0(PA12/PA8) AF4 function mapping is not enable."
#endif


//***********************************************************/
//<e>UART1
#define     CFG_UART1_EN        1
//       <o>Baudrate
//             <256000=> 256000
//             <115200=> 115200
//             <57600=>  57600
//             <38400=>  38400
//             <19200=>  19200
//             <9600=>   9600
//             <4800=>   4800
//             <2400=>   2400
//             <1200=>   1200
//             <600=>     600     
#define     CFG_UART1_BAUDRATE  115200


//<h>ADDR_UARTַüĴ
//<i>0x10 b31~16 b15~8 b7~0  
//<i>ADDR -      SMAR  SADDR 
// <o0.0..7> SADDR_UARTӲַ<0-0xFF>
// <o0.8..15> SMAR_λμĴ<0-0xFF>
//<i>SADDRЩλᱻ
//</h>
#define     CFG_UART1_ADDR_INIT 0
//<h>CR_UARTƼĴ
//<i>0x18 b31~27 b26      b25      b24 b23 b22  b21  b20 b19 b18 b17 b16   b15 b14~13 b12~11 b10 b9 b8    b7   b6    b5   b4  b3  b2    b1     b0   
//<i>CR   -      UATXFIFO UARXFIFO -   FER TNEG RNEG -   -   TEN REN LINEN SBK SM     MULTIE PS  -  SMOD0 LBDL LBDIE TCIE TIE RIE SMOD2 SBRTEN STOP 
// <o0.13..14> SM_UARTзʽλ
//    <0=>ʽ0ͬʽ̶
//    <1=>ʽ18λ첽ʽɱ䲨
//    <2=>ʽ29λ첽ʽ̶
//    <3=>ʽ39λ첽ʽɱ䲨
// <o0.0> STOP_ֹͣλλѡλ
//     <0=>ѡʹ1λֹͣλ
//     <1=>ѡʹ2λֹͣλ
// <o0.1> SBRTEN_UARTʷʹܿλ
//    <0=>òʷ
//    <1=>ʹܲʷ
// <o0.2> SMOD2_UARTʽ2ʿλ
//    <0=>ڷʽ2УΪPCLK1ʱӵ1/256
//    <1=>ڷʽ2УΪPCLK1ʱӵ1/128
// <q0.3> RIE_ֽڽжʹλ
//    <i>0: ֹжϱ־λRIж
//    <i>1: жϱ־λRIж
// <q0.4> TIE_ֽڴжʹλ
//    <i>0: ֹжϱ־λTIж
//    <i>1: жϱ־λTIж 
// <q0.5> TCIE_ȫݷжʹλ
//    <i>0: ֹݷɱ־λTCжϹ
//    <i>1: ݷɱ־λTCжϹ
// <o0.8> SMOD0_UARTʽ0ʿλ
//    <0=>ڷʽ0УΪPCLK1ʱӵ1/48
//    <1=>ڷʽ0УΪPCLK1ʱӵ1/12
// <o0.10> PS_żУѡλ
//  <0=>У
//  <1=>żУ
// <o0.11..12> MULTIE_ھλѡλ
//  <0=>Զ
//  <1=>ͨѶ־λ
//  <2=>żУλ
// <q0.17> REN_UARTչʹλ
//    <i>0:ýչ
//    <i>1:ʹܽչ
// <q0.18> TEN_UART͹ʹλ
//    <i>0:÷͹
//    <i>1:ʹܷ͹
// <o0.21> RNEG_UARTռԿλ
//    <0=>ݲȡ
//    <1=>ȡ
// <o0.22> TNEG_UARTͼԿλ
//    <0=>ݲȡ
//    <1=>ȡ
// <q0.23> FER_֡λ
//    <i>0: ֹֹͣλȷϼ飬κֹͣλλRI
//    <i>1: ֹͣλȷϼ飬ֻЧֹͣλ(1)λRI
// <e0.16> LINģʽ
//    <i>0: ֹLINģʽ
//    <i>1: ʹLINģʽ
// <o0.15> SBK_LINͬʹλ
//    <0=>ͬ
//    <1=>ͬɺԶ
// <q0.6> LBDIE_LINϷָжʹλ
//    <i>0: ֹLINϷָжϹ
//    <i>1: LINϷָжϹ
// <o0.7> LBDL_ֵͬ
//  <0=>͵ƽȴ10BIT͵ƽ
//  <1=>͵ƽȴ11BIT͵ƽ
//</e>
//<h>FIFO
// <o0.24> UARXMODE_UART Rx FIFO MODEѡλ
//    <0=>8bits Mode
//    <1=>(8+N)bits Mode
// <o0.25> UARXFIFO_UART Rx FIFOܿ
//    <0=>׼UART 
//    <1=>Rx FIFOUART
// <o0.26> UATXFIFO_UART Tx FIFOܿ
//    <0=>׼UART 
//    <1=>Tx FIFOUART
//</h>
//</h>
#define     CFG_UART1_CR_INIT   101064706


#if ((CFG_UART1_CR_INIT & (0xF<<3)) != 0)
	#define CFG_UART1_INT_EN 1
#else
	#define CFG_UART1_INT_EN 0
#endif


#define CFG_UART1_CLK		(SYS_CLK/APB_F)
#if ((CFG_UART1_CR_INIT & 0x2000) == 0x2000)
#define CFG_UART1_SBRT_VALUE 	(CFG_UART1_CLK/16/CFG_UART1_BAUDRATE-1)
#define CFG_UART1_BFINE_VALUE 	(CFG_UART1_CLK/CFG_UART1_BAUDRATE - 16*CFG_UART1_SBRT_VALUE)
#define CFG_UART1_BRT_INIT	(CFG_UART1_SBRT_VALUE | (CFG_UART1_BFINE_VALUE<<16))
#else
#define CFG_UART1_BRT_INIT	0
#endif
//</e>


#if ((CFG_UART_EN) && (CFG_UART1_EN)&& (CFG_UART1_CR_INIT & (1<<17)) && ((CFG_PA13_AFR != 4)&&(CFG_PC1_AFR != 4)))
#warning "UART1 RXD1(PA13/PC1) AF4 function mapping is not enable."
#endif


#if ((CFG_UART_EN) && (CFG_UART1_EN)&& (CFG_UART1_CR_INIT & (1<<18)) && ((CFG_PA14_AFR != 4)&&(CFG_PC0_AFR != 4)))
#warning "UART1 TXD1(PA14/PC0) AF4 function mapping is not enable."
#endif


//***********************************************************/
//<e>UART2
#define     CFG_UART2_EN        0
//       <o>Baudrate
//             <256000=> 256000
//             <115200=> 115200
//             <57600=>  57600
//             <38400=>  38400
//             <19200=>  19200
//             <9600=>   9600
//             <4800=>   4800
//             <2400=>   2400
//             <1200=>   1200
//             <600=>     600     
#define     CFG_UART2_BAUDRATE  115200


//<h>ADDR_UARTַüĴ
//<i>0x10 b31~16 b15~8 b7~0  
//<i>ADDR -      SMAR  SADDR 
// <o0.0..7> SADDR_UARTӲַ<0-0xFF>
// <o0.8..15> SMAR_λμĴ<0-0xFF>
//<i>SADDRЩλᱻ
//</h>
#define     CFG_UART2_ADDR_INIT 0
//<h>CR_UARTƼĴ
//<i>0x18 b31~27 b26      b25      b24 b23 b22  b21  b20 b19 b18 b17 b16   b15 b14~13 b12~11 b10 b9 b8    b7   b6    b5   b4  b3  b2    b1     b0   
//<i>CR   -      UATXFIFO UARXFIFO -   FER TNEG RNEG -   -   TEN REN LINEN SBK SM     MULTIE PS  -  SMOD0 LBDL LBDIE TCIE TIE RIE SMOD2 SBRTEN STOP 
// <o0.13..14> SM_UARTзʽλ
//    <0=>ʽ0ͬʽ̶
//    <1=>ʽ18λ첽ʽɱ䲨
//    <2=>ʽ29λ첽ʽ̶
//    <3=>ʽ39λ첽ʽɱ䲨
// <o0.0> STOP_ֹͣλλѡλ
//     <0=>ѡʹ1λֹͣλ
//     <1=>ѡʹ2λֹͣλ
// <o0.1> SBRTEN_UARTʷʹܿλ
//    <0=>òʷ
//    <1=>ʹܲʷ
// <o0.2> SMOD2_UARTʽ2ʿλ
//    <0=>ڷʽ2УΪPCLK1ʱӵ1/256
//    <1=>ڷʽ2УΪPCLK1ʱӵ1/128
// <q0.3> RIE_ֽڽжʹλ
//    <i>0: ֹжϱ־λRIж
//    <i>1: жϱ־λRIж
// <q0.4> TIE_ֽڴжʹλ
//    <i>0: ֹжϱ־λTIж
//    <i>1: жϱ־λTIж 
// <q0.5> TCIE_ȫݷжʹλ
//    <i>0: ֹݷɱ־λTCжϹ
//    <i>1: ݷɱ־λTCжϹ
// <o0.8> SMOD0_UARTʽ0ʿλ
//    <0=>ڷʽ0УΪPCLK1ʱӵ1/48
//    <1=>ڷʽ0УΪPCLK1ʱӵ1/12
// <o0.10> PS_żУѡλ
//  <0=>У
//  <1=>żУ
// <o0.11..12> MULTIE_ھλѡλ
//  <0=>Զ
//  <1=>ͨѶ־λ
//  <2=>żУλ
// <q0.17> REN_UARTչʹλ
//    <i>0:ýչ
//    <i>1:ʹܽչ
// <q0.18> TEN_UART͹ʹλ
//    <i>0:÷͹
//    <i>1:ʹܷ͹
// <o0.21> RNEG_UARTռԿλ
//    <0=>ݲȡ
//    <1=>ȡ
// <o0.22> TNEG_UARTͼԿλ
//    <0=>ݲȡ
//    <1=>ȡ
// <q0.23> FER_֡λ
//    <i>0: ֹֹͣλȷϼ飬κֹͣλλRI
//    <i>1: ֹͣλȷϼ飬ֻЧֹͣλ(1)λRI
// <e0.16> LINģʽ
//    <i>0: ֹLINģʽ
//    <i>1: ʹLINģʽ
// <o0.15> SBK_LINͬʹλ
//    <0=>ͬ
//    <1=>ͬɺԶ
// <q0.6> LBDIE_LINϷָжʹλ
//    <i>0: ֹLINϷָжϹ
//    <i>1: LINϷָжϹ
// <o0.7> LBDL_ֵͬ
//  <0=>͵ƽȴ10BIT͵ƽ
//  <1=>͵ƽȴ11BIT͵ƽ
//</e>
//<h>FIFO
// <o0.24> UARXMODE_UART Rx FIFO MODEѡλ
//    <0=>8bits Mode
//    <1=>(8+N)bits Mode
// <o0.25> UARXFIFO_UART Rx FIFOܿ
//    <0=>׼UART 
//    <1=>Rx FIFOUART
// <o0.26> UATXFIFO_UART Tx FIFOܿ
//    <0=>׼UART 
//    <1=>Tx FIFOUART
//</h>
//</h>
#define     CFG_UART2_CR_INIT   0
#if ((CFG_UART2_CR_INIT & (0xF<<3)) != 0)
	#define CFG_UART2_INT_EN 1
#else
	#define CFG_UART2_INT_EN 0
#endif


#define CFG_UART2_CLK		(SYS_CLK/APB_F)
#if ((CFG_UART2_CR_INIT & 0x2000) == 0x2000)
#define CFG_UART2_SBRT_VALUE 	(CFG_UART2_CLK/16/CFG_UART2_BAUDRATE-1)
#define CFG_UART2_BFINE_VALUE 	(CFG_UART2_CLK/CFG_UART2_BAUDRATE - 16*CFG_UART2_SBRT_VALUE)
#define CFG_UART2_BRT_INIT	(CFG_UART2_SBRT_VALUE | (CFG_UART2_BFINE_VALUE<<16))
#else
#define CFG_UART2_BRT_INIT	0
#endif
//</e>
#if ((CFG_UART_EN) && (CFG_UART2_EN)&& (CFG_UART2_CR_INIT & (1<<17)) && ((CFG_PA0_AFR != 4)&&(CFG_PA6_AFR != 4)))
#warning "UART2 RXD2(PA0/PA6) AF4 function mapping is not enable."
#endif


#if ((CFG_UART_EN) && (CFG_UART2_EN)&& (CFG_UART2_CR_INIT & (1<<18)) && ((CFG_PA2_AFR != 4)&&(CFG_PA9_AFR != 4)))
#warning "UART2 TXD2(PA2/PA9) AF4 function mapping is not enable."
#endif
//***********************************************************/
//</e>


//<e>SPI
#define     CFG_SPI_EN          0
//<i>CR_SPIƼĴ
//<i>0x00C b31~19 b18    b17~16 b15   b14   b13 b12 b11   b10   b9 b8  b7   b6   b5   b4    b3~0 
//<i>CR    -      FIFOEN SPDATL SPSFF SPIEN -   -   SPTIE SPRIE -  DIR MSTR CPHA CPOL SSDIS SPR 
// <q0.14> SPIEN_SPIʹλ
// <o0.7> MSTR_SPI豸λ
//     <0=>SPIΪ豸
//     <1=>SPIΪ豸
// <o0.0..3> SPR_ʱӷƵλ
//    <0=>PCLK1 /2
//    <1=>PCLK1 /4
//    <2=>PCLK1 /8
//    <3=>PCLK1 /16
//    <4=>PCLK1 /32
//    <5=>PCLK1 /64
//    <6=>PCLK1 /128
//    <7=>PCLK1 /256
//    <8=>PCLK1 /512
//    <9=>PCLK1 /1024
//    :
// <o0.4> SSDIS_NSSſλ
//    <0=>/ģʽ£NSS
//    <1=>/ģʽ£رNSSţMODFж
//    <i>ڴģʽ£CPHA=0λ
// <o0.5> CPOL_ʱӼԿλ
//    <0=>IDLE״̬CKڵ͵ƽ
//    <1=>IDLE״̬CKڸߵƽ
// <o0.6> CPHA_ʱλλ
//     <0=>CKڵĵһزɼ
//     <1=>CKڵĵڶزɼ
// <o0.8> DIR_ݴͷѡλ
//     <0=>MSBȷ
//     <1=>LSBȷ
// <q0.10> SPRIE_SPIĽжϱ־ʹλ
//    <i>0: ֹжϱ־λSPRIж
//    <i>1: жϱ־λSPRIж
// <q0.11> SPTIE_SPIĴжϱ־ʹλ
//    <i>0: ֹжϱ־λSPTIж
//    <i>1: жϱ־λSPTIж
// <o0.15> SPSFF_ӻٷģʽλ
//  <0=>ͨģʽ
//  <1=>ģʽ
//<i>CPHA=0ʱЧ
//<i>ͨģʽ£ӻSSÿδһݣ8λ16λ뱻ߣһǰSSݵλĴ
//<i>ģʽ£ӻ͵ĵһҪSS½ڶϸһCLKصλĴעͻû򲻻أ
// <o0.16..17> SPDATL_ֳѡλ
//     <0=>ÿη8bit
//     <1=>ÿη16bit 
//     <2=>ÿη32bit
// <o0.18> FIFOEN_SPI Rx FIFOܿ
//    <0=>׼SPI
//    <1=>FIFOSPI
//    <i>SPI FIFOTx/RxɶԳֻ֣һʹܿ


#define     CFG_SPI_CR_INIT     0


#if ((CFG_SPI_CR_INIT & (3<<10)) != 0)
	#define CFG_SPI_INT_EN 1
#else
	#define CFG_SPI_INT_EN 0
#endif


 
#if ((CFG_SPI_EN) && (CFG_SPI_EN) && ((CFG_PA6_AFR != 5)&&(CFG_PA10_AFR != 5)&&(CFG_PB13_AFR != 5)))
#warning "SPI SCK(PA6/PA10/PB13) AF5 function mapping is not enable."
#endif
#if ((CFG_SPI_EN) && (CFG_SPI_EN) && ((CFG_PA5_AFR != 5)&&(CFG_PB12_AFR != 5)))
#warning "SPI MOSI(PA5/PB12) AF5 function mapping is not enable."
#endif
#if ((CFG_SPI_EN) && (CFG_SPI_EN) && ((CFG_PA4_AFR != 5)&&(CFG_PB11_AFR != 5)))
#warning "SPI MISO(PA4/PB11) AF5 function mapping is not enable."
#endif
//***********************************************************/
//</e>


//<e>TWI
#define     CFG_TWI_EN          0


//<h>CR_TWIƼĴ
//<i>0x018 b31~16 b15   b14~11 b10    b9   b8    b7~6 b5~4 b3 b2  b1  b0 
//<i>CR    -      TWIEN -      TWINTE ETOT EFREE CNT  CR   -  STA STO AA 
// <o0.15> TWIEN_TWIʹλ
//    <0=>رTWI
//    <1=>ʹTWI
// <q0.10> TWINTE_TWIķͽжϱ־ʹλ
//    <i>0: ֹTWIжϱ־λTWINTж
//    <i>1: TWIжϱ־λTWINTж
// <q0.9> ETOT_߳ʱ־ʹλ
//    <i>0: ֹTWI߳ʱTOUT־
//    <i>1: TWI߳ʱTOUT־
// <q0.8> EFREE_SCLߵƽʱ־ʹλ
//    <i>0: ֹSCLߵƽʱTFREE־
//    <i>1: SCLߵƽʱTFREE־
// <o0.6..7> CNT_߳ʱλ
//    <0=>N=25000
//    <1=>N=50000
//    <2=>N=100000
//    <3=>N=200000
//    <i>Nֵ߳ʱʹ
// <o0.4..5> CR_TWIƵϵ
//    <0=>64
//    <1=>16
//    <2=>4
//    <3=>1
// <o0.2> STA_ʼλ
//    <0=>ʼ
//    <1=>߿ʱʼ
//<i>STA=1ʱʼģʽѾģʽظʼ
//<i>STASTOλʱģʽ߷һֹͣȻһʼӿڴڴģʽһڲֹͣ͵
// <o0.0> AA_Ӧ־λ
//    <0=>ظӦźţSDAߵƽ
//    <1=>ظӦźţSDA͵ƽ 
//</h>
#define     CFG_TWI_CR_INIT     4


//<h>ADDR_TWIַüĴ
//<i>0x014 b31~24 b23~17 b16~8 b7~1 b0 
//<i>ADDR  -      TWIAMR -     ADDR GC 
// <q0.0> GC_ͨõַʹλ
//    <i>0: ֹӦͨõַ
//    <i>1: Ӧͨõַ
// <o0.1..7> ADDR_TWIַλ<0-0x7F>
// <o0.17..23> TWIAMR_TWIַλ<0-0x7F>
//<i>TWIAMRÿһλTWIADRַĴӦĵַλλ1ַƥ߼ĵַλTWIADRеӦַλıȽϽλ0ӦλıȽϽ
//</h>
#define     CFG_TWI_ADDR_INIT   0


//<h>BRT_TWIüĴ
//<i>0x00C b31~8 b7~0 
//<i>BRT   -     BRT  
// <o0.0..7> BRT_TWIıλ<0-255>
//</h>
#define     CFG_TWI_BRT_INIT    0


//<h>HOC_TWIߵƽʱüĴ
//<i>0x008 b31~8 b7~0 
//<i>HOC   -     HOC  
// <o0.0..7> HOC_TWISCL߸ߵƽʱλ<0-255>
//</h>
#define     CFG_TWI_HOC_INIT    255
#if ((CFG_TWI_CR_INIT & (1<<10)) != 0)
	#define CFG_TWI_INT_EN 1
#else
	#define CFG_TWI_INT_EN 0
#endif
//</e>
#if ((CFG_TWI_EN) && ((CFG_PA0_AFR != 5)&&(CFG_PA14_AFR != 5)))
#warning "TWI SCL(PA0/PA14) AF5 function mapping is not enable."
#endif


#if ((CFG_TWI_EN) && ((CFG_PA2_AFR != 5)&&(CFG_PA13_AFR != 5)))
#warning "TWI SDA(PA2/PA13) AF5 function mapping is not enable."
#endif


//<e>CAN
#define     CFG_CAN_EN          0


//<h>CGCR_CANȫüĴ
//<i>0x200 b31~12 b11 b10    b9       b8        b7     b6 b5   b4     b3       b2  b1  b0    
//<i>CGCR  -      EIT DIAGEN INTERNAL LOOP-BACK IGNACK LO DDIR TSTPEN BUFFLOCK CTX CRX CANEN 
// <o0.0> CANEN_CANģʹλ
//    <0=>CANģʧ
//    <1=>CANģʹ
// <o0.1> CRX_յƽ
//    <0=>ԵƽΪ0ԵƽΪ1
//    <1=>ԵƽΪ1ԵƽΪ0
// <o0.2> CTX_͵ƽ
//    <0=>ԵƽΪ0ԵƽΪ1
//    <1=>ԵƽΪ1ԵƽΪ0
// <o0.3> BUFFLOCK_λ
//    <0=>ֹ
//    <1=>
// <o0.4> TSTPEN_ʱͬʹ
//    <0=>ʱͬʧ
//    <1=>ʱͬʹ
// <o0.5> DDIR_ݴ洢λ
//    <0=>ȽյĴ洢ڸλַյĴ洢ڵλַ
//    <1=>ȽյĴ洢ڵλַյĴ洢ڸλַ
// <o0.6> LO_ģʽ
//    <0=>/
//    <1=>ֻݣϢӦ
// <q0.7> IGNACK_ACKλ
//    <i>0:ģʽ
//    <i>1:ݺACKλ
// <q0.8> LOOPBACK_ػģʽ
//    <i>0:ģʽ
//    <i>1:ػģʽʹ
// <q0.9> INTERNAL_ڲģʽ
//    <i>0:ģʽ
//    <i>1:ڲģʽʹ
// <q0.10> DIAGEN_Ϲʹλ
//    <i>0:ģʽ
//    <i>1:Ϲʹ
// <o0.11> EIT_ж
//    <0=>ÿߴEIPNDλ
//    <1=>ֻе״̬ıʱEIPND
//</h>

#define     CFG_CAN0_CGCR_INIT  1
//<h>CTIM_CANʱĴ
//<i>0x204 b31~16 b15~9 b8~7 b6~3  b2~0  
//<i>CTIM  -      PSC   SJW  TSEG1 TSEG2 
// <o0.0..2> TSEG2_λ2
//    <0=>1tq
//    <1=>2tq
//    <2=>3tq
//    <3=>4tq
//    <4=>5tq
//    <5=>6tq
//    <6=>7tq
//    <7=>8tq
// <o0.3..6> TSEG1_λ1
//    <0=>Ƽ
//    <1=>2tq
//    <2=>3tq
//    <3=>4tq
//    <4=>5tq
//    <5=>6tq
//    <6=>7tq
//    <7=>8tq
//    <8=>9tq
//    <9=>10tq
//    <10=>11tq
//    <11=>12tq
//    <12=>13tq
//    <13=>14tq
//    <14=>15tq
//    <15=>16tq
// <o0.7..8> SJW_ͬת
//    <0=>1tq
//    <1=>2tq
//    <2=>3tq
//    <3=>4tq
// <o0.9..15> PSC_ԤƵ<0-127>
//<i>ʵԤƵֵ = ֵ + 2СԤƵΪ2ƵԤƵΪ128Ƶ
//</h>
#define     CFG_CAN0_CTIM_INIT  17408
//<h>GMSKX_CANȫμĴ
//<i>0x208 b31~16 b15~1 b0   
//<i>GMSKX -      GM    XRTR 
// <q0.0> XRTR_չ֡Զλ
//  <i>0: ֹ
//  <i>1: ʹ
// <o0.1..15> XGM_IDȫλXGM bit14~0 <0-0x7FFF>
//</h>

#define     CFG_CAN0_GMSKX_INIT 32766
//<h>GMSKB_CANȫμĴ
//<i>0x20C b31~16 b15~5 b4  b3  b2~0 
//<i>GMSKB -      GME   RTR IDE GM   
// <o0.0..2> XGM_չ֡IDȫλXGM bit17~15<0-0x7>
// <o0.3> IDE_չָ֡ʾλ
// <o0.4> RTRSRR_Զָ֡ʾλ
// <o0.5..15> GMXGM_չ֡IDλ bit28-18 <0-0x7FF>
//</h>

#define     CFG_CAN0_GMSKB_INIT 65031
//<h>BMSKX_CANμĴ
//<i>0x210 b31~16 b15~1 b0   
//<i>BMSKX -      BM    XRTR 
// <q0.0> XRTR_չ֡Զλ
//  <i>0: ֹ
//  <i>1: ʹ
// <o0.1..15> XBM_չ֡IDλ bit14~0 <0-0x7FFF>
//</h>

#define     CFG_CAN0_BMSKX_INIT 32767
//<h>BMSKB_CANμĴ
//<i>0x214 b31~16 b15~5 b4  b3  b2~0 
//<i>BMSKB -      BME   RTR IDE BM   
// <o0.0..2> XBM_IDȫλBM bit17~15<0-0x7>
// <o0.3> IDE_չָ֡ʾλ
// <o0.4> RTRSRR_Զָ֡ʾλ
// <o0.5..15> BMXBM_չ֡IDλbit28-18 <0-0x7FF>
//</h>

#define     CFG_CAN0_BMSKB_INIT 65031
//<h>CIEN_CANжʹܼĴ
//<i>0x218 b31~16 b15  b14   b13   b12   b11   b10   b9   b8   b7   b6   b5   b4   b3   b2   b1   b0   
//<i>CIEN  -      EIEN IEN14 IEN13 IEN12 IEN11 IEN10 IEN9 IEN8 IEN7 IEN6 IEN5 IEN4 IEN3 IEN2 IEN1 IEN0 
// <o0.15> EIEN_жʹλ
//    <0=>ֹж
//    <1=>жϣҵTECRECб仯ʱһж
// <q0.0> IEN0_0жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.1> IEN1_1жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.2> IEN2_2жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.3> IEN3_3жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.4> IEN4_4жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.5> IEN5_5жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.6> IEN6_6жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.7> IEN7_7жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.8> IEN8_8жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.9> IEN9_9жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.10> IEN10_10жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.11> IEN11_11жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.12> IEN12_12жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.13> IEN13_13жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
// <q0.14> IEN14_14жʹλ
//    <i>0:xжʧ
//    <i>1:xжʹ
//</h>

#define     CFG_CAN0_CIEN_INIT  0


#if (CFG_CAN0_CIEN_INIT != 0)
	#define CFG_CAN_INT_EN 1
#else
	#define CFG_CAN_INT_EN 0
#endif
//<h>CICEN_CANжʹܼĴ
//<i>0x224 b31~16 b15   b14    b13    b12    b11    b10    b9    b8    b7    b6    b5    b4    b3    b2    b1    b0    
//<i>CICEN -      EICEN ICEN14 ICEN13 ICEN12 ICEN11 ICEN10 ICEN9 ICEN8 ICEN7 ICEN6 ICEN5 ICEN4 ICEN3 ICEN2 ICEN1 ICEN0 
// <q0.15> EICEN_жʹλ
//    <i>0=жϹʾжĴCSTPND
//    <i>1=жϹʾжĴCSTPND
// <q0.0> ICEN0_0жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.1> ICEN1_1жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.2> ICEN2_2жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.3> ICEN3_3жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.4> ICEN4_4жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.5> ICEN5_5жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.6> ICEN6_6жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.7> ICEN7_7жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.8> ICEN8_8жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.9> ICEN9_9жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.10> ICEN10_10жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.11> ICEN11_11жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.12> ICEN12_12жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.13> ICEN13_13жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
// <q0.14> ICEN14_14жʹλ
//    <0=>xжϹλûиı
//    <1=>λxλIPND
//</h>
#define     CFG_CAN0_CICEN_INIT 0
//<h>CTMR_CANʱĴ
//<i>0x234 b31~16 b15~0 
//<i>CTMR  -      CTMR  
// <o0.0..15> CTMR_涨ʱֵ <0-65535>
//</h>
#define     CFG_CAN0_CTMR_INIT  0
#if ((CFG_CAN_EN) && ((CFG_PA1_AFR != 6)&&(CFG_PA10_AFR != 6)&&(CFG_PA14_AFR != 6)))
#warning "CAN CAN_TX(PA1/PA10/PA14) AF6 function mapping is not enable."
#endif


#if ((CFG_CAN_EN) && ((CFG_PA3_AFR != 6)&&(CFG_PA13_AFR != 6)&&(CFG_PB14_AFR != 6)))
#warning "CAN CAN_RX(PA3/PA13/PB14) AF6 function mapping is not enable."
#endif
//***********************************************************/
//</e>


//<e>FIFO4L
#define     CFG_FIFO4L_EN       0
//***********************************************************/
//<e>FIFO0
#define     CFG_FIFO0_EN        0
//<i>CR_FIFOƼĴ
//<i>0x04 b31~20 b19   b18   b17    b16    b15~14 b13~12 b11~10   b9~8     b7~6  b5~4  b3     b2      b1       b0       
//<i>CR   -      TXFEN RXFEN TXFRST RXFRST TXTRIG RXTRIG TXWRBITW RXRDBITW TXMAP RXMAP RXMODE RXOVFIE TXTRIGIE RXTRIGIE 
// <q0.18> RXFEN_Rx FIFOʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <q0.19> TXFEN_Tx FIFOʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <o0.3> RXMODE_Rx FIFO MODEѡλ
//    <0=>8bits Mode
//    <1=>(8+N)bits Mode
//<i>λֻUART壬SPI
// <o0.4..5> RXMAP_Rx FIFOӳѡ
//    <0=>UART0
//    <1=>UART1
//    <2=>UART2
//    <3=>Reserved
//    <i>4FIFO֧SPI8FIFO֧SPI
// <o0.6..7> TXMAP_Tx FIFOӳѡ
//    <0=>UART0
//    <1=>UART1
//    <2=>UART2
//    <3=>Reserved
//    <i>4FIFO֧SPI8FIFO֧SPI
// <o0.8..9> RXRDBITW_Rx FIFOݵλ
//    <0=>8 bits  
//    <1=>16 bits
//    <2=>32 bits 
//    <3=>Reserved
// <o0.10..11> TXWRBITW_Tx FIFOдݵλ
//    <0=>8 bits  
//    <1=>16 bits
//    <2=>32 bits 
//    <3=>Reserved
// <o0.12..13> RXTRIG_Rx FIFO
//<0=>Rx FIFO more than 1/4 full
//<1=>Rx FIFO more than 1/2 full
//<2=>Rx FIFO more than 3/4 full
//<3=>Rx FIFO һ
// <o0.14..15> TXTRIG_Tx FIFO
//<i>The trigger points for Tx FIFO 
//<0=>Tx FIFO less than 1/4 full
//<1=>Tx FIFO less than 1/2 full
//<2=>Tx FIFO less than 3/4 full
//<3=>Tx FIFO empty
// <q0.0> RXTRIGIE_Rx FIFOжʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <q0.1> TXTRIGIE_Tx FIFOжʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <q0.2> RXOVFIE_Rx FIFOͻжʹλ
//    <i>0: ֹ
//    <i>1: ʹ


#define     CFG_FIFO0_CR_INIT   80
#if ((CFG_FIFO0_CR_INIT & 7) != 0)
	#define CFG_FIFO0_INT_EN 1
#else
	#define CFG_FIFO0_INT_EN 0
#endif
//</e>


//***********************************************************/
//<e>FIFO1
#define     CFG_FIFO1_EN        0
//<i>CR_FIFOƼĴ
//<i>0x04 b31~20 b19   b18   b17    b16    b15~14 b13~12 b11~10   b9~8     b7~6  b5~4  b3     b2      b1       b0       
//<i>CR   -      TXFEN RXFEN TXFRST RXFRST TXTRIG RXTRIG TXWRBITW RXRDBITW TXMAP RXMAP RXMODE RXOVFIE TXTRIGIE RXTRIGIE 
// <q0.18> RXFEN_Rx FIFOʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <q0.19> TXFEN_Tx FIFOʹλ
//    <i>0: ֹ
//    <i>1: ʹ


// <o0.3> RXMODE_Rx FIFO MODEѡλ
//    <0=>8bits Mode
//    <1=>(8+N)bits Mode
//<i>λֻUART壬SPI
// <o0.4..5> RXMAP_Rx FIFOӳѡ
//    <0=>UART0
//    <1=>UART1
//    <2=>UART2
//    <3=>Reserved
//    <i>4FIFO֧SPI8FIFO֧SPI
// <o0.6..7> TXMAP_Tx FIFOӳѡ
//    <0=>UART0
//    <1=>UART1
//    <2=>UART2
//    <3=>Reserved
//    <i>4FIFO֧SPI8FIFO֧SPI
// <o0.8..9> RXRDBITW_Rx FIFOݵλ
//    <0=>8 bits  
//    <1=>16 bits
//    <2=>32 bits 
//    <3=>Reserved
// <o0.10..11> TXWRBITW_Tx FIFOдݵλ
//    <0=>8 bits  
//    <1=>16 bits
//    <2=>32bits 
//    <3=>Reserved
// <o0.12..13> RXTRIG_Rx FIFO
//<0=>Rx FIFO more than 1/4 full
//<1=>Rx FIFO more than 1/2 full
//<2=>Rx FIFO more than 3/4 full
//<3=>Rx FIFO һ
// <o0.14..15> TXTRIG_Tx FIFO
//<i>The trigger points for Tx FIFO 
//<0=>Tx FIFO less than 1/4 full
//<1=>Tx FIFO less than 1/2 full
//<2=>Tx FIFO less than 3/4 full
//<3=>Tx FIFO empty
// <q0.0> RXTRIGIE_Rx FIFOжʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <q0.1> TXTRIGIE_Tx FIFOжʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <q0.2> RXOVFIE_Rx FIFOͻжʹλ
//    <i>0: ֹ
//    <i>1: ʹ
#define     CFG_FIFO1_CR_INIT   0
#if ((CFG_FIFO1_CR_INIT & 7) != 0)
	#define CFG_FIFO1_INT_EN 1
#else
	#define CFG_FIFO1_INT_EN 0
#endif
//</e>


//***********************************************************/
//</e>


//<e>FIFO8L
//<e>FIFO2
#define     CFG_FIFO2_EN        0
//<i>CR_FIFOƼĴ
//<i>0x04 b31~20 b19   b18   b17    b16    b15~14 b13~12 b11~10   b9~8     b7~6  b5~4  b3     b2      b1       b0       
//<i>CR   -      TXFEN RXFEN TXFRST RXFRST TXTRIG RXTRIG TXWRBITW RXRDBITW TXMAP RXMAP RXMODE RXOVFIE TXTRIGIE RXTRIGIE 
// <q0.18> RXFEN_Rx FIFOʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <q0.19> TXFEN_Tx FIFOʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <o0.3> RXMODE_Rx FIFO MODEѡλ
//    <0=>8bits Mode
//    <1=>(8+N)bits Mode
//<i>λֻUART壬SPI
// <o0.4..5> RXMAP_Rx FIFOӳѡ
//    <0=>UART0
//    <1=>UART1
//    <2=>UART2
//    <3=>SPI
// <o0.6..7> TXMAP_Tx FIFOӳѡ
//    <0=>UART0
//    <1=>UART1
//    <2=>UART2
//    <3=>SPI  
//    <i>8FIFO֧SPI
// <o0.8..9> RXRDBITW_Rx FIFOݵλ
//    <0=>8 bits  
//    <1=>16 bits
//    <2=>32 bits 
//    <3=>Reserved
// <o0.10..11> TXWRBITW_Tx FIFOдݵλ
//    <0=>8 bits  
//    <1=>16 bits
//    <2=>32bits 
//    <3=>Reserved
// <o0.12..13> RXTRIG_Rx FIFO
//<0=>Rx FIFO more than 1/4 full
//<1=>Rx FIFO more than 1/2 full
//<2=>Rx FIFO more than 3/4 full
//<3=>Rx FIFO һ
// <o0.14..15> TXTRIG_Tx FIFO
//<i>The trigger points for Tx FIFO 
//<0=>Tx FIFO less than 1/4 full
//<1=>Tx FIFO less than 1/2 full
//<2=>Tx FIFO less than 3/4 full
//<3=>Tx FIFO empty


// <q0.0> RXTRIGIE_Rx FIFOжʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <q0.1> TXTRIGIE_Tx FIFOжʹλ
//    <i>0: ֹ
//    <i>1: ʹ
// <q0.2> RXOVFIE_Rx FIFOͻжʹλ
//    <i>0: ֹ
//    <i>1: ʹ
//</e>
#define     CFG_FIFO2_CR_INIT   80
#if ((CFG_FIFO2_CR_INIT & 7) != 0)
	#define CFG_FIFO2_INT_EN 1
#else
	#define CFG_FIFO2_INT_EN 0
#endif
//***********************************************************/
//</e>


#define CFG_BOD_INT_EN 0
#define CFG_RCC_INT_EN 0
#define CFG_NVIC_ISER0_INIT ((uint32_t)CFG_WWDT_INT_EN\
													|(CFG_BOD_INT_EN << 1)\
													|(CFG_RCC_INT_EN << 2)\
													|(CFG_EXTI0_INT_EN << 3)\
													|(CFG_EXTI1_INT_EN << 4)\
													|(CFG_EXTI2_INT_EN << 5)\
													|(CFG_EXTI3_INT_EN << 6)\
													|(CFG_MCM_FLT_INT_EN << 7)\
													|(CFG_MCM_PWM_INT_EN << 8)\
													|(CFG_ADC_INT_EN << 9)\
													|(CFG_PCA0_INT_EN << 10)\
													|(CFG_PCA1_INT_EN << 11)\
													|(CFG_PCA0_FLT_INT_EN << 12)\
													|(CFG_PCA1_FLT_INT_EN << 13)\
													|(CFG_CMP0_INT_EN << 14)\
													|(CFG_CMP1_INT_EN << 15)\
													|(CFG_QEI_INT_EN << 16)\
													|(CFG_CAN_INT_EN << 17)\
													|(CFG_TWI_INT_EN << 18)\
													|(CFG_SPI_INT_EN << 19)\
													|(CFG_UART0_INT_EN << 20)\
													|(CFG_UART1_INT_EN << 21)\
													|(CFG_UART2_INT_EN << 22)\
													|(CFG_TIM7_INT_EN << 23)\
													|(CFG_TIM8_INT_EN << 24)\
													|(CFG_EXTI4_7_INT_EN << 25)\
													|(CFG_FIFO0_INT_EN << 26)\
													|(CFG_FIFO1_INT_EN << 27)\
													|(CFG_FIFO2_INT_EN << 28))
													

#define CFG_NVIC_ISER1_INIT 0
													

													

void IPCA_InitCfg(void);        
void WWDT_InitCfg(void);        
void GPIO_InitCfg(void);        
void EXTI_InitCfg(void);        
void MCM_InitCfg(void);        
void PCA_InitCfg(void);        
void MACP_InitCfg(void);           
void TIM_InitCfg(void);        
void ADC_InitCfg(void);        
void QEI_InitCfg(void);        
void AMOC_InitCfg(void);       
void UART_InitCfg(void);       
void SPI_InitCfg(void);        
void TWI_InitCfg(void);   
void CAN_InitCfg(void); 
void FIFO0_InitCfg(void); 
void FIFO1_InitCfg(void); 
void FIFO2_InitCfg(void); 
void SysTick_InitCfg(void);    
void NVIC_InitCfg(void);       
void Peripherals_InitCfg(void);
void IWDT_InitCfg(void);
void SYSCFG_InitCfg(void);


#endif //__CFG33F2801_H__
