/**
  ******************************************************************************
  * @file    sh3xf2xx_sb0_IQmath.c
  * @author  sinowealth
  * @version V1.1.0
  * @date    07-March-2022 
  * @brief   This file provide MACP APIs
  *         
  *  @verbatim
  *
  *          ===================================================================
  *                                  How to use this driver
  *          ===================================================================
  *          
  *
  *  @endverbatim
  *
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2022 Sinowealth</center></h2>
  *
  ******************************************************************************
  */
  
/*==============================================================================
Function List :
             1: IQn            N=1~31
             2: IQNmpy         N=1~31
             3: IQNdiv         N=1~31             
             4: IQNSinCos      N=1~31
             5: IQNSinhCosh    N=1~31
             6: IQNatan        N=1~31
             7: IQNatan2       N=1~31
             8: IQNrms         N=1~31
             9: IQNhypot       N=1~31
             10:IQNsqrt        N=1~31
             11:IQNatanh       N=1~31
             12:IQNatanh2      N=1~31
             14:IQNrotate      N=1~31
             15:IQNpark        N=1~31
             16:IQNipark       N=1~31
             17:IQNpid         N=1~31
             18:IQNsvpwm       N=1~31

RevisionHistory:
Rev#         Date              Author        Comments(Function+Date)
-----+-----------------------+----------------+-------------------------------------------------------
0.0       2020/03/27      robin.zhang        Just build the function
0.1
==============================================================================*/

#include "sh3xf2xx_sb0_IQmath.h"
#include "sh3xf2xx_sb0_macp.h"
#if defined (__FPU_USED) && (__FPU_USED == 1U)
#include "math.h"
#endif
//	IQN iqdiv;
//	IQN	X_abs,Y_abs,X_bak,Y_bak;
//	int8_t Qadjust;
//	int8_t Vadjust;
//	int8_t OadjustX;
//	int8_t OadjustY;

/** @addtogroup SH3xF2xx_sb0_StdLib_Driver
  * @{
  */

/* IQMATH  FUNCTION----------------------------------------------------------*/
/** @defgroup IQMATH_MODULE  IQmath 
*  MACP Module: Include div,sin,cos,atan,sinh,cosh,atanh,rms,hypot,park,ipark,pid,svpwm
  * @{
  */ 
        
/** @defgroup  IQMath_Group_Pub_Funcs  Public Functions
 *  @brief   IQMATH Public Functions
 *
  * @{
  */
  
/** @defgroup IQMATH_Arithmetic Arithmetic Functions
  * @{
  */
  
/**
  * @brief  Divides an IQ number
  * @param  X: the number to be divided, in IQ format
  * @param  Y: the number to divide, in IQ format
  * @param  QN: IQ Format
  * @retval X divided by Y (x/y)
  */
IQN IQNdiv(IQN X, IQN Y, int32_t QN) 			// ӦòIQdiv(X,Y)=X/Y cordicڲRegXǷĸRegYǷӣֵʱע
{
#if defined (__FPU_USED) && (__FPU_USED == 1U)
    float fv = (float)X;
    fv /= (float)Y;
    fv *= (float)(1<<QN);
    return (int32_t)fv;     
#else    
    uint32_t iv;
    int32_t flag = 0;
    uint32_t r = 0;
    int nshift = 0;
    int overflow = 0;
    int i;
  
    if(X < 0)
    {
        iv = (uint32_t)(-X);
        flag++;
    }
    else if(X > 0)
    {           
        iv = (uint32_t)X;
        i = __CLZ((uint32_t) Y);
        if(((uint32_t)Y & ((uint32_t)0x80000000>>i)) == (uint32_t)Y) 
        {
            if(i == 0)
            {
                X >>= (31-QN);
                X = -X;
                return X;
            }
            else if(i < (31-QN))
            {
                X >>= (31-QN-i);
                return X;                
            }
        }
        
        if(i > 0 && i < (31-QN))
        {
            uint32_t mask = 0xFFFFFFFF;
            mask >>= i;
            if(((uint32_t)Y & mask) == mask)
            {                
                  X >>= (32-QN-i);
                  return X;
            }             
        }        
    }
    else
    {
        return 0;
    }
    
    if(Y < 0)
    {
        Y =-Y;
        flag++;        
    }
    
    if(Y == 0)
    {
        overflow = 1;
    }
    else
    {
       int nremain = QN;    
        while(nremain > 0)
        {        
            nshift = __CLZ((uint32_t)iv);
            if(nshift > nremain)
                nshift = nremain;
            if(nshift > 0)
            {
                if(__CLZ((uint32_t)r) < nshift)
                {
                   overflow = 1;
                   break;
                }            
                nremain -= nshift;    
                iv <<= nshift;
            }
            else{
                if(iv < (uint32_t)Y)
                {
                    r <<= nremain;
                    break;
                }
                else if(iv == 0)
                {
                    r <<= nremain;
                    break;
                }
            }        
            r <<= nshift;
            r += iv / (uint32_t)Y;
            iv = iv % (uint32_t)Y;
        }    
    }
    
    if(overflow)
    {
        if(flag == 1)
            r = 0x80000000;
        else
            r = 0x7FFFFFFF;
    }
    else if(flag == 1)
    {
        if((int)r>=0)
            r = -r;
        else
            r = 0x80000000;
    }
    else
    {
        if(r&0x80000000) //overflow
            r = 0x7FFFFFFF;
    }
    return (int32_t)(r);
    
#endif    
}

/**
  * @}
  */

/** @defgroup IQMath_Trigonometric Trigonometric Functions
  * @{
  */
  
#ifdef SINOIQMATH_USE_GENERAL

/**
  * @brief  Computes the sin(Theta) and cos(Theta) of the input value.Use cordic0 to compute
  * @param  Theta: the input value (radians)
  * @param  QN: IQ Format
  * @retval The sin(Theta) and cos(Theta) of the input value. @ref TRIG_TypeDef
  */
TRIG_TypeDef IQNSinCos_G(IQN Theta, int32_t QN)
{
	TRIG_TypeDef IQResult;
	IQN tK;
	int32_t Qadjust;
	MACP->OPRDX0 = C_IQ24_1_K;
	Qadjust = (QN-24);
	MACP->OPRDY0 = 0;
	if(Qadjust >= 0)
	{
		tK = (Theta>>Qadjust);
		tK = IQ24mpy(tK,IQ24_1_PI);
		MACP->OPRDZ0 = (uint32_t)tK;
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
			
		IQResult.Cos = ((IQN)MACP->OPRDX0 << Qadjust);
		IQResult.Sin = ((IQN)MACP->OPRDY0 << Qadjust);		
	}
	else
	{
		Qadjust = -Qadjust;
		tK = (Theta<<Qadjust);
		tK = IQ24mpy(tK,IQ24_1_PI);
		MACP->OPRDZ0 = (uint32_t)tK;
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		IQResult.Cos = ((IQN)MACP->OPRDX0 >> Qadjust);
		IQResult.Sin = ((IQN)MACP->OPRDY0 >> Qadjust);

	}			
	return IQResult;
}

/**
  * @brief  Computes the sin(Theta) and cos(Theta) of the input value.Use cordic1 to compute
  * @param  Theta: the input value (radians)
  * @param  QN: IQ Format
  * @retval The sin(Theta) and cos(Theta) of the input value. @ref TRIG_TypeDef
  */
TRIG_TypeDef IQNSinCos1_G(IQN Theta, int32_t QN)
{
	TRIG_TypeDef IQResult;
	int32_t Qadjust;
	IQN tK;
	MACP->OPRDX1 = C_IQ24_1_K;
	Qadjust = (QN-24);
	MACP->OPRDY1 = 0;
	if(Qadjust >= 0)
	{
		tK = (Theta>>Qadjust);
		tK = IQ24mpy(tK,IQ24_1_PI);
		MACP->OPRDZ1 = (uint32_t)(tK);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
			
		IQResult.Cos = ((IQN)MACP->OPRDX1 << Qadjust);
		IQResult.Sin = ((IQN)MACP->OPRDY1 << Qadjust);		
	}
	else
	{
		Qadjust = -Qadjust;
		tK = (Theta<<Qadjust);
		tK = IQ24mpy(tK,IQ24_1_PI);
		MACP->OPRDZ1 = (uint32_t)(tK);
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		IQResult.Cos = ((IQN)MACP->OPRDX1 >> Qadjust);
		IQResult.Sin = ((IQN)MACP->OPRDY1 >> Qadjust);

	}			
	return IQResult;
}
/**
  * @brief  Computes the sin(Theta) and cos(Theta) of the input value. Use cordic0 to compute
  * @param  Theta: the input value (radians) IQFormat:24
  * @retval The sin(Theta) and cos(Theta) of the input value. @ref TRIG_TypeDef
  */
TRIG_TypeDef IQNSinCos_Q24_G(IQN Theta)
{
	TRIG_TypeDef IQResult;
	MACP->OPRDX0 = C_IQ24_1_K;
	MACP->OPRDY0 = 0;
	MACP->OPRDZ0 = (uint32_t)(IQ24mpy(Theta,IQ24_1_PI));
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
			
	IQResult.Cos = ((IQN)MACP->OPRDX0);
	IQResult.Sin = ((IQN)MACP->OPRDY0);		

	return IQResult;
}
/**
  * @brief  Computes the sin(Theta) and cos(Theta) of the input value. Use cordic1 to compute
  * @param  Theta: the input value (radians) IQFormat:24
  * @retval The sin(Theta) and cos(Theta) of the input value, @ref TRIG_TypeDef
  */
TRIG_TypeDef IQNSinCos1_Q24_G(IQN Theta)
{
	TRIG_TypeDef IQResult;
	MACP->OPRDX1 = C_IQ24_1_K;
	MACP->OPRDY1 = 0;
	MACP->OPRDZ1 = (uint32_t)(IQ24mpy(Theta,IQ24_1_PI));
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
			
	IQResult.Cos = ((IQN)MACP->OPRDX1);
	IQResult.Sin = ((IQN)MACP->OPRDY1);		
		
	return IQResult;
}
#else

/******************************************************************************
*              Input & Output : Normalized by PI
******************************************************************************/
/**
  * @brief  Computes the sin(Theta) and cos(Theta) of the input value.Use cordic0 to compute
  * @param  Theta: the input value (radians)
  * @param  QN: IQ Format
  * @retval The sin(Theta) and cos(Theta) of the input value. @ref TRIG_TypeDef
  */
TRIG_TypeDef IQNSinCos_N(IQN Theta, int32_t QN)
{
	TRIG_TypeDef IQResult;
	int32_t Qadjust;
	MACP->OPRDX0 = C_IQ24_1_K;
	Qadjust = (QN-24);
	MACP->OPRDY0 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDZ0 = (uint32_t)(Theta>>Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
			
		IQResult.Cos = ((IQN)MACP->OPRDX0 << Qadjust);
		IQResult.Sin = ((IQN)MACP->OPRDY0 << Qadjust);		
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDZ0 = (uint32_t)(Theta<<Qadjust);
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		IQResult.Cos = ((IQN)MACP->OPRDX0 >> Qadjust);
		IQResult.Sin = ((IQN)MACP->OPRDY0 >> Qadjust);

	}			
	return IQResult;
}
/**
  * @brief  Computes the sin(Theta) and cos(Theta) of the input value.Use cordic1 to compute
  * @param  Theta: the input value (radians)
  * @param  QN: IQ Format
  * @retval The sin(Theta) and cos(Theta) of the input value. @ref TRIG_TypeDef
  */
TRIG_TypeDef IQNSinCos1_N(IQN Theta, int32_t QN)
{
	TRIG_TypeDef IQResult;
	int32_t Qadjust;
	MACP->OPRDX1 = C_IQ24_1_K;
	Qadjust = (QN-24);
	MACP->OPRDY1 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDZ1 = (uint32_t)(Theta>>Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
			
		IQResult.Cos = ((IQN)MACP->OPRDX1 << Qadjust);
		IQResult.Sin = ((IQN)MACP->OPRDY1 << Qadjust);		
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDZ1 = (uint32_t)(Theta<<Qadjust);
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		IQResult.Cos = ((IQN)MACP->OPRDX1 >> Qadjust);
		IQResult.Sin = ((IQN)MACP->OPRDY1 >> Qadjust);

	}			
	return IQResult;
}
/**
  * @brief  Computes the sin(Theta) and cos(Theta) of the input value.Use cordic0 to compute
  * @param  Theta: the input value (radians).QFmormat:24
  * @retval The sin(Theta) and cos(Theta) of the input value. @ref TRIG_TypeDef
  */
TRIG_TypeDef IQNSinCos_Q24_N(IQN Theta)
{
	TRIG_TypeDef IQResult;
	MACP->OPRDX0 = C_IQ24_1_K;
	MACP->OPRDY0 = 0;
	MACP->OPRDZ0 = (uint32_t)Theta;
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
			
	IQResult.Cos = ((IQN)MACP->OPRDX0);
	IQResult.Sin = ((IQN)MACP->OPRDY0);		

	return IQResult;
}

/**
  * @brief  Computes the sin(Theta) and cos(Theta) of the input value.Use cordic1 to compute
  * @param  Theta: the input value (radians).QFmormat:24
  * @retval The sin(Theta) and cos(Theta) of the input value. @ref TRIG_TypeDef
  */
TRIG_TypeDef IQNSinCos1_Q24_N(IQN Theta)
{
	TRIG_TypeDef IQResult;
	MACP->OPRDX1 = C_IQ24_1_K;
	MACP->OPRDY1 = 0;
	MACP->OPRDZ1 = (uint32_t)Theta;
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
			
	IQResult.Cos = ((IQN)MACP->OPRDX1);
	IQResult.Sin = ((IQN)MACP->OPRDY1);		
		
	return IQResult;
}
#endif

#ifdef SINOIQMATH_USE_GENERAL

/**
  * @brief  Computes the sinh(Theta) and cosh(Theta) of the input value.Use cordic0 to compute
  * @param  Theta: the input value (radians)
  * @param  QN: IQ Format
  * @retval The sinh(Theta) and cosh(Theta) of the input value. @ref TRIGH_TypeDef
  */
TRIGH_TypeDef IQNSinhCosh_G(IQN Theta, int32_t QN)
{
	TRIGH_TypeDef IQResult;
	IQN tK;
	int32_t Qadjust;
	MACP->OPRDX0 = H_IQ24_1_K;
	Qadjust = (QN-24);
	MACP->OPRDY0 = 0;
	if(Qadjust >= 0)
	{
		tK = (Theta>>Qadjust);
		tK = IQ24mpy(tK,IQ24_1_PI);
		MACP->OPRDZ0 = (uint32_t)tK;
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
			
		IQResult.Cosh = ((IQN)MACP->OPRDX0 << Qadjust);
		IQResult.Sinh = ((IQN)MACP->OPRDY0 << Qadjust);		
	}
	else
	{
		Qadjust = -Qadjust;
		tK = (Theta<<Qadjust);
		tK = IQ24mpy(tK,IQ24_1_PI);
		MACP->OPRDZ0 = (uint32_t)tK;
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		IQResult.Cosh = ((IQN)MACP->OPRDX0 >> Qadjust);
		IQResult.Sinh = ((IQN)MACP->OPRDY0 >> Qadjust);
	}			
	return IQResult;
}

/**
  * @brief  Computes the sinh(Theta) and cosh(Theta) of the input value.Use cordic1 to compute
  * @param  Theta: the input value (radians)
  * @param  QN: IQ Format
  * @retval The sinh(Theta) and cosh(Theta) of the input value. @ref TRIGH_TypeDef
  */
TRIGH_TypeDef IQNSinhCosh1_G(IQN Theta, int32_t QN)
{
	TRIGH_TypeDef IQResult;
	IQN tK;
	int32_t Qadjust;
	MACP->OPRDX1 = H_IQ24_1_K;
	Qadjust = (QN-24);
	MACP->OPRDY1 = 0;
	if(Qadjust >= 0)
	{
		tK = (Theta>>Qadjust);
		tK = IQ24mpy(tK,IQ24_1_PI);
		MACP->OPRDZ1 = (uint32_t)tK;
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
			
		IQResult.Cosh = ((IQN)MACP->OPRDX1 << Qadjust);
		IQResult.Sinh = ((IQN)MACP->OPRDY1 << Qadjust);		
	}
	else
	{
		Qadjust = -Qadjust;
		tK = (Theta<<Qadjust);
		tK = IQ24mpy(tK,IQ24_1_PI);
		MACP->OPRDZ1 = (uint32_t)tK;
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24    <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		IQResult.Cosh = ((IQN)MACP->OPRDX1 >> Qadjust);
		IQResult.Sinh = ((IQN)MACP->OPRDY1 >> Qadjust);

	}			
	return IQResult;
}
/**
  * @brief  Computes the sinh(Theta) and cosh(Theta) of the input value.Use cordic0 to compute
  * @param  Theta: the input value (radians),IQ Format:24
  * @retval The sinh(Theta) and cosh(Theta) of the input value. @ref TRIGH_TypeDef
  */
TRIGH_TypeDef IQNSinhCosh_Q24_G(IQN Theta)
{
	TRIGH_TypeDef IQResult;
	MACP->OPRDX0 = H_IQ24_1_K;
	MACP->OPRDY0 = 0;
	MACP->OPRDZ0 = (uint32_t)(IQ24mpy(Theta,IQ24_1_PI));
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
			
	IQResult.Cosh = ((IQN)MACP->OPRDX0);
	IQResult.Sinh = ((IQN)MACP->OPRDY0);
	return IQResult;
}

/**
  * @brief  Computes the sinh(Theta) and cosh(Theta) of the input value.Use cordic1 to compute
  * @param  Theta: the input value (radians),IQ Format:24
  * @retval The sinh(Theta) and cosh(Theta) of the input value. @ref TRIGH_TypeDef
  */
TRIGH_TypeDef IQNSinhCosh1_Q24_G(IQN Theta)
{
	TRIGH_TypeDef IQResult;
	MACP->OPRDX1 = H_IQ24_1_K;
	MACP->OPRDY1 = 0;
	MACP->OPRDZ1 = (uint32_t)(IQ24mpy(Theta,IQ24_1_PI));
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
			
	IQResult.Cosh = ((IQN)MACP->OPRDX1);
	IQResult.Sinh = ((IQN)MACP->OPRDY1);		

	return IQResult;
}
#else
/**
  * @brief  Computes the sinh(Theta) and cosh(Theta) of the input value.Use cordic0 to compute
  * @param  Theta: the input value (radians)
  * @param  QN: IQ Format
  * @retval The sinh(Theta) and cosh(Theta) of the input value. @ref TRIGH_TypeDef
  */
TRIGH_TypeDef IQNSinhCosh_N(IQN Theta, int32_t QN)
{
	TRIGH_TypeDef IQResult;
	int32_t Qadjust;
	MACP->OPRDX0 = H_IQ24_1_K;
	Qadjust = (QN-24);
	MACP->OPRDY0 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDZ0 = (uint32_t)(Theta>>Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
			
		IQResult.Cosh = ((IQN)MACP->OPRDX0 << Qadjust);
		IQResult.Sinh = ((IQN)MACP->OPRDY0 << Qadjust);		
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDZ0 = (uint32_t)(Theta<<Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		IQResult.Cosh = ((IQN)MACP->OPRDX0 >> Qadjust);
		IQResult.Sinh = ((IQN)MACP->OPRDY0 >> Qadjust);
	}			
	return IQResult;
}
/**
  * @brief  Computes the sinh(Theta) and cosh(Theta) of the input value.Use cordic1 to compute
  * @param  Theta: the input value (radians)
  * @param  QN: IQ Format
  * @retval The sinh(Theta) and cosh(Theta) of the input value. @ref TRIGH_TypeDef
  */
TRIGH_TypeDef IQNSinhCosh1_N(IQN Theta, int32_t QN)
{
	TRIGH_TypeDef IQResult;
	int32_t Qadjust;
	MACP->OPRDX1 = H_IQ24_1_K;
	Qadjust = (QN-24);
	MACP->OPRDY1 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDZ1 = (uint32_t)(Theta>>Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
			
		IQResult.Cosh = ((IQN)MACP->OPRDX1 << Qadjust);
		IQResult.Sinh = ((IQN)MACP->OPRDY1 << Qadjust);		
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDZ1 = (uint32_t)(Theta<<Qadjust);
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24    <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		IQResult.Cosh = ((IQN)MACP->OPRDX1 >> Qadjust);
		IQResult.Sinh = ((IQN)MACP->OPRDY1 >> Qadjust);

	}			
	return IQResult;
}
/**
  * @brief  Computes the sinh(Theta) and cosh(Theta) of the input value.Use cordic0 to compute
  * @param  Theta: the input value (radians),IQ Format:24
  * @retval The sinh(Theta) and cosh(Theta) of the input value. @ref TRIGH_TypeDef
  */
TRIGH_TypeDef IQNSinhCosh_Q24_N(IQN Theta)
{
	TRIGH_TypeDef IQResult;
	MACP->OPRDX0 = H_IQ24_1_K;
	MACP->OPRDY0 = 0;
	MACP->OPRDZ0 = (uint32_t)(Theta);
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
			
	IQResult.Cosh = ((IQN)MACP->OPRDX0);
	IQResult.Sinh = ((IQN)MACP->OPRDY0);
	return IQResult;
}
/**
  * @brief  Computes the sinh(Theta) and cosh(Theta) of the input value.Use cordic1 to compute
  * @param  Theta: the input value (radians),IQ Format:24
  * @retval The sinh(Theta) and cosh(Theta) of the input value. @ref TRIGH_TypeDef
  */
TRIGH_TypeDef IQNSinhCosh1_Q24_N(IQN Theta)
{
	TRIGH_TypeDef IQResult;
	MACP->OPRDX1 = H_IQ24_1_K;
	MACP->OPRDY1 = 0;
	MACP->OPRDZ1 = (uint32_t)(Theta);
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
			
	IQResult.Cosh = ((IQN)MACP->OPRDX1);
	IQResult.Sinh = ((IQN)MACP->OPRDY1);		

	return IQResult;
}
#endif

#ifdef SINOIQMATH_USE_GENERAL

/**
  * @brief  Computes the arctan(X) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctan(X) of the input value. 
  */
IQN IQNatan_G(IQN X, int32_t QN)
{    
	IQN rAtan;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ0 = 0;
	MACP->OPRDX0 =(uint32_t)( 1 << 24);
	if(Qadjust >= 0)
	{
		MACP->OPRDY0 =(uint32_t)( X >> Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rAtan = (IQN)MACP->OPRDZ0;
		rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));
		rAtan = ((IQN)rAtan << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDY0 =(uint32_t)( X << Qadjust);

		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rAtan = (IQN)MACP->OPRDZ0;
		rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));
		rAtan = ((IQN)rAtan >> Qadjust);
	}			
	
	return rAtan;	
}
/**
  * @brief  Computes the arctan(X) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctan(X) of the input value. 
  */
IQN IQNatan1_G(IQN X, int32_t QN)
{    
	IQN rAtan;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ1 = 0;
	MACP->OPRDX1 =(uint32_t)( 1 << 24);
	if(Qadjust >= 0)
	{
		MACP->OPRDY1 =(uint32_t)( X >> Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rAtan = (IQN)MACP->OPRDZ1;
		rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));
		rAtan = ((IQN)rAtan << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDY1 =(uint32_t)( X << Qadjust);

		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rAtan = (IQN)MACP->OPRDZ1;
		rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));
		rAtan = ((IQN)rAtan >> Qadjust);
	}			
	return rAtan;	
}

/**
  * @brief  Computes the arctan(X) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians),IQ Format:24
  * @retval The arctan(X) of the input value. 
  */
IQN IQNatan_Q24_G(IQN X)
{    
	IQN rAtan;
	MACP->OPRDZ0 = 0;
	MACP->OPRDX0 =(uint32_t)( 1 << 24);
	MACP->OPRDY0 =(uint32_t)( X );
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	rAtan = (IQN)MACP->OPRDZ0;
	rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));	
	return rAtan;	
}
/**
  * @brief  Computes the arctan(X) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians), IQ Format:24
  * @retval The arctan(X) of the input value. 
  */
IQN IQNatan1_Q24_G(IQN X)
{    
	IQN rAtan;
	MACP->OPRDZ1 = 0;
	MACP->OPRDX1 =(uint32_t)( 1 << 24);
	MACP->OPRDY1 =(uint32_t)( X );
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
		rAtan = (IQN)MACP->OPRDZ1;
		rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));
	return rAtan;	
}
#else
/**
  * @brief  Computes the arctan(X) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctan(X) of the input value. 
  */
IQN IQNatan_N(IQN X, int32_t QN)
{    
	IQN rAtan;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ0 = 0;
	MACP->OPRDX0 =(uint32_t)( 1 << 24);
	if(Qadjust >= 0)
	{
		MACP->OPRDY0 =(uint32_t)( X >> Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rAtan = ((IQN)MACP->OPRDZ0 << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDY0 =(uint32_t)( X << Qadjust);

		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rAtan = ((IQN)MACP->OPRDZ0 >> Qadjust);
	}			
	
	return rAtan;	
}
/**
  * @brief  Computes the arctan(X) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctan(X) of the input value. 
  */
IQN IQNatan1_N(IQN X, int32_t QN)
{    
	IQN rAtan;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ1 = 0;
	MACP->OPRDX1 =(uint32_t)( 1 << 24);
	if(Qadjust >= 0)
	{
		MACP->OPRDY1 =(uint32_t)( X >> Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rAtan = ((IQN)MACP->OPRDZ1 << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDY1 =(uint32_t)( X << Qadjust);

		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rAtan = ((IQN)MACP->OPRDZ1 >> Qadjust);
	}			
	return rAtan;	
}
/**
  * @brief  Computes the arctan(X) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians),IQ Format:24
  * @retval The arctan(X) of the input value. 
  */
IQN IQNatan_Q24_N(IQN X)
{    
	MACP->OPRDZ0 = 0;
	MACP->OPRDX0 =(uint32_t)( 1 << 24);
	MACP->OPRDY0 =(uint32_t)( X );
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	return (IQN)MACP->OPRDZ0;	
}
/**
  * @brief  Computes the arctan(X) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians), IQ Format:24
  * @retval The arctan(X) of the input value. 
  */
IQN IQNatan1_Q24_N(IQN X)
{    
	MACP->OPRDZ1 = 0;
	MACP->OPRDX1 =(uint32_t)( 1 << 24);
	MACP->OPRDY1 =(uint32_t)( X );
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
	return (IQN)MACP->OPRDZ1;	
}
#endif

#ifdef SINOIQMATH_USE_GENERAL

/**
  * @brief  Computes the arctan(Y/X) of the input value.Use cordic0 to compute
  * @param  X: the input value X
  * @param  Y: the input value Y
  * @param  QN: IQ Format
  * @retval The arctan(Y/X) of the input value. 
  */
IQN IQNatan2_G(IQN X, IQN Y, int32_t QN)
{
	IQN rAtan;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ0 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDX0 =(uint32_t)( X >> Qadjust);
		MACP->OPRDY0 =(uint32_t)( Y >> Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rAtan = (IQN)MACP->OPRDZ0;
		rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));
		rAtan = ((IQN)rAtan << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDX0 =(uint32_t)( X << Qadjust);
		MACP->OPRDY0 =(uint32_t)( Y << Qadjust);

		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rAtan = (IQN)MACP->OPRDZ0;
		rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));
		rAtan = ((IQN)rAtan >> Qadjust);
	}			
	
	return rAtan;	
}
/**
  * @brief  Computes the arctan(Y/X) of the input value.Use cordic1 to compute
  * @param  X: the input value X
  * @param  Y: the input value Y
  * @param  QN: IQ Format
  * @retval The arctan(Y/X) of the input value. 
  */
IQN IQNatan21_G(IQN X, IQN Y, int32_t QN)
{
	IQN rAtan;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ1 = 0;
	if(Qadjust >= 0)
	{
	  MACP->OPRDX1 =(uint32_t)( X >> Qadjust);
		MACP->OPRDY1 =(uint32_t)( Y >> Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rAtan = (IQN)MACP->OPRDZ1;
		rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));
		rAtan = ((IQN)rAtan << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
	  MACP->OPRDX1 =(uint32_t)( X << Qadjust);
		MACP->OPRDY1 =(uint32_t)( Y << Qadjust);

		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rAtan = (IQN)MACP->OPRDZ1;
		rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));
		rAtan = ((IQN)rAtan >> Qadjust);
	}			
	return rAtan;	
}
/**
  * @brief  Computes the arctan(Y/X) of the input value.Use cordic0 to compute
  * @param  X: the input value X
  * @param  Y: the input value Y
  * @param  QN: IQ Format
  * @retval The arctan(Y/X) of the input value. 
  */
IQN IQNatan2_Q24_G(IQN X, IQN Y)
{
	IQN rAtan;
	MACP->OPRDZ0 = 0;
	MACP->OPRDX0 =(uint32_t)( X );
	MACP->OPRDY0 =(uint32_t)( Y );
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	rAtan = (IQN)MACP->OPRDZ0;
	rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));
	
	return rAtan;	
}
/**
  * @brief  Computes the arctan(Y/X) of the input value.Use cordic0 to compute
  * @param  X: the input value X
  * @param  Y: the input value Y
  * @param  QN: IQ Format
  * @retval The arctan(Y/X) of the input value. 
  */
IQN IQNatan21_Q24_G(IQN X, IQN Y)
{
	IQN rAtan;
	MACP->OPRDZ1 = 0;
	MACP->OPRDX1 =(uint32_t)( X );
	MACP->OPRDY1 =(uint32_t)( Y );
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
	rAtan = (IQN)MACP->OPRDZ1;
	rAtan = IQ24mpy(rAtan,(int)(PI*(1<<24)));

	return rAtan;	
}
#else

/**
  * @brief  Computes the arctan(Y/X) of the input value.Use cordic0 to compute
  * @param  X: the input value X
  * @param  Y: the input value Y
  * @param  QN: IQ Format
  * @retval The arctan(Y/X) of the input value. 
  */
IQN IQNatan2_N(IQN X, IQN Y, int32_t QN)
{
	IQN rAtan;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ0 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDX0 =(uint32_t)( X >> Qadjust);
		MACP->OPRDY0 =(uint32_t)( Y >> Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rAtan = ((IQN)MACP->OPRDZ0 << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDX0 =(uint32_t)( X << Qadjust);
		MACP->OPRDY0 =(uint32_t)( Y << Qadjust);

		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rAtan = ((IQN)MACP->OPRDZ0 >> Qadjust);
	}			
	
	return rAtan;	
}
/**
  * @brief  Computes the arctan(Y/X) of the input value.Use cordic1 to compute
  * @param  X: the input value X
  * @param  Y: the input value Y
  * @param  QN: IQ Format
  * @retval The arctan(Y/X) of the input value. 
  */
IQN IQNatan21_N(IQN X, IQN Y, int32_t QN)
{
	IQN rAtan;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ1 = 0;
	if(Qadjust >= 0)
	{
	    MACP->OPRDX1 =(uint32_t)( X >> Qadjust);
		MACP->OPRDY1 =(uint32_t)( Y >> Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rAtan = ((IQN)MACP->OPRDZ1 << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
	  MACP->OPRDX1 =(uint32_t)( X << Qadjust);
		MACP->OPRDY1 =(uint32_t)( Y << Qadjust);

		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rAtan = ((IQN)MACP->OPRDZ1 >> Qadjust);
	}			
	return rAtan;	
}

/**
  * @brief  Computes the arctan(Y/X) of the input value.Use cordic0 to compute
  * @param  X: the input value X, IQ Format:24
  * @param  Y: the input value Y, IQ Format:24
  * @retval The arctan(Y/X) of the input value. 
  */
IQN IQNatan2_Q24_N(IQN X, IQN Y)
{
	MACP->OPRDZ0 = 0;
	MACP->OPRDX0 =(uint32_t)( X );
	MACP->OPRDY0 =(uint32_t)( Y );
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	
	return (IQN)MACP->OPRDZ0;	
}

/**
  * @brief  Computes the arctan(Y/X) of the input value.Use cordic1 to compute
  * @param  X: the input value X, IQ Format:24
  * @param  Y: the input value Y, IQ Format:24
  * @retval The arctan(Y/X) of the input value. 
  */
IQN IQNatan21_Q24_N(IQN X, IQN Y)
{
	MACP->OPRDZ1 = 0;
	MACP->OPRDX1 =(uint32_t)( X );
	MACP->OPRDY1 =(uint32_t)( Y );
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}

	return (IQN)MACP->OPRDZ1;	
}
#endif

#ifdef SINOIQMATH_USE_GENERAL

/**
  * @brief  Computes the arctanh of the input value.Use cordic0 to compute
  * @param  X: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctanh of the input value. 
  */
IQN IQNatanh_G(IQN X, int32_t QN)
{    
	IQN iqatanh;
	IQN yK;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ0 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDX0 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		X >>= Qadjust;
		yK = IQ24mpy(X,H_IQ24_1_K);		
		MACP->OPRDY0 =(uint32_t)(yK);
		
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		iqatanh = (IQN)MACP->OPRDZ0;
		iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
		iqatanh = ((IQN)iqatanh << Qadjust);
	}
	else
	{		
		MACP->OPRDX0 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		Qadjust = -Qadjust;
		X <<= Qadjust;		
		yK = IQ24mpy(X,H_IQ24_1_K);		
		MACP->OPRDY0 =(uint32_t)(yK);
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}	
		iqatanh = (IQN)MACP->OPRDZ0;
		iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
		iqatanh = ((IQN)iqatanh >> Qadjust);
	}			
	return iqatanh;	
}
/**
  * @brief  Computes the arctanh of the input value.Use cordic1 to compute
  * @param  X: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctanh of the input value. 
  */
IQN IQNatanh1_G(IQN X, int32_t QN)
{    
	IQN iqatanh;
	IQN yK;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ1 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDX1 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		
		X >>= Qadjust;	
		yK = IQ24mpy(X,H_IQ24_1_K);		
		MACP->OPRDY1 =(uint32_t)(yK);
		
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		iqatanh = (IQN)MACP->OPRDZ1;
		iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
		iqatanh = ((IQN)iqatanh << Qadjust);
	}
	else
	{
		MACP->OPRDX1 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		
		Qadjust = -Qadjust;
		X <<= Qadjust;		
		yK = IQ24mpy(X,H_IQ24_1_K);		
		MACP->OPRDY1 =(uint32_t)(yK);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}	
		iqatanh = (IQN)MACP->OPRDZ1;
		iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
		iqatanh = ((IQN)iqatanh >> Qadjust);
	}			
	return iqatanh;	
}
/**
  * @brief  Computes the arctanh of the input value.Use cordic0 to compute
  * @param  X: the input value (radians). IQ Format:24
  * @retval The arctanh of the input value. 
  */
IQN IQNatanh_Q24_G(IQN X)
{    
	IQN iqatanh;
	IQN yK;
	MACP->OPRDZ0 = 0;
	
	MACP->OPRDX0 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		
	yK = IQ24mpy(X,H_IQ24_1_K);		
	MACP->OPRDY0 =(uint32_t)(yK);
		
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	iqatanh = (IQN)MACP->OPRDZ0;
	iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
	return iqatanh;	
}
/**
  * @brief  Computes the arctanh of the input value.Use cordic1 to compute
  * @param  X: the input value (radians). IQ Format:24
  * @retval The arctanh of the input value. 
  */
IQN IQNatanh1_Q24_G(IQN X)
{    
	IQN iqatanh;
	IQN yK;
	MACP->OPRDZ1 = 0;
	
	MACP->OPRDX1 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		
	yK = IQ24mpy(X,H_IQ24_1_K);		
	MACP->OPRDY1 =(uint32_t)(yK);
		
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
	iqatanh = (IQN)MACP->OPRDZ1;
	iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
	return iqatanh;	
}
#else
/**
  * @brief  Computes the arctanh of the input value.Use cordic0 to compute
  * @param  X: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctanh of the input value. 
  */
IQN IQNatanh_N(IQN X, int32_t QN)
{    
	IQN iqatanh;
	IQN yK;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ0 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDX0 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		X >>= Qadjust;
		yK = IQ24mpy(X,H_IQ24_1_K);		
		MACP->OPRDY0 =(uint32_t)(yK);
		
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		iqatanh = ((IQN)MACP->OPRDZ0 << Qadjust);
	}
	else
	{		
		MACP->OPRDX0 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		Qadjust = -Qadjust;
		X <<= Qadjust;		
		yK = IQ24mpy(X,H_IQ24_1_K);		
		MACP->OPRDY0 =(uint32_t)(yK);
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}	
		iqatanh = ((IQN)MACP->OPRDZ0 >> Qadjust);
	}			
	return iqatanh;	
}
/**
  * @brief  Computes the arctanh of the input value.Use cordic1 to compute
  * @param  X: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctanh of the input value. 
  */
IQN IQNatanh1_N(IQN X, int32_t QN)
{    
	IQN iqatanh;
	IQN yK;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ1 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDX1 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		
		X >>= Qadjust;	
		yK = IQ24mpy(X,H_IQ24_1_K);		
		MACP->OPRDY1 =(uint32_t)(yK);
		
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		iqatanh = ((IQN)MACP->OPRDZ1 << Qadjust);
	}
	else
	{
		MACP->OPRDX1 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		
		Qadjust = -Qadjust;
		X <<= Qadjust;		
		yK = IQ24mpy(X,H_IQ24_1_K);		
		MACP->OPRDY1 =(uint32_t)(yK);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}	
		iqatanh = ((IQN)MACP->OPRDZ1 >> Qadjust);
	}			
	return iqatanh;	
}
/**
  * @brief  Computes the arctanh of the input value.Use cordic0 to compute
  * @param  X: the input value (radians). IQ Format:24
  * @retval The arctanh of the input value. 
  */
IQN IQNatanh_Q24_N(IQN X)
{    
	IQN yK;
	MACP->OPRDZ0 = 0;
	
	MACP->OPRDX0 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		
	yK = IQ24mpy(X,H_IQ24_1_K);		
	MACP->OPRDY0 =(uint32_t)(yK);
		
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	return (IQN)MACP->OPRDZ0;	
}
/**
  * @brief  Computes the arctanh of the input value.Use cordic1 to compute
  * @param  X: the input value (radians). IQ Format:24
  * @retval The arctanh of the input value. 
  */
IQN IQNatanh1_Q24_N(IQN X)
{    
	IQN yK;
	MACP->OPRDZ1 = 0;
	
	MACP->OPRDX1 =(uint32_t)(IQ24mpy((1<<24),H_IQ24_1_K)); //Q24 1/K 
		
	yK = IQ24mpy(X,H_IQ24_1_K);		
	MACP->OPRDY1 =(uint32_t)(yK);
		
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
	return (IQN)MACP->OPRDZ1;	
}
#endif

#ifdef SINOIQMATH_USE_GENERAL

/**
  * @brief  Computes the arctanh(Y/X) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians)
  * @param  Y: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctanh(Y/X) of the input value. 
  */
IQN IQNatanh2_G(IQN X, IQN Y, int32_t QN)
{
	IQN iqatanh;
	IQN xK,yK;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ0 = 0;
	if(Qadjust >= 0)
	{
		xK = X >> Qadjust;		
		xK = IQ24mpy(xK,H_IQ24_1_K);	
		MACP->OPRDX0 =(uint32_t)(xK);
		
		yK = Y >> Qadjust;
		yK = IQ24mpy(yK,H_IQ24_1_K);		
		MACP->OPRDY0 =(uint32_t)(yK);
				
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		iqatanh = (IQN)MACP->OPRDZ0;
		iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
		iqatanh = ((IQN)iqatanh << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		xK = X << Qadjust;		
		xK = IQ24mpy(xK,H_IQ24_1_K);	
		MACP->OPRDX0 =(uint32_t)(xK);
		
		yK = Y <<Qadjust;
		yK = IQ24mpy(yK,H_IQ24_1_K);		
		MACP->OPRDY0 =(uint32_t)(yK);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}	
		iqatanh = (IQN)MACP->OPRDZ0;
		iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
		iqatanh = ((IQN)iqatanh >> Qadjust);
	}			
	return iqatanh;	
}
/**
  * @brief  Computes the arctanh(Y/X) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians)
  * @param  Y: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctanh(Y/X) of the input value. 
  */
IQN IQNatanh21_G(IQN X, IQN Y, int32_t QN)
{
	IQN iqatanh;
	IQN xK,yK;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ1 = 0;
	if(Qadjust >= 0)
	{
		xK = X >> Qadjust;		
		xK = IQ24mpy(xK,H_IQ24_1_K);	
		MACP->OPRDX1 =(uint32_t)(xK);
		
		yK = Y >> Qadjust;
		yK = IQ24mpy(yK,H_IQ24_1_K);		
		MACP->OPRDY1 =(uint32_t)(yK);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		iqatanh = (IQN)MACP->OPRDZ1;
		iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
		iqatanh = ((IQN)iqatanh << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		xK = X << Qadjust;		
		xK = IQ24mpy(xK,H_IQ24_1_K);	
		MACP->OPRDX1 =(uint32_t)(xK);
		
		yK = Y <<Qadjust;
		yK = IQ24mpy(yK,H_IQ24_1_K);		
		MACP->OPRDY1 =(uint32_t)(yK);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}	
		iqatanh = (IQN)MACP->OPRDZ1;
		iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
		iqatanh = ((IQN)iqatanh >> Qadjust);
	}			
	return iqatanh;	
}
/**
  * @brief  Computes the arctanh(Y/X) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians). IQ Format:24
  * @param  Y: the input value (radians). IQ Format:24
  * @retval The arctanh(Y/X) of the input value. 
  */
IQN IQNatanh2_Q24_G(IQN X, IQN Y)
{
	IQN iqatanh;
	IQN xK,yK;
	MACP->OPRDZ0 = 0;
	xK = IQ24mpy(X,H_IQ24_1_K);	
	MACP->OPRDX0 =(uint32_t)(xK);
		
	yK = IQ24mpy(Y,H_IQ24_1_K);		
	MACP->OPRDY0 =(uint32_t)(yK);
		
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	iqatanh = (IQN)MACP->OPRDZ0;
	iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
	return iqatanh;	
}
/**
  * @brief  Computes the arctanh(Y/X) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians). IQ Format:24
  * @param  Y: the input value (radians). IQ Format:24
  * @retval The arctanh(Y/X) of the input value. 
  */
IQN IQNatanh21_Q24_G(IQN X, IQN Y)
{
	IQN iqatanh;
	IQN xK,yK;
	MACP->OPRDZ1 = 0;
	xK = IQ24mpy(X,H_IQ24_1_K);	
	MACP->OPRDX1 =(uint32_t)(xK);
		
	yK = IQ24mpy(Y,H_IQ24_1_K);		
	MACP->OPRDY1 =(uint32_t)(yK);
		
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
	iqatanh = (IQN)MACP->OPRDZ1;
	iqatanh = IQ24mpy(iqatanh,(int)((1<<24)*PI));
	return iqatanh;	
}
#else
/**
  * @brief  Computes the arctanh(Y/X) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians)
  * @param  Y: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctanh(Y/X) of the input value. 
  */
IQN IQNatanh2_N(IQN X, IQN Y, int32_t QN)
{
	IQN iqatanh;
	IQN xK,yK;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ0 = 0;
	if(Qadjust >= 0)
	{
		xK = X >> Qadjust;		
		xK = IQ24mpy(xK,H_IQ24_1_K);	
		MACP->OPRDX0 =(uint32_t)(xK);
		
		yK = Y >> Qadjust;		
		yK = IQ24mpy(yK,H_IQ24_1_K);		
		MACP->OPRDY0 =(uint32_t)(yK);
		
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		iqatanh = ((IQN)MACP->OPRDZ0 << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		xK = X << Qadjust;		
		xK = IQ24mpy(xK,H_IQ24_1_K);	
		MACP->OPRDX0 =(uint32_t)(xK);
		
		yK = Y << Qadjust;
		yK = IQ24mpy(yK,H_IQ24_1_K);		
		MACP->OPRDY0 =(uint32_t)(yK);
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}	
		iqatanh = ((IQN)MACP->OPRDZ0 >> Qadjust);
	}			
	return iqatanh;	
}
/**
  * @brief  Computes the arctanh(Y/X) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians)
  * @param  Y: the input value (radians)
  * @param  QN: IQ Format
  * @retval The arctanh(Y/X) of the input value. 
  */
IQN IQNatanh21_N(IQN X, IQN Y, int32_t QN)
{
	IQN iqatanh;
	IQN xK,yK;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ1 = 0;
	if(Qadjust >= 0)
	{
		xK = X >> Qadjust;		
		xK = IQ24mpy(xK,H_IQ24_1_K);	
		MACP->OPRDX1 =(uint32_t)(xK);
		
		yK = Y >> Qadjust;		
		yK = IQ24mpy(yK,H_IQ24_1_K);		
		MACP->OPRDY1 =(uint32_t)(yK);
				
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		iqatanh = ((IQN)MACP->OPRDZ1 << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		xK = X << Qadjust;		
		xK = IQ24mpy(xK,H_IQ24_1_K);	
		MACP->OPRDX1 =(uint32_t)(xK);
		
		yK = Y << Qadjust;
		yK = IQ24mpy(yK,H_IQ24_1_K);		
		MACP->OPRDY1 =(uint32_t)(yK);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}	
		iqatanh = ((IQN)MACP->OPRDZ1 >> Qadjust);
	}			
	return iqatanh;	
}
/**
  * @brief  Computes the arctanh(Y/X) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians). IQ Format:24
  * @param  Y: the input value (radians). IQ Format:24
  * @retval The arctanh(Y/X) of the input value. 
  */
IQN IQNatanh2_Q24_N(IQN X, IQN Y)
{
	IQN xK,yK;
	MACP->OPRDZ0 = 0;
	xK = IQ24mpy(X,H_IQ24_1_K);	
	MACP->OPRDX0 =(uint32_t)(xK);
		
	yK = IQ24mpy(Y,H_IQ24_1_K);		
	MACP->OPRDY0 =(uint32_t)(yK);
		
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	return (IQN)MACP->OPRDZ0;	
}
/**
  * @brief  Computes the arctanh(Y/X) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians). IQ Format:24
  * @param  Y: the input value (radians). IQ Format:24
  * @retval The arctanh(Y/X) of the input value. 
  */
IQN IQNatanh21_Q24_N(IQN X, IQN Y)
{
	IQN xK,yK;
	MACP->OPRDZ1 = 0;
	xK = IQ24mpy(X,H_IQ24_1_K);	
	MACP->OPRDX1 =(uint32_t)(xK);
		
	yK = IQ24mpy(Y,H_IQ24_1_K);		
	MACP->OPRDY1 =(uint32_t)(yK);
		
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
		
	return (IQN)MACP->OPRDZ1;	
}
#endif

/**
  * @}
  */
  
/** @defgroup IQMath_Mathematical Mathematical Functions
  * @{
  */  

/**
  * @brief  Computes the sqrt(X^2 + Y^2) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians).
  * @param  Y: the input value (radians).
  * @param  QN: IQ Format
  * @retval The sqrt(X^2 + Y^2) of the input value. 
  */
IQN IQNhypot(IQN X, IQN Y,int32_t QN)
{    
	IQN rMode;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ0 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDX0 =(uint32_t)( X >> Qadjust);
		MACP->OPRDY0 =(uint32_t)( Y >> Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rMode = 	((IQN)MACP->OPRDX0 << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDX0 =(uint32_t)( X << Qadjust);
		MACP->OPRDY0 =(uint32_t)( Y << Qadjust);

		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rMode = ((IQN)MACP->OPRDX0 >> Qadjust);
	}			
	
	return rMode;	
}
/**
  * @brief  Computes the sqrt(X^2 + Y^2) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians).
  * @param  Y: the input value (radians).
  * @param  QN: IQ Format
  * @retval The sqrt(X^2 + Y^2) of the input value. 
  */
IQN IQNhypot1(IQN X, IQN Y,int32_t QN)
{    
	IQN rHypot;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ1 = 0;
	if(Qadjust >= 0)
	{
	    MACP->OPRDX1 =(uint32_t)( X >> Qadjust);
		MACP->OPRDY1 =(uint32_t)( Y >> Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rHypot = 	((IQN)MACP->OPRDX1 << Qadjust);
	}
	else
	{
		Qadjust = -Qadjust;
	    MACP->OPRDX1 =(uint32_t)( X << Qadjust);
		MACP->OPRDY1 =(uint32_t)( Y << Qadjust);

		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rHypot = ((IQN)MACP->OPRDX1 >> Qadjust);
	}			
	return rHypot;	
}
/**
  * @brief  Computes the sqrt(X^2 + Y^2) of the input value.Use cordic0 to compute and IQ format is 24
  * @param  X: the input value (radians).
  * @param  Y: the input value (radians).
  * @retval The sqrt(X^2 + Y^2) of the input value. 
  */
IQN IQNhypot_Q24(IQN X, IQN Y)
{    
	MACP->OPRDZ0 = 0;
	MACP->OPRDX0 =(uint32_t)( X );
	MACP->OPRDY0 =(uint32_t)( Y );
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	
	return ((IQN)MACP->OPRDX0);
}
/**
  * @brief  Computes the sqrt(X^2 + Y^2) of the input value.Use cordic1 to compute and IQ format is 24
  * @param  X: the input value (radians).
  * @param  Y: the input value (radians).
  * @retval The sqrt(X^2 + Y^2) of the input value. 
  */
IQN IQNhypot1_Q24(IQN X, IQN Y)
{    
	MACP->OPRDZ1 = 0;
    MACP->OPRDX1 =(uint32_t)( X );
	MACP->OPRDY1 =(uint32_t)( Y );
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
	
	return ((IQN)MACP->OPRDX1 );	
}

/**
  * @brief  Computes the sqrt(X^2 + Y^2) of the input value.Use cordic0 to compute and IQ format is 24
  * @param  X: the input value (radians).
  * @param  Y: the input value (radians).
  * @retval The sqrt(X^2 + Y^2) of the input value. 
  */
IQN IQNmode_Q24(IQN X, IQN Y)
{    
	MACP->OPRDZ0 = 0;
	MACP->OPRDX0 =(uint32_t)( X );
	MACP->OPRDY0 =(uint32_t)( Y );
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	
	return ((IQN)MACP->OPRDX0);
}
/**
  * @brief  Computes the sqrt(X^2 + Y^2) of the input value.Use cordic1 to compute and IQ format is 24
  * @param  X: the input value (radians).
  * @param  Y: the input value (radians).
  * @retval The sqrt(X^2 + Y^2) of the input value. 
  */
IQN IQNmode1_Q24(IQN X, IQN Y)
{    
	MACP->OPRDZ1 = 0;
    MACP->OPRDX1 =(uint32_t)( X );
	MACP->OPRDY1 =(uint32_t)( Y );
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
	
	return ((IQN)MACP->OPRDX1 );	
}

/**
  * @brief  Computes the sqrt(((X^2)+ (Y^2))/2) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians).
  * @param  Y: the input value (radians).
  * @param  QN: IQ Format
  * @retval The sqrt(((X^2)+ (Y^2))/2) of the input value. 
  */
IQN IQNrms(IQN X, IQN Y,int32_t QN)
{    
	IQN rms;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ0 = 0;
	if(Qadjust >= 0)
	{
		MACP->OPRDX0 =(uint32_t)( X >> Qadjust);
		MACP->OPRDY0 =(uint32_t)( Y >> Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rms = (IQN)MACP->OPRDX0;
		//(1/sqrt(2)*(1<<24));
		//0.70710678118654752440084436210485 * 16777216 == 11863283
		rms = IQ24mpy(rms,11863283);
		rms <<= Qadjust;
	}
	else
	{
		Qadjust = -Qadjust;
		MACP->OPRDX0 =(uint32_t)( X << Qadjust);
		MACP->OPRDY0 =(uint32_t)( Y << Qadjust);

		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
		rms = (IQN)MACP->OPRDX0;
		rms = IQ24mpy(rms,11863283);
		rms >>= Qadjust;
	}			
	return rms;	
}
/**
  * @brief  Computes the sqrt(((X^2)+ (Y^2))/2) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians).
  * @param  Y: the input value (radians).
  * @param  QN: IQ Format
  * @retval The sqrt(((X^2)+ (Y^2))/2) of the input value. 
  */
IQN IQNrms1(IQN X, IQN Y,int32_t QN)
{    
	IQN rms;
	int32_t Qadjust;
	Qadjust = (QN-24);
	MACP->OPRDZ1 = 0;
	if(Qadjust >= 0)
	{
	  MACP->OPRDX1 =(uint32_t)( X >> Qadjust);
		MACP->OPRDY1 =(uint32_t)( Y >> Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rms = (IQN)MACP->OPRDX1;
		//(1/sqrt(2)*(1<<24));
		//0.70710678118654752440084436210485 * 16777216 == 11863283
		rms = IQ24mpy(rms,11863283);
		rms <<= Qadjust;
	}
	else
	{
		Qadjust = -Qadjust;
	  MACP->OPRDX1 =(uint32_t)( X << Qadjust);
		MACP->OPRDY1 =(uint32_t)( Y << Qadjust);

		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
		rms = (IQN)MACP->OPRDX1;
		rms = IQ24mpy(rms,11863283);
		rms >>= Qadjust;
	}			
	return rms;	
}
/**
  * @brief  Computes the sqrt(((X^2)+ (Y^2))/2) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians). IQ Format:24
  * @param  Y: the input value (radians). IQ Format:24
  * @retval The sqrt(((X^2)+ (Y^2))/2) of the input value. 
  */
IQN IQNrms_Q24(IQN X, IQN Y)
{    
	IQN rms;
	MACP->OPRDZ0 = 0;
	MACP->OPRDX0 =(uint32_t)( X );
	MACP->OPRDY0 =(uint32_t)( Y );
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
	rms = (IQN)MACP->OPRDX0;
	//(1/sqrt(2)*(1<<24));
	//0.70710678118654752440084436210485 * 16777216 == 11863283
	rms = IQ24mpy(rms,11863283); // * 1/sqrt(2)
	return rms;
}
/**
  * @brief  Computes the sqrt(((X^2)+ (Y^2))/2) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians). IQ Format:24
  * @param  Y: the input value (radians). IQ Format:24
  * @retval The sqrt(((X^2)+ (Y^2))/2) of the input value. 
  */
IQN IQNrms1_Q24(IQN X, IQN Y)
{    
	IQN rms;
    MACP->OPRDZ1 = 0;
    MACP->OPRDX1 =(uint32_t)( X );
	MACP->OPRDY1 =(uint32_t)( Y );
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((26)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
	rms = (IQN)MACP->OPRDX1;
	//(1/sqrt(2)*(1<<24));
	//0.70710678118654752440084436210485 * 16777216 == 11863283
	rms = IQ24mpy(rms,11863283);
	return rms;	
}


// 2022/3/14,modify,ǰֻQ24ʽQʽδǣ˴޸֧Qʽ
/**
  * @brief  Computes the sqrt(X) of the input value.Use cordic0 to compute
  * @param  X: the input value (radians).
  * @param  QN: IQ Format
  * @retval The sqrt(X) of the input value. 
  */
IQN IQNsqrt(IQN X, IQN QN)
{
#if defined (__FPU_USED) && (__FPU_USED == 1U)
    float fv = (float)X;
    fv /= (float)(1<<QN);
    fv = (float)sqrtf(fv);
    return (int32_t)(fv*(float)(1<<QN));    
#else     
	IQN iqsqrt;
	IQN xK,yK;
	IQN X_bak;
	int32_t Qadjust;
	int32_t	Vadjust1=0;
	int32_t	Vadjust2=0;
	
	if (X<=0)
	{
		iqsqrt = 0;				// fail
		return iqsqrt;
	}
	
	
	Qadjust = (QN-24);
	if(Qadjust >= 0)
		X_bak = (X>>Qadjust);
	else
		X_bak = (X<<(-Qadjust));	
	
	MACP->OPRDZ0 = 0;
	
	
		// Ԥ XΪ 0.025~2.215Χ
		// IQ24(0.025)=419430,IQ24(2.215)=37161533	
		// ΪX=0.25Yin=X-0.25=0⣬ɼ һģɴֱӵΪ0.27ܿYin0ֵ
		// IQ24(0.27) = 4529848

		if (X_bak<=4529848)
		{	
			while(X_bak<4529848)
			{
				Vadjust1+=2;				// 㣬ֵͽ֮λҲҪ2ϵ밴2λƣ1λ
				X_bak=(X_bak<<2);
				if (Vadjust1>=31)		//input fail
				{
						iqsqrt = 0;			// fail
						return iqsqrt;
				}
			}		
		}	
		else
		{
			while(X_bak>35232153)
			{
				Vadjust2+=2;
				X_bak=(X_bak>>2);
				if (Vadjust2>=31)		// input fail
				{
						iqsqrt = 0;			// fail
						return iqsqrt;
				}
			}
		}						
		
		xK = X_bak + 4194304; //X+1/4
		xK = IQ24mpy(xK,H_IQ24_1_K);
		MACP->OPRDX0 =(uint32_t)(xK);
		yK = X_bak - 4194304; //X-1/4
		yK = IQ24mpy(yK,H_IQ24_1_K);		
		MACP->OPRDY0 =(uint32_t)(yK);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_NONE/*CORDIC_KADJ_DIVK*//*CORDIC_KADJ_NONE*/    <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((27/*ֻӰ쾫ȣӰ26*/)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}			

		if(Qadjust >= 0)
			iqsqrt = ((IQN)MACP->OPRDX0 << Qadjust);
		else
			iqsqrt = ((IQN)MACP->OPRDX0 >> (-Qadjust));			
			

		// 
		iqsqrt >>=(Vadjust1/2);	//1λ
		iqsqrt <<=(Vadjust2/2);

	
	return iqsqrt;
#endif		 
}


// 2022/3/14,modify,ǰֻQ24ʽQʽδǣ˴޸֧Qʽ
/**
  * @brief  Computes the sqrt(X) of the input value.Use cordic1 to compute
  * @param  X: the input value (radians). 
  * @param  QN: IQ Format
  * @retval The sqrt(X) of the input value. 
  */
IQN IQNsqrt1(IQN X, IQN QN)
{ 
#if defined (__FPU_USED) && (__FPU_USED == 1U)
    float fv = (float)X;
    fv /= (float)(1<<QN);    fv = (float)sqrtf(fv);
    return (int32_t)(fv*(float)(1<<QN));    
#else  
	IQN iqsqrt;
	IQN xK,yK;
	IQN X_bak;
	int32_t Qadjust;
	int32_t	Vadjust1=0;
	int32_t	Vadjust2=0;
	
	if (X<=0)
	{
		iqsqrt = 0;				// fail
		return iqsqrt;
	}
	
	
	Qadjust = (QN-24);
	if(Qadjust >= 0)
		X_bak = (X>>Qadjust);
	else
		X_bak = (X<<(-Qadjust));	
	
	MACP->OPRDZ1 = 0;
	
	if (X_bak<=4529848)
	{	
		while(X_bak<4529848)
		{
			Vadjust1+=2;				// 㣬ֵͽ֮λҲҪ2ϵ밴2λƣ1λ
			X_bak=(X_bak<<2);
			if (Vadjust1>=31)		//input fail
			{
					iqsqrt = 0;			// fail
					return iqsqrt;
			}
		}		
	}	
	else
	{
		while(X_bak>35232153)
		{
			Vadjust2+=2;
			X_bak=(X_bak>>2);
			if (Vadjust2>=31)		// input fail
			{
					iqsqrt = 0;			// fail
					return iqsqrt;
			}
		}
	}						
		
		xK = X_bak + 4194304; //X+1/4
		xK = IQ24mpy(xK,H_IQ24_1_K);
		MACP->OPRDX1 =(uint32_t)(xK);
		yK = X_bak - 4194304; //X-1/4
		yK = IQ24mpy(yK,H_IQ24_1_K);		
		MACP->OPRDY1 =(uint32_t)(yK);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_NONE/*CORDIC_KADJ_DIVK*//*CORDIC_KADJ_NONE*/    <<MACP_CORDCSR1_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR1_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR1_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_VECTOR  <<MACP_CORDCSR1_MODE_Pos)
											|(uint32_t)((27/*ֻӰ쾫ȣӰ26*/)                <<MACP_CORDCSR1_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_HYPERBOLA <<MACP_CORDCSR1_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR1_RUN_Pos);
		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}			

		if(Qadjust >= 0)
			iqsqrt = ((IQN)MACP->OPRDX1 << Qadjust);
		else
			iqsqrt = ((IQN)MACP->OPRDX1 >> (-Qadjust));			
			
		iqsqrt >>=(Vadjust1/2);
		iqsqrt <<=(Vadjust2/2);

	
	return iqsqrt;	  
#endif	
}


/**
  * @}
  */

/** @defgroup IQMath_Miscellaneous Miscellaneous Functions
  * @{
  */
  
#ifdef SINOIQMATH_USE_GENERAL

/**
  * @brief  Rotate X Y coordinate. Use cordic0 to compute
  *         @arg @b X' = [Xcos(Angle) - Ysin(Angle)]  
  *         @arg @b Y' = [Xsin(Angle) + Ycos(Angle)]
  * @param  protate  Pointer to X Y coordinate and rotation angle. @ref ROTATE_TypeDef
  * @param  QN IQ Format
  * @retval Rotate the input value. 
  */
void IQNrotate_G(ROTATE_TypeDef* protate,IQN QN)
{
	int32_t Qadjust;
	IQN tA;
	Qadjust = (QN-24);
	if(Qadjust >= 0)
	{
		tA = (protate->Angle>>Qadjust);
		tA = IQ24mpy(tA,IQ24_1_PI);
		MACP->OPRDZ0 = (uint32_t)(tA);
		
		MACP->OPRDX0 = (uint32_t)(protate->X>>Qadjust);
		MACP->OPRDY0 = (uint32_t)(protate->Y>>Qadjust);

		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
			
		protate->X = ((IQN)MACP->OPRDX0<<Qadjust);
		protate->Y = ((IQN)MACP->OPRDY0<<Qadjust);
	}
	else
	{		
		Qadjust = -Qadjust;
		tA = (protate->Angle<<Qadjust);
		tA = IQ24mpy(tA,IQ24_1_PI);
		MACP->OPRDZ0 = (uint32_t)(tA);
		
		MACP->OPRDX0 = (uint32_t)(protate->X);
		MACP->OPRDY0 = (uint32_t)(protate->Y);

		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
			
		protate->X = ((IQN)MACP->OPRDX0);
		protate->Y = ((IQN)MACP->OPRDY0);		
	}	
}

/**
  * @brief  Rotate X Y coordinate. Use cordic1 to compute
  *         @arg @b X' = [Xcos(Angle) - Ysin(Angle)]  
  *         @arg @b Y' = [Xsin(Angle) + Ycos(Angle)]
  * @param  protate  Pointer to X Y coordinate and rotation angle. @ref ROTATE_TypeDef
  * @param  QN IQ Format
  * @retval Rotate the input value. 
  */
void IQNrotate1_G(ROTATE_TypeDef* protate,IQN QN)
{
	int32_t Qadjust;
	IQN tA;
	Qadjust = (QN-24);
	if(Qadjust >= 0)
	{
		tA = (protate->Angle>>Qadjust);
		tA = IQ24mpy(tA,IQ24_1_PI);
		MACP->OPRDZ1 = (uint32_t)(tA);
		
		MACP->OPRDX1 = (uint32_t)(protate->X>>Qadjust);
		MACP->OPRDY1 = (uint32_t)(protate->Y>>Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
			
		protate->X = ((IQN)MACP->OPRDX1<<Qadjust);
		protate->Y = ((IQN)MACP->OPRDY1<<Qadjust);
	}
	else
	{		
		Qadjust = -Qadjust;
		tA = (protate->Angle<<Qadjust);
		tA = IQ24mpy(tA,IQ24_1_PI);
		MACP->OPRDZ1 = (uint32_t)(tA);

		MACP->OPRDX1 = (uint32_t)(protate->X);
		MACP->OPRDY1 = (uint32_t)(protate->Y);


		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
			
		protate->X = ((IQN)MACP->OPRDX1);
		protate->Y = ((IQN)MACP->OPRDY1);		
	}
}
/**
  * @brief  Rotate X Y coordinate. Use cordic0 to compute and IQ format is 24
  *         @arg @b X' = [Xcos(Angle) - Ysin(Angle)]  
  *         @arg @b Y' = [Xsin(Angle) + Ycos(Angle)]
  * @param  protate  Pointer to X Y coordinate and rotation angle. @ref ROTATE_TypeDef
  * @retval Rotate the input value. 
  */
void IQNrotate_Q24_G(ROTATE_TypeDef* protate)
{
	MACP->OPRDX0 = (uint32_t)protate->X;
    MACP->OPRDY0 = (uint32_t)protate->Y;
    MACP->OPRDZ0 = (uint32_t)IQ24mpy(protate->Angle,IQ24_1_PI);

	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
			
	protate->X = (IQN)MACP->OPRDX0;
    protate->Y = (IQN)MACP->OPRDY0;
}

/**
  * @brief  Rotate X Y coordinate. Use cordic1 to compute and IQ format is 24
  *         @arg @b X' = [Xcos(Angle) - Ysin(Angle)]  
  *         @arg @b Y' = [Xsin(Angle) + Ycos(Angle)]
  * @param  protate  Pointer to X Y coordinate and rotation angle. @ref ROTATE_TypeDef
  * @retval Rotate the input value. 
  */
void IQNrotate1_Q24_G(ROTATE_TypeDef* protate)
{
	MACP->OPRDX1 = (uint32_t)protate->X;
    MACP->OPRDY1 = (uint32_t)protate->Y;
    MACP->OPRDZ1 = (uint32_t)IQ24mpy(protate->Angle,IQ24_1_PI);

	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
			
	protate->X = (IQN)MACP->OPRDX1;
    protate->Y = (IQN)MACP->OPRDY1;
}

#else

/**
  * @brief  Rotate X Y coordinate. Use cordic0 to compute.
  *         @arg @b X' = [Xcos(Angle) - Ysin(Angle)]  
  *         @arg @b Y' = [Xsin(Angle) + Ycos(Angle)]
  * @param  protate  Pointer to X Y coordinate and rotation angle. (rad and normalized by PI) @ref ROTATE_TypeDef
  * @param  QN IQ Format
  * @retval Rotate the input value. 
  */
void IQNrotate_N(ROTATE_TypeDef* protate,IQN QN)
{
	int32_t Qadjust;
	Qadjust = (QN-24);
	if(Qadjust >= 0)
	{
		MACP->OPRDX0 = (uint32_t)(protate->X>>Qadjust);
		MACP->OPRDY0 = (uint32_t)(protate->Y>>Qadjust);
		MACP->OPRDZ0 = (uint32_t)(protate->Angle>>Qadjust);

		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
			
		protate->X = ((IQN)MACP->OPRDX0<<Qadjust);
		protate->Y = ((IQN)MACP->OPRDY0<<Qadjust);
	}
	else
	{		
		Qadjust = -Qadjust;
		MACP->OPRDX0 = (uint32_t)(protate->X);
		MACP->OPRDY0 = (uint32_t)(protate->Y);
		MACP->OPRDZ0 = (uint32_t)(protate->Angle<<Qadjust);

		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}
			
		protate->X = ((IQN)MACP->OPRDX0);
		protate->Y = ((IQN)MACP->OPRDY0);		
	}	
}

/**
  * @brief  Rotate X Y coordinate. Use cordic1 to compute.
  *         @arg @b X' = [Xcos(Angle) - Ysin(Angle)]  
  *         @arg @b Y' = [Xsin(Angle) + Ycos(Angle)]
  * @param  protate  Pointer to X Y coordinate and rotation angle. (rad and normalized by PI) @ref ROTATE_TypeDef
  * @param  QN IQ Format
  * @retval Rotate the input value. 
  */
void IQNrotate1_N(ROTATE_TypeDef* protate,IQN QN)
{
	int32_t Qadjust;
	Qadjust = (QN-24);
	if(Qadjust >= 0)
	{
		MACP->OPRDX1 = (uint32_t)(protate->X>>Qadjust);
		MACP->OPRDY1 = (uint32_t)(protate->Y>>Qadjust);
		MACP->OPRDZ1 = (uint32_t)(protate->Angle>>Qadjust);

		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
			
		protate->X = ((IQN)MACP->OPRDX1<<Qadjust);
		protate->Y = ((IQN)MACP->OPRDY1<<Qadjust);
	}
	else
	{		
		Qadjust = -Qadjust;
		MACP->OPRDX1 = (uint32_t)(protate->X);
		MACP->OPRDY1 = (uint32_t)(protate->Y);
		MACP->OPRDZ1 = (uint32_t)(protate->Angle<<Qadjust);

		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}
			
		protate->X = ((IQN)MACP->OPRDX1);
		protate->Y = ((IQN)MACP->OPRDY1);		
	}
}

/**
  * @brief  Rotate X Y coordinate. Use cordic0 to compute and IQ format is 24
  *         @arg @b X' = [Xcos(Angle) - Ysin(Angle)]  
  *         @arg @b Y' = [Xsin(Angle) + Ycos(Angle)]
  * @param  protate  Pointer to X Y coordinate and rotation angle. (rad and normalized by PI) @ref ROTATE_TypeDef
  * @retval Rotate the input value. 
  */
void IQNrotate_Q24_N(ROTATE_TypeDef* protate)
{
	MACP->OPRDX0 = (uint32_t)protate->X;
    MACP->OPRDY0 = (uint32_t)protate->Y;
    MACP->OPRDZ0 = (uint32_t)protate->Angle;

	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}
			
	protate->X = (IQN)MACP->OPRDX0;
    protate->Y = (IQN)MACP->OPRDY0;
}

/**
  * @brief  Rotate X Y coordinate. Use cordic1 to compute and IQ format is 24
  *         @arg @b X' = [Xcos(Angle) - Ysin(Angle)]  
  *         @arg @b Y' = [Xsin(Angle) + Ycos(Angle)]
  * @param  protate  Pointer to X Y coordinate and rotation angle. (rad and normalized by PI) @ref ROTATE_TypeDef
  * @retval Rotate the input value. 
  */
void IQNrotate1_Q24_N(ROTATE_TypeDef* protate)
{
	MACP->OPRDX1 = (uint32_t)protate->X;
    MACP->OPRDY1 = (uint32_t)protate->Y;
    MACP->OPRDZ1 = (uint32_t)protate->Angle;

	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}
			
	protate->X = (IQN)MACP->OPRDX1;
    protate->Y = (IQN)MACP->OPRDY1;
}
#endif

/**
  * @}
  */
  
/** @defgroup IQMath_Motor_Ctrl Motor Control Functions
  * @{
  */  

/**
  * @brief  Park's Transformation. Use cordic0 to compute
  *         @arg @b input  Ialpha, Ibeta and Theta  
  *         @arg @b output Iq = Ibeta * COS(Theta) - Ialpha * SIN(Theta)
  *         @arg @b output Id = Ialpha* COS(Theta) + Ibeta  * SIN(Theta)
  * @param  ppark  Pointer to transformation parameters. @ref PARK_TypeDef
  * @param  QN IQ Format
  * @retval None. 
  */
void IQNpark(PARK_TypeDef* ppark,IQN QN)
{
	int32_t Qadjust;
	Qadjust = (QN-24);
	if(Qadjust >= 0)
	{
		MACP->OPRDX0 = (uint32_t)(ppark->Ibeta>>Qadjust);
		MACP->OPRDY0 = (uint32_t)(ppark->Ialpha>>Qadjust);
		MACP->OPRDZ0 = (uint32_t)(ppark->Theta>>Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
												|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
												|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
												|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
												|(uint32_t)((QN+1)                <<MACP_CORDCSR0_ITERA_Pos)
												|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
												|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}

		ppark->Iq = ((IQN)MACP->OPRDX0<<Qadjust);
		ppark->Id = ((IQN)MACP->OPRDY0<<Qadjust);
	}
	else
	{	
		Qadjust = -Qadjust;
		MACP->OPRDX0 = (uint32_t)(ppark->Ibeta<<Qadjust);
		MACP->OPRDY0 = (uint32_t)(ppark->Ialpha<<Qadjust);
		MACP->OPRDZ0 = (uint32_t)(ppark->Theta<<Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
												|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
												|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
												|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
												|(uint32_t)((QN+1)                <<MACP_CORDCSR0_ITERA_Pos)
												|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
												|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}

		ppark->Iq = ((IQN)MACP->OPRDX0>>Qadjust);
		ppark->Id = ((IQN)MACP->OPRDY0>>Qadjust);
	}			
}
/**
  * @brief  Park's Transformation. Use cordic1 to compute
  *         @arg @b input Ialpha, Ibeta and Theta  
  *         @arg @b output Iq = Ibeta * COS(Theta) - Ialpha * SIN(Theta)
  *         @arg @b output Id = Ialpha* COS(Theta) + Ibeta  * SIN(Theta)
  * @param  ppark  Pointer to transformation parameters. @ref PARK_TypeDef
  * @param  QN IQ Format
  * @retval None. 
  */
void IQNpark1(PARK_TypeDef* ppark,IQN QN)
{
	int32_t Qadjust;
	Qadjust = (QN-24);
	if(Qadjust >= 0)
	{
		MACP->OPRDX1 = (uint32_t)(ppark->Ibeta>>Qadjust);
		MACP->OPRDY1 = (uint32_t)(ppark->Ialpha>>Qadjust);
		MACP->OPRDZ1 = (uint32_t)(ppark->Theta>>Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
												|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
												|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
												|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
												|(uint32_t)((QN+1)                <<MACP_CORDCSR0_ITERA_Pos)
												|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
												|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}

		ppark->Iq = ((IQN)MACP->OPRDX1<<Qadjust);
		ppark->Id = ((IQN)MACP->OPRDY1<<Qadjust);
	}
	else
	{	
		Qadjust = -Qadjust;
		MACP->OPRDX1 = (uint32_t)(ppark->Ibeta<<Qadjust);
		MACP->OPRDY1 = (uint32_t)(ppark->Ialpha<<Qadjust);
		MACP->OPRDZ1 = (uint32_t)(ppark->Theta<<Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
												|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
												|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
												|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
												|(uint32_t)((QN+1)                <<MACP_CORDCSR0_ITERA_Pos)
												|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
												|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}

		ppark->Iq = ((IQN)MACP->OPRDX1>>Qadjust);
		ppark->Id = ((IQN)MACP->OPRDY1>>Qadjust);
	}			
}
/**
  * @brief  Park's Transformation. Use cordic0 to compute and IQ format is 24
  *         @arg @b input Ialpha, Ibeta and Theta  
  *         @arg @b output Iq = Ibeta * COS(Theta) - Ialpha * SIN(Theta)
  *         @arg @b output Id = Ialpha* COS(Theta) + Ibeta  * SIN(Theta)
  * @param  ppark  Pointer to transformation parameters. @ref PARK_TypeDef
  * @retval None. 
  */
void IQNpark_Q24(PARK_TypeDef* ppark)
{
	MACP->OPRDX0 = (uint32_t)(ppark->Ibeta);
	MACP->OPRDY0 = (uint32_t)(ppark->Ialpha);
	MACP->OPRDZ0 = (uint32_t)(ppark->Theta);
		
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
												|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
												|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
												|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
												|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
												|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
												|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}

	ppark->Iq = ((IQN)MACP->OPRDX0);
	ppark->Id = ((IQN)MACP->OPRDY0);
}

/**
  * @brief  Park's Transformation. Use cordic1 to compute and IQ format is 24
  *         @arg @b input Ialpha, Ibeta and Theta  
  *         @arg @b output Iq = Ibeta * COS(Theta) - Ialpha * SIN(Theta)
  *         @arg @b output Id = Ialpha* COS(Theta) + Ibeta  * SIN(Theta)
  * @param  ppark  Pointer to transformation parameters. @ref PARK_TypeDef
  * @retval None. 
  */
void IQNpark1_Q24(PARK_TypeDef* ppark)
{
	MACP->OPRDX1 = (uint32_t)(ppark->Ibeta);
	MACP->OPRDY1 = (uint32_t)(ppark->Ialpha);
	MACP->OPRDZ1 = (uint32_t)(ppark->Theta);
		
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
												|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
												|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
												|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
												|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
												|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
												|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}

	ppark->Iq = ((IQN)MACP->OPRDX1);
	ppark->Id = ((IQN)MACP->OPRDY1);
}

/**
  * @brief  IPark's Transformation. Use cordic0 to compute
  *         @arg @b input  Ud, Uq and Theta  
  *         @arg @b output Ualpha = Ud * COS(Theta) - Uq * SIN(Theta)
  *         @arg @b output Ubeta  = Ud * SIN(Theta) + Uq * COS(Theta)
  * @param  pipark  Pointer to transformation parameters. @ref IPARK_TypeDef
  * @param  QN IQ Format
  * @retval None. 
  */
void IQNipark(IPARK_TypeDef* pipark,IQN QN)
{
	int32_t Qadjust;
	Qadjust = (QN-24);
	if(Qadjust >= 0)
	{
		MACP->OPRDX0 = (uint32_t)(pipark->Ud>>Qadjust);
		MACP->OPRDY0 = (uint32_t)(pipark->Uq>>Qadjust);
		MACP->OPRDZ0 = (uint32_t)(pipark->Theta>>Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
												|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
												|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
												|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
												|(uint32_t)((QN+1)                <<MACP_CORDCSR0_ITERA_Pos)
												|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
												|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}

		pipark->Ualpha = ((IQN)MACP->OPRDX0<<Qadjust);
		pipark->Ubeta  = ((IQN)MACP->OPRDY0<<Qadjust);
	}
	else
	{	
		Qadjust = -Qadjust;
		MACP->OPRDX0 = (uint32_t)(pipark->Ud<<Qadjust);
		MACP->OPRDY0 = (uint32_t)(pipark->Uq<<Qadjust);
		MACP->OPRDZ0 = (uint32_t)(pipark->Theta<<Qadjust);
		
		MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
												|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
												|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
												|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
												|(uint32_t)((QN+1)                <<MACP_CORDCSR0_ITERA_Pos)
												|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
												|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR0.BIT.RUN){}

		pipark->Ualpha = ((IQN)MACP->OPRDX0>>Qadjust);
		pipark->Ubeta  = ((IQN)MACP->OPRDY0>>Qadjust);
	}      
}

/**
  * @brief  IPark's Transformation. Use cordic1 to compute
  *         @arg @b input  Ud, Uq and Theta  
  *         @arg @b output Ualpha = Ud * COS(Theta) - Uq * SIN(Theta)
  *         @arg @b output Ubeta  = Ud * SIN(Theta) + Uq * COS(Theta)
  * @param  pipark  Pointer to transformation parameters. @ref IPARK_TypeDef
  * @param  QN IQ Format
  * @retval None. 
  */
void IQNipark1(IPARK_TypeDef* pipark,IQN QN)
{
	int32_t Qadjust;
	Qadjust = (QN-24);
	if(Qadjust >= 0)
	{
		MACP->OPRDX1 = (uint32_t)(pipark->Ud>>Qadjust);
		MACP->OPRDY1 = (uint32_t)(pipark->Uq>>Qadjust);
		MACP->OPRDZ1 = (uint32_t)(pipark->Theta>>Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
												|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
												|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
												|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
												|(uint32_t)((QN+1)                <<MACP_CORDCSR0_ITERA_Pos)
												|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
												|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}

		pipark->Ualpha = ((IQN)MACP->OPRDX1<<Qadjust);
		pipark->Ubeta  = ((IQN)MACP->OPRDY1<<Qadjust);
	}
	else
	{	
		Qadjust = -Qadjust;
		MACP->OPRDX1 = (uint32_t)(pipark->Ud<<Qadjust);
		MACP->OPRDY1 = (uint32_t)(pipark->Uq<<Qadjust);
		MACP->OPRDZ1 = (uint32_t)(pipark->Theta<<Qadjust);
		
		MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
												|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
												|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
												|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
												|(uint32_t)((QN+1)                <<MACP_CORDCSR0_ITERA_Pos)
												|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
												|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

		__DSB();
		while(MACP->CORDCSR1.BIT.RUN){}

		pipark->Ualpha = ((IQN)MACP->OPRDX1>>Qadjust);
		pipark->Ubeta  = ((IQN)MACP->OPRDY1>>Qadjust);
	}      
}

/**
  * @brief  IPark's Transformation. Use cordic0 to compute and IQ format is 24
  *         @arg @b input  Ud, Uq and Theta  
  *         @arg @b output Ualpha = Ud * COS(Theta) - Uq * SIN(Theta)
  *         @arg @b output Ubeta  = Ud * SIN(Theta) + Uq * COS(Theta)
  * @param  pipark  Pointer to transformation parameters. @ref IPARK_TypeDef
  * @retval None. 
  */
void IQNipark_Q24(IPARK_TypeDef* pipark)
{
	
	MACP->OPRDX0 = (uint32_t)(pipark->Ud);
	MACP->OPRDY0 = (uint32_t)(pipark->Uq);
	MACP->OPRDZ0 = (uint32_t)(pipark->Theta);
	
	MACP->CORDCSR0.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

	__DSB();
	while(MACP->CORDCSR0.BIT.RUN){}

	pipark->Ualpha = ((IQN)MACP->OPRDX0);
	pipark->Ubeta  = ((IQN)MACP->OPRDY0);

}

/**
  * @brief  IPark's Transformation. Use cordic1 to compute and IQ format is 24
  *         @arg @b input  Ud, Uq and Theta  
  *         @arg @b output Ualpha = Ud * COS(Theta) - Uq * SIN(Theta)
  *         @arg @b output Ubeta  = Ud * SIN(Theta) + Uq * COS(Theta)
  * @param  pipark  Pointer to transformation parameters. @ref IPARK_TypeDef
  * @retval None. 
  */
void IQNipark1_Q24(IPARK_TypeDef* pipark)
{
	
	MACP->OPRDX1 = (uint32_t)(pipark->Ud);
	MACP->OPRDY1 = (uint32_t)(pipark->Uq);
	MACP->OPRDZ1 = (uint32_t)(pipark->Theta);
	
	MACP->CORDCSR1.V32 = (uint32_t)(CORDIC_KADJ_DIVK  <<MACP_CORDCSR0_KADJ_Pos)
											|(uint32_t)(CORDIC_XYMRS_NONE   <<MACP_CORDCSR0_XYMRS_Pos)
											|(uint32_t)(CORDIC_FMT_IQ24     <<MACP_CORDCSR0_FORMAT_Pos)
											|(uint32_t)(CORDIC_MODE_ROTATE  <<MACP_CORDCSR0_MODE_Pos)
											|(uint32_t)((25)                <<MACP_CORDCSR0_ITERA_Pos)
											|(uint32_t)(CORDIC_ARITH_CIRCULAR <<MACP_CORDCSR0_ARITH_Pos)
											|(uint32_t)(SH_ENABLE              <<MACP_CORDCSR0_RUN_Pos);

	__DSB();
	while(MACP->CORDCSR1.BIT.RUN){}

	pipark->Ualpha = ((IQN)MACP->OPRDX1);
	pipark->Ubeta  = ((IQN)MACP->OPRDY1);

}


///*=============================================================================
//																
//          Name:       IQNclarke
//          Function:   Ia,Ib,Ic to Ialpha,Ibeta
//          Input:      pointer to CLARKE_TypeDef
//          Return:     none            
//          date:       2020/3/23					
//=============================================================================*/
static const IQN SINO_IQN_SQRT_3_2[32]={0,
	IQ1(1.2247), IQ2(1.2247), IQ3(1.2247), IQ4(1.2247),
	IQ5(1.2247), IQ6(1.2247), IQ7(1.2247), IQ8(1.2247),
	IQ9(1.2247), IQ10(1.2247),IQ11(1.2247),IQ12(1.2247),
	IQ13(1.2247),IQ14(1.2247),IQ15(1.2247),IQ16(1.2247),
	IQ17(1.2247),IQ18(1.2247),IQ19(1.2247),IQ20(1.2247),
	IQ21(1.2247),IQ22(1.2247),IQ23(1.2247),IQ24(1.2247),
	IQ25(1.2247),IQ26(1.2247),IQ27(1.2247),IQ28(1.2247),
	IQ29(1.2247),IQ30(1.2247),IQ31(0.2247)
};
static const IQN SINO_IQN_SQRT_0_5[32]={0,
	IQ1(0.707), IQ2(0.707), IQ3(0.707), IQ4(0.707),
	IQ5(0.707), IQ6(0.707), IQ7(0.707), IQ8(0.707),
	IQ9(0.707), IQ10(0.707),IQ11(0.707),IQ12(0.707),
	IQ13(0.707),IQ14(0.707),IQ15(0.707),IQ16(0.707),
	IQ17(0.707),IQ18(0.707),IQ19(0.707),IQ20(0.707),
	IQ21(0.707),IQ22(0.707),IQ23(0.707),IQ24(0.707),
	IQ25(0.707),IQ26(0.707),IQ27(0.707),IQ28(0.707),
	IQ29(0.707),IQ30(0.707),IQ31(0.707)
};
/**
  * @brief  Clarke's Transformation. 
  *         @arg @b input  Ia,Ib and Ic 
  *         @arg @b output Ialpha = Ia * sqrt(3/2);
  *         @arg @b output Ibeta  = (Ib-Ic)*(1/sqrt(2));  
  * @param  pclarke  Pointer to transformation parameters. @ref CLARKE_TypeDef
  * @param  QN IQ Format
  * @retval None. 
  */
void IQNclarke(CLARKE_TypeDef* pclarke,IQN QN)
{
    /* Calculate Ialpha*/
	pclarke->Ialpha = IQNmpy(pclarke->Ia,SINO_IQN_SQRT_3_2[QN],QN);
	pclarke->Ibeta  = IQNmpy(pclarke->Ib - pclarke->Ic, SINO_IQN_SQRT_0_5[QN],QN); 
}

/**
  * @brief  Clarke's Transformation. IQ format is 24
  *         @arg @b input  Ia,Ib and Ic 
  *         @arg @b output Ialpha = Ia * sqrt(3/2);
  *         @arg @b output Ibeta  = (Ib-Ic)*(1/sqrt(2));  
  * @param  pclarke  Pointer to transformation parameters. @ref CLARKE_TypeDef
  * @retval None. 
  */
void IQNclarke_Q24(CLARKE_TypeDef* pclarke)
{
	pclarke->Ialpha = IQ24mpy(pclarke->Ia,IQ24_SQRT_3_2);
	pclarke->Ibeta  = IQ24mpy(pclarke->Ib - pclarke->Ic, IQ24_SQRT_0_5); 
}

/**
  * @brief  PID's Transformation. 
  *         @arg @b input  Ref,Fdb,Kp,Ki,Kd,ErrMax,ErrLast,UiMax,UoutMax
  *         @arg @b output Err = Ref - Fdb
  *         @arg @b output Up = Kp * Err
  *         @arg @b output Ui = Ui + Ki * Err
  *         @arg @b output Ud = Kd * (Err - ErrLast)
  *         @arg @b output Uout = Up + Ui + Ud
  *         @arg @b output ErrLast = Err    
  * @param  ppid  Pointer to transformation parameters. @ref PID_TypeDef
  * @param  QN IQ Format
  * @retval None. 
  */
void IQNpid(PID_TypeDef *ppid,IQN QN)
{
    /* Compute the error */
    ppid->Err = ppid->Ref - ppid->Fdb;

    /* Compute the proportional output */
    ppid->Up = IQNmpy(ppid->Kp,ppid->Err,QN);

    /* Compute the integral output */
    if ((ppid->Err < ppid->ErrMax) && (ppid->Err > -(ppid->ErrMax)))
    {
        ppid->Ui = ppid->Ui + IQNmpy(ppid->Ki,ppid->Err,QN);
        /* Saturate the Ui */
        if (ppid->Ui >ppid->UiMax)
        {
          ppid->Ui =  ppid->UiMax;
        }
        else if (ppid->Ui < (-(ppid->UiMax)))
        {
          ppid->Ui =  -(ppid->UiMax);
        }
    }

    /* Compute the derivative output */
    ppid->Ud = IQNmpy(ppid->Kd,(ppid->Err - ppid->ErrLast),QN);

    /* Compute the pre-saturated output */
    ppid->Uout = ppid->Up + ppid->Ui + ppid->Ud;

    /* Saturate the output */
    if (ppid->Uout > ppid->UoutMax)
      ppid->Uout =  ppid->UoutMax;
    else if (ppid->Uout < (-(ppid->UoutMax)))
      ppid->Uout =  -(ppid->UoutMax);

    /* Update the previous proportional output */
    ppid->ErrLast = ppid->Err;    
}

/**
  * @brief  PID's Transformation. IQ format is 24
  *         @arg @b input  Ref,Fdb,Kp,Ki,Kd,ErrMax,ErrLast,UiMax,UoutMax
  *         @arg @b output Err = Ref - Fdb
  *         @arg @b output Up = Kp * Err
  *         @arg @b output Ui = Ui + Ki * Err
  *         @arg @b output Ud = Kd * (Err - ErrLast)
  *         @arg @b output Uout = Up + Ui + Ud
  *         @arg @b output ErrLast = Err    
  * @param  ppid  Pointer to transformation parameters. @ref PID_TypeDef
  * @retval None. 
  */
void IQNpid_Q24(PID_TypeDef *ppid)
{
    /* Compute the error */
    ppid->Err = ppid->Ref - ppid->Fdb;

    /* Compute the proportional output */
    ppid->Up = IQ24mpy(ppid->Kp,ppid->Err);

    /* Compute the integral output */
    if ((ppid->Err < ppid->ErrMax) && (ppid->Err > -(ppid->ErrMax)))
    {
        ppid->Ui = ppid->Ui + IQ24mpy(ppid->Ki,ppid->Err);
        /* Saturate the Ui */
        if (ppid->Ui >ppid->UiMax)
        {
          ppid->Ui =  ppid->UiMax;
        }
        else if (ppid->Ui < (-(ppid->UiMax)))
        {
          ppid->Ui =  -(ppid->UiMax);
        }
    }

    /* Compute the derivative output */
    ppid->Ud = IQ24mpy(ppid->Kd,(ppid->Err - ppid->ErrLast));

    /* Compute the pre-saturated output */
    ppid->Uout = ppid->Up + ppid->Ui + ppid->Ud;

    /* Saturate the output */
    if (ppid->Uout > ppid->UoutMax)
      ppid->Uout =  ppid->UoutMax;
    else if (ppid->Uout < (-(ppid->UoutMax)))
      ppid->Uout =  -(ppid->UoutMax);

    /* Update the previous proportional output */
    ppid->ErrLast = ppid->Err;   
}

/**
  * @brief  SVPWM's Transformation.
  * @param  psvpwmdq  Pointer to transformation parameters. @ref SVPWMDQ_TypeDef
  * @param  QN IQ Format (30~11)
  * @param  seg SPWM algorithm method
            @arg 0 7-seg
            @arg 1 5-seg
  * @retval None. 
  */
void IQNsvpwm(SVPWMDQ_TypeDef* psvpwmdq,IQN QN,uint32_t seg)
{
    /* input Ualpa */
    MACP->SVUALPHA = psvpwmdq->Ualpa;
    /* input Ubeta */
    MACP->SVUBETA = psvpwmdq->Ubeta;
	
	MACP->SVIQN.V32 =  ((uint32_t)QN << MACP_SVIQN_SVIQN_Pos)
					  |(seg << MACP_SVIQN_SVTYP_Pos) // 0:7-seg 1:5-seg
	                  |(1 << MACP_SVIQN_SATEN_Pos);
	                  
    MACP->SVCON = 1;
     /* wait for the SVPWM operation to end */
    while(MACP->SVCON){}
    /* read result */
    psvpwmdq->Ta = MACP->SVTA;
    psvpwmdq->Tb = MACP->SVTB;
    psvpwmdq->Tc = MACP->SVTC;
    psvpwmdq->Sector = MACP->SVSECTOR;	
}

/**
  * @brief  SVPWM's Transformation. IQ format is 24 and use 5-seg method
  * @param  psvpwmdq  Pointer to transformation parameters. @ref SVPWMDQ_TypeDef
  * @retval None. 
  */
void IQNsvpwm5_Q24(SVPWMDQ_TypeDef* psvpwmdq)
{                                                            
    /* input Ualpa */
    MACP->SVUALPHA = psvpwmdq->Ualpa;
    /* input Ubeta */
    MACP->SVUBETA = psvpwmdq->Ubeta;
	
	MACP->SVIQN.V32 =  (24 << MACP_SVIQN_SVIQN_Pos)
					  |(SVPWM_SVTYPE_5 << MACP_SVIQN_SVTYP_Pos) // 0:7-seg 1:5-seg
	                  |(1 << MACP_SVIQN_SATEN_Pos);
	                  
    MACP->SVCON = 1;
     /* wait for the SVPWM operation to end */
    while(MACP->SVCON){}
    /* read result */
    psvpwmdq->Ta = MACP->SVTA;
    psvpwmdq->Tb = MACP->SVTB;
    psvpwmdq->Tc = MACP->SVTC;
    psvpwmdq->Sector = MACP->SVSECTOR;
}

/**
  * @brief  SVPWM's Transformation. IQ format is 24 and use 7-seg method
  * @param  psvpwmdq  Pointer to transformation parameters. @ref SVPWMDQ_TypeDef
  * @retval None. 
  */
void IQNsvpwm7_Q24(SVPWMDQ_TypeDef* psvpwmdq)
{                                                            
    /* input Ualpa */
    MACP->SVUALPHA = psvpwmdq->Ualpa;
    /* input Ubeta */
    MACP->SVUBETA = psvpwmdq->Ubeta;
	
	MACP->SVIQN.V32 =  (24 << MACP_SVIQN_SVIQN_Pos)
					  |(SVPWM_SVTYPE_7 << MACP_SVIQN_SVTYP_Pos) // 0:7-seg 1:5-seg
	                  |(1 << MACP_SVIQN_SATEN_Pos);
	                  
    MACP->SVCON = 1;
     /* wait for the SVPWM operation to end */
    while(MACP->SVCON){}
    /* read result */
    psvpwmdq->Ta = MACP->SVTA;
    psvpwmdq->Tb = MACP->SVTB;
    psvpwmdq->Tc = MACP->SVTC;
    psvpwmdq->Sector = MACP->SVSECTOR;
		
}

/**
  * @}
  */
  

/**
  * @}
  */

/**
  * @}
  */

/**
  * @}
  */


/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
